;; Predefined Entities for XML specified at https://www.w3.org/TR/xml/#sec-predefined-ent
;;
;; (C) 2019 Darcy Shen
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.

("quot"         "&#x0022")      ; "
("amp"          "&#x0026")      ; & 
("lt"           "&#x003C")      ; <
("gt"           "&#x003E")      ; >
("apos"         "&#x0027")      ; '