("align table at the center" "align table at the centre")
("align table at the horizontal center" "align table at the horizontal centre")
("authorize" "authorise")
("background color" "background colour")
("cell background color" "cell background colour")
("center" "centre")
("center text" "centre text")
("centered" "centred")
("centered block" "centred block")
("centered tabular" "centred tabular")
("color" "colour")
("emphasize text" "emphasise text")
("horizontally centre the cell" "")
("itemize" "itemise")
("select a foreground color" "select a foreground colour")
("set extension center" "set extension centre")
("use a black color" "use a black colour")
("use a blue color" "use a blue colour")
("use a brown color" "use a brown colour")
("use a green color" "use a green colour")
("use a grey color" "use a grey colour")
("use a magenta color" "use a magenta colour")
("use a orange color" "use a orange colour")
("use a pink color" "use a pink colour")
("use a red color" "use a red colour")
("use a white color" "use a white colour")
("use a yellow color" "use a yellow colour")
("vertically center the cell" "vertically centre the cell")
