("abbreviation" "okraj²ava")
("about menu" "o programu")
("about" "o programu")
("above" "nad")
("abstract" "povzetek")
("accent" "akcent")
("accept all scripts" "sprejmi vse skripte")
("accept no scripts" "zavrni vse skripte")
("accept script" "sprejmi skript")
("accept" "sprejmi")
("acknowledgment" "potrditev")
("acronym" "akronim")
("action" "akcija")
("activate" "aktiviraj")
("acute" "ostrivec")
("add package" "dodaj paket")
("address block" "blok z naslovom")
("address" "naslov (po²tni)")
("add switch after" "vstavi stikalo za")
("add switch before" "vstavi stikalo pred")
("advanced layout features" "napredna postavitev")
("advanced" "napredno")
("after" "po")
("albanian" "albansko")
("algorithm" "algoritem")
("align cell to the bottom" "poravnaj celico na dno")
("align cell to the left" "poravnaj celico na levo")
("align cell to the right" "poravnaj celico na desno")
("align cell to the top" "poravnaj celico na vrh")
("aligned" "poravnano")
("alignment" "poravnava")
("align table at base of left column" "poravnaj tabelo na bazo levega stolpca")
("align table at base of middle column" "poravnaj tabelo na bazo srednjega stolpca")
("align table at base of origin column" "poravnaj tabelo na bazo izvornega stolpca")
("align table at base of right column" "poravnaj tabelo na bazo desnega stolpca")
("align table at fraction bar height" "poravnaj tabelo na vi²ino ulomka")
("align table at the base of bottom row" "poravnaj tabelo na bazo spodnje vrstice")
("align table at the base of middle row" "poravnaj tabelo na bazo srednje vrstice")
("align table at the base of origin row" "poravnaj tabelo na bazo izvorne vrstice")
("align table at the base of top row" "poravnaj tabelo na bazo zgornje vrstice")
("align table at the bottom" "poravnaj tabelo na dno")
("align table at the center" "poravnaj tabelo na sredino")
("align table at the horizontal center" "poravnaj tabelo na vodoravno sredino")
("align table at the left" "poravnaj tabelo na levo")
("align table at the top" "poravnaj tabelo na vrh")
("align table to the right" "poravnaj tabelo na desno")
("align text to the left" "poravnaj besedilo na levo")
("align text to the right" "poravnaj besedilo na desno")
("allow" "dovoljeno")
("allowed extension" "dovoljena raz²iritev")
("allowed reduction" "dovoljena skr£itev")
("all" "vse")
("alpha release" "alfa verzija")
("alternative specification" "alternativna specifikacija")
("alt key" "tipka alt")
("american" "ameri²ko")
("a modifier" "modifikator A")
("a modifier" "modifikator A")
("A modifier" "modifikator A")
("and" "in")
("appendix" "dodatek")
("apply" "apliciraj")
("april" "april")
("arab" "arabsko")
("archaic" "arhai£no")
("architecture" "arhitektura")
("argument" "argument")
("arithmetic" "aritmetika")
("armenian" "armensko")
("arrow" "pu²£ica")
("arrows" "pu²£ice")
("article" "£lanek")
("as on paper" "kot na papirju")
("assign" "priredi")
("at fraction bar height" "na ulomkovo £rto")
("attach buffer to which project" "pripni spis na projekt")
("attach" "pripni")
("at the baseline" "na osnovnico")
("at the bottom" "spodaj")
("at the left" "levo")
("at the middle" "sredina")
("at the right" "desno")
("at the top" "na vrh")
("august" "avgust")
("author" "avtor")
("authorize" "avtoriziraj")
("automatically close brackets" "avtomatsko zapiranje oklepajev")
("automatically close brackets" "samodejno zapiraj oklepaje")
("automatically generated content" "avtomatsko generirana vsebina")
("automatic" "avtomatsko")
("autosave" "samodejno shranjevanje")
("autosave" "samoshranjevanje")
("axiom" "aksiom")
("background color" "barva ozadja")
("background evaluations" "vrednotenje v ozadju")
("background evaluations" "vrednotenje v ozadju")
("background" "ozadje")
("backward replace" "zamenjaj proti za£etku")
("backward search" "i²£i proti za£etku")
("bad data format" "slab zapis datuma")
("bard" "bard")
("bar" "£rta")
("base level" "osnovni nivo")
("bashkirian" "bashkirian")
("basic communication using pipes" "osnovna komunikacija preko cevi")
("basic communication using pipes" "osnovna komunikacija preko cevovodov")
("basic data types" "osnovni podatkovni tipi")
("basic" "osnovni")
("basic types" "osnovni tipi")
("become a TeXmacs developer" "postanite TeXmacs razvijalec")
("before" "pred")
("begin" "za£etek")
("below" "pod")
("beta release" "beta release")
("be useful" "bodi uporaben")
("bibliography file" "datoteka z literaturo")
("bibliography" "literatura")
("bibliography style" "slog literature")
("big figure" "velika slika")
("big operator" "velik operator")
("big skip" "velik preskok")
("big table" "velika tabela")
("big" "veliko")
("binary operation" "dvoji²ka operacija")
("binary relation" "dvoji²ka relacija")
("blackboard bold" "blackboard krepko")
("blackboard math" "blackboard matematika")
("blackletter" "blackletter")
("black" "£rna")
("blue" "modra")
("body" "telo")
("bold" "krepko")
("book" "knjiga")
("border" "obroba")
("both" "oba")
("bottom border" "spodnja obroba")
("bottom" "dno")
("bottom margin" "spodnji rob")
("bottom padding" "spodnja obloga")
("branch" "vejitev")
("breaking" "prelamljanje")
("break" "prelom")
("breve" "breve")
("british" "britansko")
("brown" "rjava")
("browse" "prebrskaj")
("browser" "brskalnik")
("browse web" "prebrskaj splet")
("buffer" "spis")
("bulgarian" "bolgarsko")
("bullet" "pika")
("bullets" "pike")
("by" "avtor:")
("bytes free" "prostih bajtov")
("bytes used" "uporabljenih bajtov")
("by typing" "s tipkanjem")
("calligraphic" "kaligrafsko")
("cancel" "prekli£i")
("caps-lock key" "tipka caps-lock")
("case" "case")
("cc" "kopija")
("cell background color" "barva ozadja v celici")
("cell border" "obroba celice")
("cell" "celica")
("cell height" "vi²ina celice")
("cell operation mode" "reºim celice")
("cell width" "²irina celice")
("centered block" "centriran blok")
("centered" "na sredini")
("centered tabular" "centriran tabular")
("center" "sredina")
("center text" "poravnaj besedilo na sredino")
("change border of cell" "spremeni obrobo celice")
("change cell operation mode" "spremeni reºim celice")
("change log" "dnevnik sprememb")
("changes" "spremembe")
("chapter" "poglavje")
("check" "stre²ica")
("check text for spelling errors" "prei²£i besedilo za pravopisne napake")
("chinese" "kitajsko")
("choice" "izbira")
("citation" "sklic na literaturo")
("cite" "citat")
("class" "razred")
("clear" "izbri²i")
("clear selection" "izbri²i izbiro")
("clipped and magnified" "obrezano in pove£ava")
("clipped and resized" "obrezano in pove£ano")
("clipped" "obrezano")
("clone" "podvoji")
("clone window" "podvoji okno")
("close buffer" "zapri spis")
("close session" "zapri sejo")
("close TeXmacs" "zapri TeXmacs")
("close window" "zapri okno")
("close" "zapri")
("closing style" "slog zapiranja")
("closing" "zapiram")
("code" "koda")
("color" "barva")
("column contains glued items" "stolpec vsebuje lepilo")
("column" "stolpec")
("compactification" "kompaktifikacija")
("compact" "kompaktno")
("compact" "kompaktno")
("compact" "kompaktno")
("compatibility with other formats" "zdruºljivost z drugimi zapisi")
("compile article" "prevedi £lanek")
("compile book" "prevedi knjigo")
("compile buffer" "prevedi spis")
("compile project" "prevedi projekt")
("completion" "dopolnitev")
("completion" "dopolnitev")
("complex" "kompleksno")
("concrete" "concrete")
("condensed" "zoºeno")
("condition" "condition")
("condition" "pogoj")
("configuration" "konfiguracija")
("contact" "kontakt")
("contact" "kontakt")
("content tag" "vsebinska oznaka")
("content" "vsebina")
("content" "vsebina")
("content" "vsebina")
("context dependent icons" "kontekstno odvisne ikone")
("continuation of" "nadaljevanje od")
("contribute" "prispevajte")
("contribute" "prispevajte")
("control flow" "kontrola toka")
("convention" "konvencija")
("converters to other data formats" "pretvorniki v druge zapise podatkov")
("copying" "kopiram")
("copy" "kopiraj")
("copy text" "kopiraj besedilo")
("copy to" "kopiraj v")
("corollary" "korolar")
("correct text" "popravi besedilo")
("create web site" "ustvari spletno mesto")
("cursors" "kurzorji")
("customize" "prilagodi")
("customizing TeXmacs" "prilagajanje TeXmacsa")
("customizing the TeXmacs styles" "prilagajanje TeXmacs slogov")
("custom tab" "poseben tabulator")
("custum tab" "poseben tabulator")
("cut" "izreºi")
("cut text" "izreºi besedilo")
("cut to" "izreºi v")
("cypriot" "cypriot")
("cyrillic" "cirilica")
("cyrillic input method" "vhodna metoda za cirilico")
("cyrillic italic right" "cirilica kurzivno desno")
("czech" "£e²ko")
("dancers" "dancers")
("danish" "dansko")
("dark grey" "temno siva")
("dark grey" "temno siva")
("dashes" "£rtice")
("dash" "£rtica")
("data conversion" "pretvorba podatkov")
("data format" "oblikovanje podatkov")
("date" "datum")
("deactivate" "deaktiviraj")
("deactivate table" "deaktiviraj tabelo")
("december" "december")
("decorate atoms" "okrasi atome")
("default padding" "privzeta obloga")
("default" "privzeto")
("definition" "definicija")
("delete column" "izbri²i stolpec")
("delete" "izbri²i")
("delete row" "izbri²i vrstico")
("denominator" "imenovalec")
("description" "opis")
("destination" "cilj")
("detach" "lo£i")
("detailed" "podrobno")
("determinant" "determinanta")
("devangari" "devangari")
("developers guide" "vodi£ za razvijalce")
("directory" "imenik")
("disable first indentation after" "onemogo£i prvi zamik za")
("disable first indentation before" "onemogo£i prvi zamik pred")
("disable first indentation" "onemogo£i prvi zamik")
("disable indentation after" "onemogo£i zamik za")
("disable indentation before" "onemogo£i zamik pred")
("disable indentation" "onemogo£i zamik")
("disable last indentation after" "onemogo£i zadnji zamik za")
("disable last indentation before" "onemogo£i zadnji zamik pred")
("disable last indentation" "onemogo£i zadnji zamik")
("disable" "onemogo£i")
("disable" "onemogo£i")
("disallow" "prepovej")
("distribute unused space" "porazdeli neporabljen prostor")
("div" "razdelek")
("documentation" "dokumentacija")
("document" "dokument")
("document format" "format dokumenta")
("documents are trees" "dokumenti so drevesa")
("document style" "slog dokumenta")
("document styles" "slogi dokumenta")
("do not remap" "ne mapiraj")
("do not remap" "ne remapiraj")
("dots" "to£ke")
("dot" "to£ka")
("double stroke" "dvakrat pre£rtano")
("down" "dol")
("dpi" "DPI")
("duplicate" "podvoji")
("dutch" "holandsko")
("dynamic libraries" "dinami£ne knjiºnice")
("editing tools" "orodja za urejanje")
("edit source tree" "urejaj izvorno kodo")
("edit" "urejanje")
("email" "email")
("emphasize" "poudarjeno")
("emphasize text" "poudari besedilo")
("empty box" "prazna ²katla")
("enable first indentation after" "omogo£i prvi zamik za")
("enable first indentation before" "omogo£i prvi zamik pred")
("enable first indentation" "omogo£i prvi zamik")
("enable indentation after" "omogo£i zamik za")
("enable indentation before" "omogo£i zamik pred")
("enable indentation" "omogo£i zamik")
("enable last indentation after" "omogo£i zadnji zamik za")
("enable last indentation before" "omogo£i zadnji zamik pred")
("enable last indentation" "omogo£i zadnji zamik")
("encl" "encl")
("end" "konec")
("english" "angle²£ina")
("enter a title" "vpi²i naslov")
("enumerate|alpha" "²tevil£i|abecedno")
("enumerate|Alpha" "²tevil£i|Abecedno")
("enumerate|roman" "²tevil£i|rimsko")
("enumerate|Roman" "²tevil£i|Rimsko")
("enumerate" "²tevil£i")
("env" "env")
("environment" "okolje")
("epilogue" "epilog")
("equal" "enako")
("equation" "ena£ba")
("equations" "ena£be")
("equivalent for" "ekvivalent za")
("error" "napaka")
("esperanto" "esperanto")
("etruscan" "etru²£ansko")
("evaluate" "ovrednoti")
("evaluate scheme expression" "ovrednoti izraz v Scheme")
("evaluation" "ovrednotenje")
("even page footer" "noga sodih strani")
("even page header" "glava sodih strani")
("even page left margin" "levi rob sodih strani")
("even page margin" "rob sodih strani")
("even page right margin" "desni rob sodih strani")
("even page text" "besedilo sodih strani")
("exact horizontal" "to£no vodoravno")
("exact mode" "to£en reºim")
("exam" "izpit")
("example" "primer")
("exclusive" "ekskluzivno")
("exclusive or" "ekskluzivni ali")
("executable" "izvr²na koda")
("execute a TeXmacs command" "izvr²i ukaz TeXmacsa")
("execute" "izvr²i")
("execute system command" "izvr²i ukaz sistema")
("executive" "executive")
("exercise" "vaja")
("expand" "raz²iri")
("explained" "razloºeno")
("export as" "izvozi kot")
("export" "izvozi")
("extend or normal" "raz²irjeno ali normalno")
("extern " "zunanje")
("extern" "zunanji")
("extract format" "to£en format")
("extra" "ekstra")
("family" "druºina")
("february" "februar")
("figure" "slika")
("file" "datoteka")
("file already exists" "datoteka ºe obstaja")
("file name" "ime datoteke")
("file not found" "ne najdem datoteke")
("find file" "najdi datoteko")
("find next match" "poi²£i naslednjega")
("find text" "poi²£i besedilo")
("finnish" "Finsko")
("first contact" "prvi kontakt")
("first indentation" "prvi zamik")
("first item" "prva postavka")
("first page" "prva stran")
("first start" "za£etek od")
("flat" "splo²£eno")
("flexibility factor for vertical spacing" "faktor raztegljivosti za navpi£ne razmike")
("flexibility" "fleksibilnost")
("floating figure" "plavajo£a slika")
("floating object" "plavajo£ objekt")
("floating table" "plavajo£a tabela")
("folded" "prepognjeno")
("fold input field" "prepogni vnosno polje")
("fold" "prepogni")
("font base size" "osnovna velikost pisave")
("font dpi" "DPI pisave")
("font family" "druºina pisave")
("font name" "ime pisave")
("font" "pisava")
("font series" "serija pisave")
("font shape" "oblika pisave")
("font size" "velikost pisave")
("fonts" "pisave")
("font type" "vrsta pisave")
("font variant" "varianta pisave")
("footer" "noga")
("footnote" "opomba pod £rto")
("foreground" "ospredje")
("foreign" "tuje")
("for" "for")
("format" "oblika")
("formatted date" "formatiran datum")
("formatting" "formatiranje")
("formula" "formula")
("formula style" "slog formule")
("forward replace" "zamenjaj naprej")
("forward search" "i²£i naprej")
("fraction" "ulomek")
("french" "francosko")
("full manuals" "celotni priro£niki")
("full screen mode" "celozaslonski reºim")
("function" "funkcija")
("further customization" "nadaljne prilagajanje")
("future changes" "prihodnje spremembe")
("general architecture of TeXmacs" "ob£a architektura TeXmacsa")
("general negation" "ob£a negacija")
("general note" "splo²na opomba")
("generating font file" "ra£unam pisavo")
("generic" "ob£e")
("georgian" "georgian")
("german" "nem²ko")
("getting started" "kako za£eti")
("glossary" "besednjak")
("glossary entry" "zapis v besednjaku")
("glue decorations" "prilepi dekoracijo")
("glue" "lepilo")
("GNU" "GNU")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs je brez kakr²negakoli pravnega jamstva")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs spada pod javno licenco GNU")
("go" "pojdi na")
("gothic" "gotica")
("graphical interface" "grafi£ni vmesnik")
("grave" "krativec")
("greater or equal" "ve£je ali enako")
("greater" "ve£je")
("greek" "gr²ko")
("greek letter" "gr²ka £rka")
("green" "zelena")
("grey" "siva")
("group" "skupina")
("happy typing" "sre£no tipkanje")
("has been aborted" "je bil prekinjen")
("has completed its task" "je kon£al nalogo")
("hat" "stre²ica")
("header and footer" "glava in noga")
("header" "glava")
("hebrew" "hebrejsko")
("height is exactly the specified height" "vi²ina je natanko dolo£ena vi²ina")
("height is maximum of specified height and box height" "vi²ina je maksimum dolo£ene vi²ine in vi²ine ²katle")
("height is minimum of specified height and box height" "vi²ina je minimum dolo£ene vi²ine in vi²ine ²katle")
("height magnification" "pove£ava vi²ine")
("height" "vi²ina")
("help me" "pomagajte mi")
("help" "pomo£")
("help us" "pomagajte nam")
("here" "tukaj")
("h modifier" "modifikator H")
("h modifier" "modifikator H")
("H modifier" "modifikator H")
("hidden" "skrito")
("home" "domov")
("homepage" "doma£a stran")
("horizontal cell alignment" "vodoravna poravnava celice")
("horizontal ink separation" "vodoravni razmik med £rnili")
("horizontally align cell to the base" "vodoravno poravnaj celico na bazo")
("horizontally center the cell" "vodoravno centriraj celico")
("horizontal part" "vodorovni del")
("horizontal position" "vodorovna pozicija")
("horizontal space" "vodoravni presledek")
("horizontal table alignment" "vodorovna poravnava tabele")
("horizontal" "vodoravno")
("how much longer may pages become" "koliko se lahko stran podalj²a")
("how much shorter may pages become" "koliko se lahko stran skraj²a")
("html" "HTML")
("huge" "ogromno")
("hungarian" "madºarsko")
("hybrid command" "hibriden ukaz")
("hybrid command" "hibriden ukaz")
("hyperlink" "hiperpovezava")
("hyphenation" "deljenje besed")
("icelandic" "islandsko")
("if" "if")
("image links" "povezave na sliko")
("image" "slika")
("implementation" "implementacija")
("import" "uvozi")
("improving the current implementation" "izbolj²ava trenutne izvedbe")
("inactive" "neaktivno")
("include a document" "vstavi dokument")
("include file" "vstavi datoteko")
("include" "vklju£i")
("inclusion into TeXmacs" "vklju£itev v TeXmacs")
("inclusions" "vloºki")
("indentation flag" "nastavitev zamika")
("indent" "zamik")
("index entry" "zapis v stvarnem kazalu")
("index level" "nivo stvarnega kazala")
("index" "stvarno kazalo")
("informative flags" "informativne oznake")
("input mode" "vhodni reºim")
("insert a big operator" "vstavi veliki operator")
("insert a binary operation" "vstavi dvoji²ko operacijo")
("insert a binary relation" "vstavi dvoji²ko relacijo")
("insert a blackboard bold character" "vstavi blackboard bold znak")
("insert a bold calligraphic character" "vstavi krepki kaligrafski znak")
("insert a bold character" "vstavi krepki znak")
("insert a calligraphic character" "vstavi kaligrafski znak")
("insert a fraction" "vstavi ulomek")
("insert a fraktur character" "vstavi fraktur znak")
("insert a greek character" "vstavi gr²ko £rko")
("insert a large left delimiter" "vstavi veliki levi lo£evalnik")
("insert a large right delimiter" "vstavi veliki desni lo£evalnik")
("insert a large separator" "vstavi veliki razdelilnik")
("insert a left subscript" "vstavi levi indeks")
("insert a link" "vstavi povezavo")
("insert a miscellaneous symbol" "vstavi drug simbol")
("insert an accent" "vstavi akcent")
("insert an arrow" "vstavi pu²£ico")
("insert an environment" "vstavi okolje")
("insert a new branch" "vstavi novo vejitev")
("insert a new item" "vstavi novo alinejo")
("insert an n" "vstavi n")
("insert an" "vstavi")
("insert a picture" "vstavi sliko")
("insert appendix" "vstavi dodatek")
("insert arccos" "vstavi arccos")
("insert arcsin" "vstavi arcsin")
("insert arctan" "vstavi arctan")
("insert argument" "vstavi argument")
("insert arg" "vstavi arg")
("insert a square root" "vstavi kvadratni koren")
("insert a table or a matrix" "vstavi tabelo ali matriko")
("insert a table" "vstavi tabelo")
("insert a TeXmacs symbol" "vstavi TeXmacs simbol")
("insert automatically generated content" "vstavi automatsko generirano vsebino")
("insert author" "vstavi avtorja")
("insert a wide symbol above" "vstavi ²irok simbol nad")
("insert a wide symbol below" "vstavi ²irok simbol pod")
("insert big contour integral" "vstavi veliki krivuljni integral")
("insert big coproduct" "vstavi veliki koprodukt")
("insert big direct sum" "vstavi veliko direktno vsoto")
("insert big dotted point" "vstavi veliko piko s kolesom")
("insert big integral" "vstavi veliki integral")
("insert big intersection" "vstavi veliki presek")
("insert big logical and" "vstavi veliko konjunkvijo")
("insert big logical or" "vstavi veliko disjunkcijo")
("insert big product" "vstavi veliki produkt")
("insert big square union" "vstavi veliko oglato unijo")
("insert big summation" "vstavi veliko vsoto")
("insert big tensor product" "vstavi veliki tenzorski produkt")
("insert big union sum" "vstavi veliko vsoto unij")
("insert big union" "vstavi veliko unijo")
("insert big vertical space" "vstavi veliki navpi£ni presledek")
("insert chapter" "vstavi poglavje")
("insert column to the left" "vstavi stolpec na levi")
("insert column to the right" "vstavi stolpec na desni")
("insert column" "vstavi stolpec")
("insert cosh" "vstavi cosh")
("insert cos" "vstavi cos")
("insert coth" "vstavi coth")
("insert cot" "vstavi cot")
("insert csc" "vstavi csc")
("insert deg" "vstavi deg")
("insert det" "vstavi det")
("insert dim" "vstavi dim")
("insert dollar" "vstavi dolar")
("insert equation" "vstavi ena£bo")
("insert executable markup" "vstavi izvr²ljive zna£ke")
("insert exp" "vstavi exp")
("insert fields" "vstavi polja")
("insert footnote" "vstavi opombo pod £rto")
("insert formula" "vstavi vzorec")
("insert gcd" "vstavi gcd")
("insert hom" "vstavi hom")
("insert horizontal interword space" "vstavi vodoravni medbesedni presledek")
("insert image" "vstavi sliko")
("insert inactive markup" "vstavi neaktivno zna£ko")
("insert inf" "vstavi inf")
("insert input field above" "vstavi vnosno polje nad")
("insert input field below" "vstavi vnosno polje pod")
("insert ker" "vstavi ker")
("insert lg" "vstavi lg")
("insert liminf" "vstavi liminf")
("insert limsup" "vstavi limsup")
("insert lim" "vstavi lim")
("insert ln" "vstavi ln")
("insert log" "vstavi log")
("insert macro" "vstavi makro")
("insert mathematics" "vstavi matematiko")
("insert max" "vstavi max")
("insert medium horizontal space" "vstavi srednji vodoravni presledek")
("insert medium vertical space" "vstavi srednji navpi£ni presledek")
("insert min" "vstavi min")
("insert negative horizontal space" "vstavi negativni vodorovni presledek")
("insert new item or number" "vstavi novo alinejo")
("insert new rows or columns" "vstavi nove stolpce ali vrstice")
("insert or delete rows or columns" "vstavi ali izbri²i stolpce ali vrstice")
("insert Pr" "vstavi Pr")
("insert row above" "vstavi vrstico nad")
("insert row below" "vstavi vrstico pod")
("insert row" "vstavi vrstico")
("insert section" "vstavi razdelek")
("insert sec" "vstavi sec")
("insert sharp" "vstavi vi²aj")
("insert sinh" "vstavi sinh")
("insert sin" "vstavi sin")
("insert small horizontal space" "vstavi mali vodorovni presledek")
("insert small vertical space" "vstavi mali navpi£ni presledek")
("insert structural markup" "vstavi strukturne zna£ke")
("insert subsection" "vstavi podrazdelek")
("insert subsubsection" "vstavi podpodrazdelek")
("insert sup" "vstavi sup")
("insert tanh" "vstavi tanh")
("insert tan" "vstavi tan")
("insert text field" "vstavi tekstovno polje")
("insert thick horizontal space" "vstavi debel vodoraven presledek")
("insert title" "vstavi naslov")
("insert value" "vstavi vrednost")
("insert" "vstavi")
("interfacing" "povezovanje")
("interfacing TeXmacs with other systems" "povezava TeXmacsa z drugimi sistemi")
("interjection" "interjection")
("interline separation" "lo£itev med vrsticami")
("interline space" "presledek med vrsticami")
("internationalization" "lokalizacija")
("interparagraph space" "presledek med odstavki")
("interrupt execution" "prekini izvajanje")
("introduction" "uvod")
("invisible citation" "neviden citat")
("invisible" "nevidno")
("irish" "irsko")
("ispell does not respond" "ispell se ne odziva")
("ispell is already busy" "ispell je zaposlen")
("is running" "te£e")
("is tuple" "je n-terka")
("italian" "italijansko")
("italic" "kurzivno")
("italic right" "kurzivno desno")
("item" "alineja")
("itemize" "alineje")
("january" "januar")
("japanese" "japonsko")
("july" "julij")
("june" "junij")
("justified" "obojestranska")
("justify text" "poravnaj besedilo obojestransko")
("keyboard equivalent" "ekvivalent na tipkovnici")
("keyboard modifiers" "modifikator tipkovnice")
("keyboard shortcut" "okraj²ava na tipkovnici")
("keyboard" "tipkovnica")
("keymaps" "razporeditve tipk")
("key" "tipka")
("keyword" "klju£na beseda")
("keywords" "klju£ne besede")
("kill" "pobij")
("known bugs" "znani hro²£i")
("label" "oznaka")
("landscape" "pokrajina")
("language" "jezik")
("large closing bracket" "veliki zaklepaj")
("large delimiter" "veliki lo£evalnik")
("large opening bracket" "veliki predklepaj")
("large separator" "veliki razdelilnik")
("large" "veliko")
("last indentation" "zadnji zamik")
("last page" "zadnja stran")
("latex command" "LaTeX ukaz")
("LaTeX" "LaTeX")
("latin" "latinica")
("layout" "postavitev")
("left arrow" "pu²£ica levo")
("left arrow" "pu²£ica levo")
("left border" "leva obroba")
("left" "levo")
("left margin" "levi rob")
("left padding" "leva obloga")
("left prime" "left prime")
("left aligned" "leva")
("left slanted" "postrani levo")
("left subscript" "levi indeks")
("left superscript" "levi eksponent")
("left surrounding" "levo naokoli")
("legal" "legal")
("lemma" "lema")
("length" "dolºina")
("less" "manj²e")
("less or equal" "manj²e ali enako")
("letter" "pismo")
("license" "licenca")
("light grey" "svetlo siva")
("light grey" "svetlo siva")
("light" "lahko")
("limitations" "omejitve")
("limits" "omejitev")
("line break" "prelom vrste")
("line stretch" "razteg vrstice")
("line" "vrstica")
("link image" "poveºi sliko")
("link" "povezava")
("list of figures" "seznam slik")
("list of tables" "seznam tabel")
("list" "seznam")
("load a file" "naloºi datoteko")
("load buffer" "naloºi spis")
("loaded" "naloºeno")
("load file" "naloºi datoteko")
("load html file" "naloºi datoteko HTML")
("load image" "naloºi sliko")
("load in new window" "naloºi v novo okno")
("load latex file" "naloºi datoteko LaTeX")
("load LaTeX file" "naloºi datoteko LaTeX")
("load more recent autosave file" "naloºi novej²o avtomatsko shranjeno datoteko")
("load" "naloºi")
("load tex file" "naloºi datoteko TeX")
("load TeX file" "naloºi datoteko TeX")
("load TeXmacs file" "naloºi datoteko TeXmacs")
("load TeXmacs style file" "naloºi datoteko TeXmacs slog")
("load verbatim file" "odpri datoteko dobesedno")
("long" "dolgo")
("look and feel" "ob£utek in videz")
("look up" "poglej v")
("lower border" "niºja obroba")
("macro" "makro")
("magenta" "magenta")
("magic" "£arovnija")
("magnification" "pove£ava")
("magnified" "pove£ano")
("main" "glavni")
("main icon bar" "glavne ikone")
("major changes" "glavne spremembe")
("make acute" "ustvari ostrivec")
("make a page insertion" "vstavi v stran")
("make a subscript" "ustvari indeks")
("make a superscript" "ustvari eksponent")
("make bar" "make bar")
("make check" "vstavi stre²ico")
("make fraction" "ustvari ulomek")
("make grave" "ustvari krativec")
("make hat" "make hat")
("make label" "ustvari oznako")
("make negation" "ustvari negacijo")
("make page reference" "ustvari sklic na stran")
("make reference" "ustvari sklic")
("make square root" "ustvari kvadratni koren")
("make tilde" "ustvari tildo")
("make title" "ustvari naslov")
("make vector" "ustvari vektor")
("making donations" "finan£na podpora")
("manual" "priro£nik")
("map to" "mapiraj na")
("march" "marec")
("margins as on paper" "robovi kot na papirju")
("margins" "robovi")
("master file" "datoteka gospodar")
("master" "gospodar")
("mathematical font" "pisava za matematiko")
("mathematical formulas" "matemati£ne formule")
("mathematical input" "matemati£en vnos")
("mathematical input" "matemati£en vnos")
("mathematical" "matemati£no")
("mathematical typesetting" "matemati£no stavljenje")
("mathematics" "matematika")
("math font family" "druºina matemati£ne pisave")
("math font" "pisava za matematiko")
("math font series" "serija matemati£ne pisave")
("math font shape" "oblika matemati£ne pisave")
("math" "matematika")
("matrix" "matrika")
("maximal" "maksimalno")
("maximal number of columns" "najve£ stolpcev")
("maximal number of rows" "najve£ vrstic")
("maximum mode" "maksimalni reºim")
("may" "maj")
("medium skip" "srednji preskok")
("medium" "srednje")
("meminfo" "informacije o pomnilniku")
("memory information" "informacije o pomnilniku")
("merge" "zdruºi")
("messy" "messy")
("meta key" "tipka meta")
("middle" "sredina")
("minimal" "minimalno")
("minimal number of columns" "najmanj stolpcev")
("minimal number of rows" "najmanj vrstic")
("minimum mode" "minimalni reºim")
("minus" "minus")
("miscellaneous" "razno")
("m modifier" "modifikator M")
("m modifier" "modifikator M")
("M modifier" "modifikator M")
("mode" "na£in")
("modifier" "modifikator")
("modify cell alignment" "spremeni poravnavo celice")
("modify cell border" "spremeni obrobo celice")
("modify cell padding" "spremeni oblogo celice")
("modify cell size" "spremeni velikost celice")
("modify table border" "spremeni obrobo tabele")
("modify table padding" "spremeni oblogo tabele")
("mod" "modulo")
("mongolian" "mongolsko")
("more information about GNU TeXmacs can be found in the help" "Ve£ informacij o GNU TeXmacsu lahko najdete v pomo£i")
("mosaic" "mozaik")
("move down" "premakni dol")
("move object" "premakni objekt")
("move to the right when finished" "prestavi desno ko kon£a²")
("move up" "premakni gor")
("multiline input" "ve£vrsti£ni vnos")
("multiline input" "vnos v ve£ vrsticah")
("my documents" "moji dokumenti")
("my documents" "moji dokumenti")
("name" "ime")
("negation" "negacija")
("new buffer" "nov spis")
("new column" "nov stolpec")
("new item" "nova alineja")
("new line" "nova vrsta")
("new" "nova")
("new number" "novo ²tevilo")
("new page before" "nova stran pred")
("new page" "nova stran")
("new paragraph" "nov odstavek")
("new roman" "new roman")
("new row" "nova vrstica")
("new table" "nova tabela")
("next line" "naslednja vrstica")
("next" "naslednje")
("next" "naslednji")
("no changes need to be saved" "shranjevanje sprememb ni potrebno")
("no dictionary for" "ni slovarja za")
("no first indentation" "brez prvega zamika")
("no indentation" "brez zamika")
("no last indentation" "brez poslednjega zamika")
("no line break" "brez preloma vrste")
("no matches found for" "ni ujemanja za")
("no matches found" "ni£ najdeno")
("no more matches for" "ni£ ve£ najdb za")
("no more redo information available" "na koncu")
("no more undo information available" "na za£etku")
("no name" "brez imena")
("none" "brez")
("no page break after" "brez preloma strani za")
("no page break before" "brez preloma strani pred")
("normal" "normalno")
("norwegian" "norve²ko")
("no spelling errors found in text" "besedilo je brez pravopisnih napak")
("no style" "brez sloga")
("notation" "notacija")
("note" "notica")
("not equal" "neenako")
("not found" "ni najdeno")
("not" "non")
("november" "november")
("n-th" "n-ti")
("n-th root" "n-ti koren")
("numbered equations" "²tevil£ene ena£be")
("numbered equation" "²tevil£ena ena£ba")
("number equation" "o²tevil£i ena£bo")
("number of columns" "²tevilo stolpcev")
("number" "²tevilo")
("numerator" "²tevec")
("numeric" "numeri£no")
("objectives" "cilj")
("occurrences" "pojavov")
("october" "oktober")
("odd page footer" "noga lihih strani")
("odd page header" "glava lihih strani")
("odd page left margin" "levi rob lihih strani")
("odd page margin" "rob lihih strani")
("odd page text" "besedilo lihih strani")
("off" "izklopljeno")
("ok" "ok")
("old english" "staro angle²ko")
("old slavonic" "staro slovensko")
("old style" "stari slog")
("on cells" "na celice")
("on columns" "na stolpce")
("on entire table" "na celo tabelo")
("one spelling error has been corrected" "ena pravopisna napaka odpravljena")
("online documentation" "online dokumentacija")
("online help" "online pomo£")
("on rows" "na vrstice")
("on" "vklopljeno")
("open a new buffer" "odpri nov spis")
("opening" "odpiram")
("open new window" "odpri novo okno")
("open" "odpri")
("operation on named selection" "operacija na poimenovani izbiri")
("operation on primary selection" "operacija na primarni izbiri")
("operation on secondary selection" "operacija na sekundarni izbiri")
("operation on ternary selection" "operacija na terciarni izbiri")
("optical" "optical")
("option" "nastavitev")
("options" "nastavitve")
("or" "ali")
("orange" "oranºna")
("orientation" "orientacija")
("original welcome message" "originalna dobrodo²lica")
("origin" "p·vod")
("other" "drugo")
("other pages" "druge strani")
("other projects" "drugi projekti")
("other style" "drug slog")
("outlined roman" "roman obrobljeno")
("overbrace" "nadklepaj")
("overbrace" "nadklepaj")
("overline" "nad£rtano")
("over" "nad")
("overwrite existing file" "naj prepi²em obstoje£o datoteko (y/n)")
("padding" "obloga")
("page bottom margin" "spodnji rob strani")
("page break before" "prelom strani pred")
("page break" "prelom strani")
("page height" "vi²ina strani")
("page insertion" "vstavi na stran")
("page layout" "postavitev strani")
("page numbering" "²tevil£enje strani")
("page number text" "tekst ²tevilke strani")
("page reference" "sklic na stran")
("page right margin" "desni rob strani")
("page setup" "nastavitev strani")
("page" "stran")
("page top margin" "zgornji rob strani")
("page type" "tip strani")
("page width" "²irina strani")
("paper" "papir")
("paper type" "velikost papirja")
("papyrus" "papirus")
("paragraph mode" "reºim odstavka")
("paragraph" "odstavek")
("paragraph width" "²irina odstavka")
("part" "del")
("past changes" "minule spremembe")
("paste from" "prilepi iz")
("paste" "prilepi")
("paste text" "prilepi besedilo")
("path" "pot")
("pdf" "PDF")
("perform operations on cells" "izvedi operacijo na celicah")
("perform operations on columns" "izvedi operacijo na stolpcih")
("perform operations on entire table" "izvedi operacijo na celotni tabeli")
("perform operations on rows" "izvedi operacijo na vrsticah")
("permanent" "permanentno")
("personal dictionary has been modified" "osebni slovar je bil spremenjen")
("person" "oseba")
("phantasy" "fantazija")
("philosophy" "filozofija")
("phoenician" "feni£an")
("phonetic" "foneti£no")
("pink" "roºnata")
("plain block" "navaden blok")
("plain tabular" "navaden tabular")
("planned changes" "na£rtovane spremebe")
("plans for the future" "na£rti za prihodnost")
("please" "prosim")
("please wait" "po£akajte prosim")
("plugins" "vstavki")
("plugins" "vstavki")
("plugin" "vstavek")
("plugin" "vstavek")
("plus" "plus")
("polish" "poljsko")
("porting TeXmacs to other platforms" "prenos TeXmacsa na druge platforme")
("portrait" "portret")
("portuguese" "portugalsko")
("position floating object" "pozicioniraj plavajo£ objekt")
("position float" "pozicionioraj plovko")
("position" "pozicija")
("position the table" "pozicioniraj tabelo")
("postscript image" "slika v PostScriptu")
("postscript" "postscript")
("pre-alpha release" "pred-alfa release")
("preamble mode" "reºim preambule")
("preamble" "preambula")
("preferences" "nastavitve")
("presentation mode" "prezentacijski reºim")
("presentation" "prezentacija")
("presentation tag" "prezentacijska oznaka")
("preview before printing" "predogled tiskanja")
("preview command" "ukaz za predogled")
("preview with ghostview" "predogled z GhostScriptom")
("previous" "prej²nje")
("previous" "prej²nji")
("primary" "primarno")
("prime" "pra²tevilo")
("print all" "natisni vse")
("print all to file" "natisni vse v datoteko")
("printer dpi" "DPI tiskalnika")
("printer" "tiskalnik")
("printing command" "ukaz za tiskanje")
("print" "natisni")
("print page selection" "natisni izbor strani")
("print page selection to file" "natisni izbor strani v datoteko")
("print to postscript file" "natisni v PostScript datoteko")
("problem" "problem")
("professional" "profesionalno")
("prog font family" "druºina pisave za prog")
("prog font" "pisava za prog")
("prog font series" "serija pisave za prog")
("prog font shape" "oblika pisave za prog")
("prog" "prog")
("program font" "pisava za programe")
("programming" "programiranje")
("program mode" "reºim programa")
("program" "program")
("progressive" "progresivno")
("project" "projekt")
("projects" "projekti")
("prologue" "prolog")
("prompt on scripts" "vpra²aj pri skriptih")
("proof" "dokaz")
("proportional" "proporcionalno")
("proportional typewriter" "proporcionalni pisalni stroj")
("proposition" "izjava")
("query replace" "zamenjaj s potrditvijo")
("quit" "konec")
("quotation" "quotation")
("quote" "quote")
("range" "obseg")
("really close it" "zares zapri")
("really huge" "zares ogromno")
("really quit" "zares kon£aj")
("really tiny" "zares drobno")
("recover autosave file" "povrnem samodejno shranjeno datoteko")
("redo" "ponovi")
("redo undone changes" "ponovi razveljavljeno")
("red" "rde£a")
("reduce bottom margin by" "zmanj²aj spodnji rob za")
("reduce left margin by" "zmanj²aj levi rob za")
("reduce margins" "zmanj²aj robove")
("reduce right margin by" "zmanj²aj desni rob za")
("reduce top margin by" "zmanj²aj zgornji rob za")
("reduction even page margin" "pomanj²ava roba sodih strani")
("reduction odd page margin" "pomanj²ava roba lihih strani")
("reduction page bottom margin" "pomanj²ava spodnjega roba strani")
("reduction page right margin" "pomanj²ava desnega roba strani")
("reduction page top margin" "pomanj²ava zgornjega roba strani")
("reference" "sklic")
("reference guide" "Referen£ni vodi£")
("references" "sklicevanja")
("regular" "regularen")
("release" "release")
("reload" "ponovno naloºi")
("remark" "opomba")
("remove all output fields" "odstrani vsa izhodna polja")
("remove all output fields" "odstrani vsa vnosna polja")
("remove fields" "odstrani polja")
("remove fields" "odstrani polja")
("remove input field above" "odstrani vnosno polje nad")
("remove input field above" "odstrani vpisno polje nad")
("remove input field" "odstrani vnosno polje")
("remove input field" "odstrani vpisno polje")
("remove number" "odstrani ²tevilo")
("remove package" "odstrani paket")
("remove this switch" "izbri²i stikalo")
("renumber this page" "ponovno o²tevil£i teko£o stran")
("repeat object" "ponovi objekt")
("replace by" "zamenjano")
("replaced one occurrence" "zamenjal enkrat")
("replaced" "zamenjav")
("replace" "zamenjaj")
("reset" "reset")
("resized" "pove£ano")
("resize object" "pove£aj")
("search results for" "rezultati iskanja za")
("search results for" "rezultati iskanja za")
("return" "return")
("revert buffer" "povrni spis")
("revert" "povrni")
("right arrow" "pu²£ica desno")
("right arrow" "pu²£ica desno")
("right border" "desna obroba")
("right" "desno")
("right margin" "desni rob")
("right padding" "desna obloga")
("right aligned" "desna")
("right subscript" "desni indeks")
("right superscript" "desni eksponent")
("right surrounding" "desno okoli")
("rigid horizontal" "rigidno vodoravno")
("rigid" "rigidno")
("rigid space" "rigiden presledek")
("romanian" "romunsko")
("root" "koren")
("rotate backward" "zasukaj nazaj")
("rotate forward" "zasukaj naprej")
("row contains glued items" "vrstica vsebuje prilepljene predmete")
("row" "vrstica")
("runic" "rune")
("running author" "avtor")
("running title" "teko£i naslov")
("russian and Ukrainian users" "uporabniki iz Rusije in Ukrajine")
("russian" "rusko")
("sample" "primer")
("sans serif" "brez serifov")
("save as LaTeX" "shrani kot LaTeX")
("save as" "shrani kot")
("save as TeX" "shrani kot TeX")
("save buffer as" "shrani spis kot")
("save buffer" "shrani spis")
("saved" "shranjeno")
("save file" "shrani datoteko")
("save html file" "shrani datoteko HTML")
("save image" "shrani sliko")
("save latex file" "shrani datoteko LaTeX")
("save" "shrani")
("save tex file" "shrani datoteko TeX")
("save TeXmacs file" "shrani kot TeXmacs")
("save TeXmacs style file" "shrani kot TeXmacs slog")
("save this buffer" "shrani ta spis")
("save verbatim file" "shrani datoteko dobesedno")
("screen layout" "postavitev na zaslonu")
("screen margins" "robovi na zaslonu")
("screen" "zaslon")
("script above" "indeks nad")
("script below" "indeks pod")
("script" "indeks")
("script script size" "velikost indeks indeksa")
("script size" "velikost indeksa")
("scripts not accepted" "skripti so zavrnjeni")
("search" "i²£i")
("searching" "i²£em")
("search words in my documents" "i²£i besede v mojih dokumentih")
("search words in my documents" "i²£i besede v mojih dokumentih")
("search words in the documentation" "i²£i besede v dokumentaciji")
("search words in the documentation" "i²£i besede v dokumentaciji")
("search words in the source code" "i²£i besede v izvorni kodi")
("search words in the source code" "i²£i besede v izvorni kodi")
("secondary" "sekundarno")
("section" "razdelek")
("security" "varnost")
("see" "glej")
("select a document style" "izberi slog dokumenta")
("select a foreground color" "izberi barvo ospredja")
("select a language" "izberite jezik")
("selected region" "izberite regijo")
("selection" "izbira")
("selections" "izbire")
("seminar" "seminar")
("sending commands to TeXmacs" "po²iljanje ukazov TeXmacs-u")
("sending commands to TeXmacs" "po²iljanje ukazov TeXmacsu")
("separation between lines" "razmak med vrsticami")
("separation between paragraphs" "razmak med odstavki")
("separator" "razdelilnik")
("september" "september")
("serb" "srbsko")
("series|right" "serija|right")
("series" "serija")
("session name" "ime seje")
("session" "seja")
("sessions" "seje")
("session type" "tip seje")
("set background color of cell" "nastavi barvo ozadja celice")
("set cell mode" "nastavi reºim celice")
("set extension center" "nastavi center raz²iritve")
("set height" "nastavi vi²ino")
("set height of cell" "nastavi vi²ino celice")
("set margins" "nastavi robove")
("set" "nastavi")
("set n" "nastavi n")
("set paragraph margins" "nastavi robove odstavka")
("set paragraph mode" "nastavi poravnavo odstavka")
("set printer dpi" "nastavi DPI tiskalnika")
("set printing command" "nastavi ukaz za tiskanje")
("set span" "nastavi razpetost")
("set special cell properties" "nastavi posebne lastnosti celive")
("set special table properties" "nastavi posebne lastnosti tabele")
("set text width" "nastavi ²irino besedila")
("settings" "nastavitve")
("setup printer" "nastavitev tiskanja")
("set width" "nastavi ²irino")
("set width of cell" "nastavi ²irino celice")
("shape" "oblika")
("shift-down" "pomakni-dol")
("shift-right" "pomakni-desno")
("short" "kratko")
("show header and footer" "pokaºi glavo in nogo")
("show hidden" "pokaºi skrito")
("show on screen" "pokaºi na zaslonu")
("show" "pokaºi")
("shrinking factor" "faktor pomanj²ave")
("signature" "podpis")
("size limits" "omejitve velikosti")
("size tag" "oznaka velikosti")
("size" "velikost")
("slanted" "postrani")
("sloppy" "povr²no")
("slovene" "slovensko")
("small caps" "kapitelke")
("small figure" "mala slika")
("small" "majhno")
("small skip" "majhen preskok")
("small table" "mala tabela")
("source code" "izvorna koda")
("space between lines" "presledek med vrsticami")
("space between paragraphs" "presledek med odstavki")
("space" "presledek")
("spacing" "razmak")
("spanish" "²pansko")
("special cell properties" "posebne lastnosti celice")
("special" "posebno")
("special table properties" "posebne lastnosti tabele")
("specific" "specifi£no")
("spell checking complete" "kontrola pravopisa kon£ana")
("spelling error" "pravopisna napaka")
("spelling errors have been corrected" "pravopisne napake popravljene")
("spell" "pravopis")
("split" "razdeli")
("split session" "predeli sejo")
("split session" "razdeli sejo")
("square root" "kvadratni koren")
("standard environment variables" "standardne spremenljivke okolja")
("standard TeXmacs styles" "standardni TeXmacs slogi")
("start a new chapter" "za£ni novo poglavje")
("start a new section" "za£ni nov razdelek")
("start an interactive session" "poºeni interaktivno sejo")
("start" "za£etek")
("status bar" "statusna vrstica")
("stretchable horizontal" "vodoravno raztegljivo")
("stretchable" "raztegljivo")
("stretchable vertical" "navpi£no raztegljivo")
("stroke" "pre£rtano")
("strokes" "pre£rtaji")
("strong" "mo£no")
("structural" "strukturno")
("style" "slog")
("styles" "slogi")
("subparagraph" "pododstavek")
("sub" "pod-")
("subscript" "indeks")
("subsection" "podrazdelek")
("subsub" "podpod-")
("subsubsection" "podpodrazdelek")
("subtable" "podtabela")
("subtitle" "podnaslov")
("summary of the principal TeXmacs tags" "povzetek glavnih TeXmacs zna£k")
("summary" "povzetek")
("superposed" "superponirano")
("superpose" "superpozicija")
("superscript" "eksponent")
("swedish" "²vedsko")
("switching and folding" "preklapljanje in prepogibanje")
("switch" "stikalo")
("switch to first" "preklopi na prvega")
("switch to formula style" "preklopi na formule")
("switch to last" "preklopi na zadnjega")
("switch to next" "preklopi na naslednjega")
("switch to previous" "preklopi na prej²njega")
("symbol" "simbol")
("system environment variables" "spremenljivke sistemskega okolja")
("table command" "ukaz za tabele")
("table of contents" "kazalo")
("tables" "tabele")
("table" "tabela")
("tab" "tabulator")
("tabular material" "tabularni material")
("tabular" "tabular")
("ternary" "terciarno")
("test" "test")
("teXmacs as an interface" "TeXmacs kot vmesnik")
("teXmacs fonts" "pisave v TeXmacsu")
("teXmacs notice" "TeXmacs opomba")
("teXmacs plugins" "TeXmacs vstavki")
("teXmacs plugins" "TeXmacs vstavki")
("teXmacs primitives" "TeXmacs primitivi")
("teXmacs style files" "TeXmacs slogovne datoteke")
("text" "besedilo")
("tex" "TeX")
("TeX" "TeX")
("text font" "pisava besedila")
("text height correction" "popravek vi²ine besedila")
("texts" "besedila")
("text width" "²irina besedila")
("thai" "tajsko")
("th century bc" ". stoletje")
("the application did not send its usual startup banner" "aplikacija ni poslala obi£ajnega startnega sporo£ila")
("the application does not reply" "aplikacija se ne odziva")
("the application is already running" "aplikacija ºe te£e")
("the boxes produced by the typesetter" "²katle, ki jih naredi stavec")
("the graphical user interface" "grafi£ni uporabni²ki vmesnik")
("the leaves of TeXmacs trees" "listi TeXmacs dreves")
("the mycas example" "primer z Mycas")
("theorem" "izrek")
("the primitive TeXmacs constructs" "primitivni TeXmacs konstrukti")
("there are unsaved documents" "nekatere datoteke niso shranjene")
("the standard TeXmacs styles" "standardni TeXmacs slogi")
("the TeXmacs authors" "TeXmacs avtorji")
("the TeXmacs format" "oblika TeXmacs datotek")
("the document has not been saved" "spis ni shranjen")
("this document has been produced using" "ta dokument je bil narejen z")
("this line" "ta vrstica")
("this page" "ta stran")
("th root" "-ti koren")
("tilda" "tilda")
("tilde" "tilda")
("times" "times")
("tiny" "drobno")
("title" "naslov")
("today" "danes")
("tools" "orodja")
("top border" "zgornja obroba")
("top level" "zgornji nivo")
("top margin" "zgornji rob")
("top padding" "zgornja obloga")
("top" "vrh")
("to the left" "na levo")
("to the right" "na desno")
("translate" "pretolma£i")
("tree" "drevo")
("tuple" "n-terka")
("turkish" "tur²ko")
("tutorial" "lekcija")
("type a latex command followed by" "napi²ite LaTeX ukaz, ki mu sledi")
("type body" "napi²i telo")
("type denominator" "napi²i imenovalec")
("type numerator" "napi²i ²tevec")
("type script" "napi²i skript")
("typesetted boxes" "postavljene ²katle")
("type" "tip")
("typewriter" "pisalni stroj")
("typewriter small caps" "pisalni stroj male kapitelke")
("typing a simple text" "pisanje preprostega besedila")
("typing simple texts" "pisanje preprostih besedil")
("ugaritic" "ugaritic")
("ukrainian" "ukrajinsko")
("underbrace" "podklepaj")
("underbrace" "podklepaj")
("underline" "pod£rtano")
("undo last changes" "razveljavi zadnje spremembe")
("undo" "razveljavi")
("unevaluated argument" "neovrednoten argument")
("unevaluated value" "neovrednotena vrednost")
("unfold" "zravnaj")
("update from web" "posodobi s spleta")
("update image links" "posodobi povezave na slike")
("update" "posodobi")
("up" "gor")
("upper border" "gornja obroba")
("use a black color" "uporabi £rno barvo")
("use a blue color" "uporabi modro barvo")
("use a bold font" "uporabi krepko pisavo")
("use a brown color" "uporabi rjavo barvo")
("use a calligraphic font" "uporabi kaligrafsko pisavo")
("use a green color" "uporabi zeleno barvo")
("use a grey color" "uporabi sivo barvo")
("use a magenta color" "uporabi magenta barvo")
("use a orange color" "uporabi oranºno barvo")
("use a pink color" "uporabi roºnato barvo")
("use a red color" "uporabi rde£o barvo")
("use a sans serif font" "uporabi pisavo brez serifov")
("use a typewriter font" "uporabi pisavo pisalnega stroja")
("use a white color" "uporabi belo barvo")
("use a yellow color" "uporabi rumeno barvo")
("use blackboard bold font" "uporabi pisavo blackboard bold")
("use bold font series" "uporabi krepko serijo pisave")
("use calligraphical font" "uporabi kaligrafsko pisavo")
("use footnote font size" "uporabi velikost pisave za opombe pod £rto")
("use fraktur font" "uporabi pisavo fraktur")
("use huge font size" "uporabi ogromno pisavo")
("use italic font shape" "uporabi kurzivno pisavo")
("use large font size" "uporabi veliko pisavo")
("use left hand column as border" "uporabi levi stolpec kot obrobo")
("use medium font series" "uporabni srednjekrepko serijo pisave")
("use normal font size" "uporabi normalno velikost")
("use package" "uporabi paket")
("use paragraph width" "uporabi ²irino odstavka")
("use really huge font size" "uporabi zares ogromno velikost pisave")
("use right font shape" "uporabi desno obliko pisave")
("use right hand column as border" "uporabi desni stolpec kot obrobo")
("user manual" "uporabni²ki priro£nik")
("use roman font family" "uporabi pisavo roman")
("use row above as border" "uporabi gornjo vrstico kot obrobo")
("use row below as border" "uporabi spodnjo vrsticko kot obrobo")
("user provided icons" "uporabnikove ikone")
("users of Cyrillic languages" "uporabniki jezikov v cirilici")
("users of Cyrillic languages" "uporabniki jezikov v Cirilici")
("use sans serif font family" "uporabi druºino pisave brez serifov")
("use script font size" "uporabi velikost pisave za indekse")
("use slanted font shape" "uporabi postrani obliko pisave")
("use small capitals" "uporabi kapitelke")
("use small-caps font shape" "uporabi male kapitelke")
("use small font size" "uporabi malo pisavo")
("use TeXmacs" "uporabljajte TeXmacs")
("use the blackboard bold font" "uporabi obliko blackboard bold")
("use the fraktur font" "uporabi pisavo fraktur")
("use tiny font font size" "uporabi drobno pisavo")
("use typewriter font family" "uporabi pisavo pisalnega stroja")
("use very large font size" "uporabi zelo veliko pisavo")
("value" "vrednost")
("variable" "spremenljivka")
("variant" "varianta")
("vector" "vektor")
("verbatim" "dobesedno")
("verse" "verz")
("vertical after" "navpi£no za")
("vertical before" "navpi£no pred")
("vertical cell alignment" "navpi£na poravnava celice")
("vertically align cell to the base" "navpi£no poravnaj celico na bazo")
("vertically center the cell" "navpi£no centriraj celico")
("vertical" "navpi£no")
("vertical part" "navpi£ni del")
("vertical position" "navpi£na pozicija")
("vertical space" "navpi£ni presledek")
("vertical table alignment" "navpi£na poravnava tabele")
("very large" "zelo veliko")
("very small" "zelo majhno")
("vietnamese" "vietnamsko")
("view" "pogled")
("visible" "vidno")
("warning" "opozorilo")
("web" "splet")
("welcome" "dobrodo²li")
("welcome to GNU TeXmacs" "Dobrodo²li v GNU TeXmacs")
("what is new" "kaj je novega")
("when finished" "po zaklju£ku")
("while" "while")
("white" "bela")
("wide accent" "²iroki akcent")
("wide bar" "²iroka £rta")
("width" "²irina")
("width is exactly the specified width" "²irina je natanko dolo£ena ²irina")
("width is maximum of specified width and box width" "²irina je maksimum dolo£ene ²irine in ²irine ²katle")
("width is minimum of specified width and box width" "²irina je minimum dolo£ene ²irine in ²irine ²katle")
("width magnification" "pove£ava ²irine")
("window height" "vi²ina okna")
("window" "okno")
("windows key" "tipka windows")
("window width" "²irina okna")
("with" "with")
("write a name" "pi²i ime")
("write bold mathematics" "pi²i krepko matematiko")
("write bold text" "pi²i krepko besedilo")
("write italic text" "pi²i kurzivno besedilo")
("write sample text" "pi²i primer besedila")
("write strong text" "pi²i mo£no besedilo")
("write typewriter text" "pi²i besedilo na pisalni stroj")
("write verbatim text" "pi²i besedilo dobesedno")
("writing data converters" "tvorba pretvornikov podatkov")
("writing your own style files" "tvorba lastnih slogov")
("written with TeXmacs" "napisano z TeXmacs")
("xml" "XML")
("yellow" "rumena")
("you can also obtain" "lahko tudi dobite")
("your document is back in its original state" "va² dokument je v svojem izvornem stanju")
("your first interface" "va² prvi vmesnik")
("your language" "va² jezik")
