("\"encryption\" features from the preference panel" "\x12криптиране\x10 от предпочитания панел")
("(Re)Build autocompletion index" "(Re) Създаване на индекс за автоматично довършване")
("a modifier" "модификатор")
("a series" "серия")
("a.C.M. computing class" "клас за изчисляване на а.С.М.")
("a.M.S. subject class" "предметен клас в американец")
("abbreviated authors" "съкратени автори")
("abreviated authors" "съкратени автори")
("accent above" "акцент над")
("accent below" "акцент отдолу")
("accept during this pass" "приемам по време на този пропуск")
("acknowledgments" "признания")
("activate hidden" "активиране на скрито")
("activate once" "активиране веднъж")
("activation" "активиране")
("active link types" "активни типа връзки")
("add" "добавяне")
("add abstract information" "добавете абстрактна информация")
("add author information" "добавяне на информация за автора")
("add branch after" "добавяне на клон след")
("add branch before" "добавяне на клон преди")
("add other package" "добави друг пакет")
("add package" "добавяне на пакет")
("add style package" "добавяне на пакет за стил")
("add title information" "добавяне на информация за заглавието")
("addition" "добавяне")
("adjust" "коригиране")
("adjust limits" "коригиране на граници")
("advanced font customization" "разширено персонализиране на шрифтове")
("affiliation" "принадлежност")
("align cell to the decimal comma" "изравняване на клетката с десетичната запетая")
("align cell to the decimal dot" "подравняване на клетката към десетичната точка")
("align table at axis" "подравняване на таблицата по оста")
("aligned" "подравнени")
("alignment of balloon" "подравняване на балон")
("all cells" "всички клетки")
("all data attached to this identity will be lost" "всички данни, прикачени към тази идентичност, ще бъдат загубени")
("all saved passphrases will be lost forever" "всички запазени пароли ще бъдат загубени завинаги")
("allow for macro definitions in preamble" "позволяват макроопределения в преамбюла")
("allowed page height extension" "разрешено разширение на височината на страницата")
("allowed page height reduction" "разрешено намаляване на височината на страницата")
("allowed positions" "разрешени позиции")
("allowed positions of floating object" "разрешени позиции на плаващ обект")
("alpha transparency" "алфа прозрачност")
("also on paper" "също на хартия")
("alter" "промени")
("alternate" "заместник")
("alternate except here" "заместник, освен тук")
("alternate from here on" "се редуват оттук нататък")
("alternate only here" "се редуват само тук")
("alternate until here" "се редуват до тук")
("alternative specification" "алтернативна спецификация")
("always" "винаги")
("american" "американски")
("amplified" "усилени")
("and perform casual settings from the \"Encryption\" tab" "и изпълнете случайни настройки от раздела \x12Шифроване\x10")
("angular" "ъглови")
("animate" "анимиране")
("animate folding" "анимално сгъване")
("animate unfolding" "разгъване на анимация")
("animated" "анимирани")
("animation" "анимация")
("animation toolbar" "лента с инструменти за анимация")
("annotate" "пояснение")
("answer" "отговор")
("answer field" "поле за отговор")
("answer to question" "отговор на въпрос")
("answers only" "отговори само")
("any" "всякакви")
("appear" "се появяват")
("apply macro" "прилага макро")
("apply macro once" "прилага макрос веднъж")
("approximate" "приблизително")
("arc" "дъга")
("arc cosine" "дъга косинус")
("arc sine" "дъга")
("arc tangent" "дъгова тангента")
("arch series" "арка серия")
("are you sure you want to delete collected public keys" "сигурни ли сте, че искате да изтриете събраните публични ключове")
("are you sure you want to delete selected public keys" "сигурни ли сте, че искате да изтриете избраните публични ключове")
("are you sure you want to delete selected secret keys" "сигурни ли сте, че искате да изтриете избрани секретни ключове")
("are you sure you want to destroy the wallet" "сигурни ли сте, че искате да унищожите портфейла")
("art frame" "художествена рамка")
("arxiv category" "категория arxiv")
("as visual grid" "като визуална решетка")
("aspect" "аспект")
("attach master" "прикачи майстор")
("auto" "автоматично")
("auto-save file" "файл за автоматично запазване")
("automatic brackets" "автоматични скоби")
("automatic content generation" "автоматично генериране на съдържание")
("automatic program brackets" "автоматични скоби на програмата")
("automatic quotes" "автоматични кавички")
("automatically close brackets" "автоматично затваряне на скобите")
("automatically import bibliographies when opening files" "автоматично импортиране на библиографии при отваряне на файлове")
("automatically remember all passphrases in the wallet" "автоматично запомня всички пароли в портфейла")
("automatically save" "автоматично запазване")
("autosave" "автоматично запазване")
("axis" "ос")
("b series" "b серия")
("back" "назад")
("background evaluations" "фонови оценки")
("backtrace errors" "назад грешки")
("base" "база")
("baseline" "базова линия")
("basic communication using pipes" "основна комуникация с помощта на тръби")
("beamer" "греда")
("beamer formats" "формати на гредата")
("beamer theme" "тема на лъча")
("bench" "пейка")
("bend bottom" "огъване на дъното")
("bend corner" "ъгъл на огъване")
("bend diagonal" "диагонал на огъване")
("bend in" "огъване")
("bend out" "огъване")
("bezier" "безие")
("bibTeX command" "bibTeX команда")
("bidirectional" "двупосочни")
("big environment box" "голяма околна кутия")
("big focus" "голям фокус")
("binary operator" "двоичен оператор")
("bitmap resolution (dpi)" "резолюция на растерната карта (dpi)")
("black floral I" "черен флорален I")
("black floral II" "черен флорален II")
("blackboard embold" "черна дъга")
("blank column" "празна колона")
("blank row" "празен ред")
("block" "блок")
("block content" "блокиране на съдържание")
("block of code" "блок код")
("blur" "размазване")
("both versions" "и двете версии")
("bottom baseline" "долната базова линия")
("bottom cell border" "долната граница на клетката")
("bottom cell padding" "подложка от долната клетка")
("bottom table border" "долна граница на таблицата")
("bottom table padding" "подложка за дъното")
("bottom tools" "дънни инструменти")
("box" "кутия")
("broken white" "счупено бяло")
("browse back" "преглед назад")
("browse forward" "сърфиране напред")
("browse modules documentation" "преглед на документацията за модули")
("buffer management" "управление на буфера")
("buffer must be on disk" "буфер трябва да е на диск")
("buffer must have a name" "буферът трябва да има име")
("build buffer" "буфер за изграждане")
("build buffer in" "изграждане на буфер в")
("build directory" "изграждане на директория")
("build directory in" "изграждане на директория в")
("build link pages" "създаване на връзки страници")
("build-all" "изграждане на всички")
("bump" "чука")
("busy" "заети")
("cJK" "cJK")
("cJK spacing" "cJK разстояние")
("calculus" "смятане")
("cancelled" "отменено")
("cannot download directory to file" "не може да изтеглите директория във файл")
("cannot rename across different servers" "не може да се преименува на различни сървъри")
("cannot upload directory to file" "Не мога да кача директория във файл")
("cartesian" "декартови")
("carved wood" "дърворезба")
("case-insensitive search" "нечувствително към регистър търсене")
("categories" "категории")
("category" "категория")
("cell properties" "свойства на клетките")
("cells" "клетки")
("change default unit" "промяна на единицата по подразбиране")
("change passphrase" "промяна на пропуск")
("change step-size" "промяна на стъпка размер")
("change tags" "промяна на маркери")
("change the TeXmacs preferences" "промяна на предпочитанията на TeXmacs")
("change the border of the table" "промяна на границата на таблицата")
("change the style of mathematical formulas" "променете стила на математическите формули")
("character contraction" "свиване на символите")
("character encoding" "кодиране на символи")
("character expansion" "разширение на знаците")
("check for updates" "проверка за актуализации")
("checkable field" "проверимо поле")
("cipher algorithm for passphrase encryption" "шифров алгоритъм за криптиране на парола")
("circle" "кръг")
("classification" "класификация")
("clean slate" "чист шисти")
("clear all fields" "изчистване на всички полета")
("clear local information" "ясна местна информация")
("clear menu" "изчистено меню")
("clear undo history" "изчистена история на отмяна")
("click Ok button twice to discard this warning" "щракнете върху бутона ОК два пъти, за да отхвърлите това предупреждение")
("clip" "клип")
("clipboard image format" "формат на изображението в клипборда")
("close animation tool" "инструмент за затваряне на анимация")
("close document" "затворен документ")
("close program" "програма за затваряне")
("close replace tool" "инструмент за затваряне на замяна")
("close search tool" "затвори инструмент за търсене")
("close spell tool" "инструмент за затваряне на правописа")
("close translations to rebuild" "затворени преводи за възстановяване")
("closed bezier" "затворен безир")
("closed curve" "затворена крива")
("closed smooth" "затворен гладък")
("closed spline" "затворен шплин")
("closing style" "стил на затваряне")
("cluster by affiliation" "клъстер по принадлежност")
("collect garbage" "събиране на боклук")
("collected keys" "събрани ключове")
("color of the axes" "цвят на осите")
("color of the subunits" "цвят на поделенията")
("color of the units" "цвят на единиците")
("colors" "цвята")
("column to the left" "колона вляво")
("column to the right" "колона вдясно")
("columns" "колони")
("column separation" "разделяне на колони")
("commit file" "файл за ангажиране")
("common" "общи")
("common formats" "общи формати")
("commutative diagram" "комутативна диаграма")
("compact" "компактен")
("compactification" "уплътняване")
("compactify" "уплътняване")
("complete bibliographic reference" "пълна библиографска справка")
("completion" "завършване")
("complex actions" "сложни действия")
("compose" "композиране")
("compound" "съединение")
("compress" "компрес")
("compress into toolbar" "компресиране в лентата с инструменти")
("compressed" "компресиран")
("conceal" "скриване")
("configure look and feel" "конфигуриране на външния вид и усещането")
("confirm database entry" "потвърждаване на запис в базата данни")
("confirm entry" "потвърди влизането")
("confirm selected database entries" "потвърди избраните записи в базата данни")
("confirm selected entries" "потвърди избраните записи")
("conservative conversion options" "консервативни опции за преобразуване")
("consoles" "конзоли")
("constellation" "съзвездие")
("contact" "контакт")
("content" "съдържание")
("context aids" "контекстни помагала")
("contextual hints" "контекстуални подсказки")
("continue" "продължи")
("continued fraction" "продължителна фракция")
("contour" "контур")
("contract logarithms" "договорни логаритми")
("contribute" "допринесе")
("control flow" "контролен поток")
("control the evaluation of expressions" "контрол на оценката на изразите")
("convert" "конвертиране")
("converters" "преобразуватели")
("convertible" "кабриолет")
("copyright" "авторски права")
("cork charset with TeX catcode definition in preamble" "коркова карта с определение на кода на TeX в преамбюла")
("correct" "правилно")
("correct all" "коригирайте всички")
("correct formula" "правилна формула")
("correct manually" "правилно ръчно")
("correct mathematical formulas" "правилни математически формули")
("correction" "корекция")
("cosine" "косинус")
("count characters" "брои знаци")
("count lines" "преброяване на редове")
("count words" "брои думи")
("create a new document" "създаване на нов документ")
("create link" "създаване на връзка")
("create preamble" "създаване на преамбюла")
("create remote directory" "създаване на отдалечена директория")
("create remote file" "създаване на отдалечен файл")
("create subprogram" "създаване на подпрограма")
("create subsession" "създаване на подсесия")
("create table macro" "създаване на макрос на таблицата")
("create web site" "създаване на уеб сайт")
("creating new account" "създаване на нов акаунт")
("creating technical pictures" "създаване на технически снимки")
("crop" "култура")
("crop marks" "маркировки на реколтата")
("cross" "кръст")
("crossed boxes" "кръстосани кутии")
("crossed circles" "кръстосани кръгове")
("current user version" "текуща потребителска версия")
("current version" "текуща версия")
("cursor" "курсор")
("curve" "крива")
("curve intersections" "криви кръстовища")
("curve points" "криви точки")
("customizations" "персонализиране")
("customizing and extending the user interface" "персонализиране и разширяване на потребителския интерфейс")
("dark grey" "тъмно сиво")
("data" "данни")
("database entry" "запис в база данни")
("database tool" "инструмент за база данни")
("database toolbar" "лента с инструменти на базата данни")
("deactivate once" "деактивиране веднъж")
("dead" "мъртви")
("debug" "грешка")
("debugging console" "конзола за отстраняване на грешки")
("debugging tool" "инструмент за отстраняване на грешки")
("decimal comma" "десетична запетая")
("decimal dot" "десетична точка")
("decomposed" "разложен")
("decorated" "украсени")
("decorated wood" "украсена дървесина")
("decrease size" "намаляване на размера")
("decrypt" "дешифриране")
("default size" "размер по подразбиране")
("degrade" "понижаване")
("degraded" "влошени")
("delete documentation cache" "изтриване на кеш на документацията")
("delete entries" "изтриване на записи")
("delete link" "изтриване на връзка")
("deleted" "изтрити")
("describe" "опишете")
("describe tag" "описване на маркер")
("destroy" "унищожи")
("detach master" "откъсващ майстор")
("detailed" "подробно")
("detailed menus" "подробни менюта")
("details in menus" "подробности в менютата")
("determine margins from text width" "определяне на маржовете от ширината на текста")
("developer" "разработчик")
("developer tool" "инструмент за разработчици")
("device" "устройство")
("diamond" "диамант")
("differentiate" "диференцирай")
("dilate" "дилатат")
("direction of progression" "посока на прогресия")
("direction of translation" "посока на превод")
("disable" "деактивиране")
("disable coloring on paper" "деактивиране на оцветяването на хартия")
("disable encryption" "деактивиране на криптирането")
("disappear" "изчезва")
("disk" "диск")
("display style" "стил на показване")
("displayed formula" "показана формула")
("dissociate joined cells" "дисоцииращи съединени клетки")
("distort" "изкривяване")
("distorted" "изкривени")
("division" "дивизия")
("do not remap" "не пренареждайте")
("document font selector" "избор на шрифт на документ")
("document language" "език на документа")
("document page format" "формат на страница с документи")
("document paragraph format" "формат на абзаца на документа")
("document updates run" "актуализации на документи стартират")
("download" "изтегляне")
("downwards" "надолу")
("dragging" "влачене")
("draw image" "нарисувайте изображение")
("draw over" "изтегляне над")
("draw over selection" "изтегляне на селекцията")
("drop" "капка")
("due to" "поради")
("dynamic" "динамичен")
("eRROR" "eRROR")
("edit animation" "редактиране на анимация")
("edit groups of objects" "редактиране на групи от обекти")
("edit macro" "редактиране на макрос")
("edit macros" "редактиране на макроси")
("edit preamble" "редактиране на преамбюла")
("edit source" "редактиране на източник")
("edit source tree" "редактиране на дърво на източника")
("edit style" "редактиране стил")
("edit translations file" "редактиране на преводния файл")
("education" "образование")
("effect pen" "писалка с ефект")
("eigenvalues" "собствени стойности")
("eighth" "осми")
("embold" "релеф")
("emboss" "релеф")
("enable page breaking" "разрешаване на разбиване на страници")
("encoding" "кодиране")
("encrypt" "криптиране")
("encryption" "криптиране")
("encryption facilities are not currently available" "средства за криптиране понастоящем не са налични")
("encryption facilities have not been enabled for TeXmacs" "Устройствата за криптиране не са активирани за TeXmacs")
("enforce brackets to match" "налагане на скоби за съвпадение")
("engrave" "гравиране")
("enter data" "въведете данни")
("enter graphics" "въведете графика")
("enter graphics mode" "влиза в графичен режим")
("enter new passphrase for encryption" "въведете нова парола за криптиране")
("enter passphrase for decryption" "въведете парола за декриптиране")
("enter passphrase for identity" "въведете парола за идентичност")
("enter title information" "въведете информация за заглавието")
("entire table" "цялата таблица")
("entry up to date in database" "актуализиране на данните в базата данни")
("enunciation" "изговор")
("environment variable" "променлива среда")
("environments" "среди")
("erode" "ерозира")
("error messages" "съобщения за грешка")
("error output" "изход за грешка")
("error status report" "доклад за състоянието на грешката")
("error: bracket does not match" "грешка: скобата не съвпада")
("error: cyclic or missing chunks detected" "грешка: циклични или липсващи парчета са открити")
("error: file not found" "грешка: файлът не е намерен")
("error: ghostview does not seem to be installed on your system" "грешка: изглежда, че ghostview не е инсталиран във вашата система")
("error: one of the alternatives should be filled out" "грешка: една от алтернативите трябва да бъде попълнена")
("error: only one alternatives should be filled out" "Грешка: трябва да бъдат попълнени само една алтернатива")
("error: should fill out name for referencing" "грешка: трябва да попълни име за препратка")
("error: should fill out required field" "грешка: трябва да попълните задължително поле")
("evaluable field" "поле за оценка")
("evaluate above" "оценка по-горе")
("evaluate all" "оцени всички")
("evaluate below" "оцени по-долу")
("evaluate fields" "оценка на полета")
("evaluate fields in order" "оценяване на полетата по ред")
("evaluate script" "оценка сценарий")
("evaluation" "оценка")
("evaluation switch" "превключвател за оценка")
("evaluation tag" "оценка")
("even page" "четна страница")
("even page left margin" "равномерно ляво поле")
("even page shift" "равномерна смяна на страници")
("even pages" "четни страници")
("events" "събития")
("exact" "точно")
("execution of scripts" "изпълнение на скриптове")
("exit graphics" "графика за излизане")
("exit graphics mode" "графичен режим на изход")
("exit left" "изход вляво")
("exit right" "изход вдясно")
("exit tag on the left" "изходен маркер отляво")
("exit tag on the right" "изходен маркер отдясно")
("expand TeXmacs macros with no LaTeX equivalents" "разгънете TeXmacs макроси без LaTeX еквиваленти")
("expand beamer slides" "разширяване на слайдове на гредата")
("expand inclusions" "разгъване на включвания")
("expand logarithms" "разширяване на логаритми")
("expand trigonometric functions" "разширяване на тригонометрични функции")
("expand unrecognized macros" "разширяване на неразпознати макроси")
("expand user-defined macros" "разширяване на дефинирани от потребителя макроси")
("expanded" "разширено")
("experimental features (to be used with care)" "експериментални функции (да се използват внимателно)")
("explain" "обясни")
("explanatory item" "обяснителен елемент")
("explicit keystroke" "изрично натискане на клавиш")
("explicit margins" "изрични маржове")
("exponential" "експоненциална")
("export bibliographies as links" "експортни библиографии като връзки")
("export bibliography" "експортна библиография")
("export entries in buffer" "експортни записи в буфер")
("export file" "експортен файл")
("export formulas as images" "експортни формули като изображения")
("export mathematical formulas as MathML" "експортиране на математически формули като MathML")
("export mathematical formulas as images" "експортиране на математически формули като изображения")
("export selected entries" "експортиране на избрани записи")
("export selection" "избор за износ")
("export selection as image" "избор на експорт като изображение")
("export selections as" "избор за износ като")
("export sessions" "експортни сесии")
("exported bibliographic entries" "изнесени библиографски записи")
("exported bibliographic references" "изнесени библиографски справки")
("extend" "удължаване")
("extended" "удължено")
("extensible left arrow" "разтегателна лява стрелка")
("extensible right arrow" "разтегателна дясна стрелка")
("extern" "екстерн")
("external" "външни")
("extra branch" "допълнителен клон")
("extra interline space" "допълнително междуредово пространство")
("extra name" "допълнително име")
("extract" "екстракт")
("extract style file" "файл за извличане на стил")
("extract style package" "пакет екстракти стил")
("factor" "фактор")
("fade" "избледняват")
("fade in" "избледняват")
("fade out" "избледняват")
("fast" "бързи")
("fast decrease" "бързо намаление")
("fast environments" "бързи среди")
("fast increase" "бързо увеличение")
("field reference" "справка в полето")
("fifth" "пети")
("file saved" "файлът е запазен")
("fill color" "цвят на запълване")
("fill out" "попълни")
("filter" "филтър")
("find file" "намери файл")
("finished collecting symbols documentation" "завършена документация за събиране на символи")
("first" "първи")
("first chunk" "първи парче")
("first difference" "първа разлика")
("first error" "първа грешка")
("first field" "първо поле")
("first occurrence" "първо възникване")
("first similar" "първи подобен")
("fit to screen" "годни за екран")
("fit to screen width" "годни за ширина на екрана")
("five columns" "пет колони")
("fixed" "фиксирани")
("flag is off" "флагът е изключен")
("flag is on" "флагът е включен")
("flatten" "сплескам")
("floating algorithm" "плаващ алгоритъм")
("floating phantom" "плаващ фантом")
("focus" "фокус")
("focus dependent icons" "фокусирани икони")
("fold all" "сгъване всички")
("fold all fields" "сгъване на всички полета")
("fold back" "сгъване назад")
("fold input field" "поле за въвеждане на сгъване")
("follow external links" "следвайте външни връзки")
("follow inverse links" "следвайте обратни връзки")
("font effects" "шрифтови ефекти")
("font selector" "избор на шрифт")
("font type" "тип шрифт")
("for each" "за всеки")
("force reloading of translations" "принудително презареждане на преводи")
("formatted and structured output" "форматиран и структуриран изход")
("formatting" "форматиране")
("forward" "напред")
("four columns" "четири колони")
("four dots" "четири точки")
("fourth" "четвърти")
("fraktur" "fraktur")
("framed" "в рамка")
("from" "от")
("from center" "от центъра")
("front matter" "предна част")
("full" "пълни")
("full author list" "пълен списък с автори")
("full screen mode" "режим на цял екран")
("functional" "функционални")
("gap" "празнина")
("garbage collection" "сметосъбиране")
("gaussian" "гаусски")
("gcd" "gcd")
("general" "общо")
("general note" "обща бележка")
("generated LaTeX document contains no errors" "генериран LaTeX документ не съдържа грешки")
("generated field" "генерирано поле")
("geometry" "геометрия")
("get arity" "получете arity")
("get label" "получи етикет")
("get list with remote versions" "получите списък с отдалечени версии")
("glyphs" "глифове")
("gnaw" "гризане")
("gnawed" "гризани")
("gnuPG command" "gnuPG команда")
("gnuPG error: buffer encryption failed" "gnuPG грешка: буферното криптиране не е успешно")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG грешка: не може да се намери подходящ секретен ключ за декриптиране")
("gnuPG requires name and email to have at least 5 characters" "gnuPG изисква име и имейл да имат поне 5 знака")
("go to anchor" "отидете на котва")
("go to anchor or float" "отидете на котва или поплавък")
("go to anchor or footnote" "отидете на котва или бележка под линия")
("go to first similar tag" "отидете на първия подобен маркер")
("go to float" "отиди да плаваш")
("go to footnote" "отидете на бележка под линия")
("go to last similar tag" "отидете на последния подобен маркер")
("go to next similar tag" "отидете на следващия подобен маркер")
("go to previous similar tag" "отидете на предишен подобен маркер")
("go to section" "отидете на раздел")
("grain" "зърно")
("granite" "гранит")
("graphical effects" "графични ефекти")
("graphical interface font scale" "скала на шрифта на графичния интерфейс")
("graphics" "графики")
("graphics geometry" "графична геометрия")
("graphics grids" "графични решетки")
("greyed" "сив")
("grid" "решетка")
("grid curves" "криви на мрежата")
("grid points" "мрежови точки")
("grid-curve intersections" "пресичания на крива на решетката")
("group of objects" "група от обекти")
("group/ungroup" "група / разгрупа")
("grouped" "групирани")
("guarantee transparent source tracking" "гарантирано прозрачно проследяване на източника")
("h modifier" "h модификатор")
("half wide" "наполовина широк")
("hand drawn" "нарисувана ръка")
("headers" "хедъри")
("hidden" "скрити")
("history" "история")
("homepage" "начална страница")
("homoglyph substitutions" "хомоглифни замествания")
("horizontal alignment" "хоризонтално подравняване")
("horizontal collapse distance" "разстояние от хоризонтално срутване")
("horizontal margins" "хоризонтални граници")
("hybrid command" "хибридна команда")
("hyphenate as" "тире като")
("icon" "икона")
("if hyphenated" "ако е с тире")
("ignore" "игнорирай")
("impact" "въздействие")
("import bibliography" "импортна библиография")
("import database entry" "въвеждане на база данни за импортиране")
("import entries in buffer" "вписвания за импортиране в буфер")
("import entry" "запис за внос")
("import file" "файл за импортиране")
("import selected database entries" "импортиране на избрани записи в базата данни")
("import selected entries" "импортиране на избрани записи")
("import selections as" "Избор на импортиране като")
("import sessions" "сесии за импортиране")
("import sophisticated objects as pictures" "импортиране на сложни обекти като снимки")
("imported bibliographic entries" "внесени библиографски записи")
("in popup windows" "в изскачащи прозорци")
("inanimated" "неодушевени")
("inch" "инча")
("incomplete entries found to be filled out" "намерени непълни записи са попълнени")
("increase size" "увеличаване на размера")
("indent paragraphs" "абзаци")
("indentation" "вдлъбнатина")
("indication" "индикация")
("informative flags" "информационни знамена")
("initialize" "инициализиране")
("ink here" "мастило тук")
("ink in" "мастило в")
("ink out" "изваждане с мастило")
("inline" "вградени")
("inline arguments" "вградени аргументи")
("inline code" "вграден код")
("inline content" "вградено съдържание")
("inline formula" "вградена формула")
("inner bottom" "вътрешно дъно")
("inner left" "вътрешна лява")
("inner right" "вътрешна дясна")
("inner top" "вътрешен връх")
("input command" "команда за въвеждане")
("input field" "поле за въвеждане")
("input mode" "режим на въвеждане")
("input options" "опции за въвеждане")
("insert a computer program" "поставете компютърна програма")
("insert a condition" "въведете условие")
("insert a control flow instruction" "вмъкнете инструкция за контролен поток")
("insert a gap" "вмъкнете празнина")
("insert a list" "вмъкване на списък")
("insert a multiple choice" "вмъкване на множество възможности за избор")
("insert a negation" "вмъкване на отрицание")
("insert a new entry" "вмъкване на нов запис")
("insert a note or a floating object" "вмъкване на бележка или плаващ обект")
("insert a numerical operation" "вмъкнете числова операция")
("insert a prominent piece of text" "вмъкнете видно парче текст")
("insert a question" "вмъкване на въпрос")
("insert a root" "вмъкване на корен")
("insert a script" "вмъкване на скрипт")
("insert a section block" "вмъкнете блок от секции")
("insert a textual operation" "вмъкнете текстова операция")
("insert a textual operator" "вмъкване на текстов оператор")
("insert a wide symbol above" "поставете широк символ отгоре")
("insert a wide symbol below" "поставете широк символ отдолу")
("insert above" "вмъкнете по-горе")
("insert abstract" "вмъкване на абстракт")
("insert an answer" "вмъкни отговор")
("insert an enunciation" "вмъкване на изказване")
("insert an operation on tuples" "вмъкване на операция върху кортежи")
("insert annotation" "вмъкване на пояснение")
("insert author" "вмъкване на автор")
("insert below" "вмъкнете по-долу")
("insert copyright and license information" "вмъкване на информация за авторското право и лиценза")
("insert explanatory item" "вмъкнете обяснителен елемент")
("insert field above" "вмъкване на полето по-горе")
("insert field below" "вмъкване на полето по-долу")
("insert fields" "вмъкване на полета")
("insert input field above" "въведете поле за въвеждане над")
("insert input field below" "въведете поле за въвеждане отдолу")
("insert large delimiters" "поставете големи разделители")
("insert last name" "вмъкни фамилно име")
("insert left" "вмъкване вляво")
("insert macro" "вмъкване на макрос")
("insert missing invisible operators" "вмъкнете липсващи невидими оператори")
("insert more names" "вмъкване на още имена")
("insert particle" "поставете частица")
("insert plain text" "вмъкване на обикновен текст")
("insert right" "вмъкване вдясно")
("insert similar above" "вмъкнете подобно по-горе")
("insert similar below" "вмъкнете подобно по-долу")
("insert similar block above" "поставете подобен блок по-горе")
("insert similar block below" "вмъкнете подобен блок отдолу")
("insert subtable" "вмъкване на подтаблица")
("insert symbol documentation" "вмъкване на символна документация")
("insert template" "вмъкване на шаблон")
("insert text field" "вмъкване на текстово поле")
("insert text field above" "вмъкване на текстово поле отгоре")
("insert text field below" "вмъкнете текстово поле отдолу")
("insert title" "вмъкване на заглавие")
("insert title after name" "вмъкнете заглавие след име")
("insert user interface related markup" "вмъкване на маркировка, свързана с потребителски интерфейс")
("insert value" "вмъкване на стойност")
("inserting control points" "поставяне на контролни точки")
("integrate" "интегриране")
("interactive command" "интерактивна команда")
("interactive questions" "интерактивни въпроси")
("intercharacter compression" "междучастово компресиране")
("intercharacter stretching" "междучастово разтягане")
("interrupted" "прекъснато")
("invalid multi-paragraph selection" "невалиден избор на много абзаци")
("invalid renaming" "невалидно преименуване")
("invert" "инвертиране")
("inverted breve" "обърнат брев")
("invisible ending" "невидим завършек")
("invisible newline" "невидим нов ред")
("invisible opening" "невидим отвор")
("join selected cells" "присъединяване към избрани клетки")
("jump in" "скок в")
("junior" "младши")
("keep evaluated expressions" "запазване на оценяваните изрази")
("keep local" "запази местно")
("keep remote" "запази дистанционно")
("keep track of source code" "проследяване на изходния код")
("keep unfolded" "дръжте разгъната")
("keyboard configuration" "конфигурация на клавиатурата")
("keyboard shortcut" "клавишна комбинация")
("laptop presentations" "презентации за лаптопи")
("large cells" "големи клетки")
("large displayed" "големи показани")
("large displayed fraction" "голяма показана фракция")
("large tables" "големи маси")
("last" "последен")
("last difference" "последна разлика")
("last error" "последна грешка")
("last field" "последно поле")
("last name" "фамилия")
("last occurrence" "последно събитие")
("last similar" "последен подобен")
("lcm" "lcm")
("left arrow" "лява стрелка")
("left axis" "лява ос")
("left baseline" "лява основна линия")
("left bottom" "ляво дъно")
("left cell border" "граница на лявата клетка")
("left cell padding" "лява клетка подплънка")
("left center" "ляв център")
("left click: add point; Right click: undo" "ляв клик: добавяне на точка; десен бутон на мишката: отмяна")
("left click: finish; Right click: undo" "ляв клик: завършване; десен бутон: отмяна")
("left click: new object" "щракване с левия бутон: нов обект")
("left click: operate" "щракване с левия бутон: опериране")
("left down" "наляво надолу")
("left on even pages" "оставени на четни страници")
("left table border" "граница на лявата таблица")
("left table padding" "лява подложка за маса")
("left top" "ляв връх")
("left up" "наляво нагоре")
("left-right arrow" "стрелка наляво-надясно")
("leftwards" "наляво")
("let the environment float" "оставете околната среда да плава")
("light grey" "светлосиво")
("line breaking" "прекъсване на линии")
("line wrapping" "опаковане на линии")
("linear 2D" "линеен 2D")
("linear algebra" "линейна алгебра")
("lines around" "линии около")
("link image and copies as" "изображение за връзка и копира като")
("link image as" "изображение за връзка като")
("link mode" "режим на връзка")
("link to URL" "връзка към URL адрес")
("linking tool" "свързващ инструмент")
("live" "на живо")
("live input-output" "жив вход-изход")
("load help file" "зареждане на помощния файл")
("load remote file" "зареждане на отдалечен файл")
("loading" "зареждане")
("local entries" "местни записи")
("loci" "локуси")
("locus" "локус")
("locus rendering" "локусиране")
("logarithm" "логаритъм")
("logarithmic" "логаритмични")
("logarithmic base" "логаритмична основа")
("logarithms" "логаритми")
("logging in" "влизане")
("logical and" "логични и")
("logical implication" "логическо значение")
("logical not" "логично не")
("logical or" "логично или")
("login" "влизане")
("logout" "излизане")
("long macro" "дълъг макрос")
("long text" "дълъг текст")
("look for more fonts" "търси повече шрифтове")
("loops" "бримки")
("m modifier" "m модификатор")
("macro argument" "макро аргумент")
("macro definition" "макроопределение")
("macro name" "име на макрос")
("macros" "макроси")
("magnify horizontally" "увеличаване хоризонтално")
("magnify vertically" "увеличете вертикално")
("main presentation style" "основен стил на представяне")
("make a letter environment" "направи буквена среда")
("make a multi-slide presentation" "направи мулти-слайд презентация")
("make floating" "направи плаващ")
("make link" "направи връзка")
("make non floating" "направи неплаващ")
("manila paper" "манила хартия")
("map arguments" "аргументи на картата")
("marginal note" "пределна нота")
("margins from width" "полета от ширина")
("margins on paper" "маржове на хартия")
("margins on screen" "маржове на екрана")
("marked" "маркирани")
("material" "материал")
("mathematical and customized input" "математически и персонализиран вход")
("mathematical font" "математически шрифт")
("mathematical input" "математически вход")
("mathematical output" "математически изход")
("matrices" "матрици")
("maximal" "максимално")
("maximal cell height" "максимална височина на клетката")
("maximal clustering" "максимално групиране")
("maximal table height" "максимална височина на масата")
("maximal table width" "максимална ширина на масата")
("maximum" "максимум")
("meander" "меандър")
("memory" "памет")
("memory usage" "използване на паметта")
("menu" "меню")
("merge lines into paragraphs unless separated by blank lines" "линии за сливане в абзаци, освен ако не са разделени с празни редове")
("messages" "съобщения")
("meta data" "метаданни")
("metadata" "метаданни")
("metal" "метал")
("middle baseline" "средна базова линия")
("minimal" "минимален")
("minimal cell height" "минимална височина на клетката")
("minimal cell width" "минимална ширина на клетката")
("minimal line separation" "минимално разделяне на линии")
("minimal table height" "минимална височина на масата")
("minimal table width" "минимална ширина на масата")
("minimum" "минимум")
("mirror" "огледало")
("miscellaneous features" "различни функции")
("miscellanous" "разни")
("mode dependent icons" "икони, зависими от режим")
("modify remote live document" "промяна на отдалечен документ на живо")
("module" "модул")
("monospaced" "еднократно")
("more information about GNU TeXmacs can be found in the Help" "повече информация за GNU TeXmacs може да намерите в Помощта")
("more information about GNU TeXmacs can be found in the Help->About menu" "повече информация за GNU TeXmacs може да намерите в менюто Помощ-> За нас")
("motion" "движение")
("mouse over object" "мишка над обект")
("move" "ход")
("move objects" "преместване на обекти")
("move over object on which to operate" "преместване върху обект, върху който да се работи")
("multiline" "многоредови")
("multiline input" "многоредов вход")
("multiple choice" "множествен избор")
("multiple root" "множество корен")
("multiplication" "умножение")
("mutator tags" "маркери за мутатори")
("my documents" "моите документи")
("navigation options" "опции за навигация")
("never" "никога")
("new account" "нов акаунт")
("new bibliography dialogue" "нов библиографски диалог")
("new document" "нов документ")
("new double page" "нова двойна страница")
("new double page before" "нова двойна страница преди")
("new entry" "нов запис")
("new identity" "нова идентичност")
("new locus" "нов локус")
("new macro" "нов макрос")
("new passphrase" "нова парола")
("new remote directory" "нова отдалечена директория")
("new remote file" "нов отдалечен файл")
("new style fonts" "шрифтове в нов стил")
("new style page breaking" "разбиване на нова страница в стил")
("new version" "нова версия")
("new window" "нов прозорец")
("newer version" "по-нова версия")
("next" "следващ")
("next chunk" "следващ парче")
("next difference" "следваща разлика")
("next error" "следваща грешка")
("next field" "следващо поле")
("next occurrence" "следващо събитие")
("next screen" "следващ екран")
("next similar" "следващ подобен")
("no clustering" "няма групиране")
("no completions" "без допълнения")
("no errors have been corrected" "грешки не са коригирани")
("no grid" "без решетка")
("no matches found for" "не са намерени съвпадения за")
("no new public key in document" "няма нов публичен ключ в документа")
("no page break" "няма прекъсване на страницата")
("no page numbers" "няма номера на страници")
("no parent" "няма родител")
("no selection" "без избор")
("no spelling errors" "няма правописни грешки")
("normal loci" "нормални локуси")
("not allowed to remove home directory" "не е позволено да премахнете домашната директория")
("not connected to server" "не е свързан със сървъра")
("not yet implemented" "все още не е приложено")
("notebook" "тетрадка")
("number of polar steps" "брой полярни стъпки")
("number of subunit steps" "брой стъпки на подединица")
("numbering" "номериране")
("numeric spreadsheet" "числова електронна таблица")
("odd page" "странна страница")
("odd page left margin" "ляв марж с нечетна страница")
("odd page right margin" "десен марж на нечетната страница")
("odd page shift" "странна смяна на страници")
("odd pages" "странни страници")
("of fingerprint" "от пръстов отпечатък")
("old version" "стара версия")
("older version" "по-стара версия")
("on the footer" "в долния колонтитул")
("on your system and set it up from the \"Security\" tab" "във вашата система и го настройте от раздела \x12Защита\x10")
("one column" "една колона")
("one error has been corrected" "една грешка е коригирана")
("one lower case letter, one non alpha-numeric symbol" "една малка буква, един не буквено-цифров символ")
("one numeric character, one upper case letter" "един цифров символ, една главна буква")
("only convert changes when re-importing" "конвертира промените само при повторно импортиране")
("only convert changes with respect to imported version" "конвертира само промени по отношение на внесената версия")
("only convert changes with respect to tracked version" "конвертира само промени по отношение на проследена версия")
("only implemented for complete subtrees" "внедрено само за пълни подредове")
("only inline tags" "само вградени маркери")
("only keep folded" "поддържайте само сгънати")
("only keep unfolded" "само да се разгъва")
("only show semantic focus" "показват само семантичен фокус")
("opacity" "непрозрачност")
("open bibliography" "отворена библиография")
("open identities" "отворени идентичности")
("open in new window" "отвори в нов прозорец")
("open key manager" "мениджър на отворени ключове")
("open licence agreement" "отворено лицензионно споразумение")
("open mailbox" "отворена пощенска кутия")
("open module browser" "браузър с отворен модул")
("open symbol browser" "браузър за отворени символи")
("open tool in separate window" "отворен инструмент в отделен прозорец")
("operation mode" "режим на работа")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "или дайте пълния път на командата \x12gpg\x10 или \x12gpg2\x10")
("order" "поръчка")
("ordinary symbol" "обикновен символ")
("ornamented" "орнаментирани")
("other login" "друго влизане")
("other package" "друг пакет")
("outer bottom" "външно дъно")
("outer left" "външна лява")
("outer right" "външна дясна")
("outer top" "външен връх")
("outline" "контур")
("outlined" "очертани")
("outlined emboss" "очертан релеф")
("outlined engrave" "очертана гравюра")
("output options" "опции за изход")
("oval" "овални")
("overbrace" "свръхбрейс")
("overlap" "припокриване")
("overlay" "наслагване")
("overlays" "наслагвания")
("overline" "преобличане")
("overlined" "подчертани")
("overview of the scheme extension language" "преглед на езика за разширение на схемата")
("padded" "подплатени")
("page background" "фон на страницата")
("page break after" "прекъсване на страницата след")
("page breaking algorithm" "алгоритъм за разбиване на страници")
("page number" "номер на страницата")
("page number rendering" "изобразяване на номер на страница")
("page rendering" "изобразяване на страница")
("page setup" "настройка на страницата")
("palette" "палитра")
("panorama" "панорама")
("paragraphs" "параграфи")
("parametric curve" "параметрична крива")
("parametric surface" "параметрична повърхност")
("parenthesis" "скоби")
("parenthesized" "поставени в кръг")
("particle" "частица")
("passphrase encryption" "криптиране на парола")
("passphrase wallet facilities are not currently available" "средства за портфейл с парола понастоящем не са налични")
("passphrases are expected to have at least: 8 characters" "парола се очаква да съдържа най-малко: 8 знака")
("passphrases mismatch" "несъответствие на паролите")
("pastel" "пастел")
("pattern" "модел")
("pause" "пауза")
("pen width" "ширина на писалката")
("permanent footer" "перманентно подножие")
("permanent header" "постоянна глава")
("permanently add to dictionary" "за постоянно добавяне в речника")
("permanently insert into dictionary" "постоянно вмъкване в речника")
("permissions" "разрешения")
("phantom" "фантом")
("phantoms" "фантоми")
("physics and astronomy class" "клас по физика и астрономия")
("picture" "снимка")
("pine" "бор")
("plain" "обикновен")
("plain boxes" "обикновени кутии")
("plain circles" "обикновени кръгове")
("play" "игра")
("play animation" "възпроизвеждане на анимация")
("please install GnuPG software from https://www.gnupg.org" "моля инсталирайте GnuPG софтуер от https://www.gnupg.org")
("plot" "парцел")
("plug-ins" "приставки")
("plugin" "плъгин")
("plugins" "плъгини")
("plural" "множествено число")
("point" "точка")
("polar" "полярни")
("polygon" "многоъгълник")
("pop server settings" "настройки на поп сървъра")
("position of marginal note" "позиция на пределна нота")
("poster formats" "формати за плакати")
("poster theme" "тема на плаката")
("postfix" "постфикс")
("preferences for editing mathematical formulas" "предпочитания за редактиране на математически формули")
("preferences for tag" "предпочитания за маркер")
("prefix" "префикс")
("presentation" "презентация")
("presentation tag" "презентационен маркер")
("presentation tool" "инструмент за представяне")
("preserve" "резерват")
("preserve tags" "запазване на маркери")
("pretty tree output" "доста дървесни резултати")
("preview" "визуализация")
("preview command" "команда за преглед")
("previous" "предишен")
("previous difference" "предишна разлика")
("previous error" "предишна грешка")
("previous field" "предишно поле")
("previous occurrence" "предишно възникване")
("previous screen" "предишен екран")
("previous similar" "предишен подобен")
("primitive or macro" "примитивни или макро")
("print buffer" "буфер за печат")
("print buffer to file" "буфер за печат във файл")
("print to file" "отпечатване във файл")
("printer setup" "настройка на принтера")
("program bracket matching" "съвпадение на скоби на програмата")
("program bracket selections" "избор на програмни скоби")
("program commands" "програмни команди")
("program font" "шрифт на програмата")
("program interface for buffer management" "програмен интерфейс за управление на буфер")
("programming routines for editing documents" "програмиране на програми за редактиране на документи")
("prominent" "видни")
("prompts and default input" "подкани и въвеждане по подразбиране")
("provoke C++ error" "провокира C ++ грешка")
("provoke menu error" "провокира грешка в менюто")
("provoke scheme error" "провокира грешка в схемата")
("pseudo code" "псевдо код")
("public key encryption" "криптиране с публичен ключ")
("public keys" "публични ключове")
("pulse" "пулс")
("qt GUI only, sorry. Use \"Export selection\"" "само qt GUI, съжалявам. Използвайте \x12Експорт на избор\x10")
("qt-widgets" "qt-widgets")
("quantifier" "количествен показател")
("quasi" "квази")
("question" "въпрос")
("questions only" "само въпроси")
("questions with answers" "въпроси с отговори")
("quick evaluation of formulas" "бърза оценка на формули")
("rank" "ранг")
("raw" "сурови")
("really delete user identity" "наистина изтриване на самоличността на потребителя")
("really tiny" "наистина мънички")
("rebuild translations file" "файл за възстановяване на преводи")
("recent" "скорошни")
("recent documents" "скорошни документи")
("recipients" "получатели")
("recognize" "разпознаване")
("recover autosave file" "възстановяване на автоматично запазване на файла")
("rectangular" "правоъгълни")
("reduce" "намаление")
("reduce trigonometric functions" "намаляване на тригонометричните функции")
("reduced margins" "намалени маржове")
("reference guide" "справочник")
("reference guide for the TeXmacs primitives" "справочник за примитивите на TeXmacs")
("reference guide for the standard TeXmacs styles" "справочно ръководство за стандартните стилове на TeXmacs")
("regenerate" "регенерира")
("register file" "регистър файл")
("relate" "отношение")
("relation" "връзка")
("release left button: finish editing" "пуснете левия бутон: завършете редактирането")
("remote" "дистанционно")
("remote connections" "отдалечени връзки")
("remote control" "дистанционно управление")
("remote controllers with keyboard simulation" "дистанционни контролери с симулация на клавиатура")
("remote directory" "отдалечена директория")
("remote servers" "отдалечени сървъри")
("remote tool" "дистанционен инструмент")
("remove" "премахване")
("remove all output fields" "премахване на всички изходни полета")
("remove banner" "премахване на банер")
("remove database entry" "премахване на запис в базата данни")
("remove downwards" "премахване надолу")
("remove entries" "премахване на записи")
("remove entry" "премахване на запис")
("remove field above" "премахване на полето по-горе")
("remove field below" "премахване на полето по-долу")
("remove fields" "премахване на полета")
("remove folded" "премахване на сгънато")
("remove input field" "премахване на поле за въвеждане")
("remove input field above" "премахване на полето за въвеждане отгоре")
("remove last field" "премахване на последното поле")
("remove leftwards" "премахване наляво")
("remove link" "премахване на връзка")
("remove next field" "премахване на следващото поле")
("remove package" "премахване на пакета")
("remove previous field" "премахване на предишното поле")
("remove rightwards" "премахване надясно")
("remove selected database entries" "премахване на избрани записи в базата данни")
("remove selected entries" "премахване на избрани записи")
("remove superfluous invisible operators" "премахване на излишни невидими оператори")
("remove tag" "премахване на маркер")
("remove this branch" "премахване на този клон")
("remove unfolded" "премахване на разгъната")
("remove upwards" "премахване нагоре")
("removed entries from database" "премахнати записи от базата данни")
("removed entry from database" "премахнат запис от базата данни")
("rename" "преименуване")
("rename section" "преименуване на раздел")
("repeat" "повторение")
("replace TeXmacs styles with no LaTeX equivalents" "замени стилове на TeXmacs без LaTeX еквиваленти")
("replace all further occurrences" "замени всички по-нататъшни събития")
("replace one occurrence" "замени едно събитие")
("replace toolbar" "замяна на лентата с инструменти")
("replace unrecognized styles" "замени неразпознати стилове")
("reset error counters" "нулиране броячи на грешки")
("resize" "преоразмеряване")
("resize objects" "преоразмеряване на обекти")
("restart TeXmacs in order to let changes take effect" "рестартирайте TeXmacs, за да оставите промените да влязат в сила")
("restart in order to let the new look and feel take effect" "рестартиране, за да може новият облик да влезе в сила")
("retain" "запазване")
("retime" "ретима")
("retina settings" "настройки на ретината")
("retrieve email" "извличане на имейл")
("retrieve remote live document" "извличане на отдалечен документ на живо")
("retrieved contents" "извлечено съдържание")
("reverse" "обратен")
("reverse ordering" "обратна поръчка")
("ridged paper" "релефна хартия")
("right arrow" "стрелка надясно")
("right baseline" "дясна базова линия")
("right cell border" "дясна граница на клетката")
("right cell padding" "дясна подложка за клетка")
("right down" "право надолу")
("right on even pages" "точно на четни страници")
("right table border" "дясна граница на таблицата")
("right table padding" "десен накладки за маса")
("right up" "вдясно")
("rightwards" "вдясно")
("rigid box" "твърда кутия")
("rotate" "завъртане")
("rotate objects" "завъртане на обекти")
("rough" "груб")
("rough paper" "груба хартия")
("round" "кръг")
("round overbrace" "кръгла свръхчестота")
("round underbrace" "кръгло подкожие")
("row above" "ред отгоре")
("row below" "ред отдолу")
("rows" "редове")
("run" "бягане")
("run current file" "стартиране на текущия файл")
("same names" "същите имена")
("same screen margins as on paper" "същите полета на екрана като на хартия")
("sample text" "примерен текст")
("save auxiliary data" "запазване на спомагателни данни")
("save entries" "запазване на записи")
("save entry" "запазване на записа")
("save image as" "запазване на изображението като")
("save position" "запазване на позиция")
("save remote file" "запазване на отдалечен файл")
("saved modifications in database" "запазени модификации в базата данни")
("scheme command" "командна схема")
("scheme developers guide" "Ръководство за разработчици на схеми")
("scheme extensions" "разширения на схемата")
("scheme interface for the graphical mode" "интерфейс на схемата за графичния режим")
("screen" "екран")
("screen rendering" "изобразяване на екрана")
("screens" "екрана")
("screenshot" "екранна снимка")
("scripting language" "скриптов език")
("scripts" "скриптове")
("search and replace" "търсене и замяна")
("search results for" "резултати от търсенето за")
("search toolbar" "лента с инструменти за търсене")
("search words in my documents" "думи за търсене в документите ми")
("search words in the documentation" "думи за търсене в документацията")
("search words in the source code" "думи за търсене в изходния код")
("second" "секунда")
("secret keys" "секретни ключове")
("sections" "секции")
("see documentation" "виж документация")
("select pen" "изберете химикалка")
("select the action to be undertaken for each conflict" "изберете действието, което ще се предприеме за всеки конфликт")
("select view mode" "изберете режим на изглед")
("semantic correctness" "семантична коректност")
("semantic editing" "семантична редакция")
("semantic selections" "семантични селекции")
("semantics" "семантика")
("sending commands to TeXmacs" "изпращане на команди към TeXmacs")
("senior" "старши")
("serif" "сериф")
("server" "сървър")
("session commands" "командни сесии")
("set default" "задаване по подразбиране")
("set difference" "зададена разлика")
("set intersection" "зададено кръстовище")
("set number of columns" "задаване на броя колони")
("set number of rows" "задаване на брой редове")
("set or get environment variables" "задайте или вземете променливи в средата")
("set properties" "задаване на имоти")
("set union" "набор съюз")
("set user information" "задаване на информация за потребителя")
("seventh" "седма")
("several equations" "няколко уравнения")
("shadow" "сянка")
("shadowed" "в сянка")
("shadowed raise" "вдигнат в сянка")
("shift" "смяна")
("short" "къса")
("show all parts" "покажи всички части")
("show current focus" "показване на текущия фокус")
("show full context" "показване на целия контекст")
("show hidden" "покажи скрито")
("show key presses" "показване на натискане на клавиши")
("show main document" "покажи основния документ")
("show memory usage" "показване на използването на паметта")
("show one part" "покажи една част")
("show panorama" "покажи панорама")
("show preamble" "показване на преамбюла")
("show several parts" "покажи няколко части")
("show subunits" "показване на субединици")
("show table cells" "показване на клетките на таблицата")
("show timings" "показване на времето")
("side tools" "странични инструменти")
("simple" "прости")
("simplification" "опростяване")
("simplified evaluation of formulas" "опростена оценка на формули")
("simplified menus" "опростени менюта")
("simplify" "опростяване")
("sine" "синус")
("sixth" "шести")
("size tag" "размер размер")
("skew" "коси")
("skip all" "пропуснете всички")
("slant" "наклон")
("slashed fraction" "нарязана фракция")
("slides" "слайдове")
("slovene" "словенско")
("slow" "бавно")
("slow decrease" "бавно намаляване")
("slow increase" "бавно увеличение")
("small capitals" "малки столици")
("small environment box" "малка кутия за околната среда")
("small focus" "малък фокус")
("small inline" "малки вградени")
("small inline fraction" "малка вградена фракция")
("smash" "разбиване")
("smooth" "гладка")
("smooth end" "гладък край")
("smooth extremities" "гладки крайници")
("smooth start" "плавен старт")
("snap" "щракване")
("snap distance" "разстояние за щракване")
("snap to curves" "щракване към криви")
("snap to grid" "щракване към мрежа")
("snap to grid curve" "крива на мрежата")
("snap to intersections of curves" "щракване към кръстовищата на кривите")
("snap to text borders" "щракване към текстови граници")
("snap to text corners" "щракване към ъглите на текста")
("solution" "разтвор")
("solution to exercise" "решение за упражняване")
("solution to problem" "решение на проблема")
("solutions" "решения")
("sound" "звук")
("source" "източник")
("source macros tool" "инструмент за макроси на източник")
("source tags" "изходни маркери")
("south" "юг")
("south east" "югоизток")
("space bar in math mode" "интервал в математически режим")
("space bar in text mode" "интервал в текстов режим")
("space stretchability" "разтегливост на пространството")
("span" "педя")
("span over all columns" "обхват над всички колони")
("special functions" "специални функции")
("special properties" "специални свойства")
("specific baseline" "специфична базова линия")
("specify color alternation" "посочете редуване на цвета")
("specify how to traverse the manual" "посочете как да преминете ръководството")
("specify semantics of a symbol or formula" "посочете семантика на символ или формула")
("specify the size of the table" "посочете размера на таблицата")
("spell check" "проверка на правописа")
("spline" "шплин")
("split program" "сплит програма")
("split session" "разделена сесия")
("square" "квадрат")
("square overbrace" "квадратна свръхбручка")
("square underbrace" "квадратна подложка")
("stack" "стека")
("standard" "стандарт")
("standard Output" "стандартен изход")
("standard TeXmacs styles" "стандартни стилове TeXmacs")
("standard environment variables" "стандартни променливи на средата")
("standard formats" "стандартни формати")
("standard fraction" "стандартна фракция")
("star" "звезда")
("start server" "стартов сървър")
("statement" "изявление")
("statistics" "статистика")
("status" "статус")
("stop server" "стоп сървър")
("storage" "хранилище")
("store tracking information in LaTeX files" "съхраняване на информация за проследяване във файлове на LaTeX")
("stretch" "участък")
("stretch factor" "коефициент на разтягане")
("stretched" "опъната")
("strict Ascii" "строг Асий")
("strike through" "стачка")
("structured insert above" "структурирана вмъкване отгоре")
("structured insert at the left" "структурирана вложка отляво")
("structured insert at the right" "структурирана вложка отдясно")
("structured insert below" "структурирана вмъкване отдолу")
("structured remove downwards" "структурирано премахване надолу")
("structured remove leftwards" "структурирано премахване наляво")
("structured remove rightwards" "структурирано премахване надясно")
("structured remove upwards" "структурирано премахване нагоре")
("structured variant" "структуриран вариант")
("style options" "опции за стил")
("style parameters" "параметри на стил")
("stylesheet language" "език на таблицата за стилове")
("subject" "предмет")
("submenu" "подменю")
("subscript below" "подпис отдолу")
("subsubmenu" "подменю")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "подтаблица")
("subtitle" "субтитри")
("subtraction" "изваждане")
("summarized" "обобщен")
("superscript above" "суперскрипт по-горе")
("supported plug-ins" "поддържани приставки")
("surface" "повърхност")
("inflate" "набъбване")
("swiss" "швейцарска")
("switch to buffer" "превключване към буфер")
("symbol properties not found" "свойства на символа не са намерени")
("symbols" "символа")
("synchronize" "синхронизиране")
("synchronize bibliographic references" "синхронизиране на библиографски справки")
("synchronize with remote server" "синхронизиране с отдалечен сървър")
("synopsis" "синопсис")
("system command" "системна команда")
("tab-completion" "попълване на раздела")
("tabbed" "раздела")
("table breaking" "разбиване на маса")
("table height" "височина на масата")
("table properties" "свойства на таблицата")
("table width" "ширина на масата")
("tags with special rendering" "тагове със специално изобразяване")
("tangent" "допирателна")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Очаква се буфер TeXmacs")
("teXmacs buffer on disk expected" "Очаква се буфер TeXmacs на диска")
("teXmacs extensions to scheme and utilities" "разширения на TeXmacs към схема и комунални услуги")
("teXmacs macro" "макрос на TeXmacs")
("teXmacs package" "пакет TeXmacs")
("teXmacs plugins" "teXmacs приставки")
("teXmacs primitives" "примитиви на TeXmacs")
("teXmacs style" "стил TeXmacs")
("test routine" "тестова рутина")
("testing tree-view" "тестване на изглед към дърво")
("text borders" "граници на текста")
("text box style" "стил на текстовото поле")
("text corners" "текстови ъгли")
("textual" "текстови")
("textual operator" "текстов оператор")
("textual spreadsheet" "текстова електронна таблица")
("the TeXmacs format" "форматът на TeXmacs")
("the TeXmacs plug-in system" "приставката за TeXmacs")
("the document has not been saved" "документът не е запазен")
("theme parameters" "параметри на темата")
("these collected public keys will be definitely lost" "тези събрани публични ключове определено ще бъдат загубени")
("these public keys will be definitely lost" "тези публични ключове определено ще бъдат загубени")
("these secret keys will be definitely lost" "тези секретни ключове определено ще бъдат загубени")
("thicken" "сгъстявам")
("third" "трети")
("this" "това")
("this column" "тази колона")
("this page footer" "футера на тази страница")
("this page header" "тази заглавна страница на страницата")
("this page number" "този номер на страницата")
("this row" "този ред")
("this style specifies page margins in the TeX way" "този стил определя маржовете на страниците по начин TeX")
("three columns" "три колони")
("three dots" "три точки")
("through popup windows" "през изскачащи прозорци")
("through the menus" "през ​​менютата")
("thumbnails" "миниатюри")
("time evolution" "времева еволюция")
("timings" "тайминги")
("title presentation options" "опции за представяне на заглавие")
("title style" "стил на заглавието")
("title suffix" "наставка на заглавието")
("titled block" "заглавен блок")
("toggle cell wrapping mode" "превключване на режим на опаковане на клетки")
("toggle here" "превключване тук")
("toggle off" "превключване")
("toggle on" "включване")
("tolerant" "толерантен")
("top baseline" "горна основна линия")
("top cell border" "горна граница на клетката")
("top cell padding" "връхни клетки")
("top table border" "граница на горната маса")
("top table padding" "подплънки на горната маса")
("transform" "трансформация")
("transform cell into subtable" "трансформиране на клетка в подменяема")
("translations" "преводи")
("translations loaded" "преводите са заредени")
("transpose" "транспониране")
("traversal" "обход")
("traverse" "траверс")
("triangle" "триъгълник")
("triangularize" "триъгълник")
("trigonometric" "тригонометричен")
("trigonometry" "тригонометрия")
("turn off" "изключете")
("turn on" "включете")
("two columns" "две колони")
("two dots" "две точки")
("type a latex command followed by return" "въведете латексна команда, последвана от връщане")
("underbrace" "подбраз")
("underline" "подчертаване")
("underlined" "подчертано")
("unevaluated argument" "неоценен аргумент")
("unevaluated value" "неоценена стойност")
("unfold" "разгъване")
("unfold all" "разгънете всички")
("unfold all fields" "разгъване на всички полета")
("unit" "единица")
("unit length" "дължина на единица")
("unknown secret key fingerprint" "отпечатък на неизвестен секретен ключ")
("unregistered file" "нерегистриран файл")
("unroll" "разгръщане")
("unsecure script refused" "неосигурен скрипт е отказан")
("unsupported link mode" "неподдържан режим на връзка")
("until" "до")
("untitled block" "блок без име")
("up to date" "актуален")
("update buffer" "буфер за актуализация")
("update this buffer" "актуализиране на този буфер")
("update web site" "актуализиращ уеб сайт")
("upight" "изправяне")
("upload" "качване")
("upright" "изправено")
("upwards" "нагоре")
("use CSS for more advanced formatting" "използвайте CSS за по-разширено форматиране")
("use MathML" "използвайте MathML")
("use as master" "използване като главен")
("use extensible brackets" "използвайте разтегателни скоби")
("use line wrapping for lines which are longer than 80 characters" "използвайте опаковане на линии за линии, които са по-дълги от 80 знака")
("use margin kerning (protrusion)" "използване на марджин кернинг (изпъкналост)")
("use protrusion" "използвайте изпъкналост")
("use relative path" "използва относителна пътека")
("user interface" "потребителски интерфейс")
("user interface language" "език на потребителския интерфейс")
("user preferences" "предпочитания на потребителите")
("users of Cyrillic languages" "потребители на кирилица")
("users of oriental languages" "потребители на ориенталски езици")
("utf-8 with inputenc LaTeX package" "utf-8 с пакет inputenc LaTeX")
("utilities" "комунални услуги")
("vanish" "изчезва")
("verbose" "многословен")
("version" "версия")
("versioning tool" "инструмент за версия")
("vertical alignment" "вертикално подравняване")
("vertical margins" "вертикални полета")
("vertical space after" "вертикално пространство след")
("vertical space before" "вертикално пространство преди")
("vertical space stretchability" "вертикална разтегливост на пространството")
("visible except here" "видимо, освен тук")
("visible from here on" "видимо от тук нататък")
("visible only here" "видимо само тук")
("visible until here" "видимо до тук")
("visited loci" "посетени локуси")
("wallet" "портфейл")
("wave" "вълна")
("web" "уеб")
("weight" "тегло")
("when line wrapping" "при опаковане на линии")
("whitespace" "бяло пространство")
("wide" "широк")
("wide bar" "широка лента")
("wide block" "широк блок")
("wide colored" "широкоцветни")
("wide float" "широк поплавък")
("wide footnote" "широка бележка под линия")
("wide tabular" "широк табличен")
("widescreen" "широкоекранен")
("wrap lines" "опаковъчни линии")
("write a macro" "напишете макрос")
("writing TeXmacs bibliography styles" "писане на библиографски стилове на TeXmacs")
("writing documentation" "писмена документация")
("written with TeXmacs" "написано с TeXmacs")
("wrong empty passphrase" "грешна празна парола")
("wrong passphrase" "грешна парола")
("year" "година")
("you are attempting to open an encrypted file while" "се опитвате да отворите криптиран файл, докато")
("you might consider enabling the experimental" "може да помислите за активиране на експерименталния")
("you must add a bibliography file" "трябва да добавите библиографски файл")
("you should also make sure that GnuPG is installed" "вие също трябва да се уверите, че GnuPG е инсталиран")
("your language" "вашият език")
("your personal dictionary has been modified" "личният ви речник е променен")
("zoom" "увеличение")
("zoom in" "увеличение")
("zoom out" "намаляване")
