("\"encryption\" features from the preference panel" "\"kryptering\" funktioner fra indstillingspanelet")
("(Re)Build autocompletion index" "(Re) Build autocompletion index")
("a.C.M. computing class" "a.C.M. computing class")
("a.M.S. subject class" "a.M.S. fagklasse")
("abbreviated authors" "forkortede forfattere")
("abreviated authors" "forkortede forfattere")
("accent above" "accent ovenfor")
("accent below" "accent nedenfor")
("accept during this pass" "accepter under dette pass")
("acknowledgments" "kvitteringer")
("active link types" "aktive linktyper")
("add" "tilføj")
("add abstract information" "tilføj abstrakt information")
("add author information" "tilføj forfatteroplysninger")
("add branch after" "tilføj gren efter")
("add branch before" "tilføj gren før")
("add other package" "tilføj anden pakke")
("add style package" "tilføj stilpakke")
("add title information" "Tilføj titeloplysninger")
("addition" "tilføjelse")
("adjust" "juster")
("adjust limits" "juster grænser")
("advanced font customization" "avanceret skrifttilpasning")
("affiliation" "tilknytning")
("align cell to the decimal comma" "juster celle efter decimal komma")
("align cell to the decimal dot" "juster celle efter decimalprikken")
("align table at axis" "Juster tabel ved akse")
("alignment of balloon" "justering af ballon")
("all cells" "alle celler")
("all data attached to this identity will be lost" "alle data, der er knyttet til denne identitet, vil gå tabt")
("all saved passphrases will be lost forever" "alle gemte adgangssætninger vil gå tabt for evigt")
("allow for macro definitions in preamble" "giver mulighed for makrodefinitioner i ingressen")
("allow multiple spaces" "tillad flere mellemrum")
("allow spurious spaces" "tillad falske mellemrum")
("allowed page height extension" "tilladt sidehøjdeudvidelse")
("allowed page height reduction" "tilladt sidehøjdebegrænsning")
("allowed positions" "tilladte positioner")
("allowed positions of floating object" "tilladte positioner af flydende objekt")
("alpha transparency" "alfa-gennemsigtighed")
("also on paper" "også på papir")
("alter" "ændre")
("alternate" "alternativ")
("alternate except here" "alternativ undtagen her")
("alternate from here on" "skiftevis fra her af")
("alternate only here" "kun alternativ her")
("alternate until here" "skiftevis indtil her")
("alternative colors" "alternative farver")
("always" "altid")
("amplified" "forstærket")
("ancient" "gamle")
("and perform casual settings from the \"Encryption\" tab" "og udfør afslappede indstillinger fra fanen \"Kryptering\"")
("animate" "animeret")
("animate folding" "animeret foldning")
("animate object" "animeret objekt")
("animate objects" "animerede objekter")
("animate unfolding" "animeret udfoldelse")
("animated" "animeret")
("animation" "animation")
("animation toolbar" "animationsværktøjslinje")
("annotate" "kommentar")
("answer" "svar")
("answer field" "svarfelt")
("answer to question" "svar på spørgsmål")
("answers only" "svarer kun")
("any" "hvilken som helst")
("appear" "vises")
("approximate" "omtrentlig")
("arc" "lysbue")
("arc cosine" "arc cosinus")
("arc sine" "bue sinus")
("arc tangent" "lysbue-tangens")
("are you sure you want to delete collected public keys" "er du sikker på, at du vil slette indsamlede offentlige nøgler")
("are you sure you want to delete selected public keys" "er du sikker på, at du vil slette valgte offentlige nøgler")
("are you sure you want to delete selected secret keys" "er du sikker på, at du vil slette valgte hemmelige nøgler")
("are you sure you want to destroy the wallet" "er du sikker på, at du vil ødelægge tegnebogen")
("art Pen" "kunstpen")
("art frame" "kunstramme")
("arxiv category" "arxiv kategori")
("as visual grid" "som visuelt gitter")
("aspect" "aspekt")
("attach master" "vedhæft master")
("attached" "vedhæftet")
("auto" "auto")
("auto-save file" "auto-gem fil")
("automatic brackets" "automatiske beslag")
("automatic content generation" "generering af automatisk indhold")
("automatic program brackets" "automatiske programbeslag")
("automatically import bibliographies when opening files" "importerer automatisk bibliografier ved åbning af filer")
("automatically remember all passphrases in the wallet" "husk automatisk alle adgangsfraser i tegnebogen")
("automatically save" "gemme automatisk")
("avoid spurious spaces" "undgå falske rum")
("axis" "akse")
("back" "tilbage")
("background picture selector" "valg af baggrundsbillede")
("backtrace errors" "fejl i tilbagetrækning")
("base" "base")
("baseline" "baseline")
("beamer" "beamer")
("beamer formats" "beamer-formater")
("beamer theme" "beamer-tema")
("bench" "bænk")
("bend bottom" "bøj bund")
("bend corner" "bøjningshjørne")
("bend diagonal" "bøjningsdiagonal")
("bend in" "bøj ind")
("bend out" "bøje ud")
("bezier" "bezier")
("bibTeX command" "bibTeX-kommando")
("bidirectional" "tovejs")
("big environment box" "stor miljøboks")
("big focus" "stort fokus")
("binary operator" "binær operatør")
("bitmap resolution (dpi)" "bitmapopløsning (dpi)")
("black floral I" "sort blomster I")
("black floral II" "sort blomster II")
("blackboard embold" "blackboard embold")
("blank column" "tom søjle")
("blank row" "blank række")
("block" "blok")
("block content" "blokere indhold")
("block of code" "blok af kode")
("blur" "sløret")
("both versions" "begge versioner")
("bottom baseline" "bundlinie")
("bottom cell border" "bundcellekant")
("bottom cell padding" "polstring af bundcelle")
("bottom table border" "nederste tabel kant")
("bottom table padding" "polstring under bordet")
("bottom tools" "bundværktøjer")
("box" "boks")
("browse back" "Gennemse tilbage")
("browse forward" "Gennemse fremad")
("browse modules documentation" "Gennemse dokumentationsmoduler")
("buffer management" "bufferstyring")
("buffer must be on disk" "buffer skal være på disk")
("buffer must have a name" "buffer skal have et navn")
("build buffer" "build buffer")
("build buffer in" "build buffer i")
("build directory" "build directory")
("build directory in" "build katalog i")
("build link pages" "build links sider")
("build-all" "build-all")
("bump" "ujævnhed")
("busy" "optaget")
("cJK" "cJK")
("cJK spacing" "cJK-afstand")
("calculus" "beregning")
("cancelled" "annulleret")
("cannot download directory to file" "kan ikke downloade bibliotek til fil")
("cannot rename across different servers" "kan ikke omdøbe på tværs af forskellige servere")
("cannot upload directory to file" "kan ikke uploade katalog til fil")
("cartesian" "kartesisk")
("carved wood" "udskåret træ")
("case-insensitive search" "case-insensitive search")
("categories" "kategorier")
("category" "kategori")
("cell properties" "celleegenskaber")
("cells" "celler")
("center baseline" "center baseline")
("chalk" "kridt")
("change default unit" "ændre standardenhed")
("change passphrase" "ændre adgangssætning")
("change permissions" "ændre tilladelser")
("change step-size" "ændre trinstørrelse")
("change tags" "ændre tags")
("change the TeXmacs preferences" "ændre TeXmacs-præferencer")
("change the border of the table" "ændre bordets kant")
("change the style of mathematical formulas" "ændre stil med matematiske formler")
("change wallet passphrase" "ændre tegnbog-adgangssætning")
("character contraction" "tegnkontraktion")
("character encoding" "tegnkodning")
("character expansion" "tegnudvidelse")
("check exported Pdf files for correctness" "Kontroller eksporterede Pdf-filer for korrekthed")
("check for automatic updates" "Kontroller for automatiske opdateringer")
("check for updates" "Kontroller for opdateringer")
("checkable field" "felt, der kan kontrolleres")
("choose background" "vælg baggrund")
("choose color" "vælg farve")
("cipher algorithm for passphrase encryption" "chifferalgoritme til kodeordkryptering")
("classification" "klassificering")
("clean slate" "ren skifer")
("clear all fields" "ryd alle felter")
("clear local information" "klar lokal information")
("clear menu" "ryd menu")
("clear undo history" "ryd fortryd historik")
("click Ok button twice to discard this warning" "Klik på OK-knappen to gange for at kaste denne advarsel")
("clip" "klip")
("clipboard image format" "billedformat til udklipsholder")
("close animation tool" "lukke animationsværktøj")
("close document" "luk dokument")
("close program" "lukke program")
("close replace tool" "værktøj til tæt udskiftning")
("close search tool" "luk søgeværktøj")
("close spell tool" "lukke staveværktøj")
("close translations to rebuild" "lukke oversættelser for at genopbygge")
("closed bezier" "lukket bezier")
("closed curve" "lukket kurve")
("closed smooth" "lukket glat")
("closed spline" "lukket spline")
("cluster by affiliation" "klynge efter tilknytning")
("collect garbage" "indsamle skrald")
("collected keys" "indsamlede nøgler")
("color of the axes" "farven på akserne")
("color of the subunits" "farve på underenhederne")
("color of the units" "enhedsfarve")
("colors" "farver")
("column to the left" "kolonne til venstre")
("column to the right" "kolonne til højre")
("columns" "kolonner")
("column separation" "kolonneseparation")
("commit" "begå")
("commit file" "begå fil")
("common" "almindelig")
("commutative diagram" "kommutativt diagram")
("compare" "sammenligne")
("compare with" "sammenlign med")
("complete bibliographic reference" "komplet bibliografisk reference")
("complex actions" "komplekse handlinger")
("compose" "komponere")
("compress" "komprimere")
("compress into toolbar" "komprimere i værktøjslinjen")
("compressed" "komprimeret")
("conceal" "skjule")
("configure look and feel" "konfigurer look and feel")
("confirm collected public key deletion" "bekræft indsamlet sletning af offentlig nøgle")
("confirm database entry" "bekræft databasepost")
("confirm entry" "bekræft indrejse")
("confirm public key deletion" "bekræft sletning af offentlig nøgle")
("confirm secret key deletion" "bekræft sletning af hemmelig nøgle")
("confirm selected database entries" "bekræft valgte databaseposter")
("confirm selected entries" "bekræft valgte poster")
("confirm wallet destruction" "bekræft ødelæggelse af tegnebogen")
("conservative conversion options" "konservative konverteringsindstillinger")
("consoles" "konsoller")
("constellation" "konstellation")
("context aids" "konteksthjælpemidler")
("contextual hints" "kontekstuelle tip")
("continue" "fortsæt")
("continued fraction" "fortsat fraktion")
("contour" "kontur")
("contract logarithms" "kontraktlogaritmer")
("convert" "konvertere")
("converters" "konvertere")
("convertible" "konvertible")
("copy new objects to all frames" "kopier nye objekter til alle rammer")
("copy new objects to previous frames" "kopier nye objekter til tidligere rammer")
("copy new objects to subsequent frames" "kopier nye objekter til efterfølgende rammer")
("copy to all frames after" "kopi til alle rammer efter")
("copy to all frames before" "kopi til alle rammer før")
("copy to all other frames" "kopi til alle andre rammer")
("copyright" "copyright")
("cork charset with TeX catcode definition in preamble" "korkcharset med TeX-kattekodedefinition i ingressen")
("cork with catcodes" "kork med koder")
("correct" "korrekt")
("correct all" "korriger alle")
("correct formula" "korrekt formel")
("correct manually" "korrekt manuelt")
("correct mathematical formulas" "korrekte matematiske formler")
("correction" "korrektion")
("cosine" "kosinus")
("count characters" "tæller tegn")
("count lines" "tællelinjer")
("count words" "tæl ord")
("create a new document" "Opret et nyt dokument")
("create link" "Opret link")
("create preamble" "Opret ingress")
("create remote account" "Opret fjernkonto")
("create remote directory" "Opret fjernkatalog")
("create remote file" "Opret fjernfil")
("create subprogram" "Opret underprogram")
("create subsession" "Opret subsession")
("create table macro" "Opret tabelmakro")
("creating new account" "Oprettelse af ny konto")
("creating technical pictures" "Oprettelse af tekniske billeder")
("crop" "afgrøde")
("crop marks" "afgrødemærker")
("cross" "kryds")
("crossed boxes" "krydsede kasser")
("crossed circles" "krydsede cirkler")
("current user version" "nuværende bruger version")
("current version" "nuværende version")
("cursor" "markør")
("curve" "kurve")
("curve intersections" "kurvekryds")
("curve points" "kurvepunkter")
("customizations" "tilpasninger")
("customizing and extending the user interface" "tilpasning og udvidelse af brugergrænsefladen")
("cyan" "cyan")
("data" "data")
("database entry" "databaseindgang")
("database tool" "databaseværktøj")
("database toolbar" "databaseværktøjslinje")
("dead" "død")
("debug" "debug")
("debugging console" "fejlsøgningskonsol")
("debugging tool" "fejlsøgningsværktøj")
("decimal comma" "decimal komma")
("decimal dot" "decimalprik")
("decomposed" "dekomponeret")
("decorated" "dekoreret")
("decorated wood" "dekoreret træ")
("decorative" "dekorativ")
("decrease size" "formindsk størrelse")
("decrypt" "dekrypter")
("decrypted" "dekrypteret")
("decryption" "dekryptering")
("default size" "standardstørrelse")
("degrade" "nedbrydes")
("degraded" "nedbrudt")
("delete documentation cache" "slet dokumentationscache")
("delete entries" "slet poster")
("delete link" "slet link")
("delete selected entries in wallet" "slet valgte poster i tegnebogen")
("delete user identity" "slet brugeridentitet")
("deleted" "slettet")
("describe" "beskrive")
("describe tag" "beskriv tag")
("destroy" "ødelægge")
("detach master" "løsne master")
("detailed menus" "detaljerede menuer")
("details in menus" "detaljer i menuer")
("determine margins from text width" "bestem margener fra tekstbredden")
("developer" "udvikler")
("developer tool" "udviklerværktøj")
("device" "enhed")
("diamond" "diamant")
("differentiate" "differentiere")
("digital" "digital")
("dilate" "dilat")
("direction of progression" "progressionsretning")
("direction of translation" "retning af oversættelse")
("disable coloring on paper" "deaktiver farve på papir")
("disable encryption" "deaktiver kryptering")
("disabled" "deaktiveret")
("disappear" "forsvinde")
("disk" "disk")
("displayed formula" "vist formel")
("dissociate joined cells" "dissocierer sammenføjede celler")
("distill encapsulated Pdf files" "destillere indkapslede Pdf-filer")
("distort" "forvrænge")
("distorted" "forvrænget")
("division" "division")
("document colors" "dokumentfarver")
("document font selector" "dokumenttypevælger")
("document language" "dokumentsprog")
("document metadata" "dokumentmetadata")
("document page format" "dokumentsideformat")
("document paragraph format" "format for dokumentafsnit")
("document source tree preferences" "præferencer for dokumentkildetræ")
("document updates run" "dokumentopdateringer køres")
("documents in separate windows" "dokumenter i separate vinduer")
("download file or directory" "download fil eller bibliotek")
("downwards" "nedad")
("dragging" "trækker")
("draw" "lodtrækning")
("draw graphics" "tegne grafik")
("draw image" "tegne billede")
("draw over" "trækning")
("draw over selection" "valg af træk")
("drop" "drop")
("due to" "på grund af")
("dynamic" "dynamisk")
("eRROR" "eRROR")
("edit animation" "rediger animation")
("edit groups of objects" "rediger grupper af objekter")
("edit macro" "rediger makro")
("edit macros" "rediger makroer")
("edit object properties" "rediger objektegenskaber")
("edit preamble" "rediger præambel")
("edit source" "rediger kilde")
("edit style" "redigeringsstil")
("edit translations file" "rediger oversættelsesfil")
("education" "uddannelse")
("effect pen" "effektpen")
("eigenvalues" "egenværdier")
("eighth" "ottende")
("embold" "embold")
("emboss" "prægning")
("enable page breaking" "aktiver sidebrydning")
("enabled" "aktiveret")
("encoding" "kodning")
("encrypt" "krypteret")
("encrypted" "krypteret")
("encrypted buffer" "krypteret buffer")
("encryption" "kryptering")
("encryption error" "krypteringsfejl")
("encryption facilities are not currently available" "krypteringsfaciliteter er ikke aktuelt tilgængelige")
("encryption facilities have not been enabled for TeXmacs" "krypteringsfaciliteter er ikke aktiveret for TeXmacs")
("enforce brackets to match" "håndhæv parentes til at matche")
("engrave" "graver")
("enter data" "indtast data")
("enter graphics" "indtast grafik")
("enter graphics mode" "gå ind i grafiktilstand")
("enter new passphrase for encryption" "indtast ny adgangssætning til kryptering")
("enter passphrase for decryption" "indtast adgangskode til dekryptering")
("enter passphrase for identity" "indtast adgangskode for identitet")
("enter title information" "indtast titeloplysninger")
("entire table" "hele tabellen")
("entry up to date in database" "opdateret post i databasen")
("enunciation" "udtale")
("environment variable" "miljøvariabel")
("environments" "miljøer")
("erode" "erodere")
("error messages" "fejlmeddelelser")
("error output" "fejloutput")
("error status report" "fejlstatusrapport")
("error: bracket does not match" "fejl: beslag stemmer ikke overens")
("error: cyclic or missing chunks detected" "fejl: cykliske eller manglende dele opdaget")
("error: file not found" "fejl: fil ikke fundet")
("error: ghostview does not seem to be installed on your system" "fejl: ghostview ser ikke ud til at være installeret på dit system")
("error: one of the alternatives should be filled out" "fejl: et af alternativerne skal udfyldes")
("error: only one alternatives should be filled out" "fejl: kun et alternativ skal udfyldes")
("error: should fill out name for referencing" "fejl: skal udfylde navn til henvisning")
("error: should fill out required field" "fejl: skal udfylde det krævede felt")
("escape" "flugt")
("evaluable field" "evaluerbart felt")
("evaluate above" "evaluering ovenfor")
("evaluate all" "evaluer alle")
("evaluate below" "evaluer nedenfor")
("evaluate fields" "evalueringsfelter")
("evaluate fields in order" "evaluere felter i rækkefølge")
("evaluate script" "evaluere script")
("evaluation switch" "evalueringskontakt")
("evaluation tag" "evalueringskode")
("even page" "lige side")
("even pages" "lige sider")
("events" "begivenheder")
("exact" "nøjagtigt")
("execution of scripts" "udførelse af scripts")
("exit graphics" "exit-grafik")
("exit graphics mode" "afslutte grafiktilstand")
("exit left" "exit exit")
("exit right" "frakørsel til højre")
("exit tag on the left" "exit-kode til venstre")
("exit tag on the right" "exit-kode til højre")
("expand TeXmacs macros with no LaTeX equivalents" "udvid TeXmacs-makroer uden LaTeX-ækvivalenter")
("expand beamer slides" "udvid Beamer-slides")
("expand inclusions" "udvid indeslutninger")
("expand logarithms" "udvid logaritmer")
("expand trigonometric functions" "udvide trigonometriske funktioner")
("expand unrecognized macros" "udvide ukendte makroer")
("expand user-defined macros" "udvid brugerdefinerede makroer")
("expanded" "udvidet")
("experimental features (to be used with care)" "eksperimentelle funktioner (skal bruges med omhu)")
("explain" "forklar")
("explanatory item" "forklarende artikel")
("explicit keystroke" "eksplicit tastetryk")
("explicit margins" "eksplicit margen")
("exponential" "eksponentiel")
("export bibliographies as links" "eksporter bibliografier som links")
("export bibliography" "eksportbibliografi")
("export entries in buffer" "eksportere poster i buffer")
("export file" "eksportfil")
("export formulas as images" "eksportformler som billeder")
("export mathematical formulas as MathML" "eksportere matematiske formler som MathML")
("export mathematical formulas as images" "eksportere matematiske formler som billeder")
("export selected entries" "eksportere valgte poster")
("export selection" "eksportvalg")
("export selection as image" "eksportvalg som billede")
("export selections as" "eksportvalg som")
("export sessions" "eksportsessioner")
("exported bibliographic entries" "eksporterede bibliografiske poster")
("exported bibliographic references" "eksporterede bibliografiske referencer")
("extend" "forlænge")
("extend table to full paragraph width" "udvide tabellen til fuld afsnitbredde")
("extended" "udvidet")
("extensible left arrow" "udvidelig venstre pil")
("extensible right arrow" "udvidelig højre pil")
("extern" "ekstern")
("external" "ekstern")
("extra branch" "ekstra gren")
("extra interline space" "ekstra interline plads")
("extra name" "ekstra navn")
("extract" "ekstrakt")
("extract style file" "uddragsstilfil")
("extract style package" "pakke med uddragsstil")
("factor" "faktor")
("fade" "falme")
("fade in" "falme ind")
("fade out" "falme ud")
("fast" "hurtigt")
("fast decrease" "hurtigt fald")
("fast environments" "hurtige miljøer")
("fast increase" "hurtig stigning")
("field reference" "feltreference")
("fifth" "femte")
("file saved" "fil gemt")
("fill color" "fyldfarve")
("fill out" "udfyld")
("filter" "filter")
("finished collecting symbols documentation" "færdig indsamling af symboler-dokumentation")
("first" "først")
("first chunk" "første del")
("first difference" "første forskel")
("first error" "første fejl")
("first field" "første felt")
("first occurrence" "første forekomst")
("first similar" "første lignende")
("fit" "fit")
("fit to height" "passer til højden")
("fit to screen" "fit to screen")
("fit to screen width" "passer til skærmbredde")
("fit to width" "passer til bredden")
("five columns" "fem kolonner")
("fixed" "fast")
("flag is off" "flag er slået fra")
("flag is on" "flag er tændt")
("flatten" "flad")
("floating algorithm" "flydende algoritme")
("floating phantom" "flydende fantom")
("focus" "fokus")
("focus dependent icons" "fokusafhængige ikoner")
("fold all" "fold alle")
("fold all fields" "fold alle felter")
("fold back" "fold tilbage")
("follow external links" "følg eksterne links")
("follow inverse links" "følg omvendte links")
("font customization" "skrifttilpasning")
("font effects" "fonteffekter")
("font selector" "skrifttypevælger")
("force reloading of translations" "kraft omlæsning af oversættelser")
("forward" "frem")
("four columns" "fire kolonner")
("four dots" "fire prikker")
("fourth" "fjerde")
("fraktur" "fraktur")
("framed" "indrammet")
("framed theorems" "indrammede sætninger")
("from" "fra")
("from center" "fra centrum")
("front matter" "front materie")
("full" "fuld")
("full author list" "fuld forfatterliste")
("full screen mode" "fuldskærmstilstand")
("gap" "hul")
("garbage collection" "garbage collection")
("gaussian" "gaussisk")
("gcd" "gcd")
("general" "generelt")
("generate GnuPG key" "generer GnuPG-nøgle")
("generated LaTeX document contains no errors" "genereret LaTeX-dokument indeholder ingen fejl")
("generated field" "genereret felt")
("geometry" "geometri")
("get list with remote versions" "få liste med fjernversioner")
("global log" "global log")
("global status" "global status")
("glue multiple spaces" "lim flere mellemrum")
("glyphs" "glyphs")
("gnaw" "gnag")
("gnawed" "gnugd")
("gnuPG command" "gnuPG-kommando")
("gnuPG decryption error" "gnuPG-dekrypteringsfejl")
("gnuPG error: buffer encryption failed" "gnuPG-fejl: bufferkryptering mislykkedes")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG-fejl: kan ikke finde en passende hemmelig nøgle til at dekryptere")
("gnuPG requires name and email to have at least 5 characters" "gnuPG kræver navn og e-mail for at have mindst 5 tegn")
("go to anchor" "gå til anker")
("go to anchor or float" "gå til anker eller float")
("go to anchor or footnote" "gå til anker eller fodnote")
("go to first similar tag" "gå til det første lignende tag")
("go to float" "gå til flydende")
("go to footnote" "gå til fodnote")
("go to last similar tag" "gå til det sidste lignende tag")
("go to next similar tag" "gå til næste lignende tag")
("go to previous similar tag" "gå til forrige lignende tag")
("go to section" "gå til sektion")
("grain" "korn")
("granite" "granit")
("graphical effects" "grafiske effekter")
("graphical interface font scale" "skala for grafisk interface font")
("graphical overlays" "grafiske overlays")
("graphical slides and overlays" "grafiske dias og overlejringer")
("graphics" "grafik")
("graphics geometry" "grafikgeometri")
("graphics grids" "grafiknet")
("greyed" "gråtonet")
("grid" "gitter")
("grid curves" "gitterkurver")
("grid points" "gitterpunkter")
("grid-curve intersections" "krydsning af gitterkurve")
("group of objects" "gruppe af objekter")
("group/ungroup" "gruppe / fjern gruppe")
("group/ungroup objects" "gruppe / fjern gruppering af objekter")
("grouped" "grupperet")
("guarantee transparent source tracking" "garantere gennemsigtig kildesporing")
("half wide" "halv bred")
("hand drawn" "håndtegnet")
("handwritten" "håndskrevet")
("hangul" "hangul")
("headers" "overskrifter")
("high resolution settings" "højopløsningsindstillinger")
("history" "historie")
("homoglyph substitutions" "homoglyph-substitutioner")
("horizontal alignment" "vandret justering")
("horizontal collapse distance" "vandret sammenbrudafstand")
("horizontal margins" "vandrette margener")
("hyphenate as" "bindestreg som")
("icon" "ikon")
("if hyphenated" "hvis bindestregel")
("ignore" "ignorere")
("impact" "påvirkning")
("import bibliography" "importbibliografi")
("import database entry" "import af databasepost")
("import entries in buffer" "importer poster i buffer")
("import entry" "importindgang")
("import file" "importfil")
("import public keys from buffer" "importere offentlige nøgler fra buffer")
("import selected database entries" "importere valgte databaseposter")
("import selected entries" "importere valgte poster")
("import selections as" "importvalg som")
("import sessions" "import sessioner")
("import sophisticated objects as pictures" "importer sofistikerede objekter som billeder")
("imported bibliographic entries" "importerede bibliografiske poster")
("in popup windows" "i popup-vinduer")
("inanimated" "godkendt")
("inch" "tomme")
("incomplete entries found to be filled out" "ufuldstændige poster fundet udfyldt")
("increase size" "forøg størrelse")
("indent paragraphs" "led indgår")
("indentation" "indrykket")
("indication" "indikation")
("initialize" "initialisere")
("initialize wallet" "initialiser tegnebog")
("initials" "initialer")
("ink here" "blæk her")
("ink in" "blæk ind")
("ink out" "blæk ud")
("inline" "inline")
("inline args" "inline args")
("inline code" "inline-kode")
("inline content" "inline indhold")
("inline formula" "inline formel")
("inner bottom" "indre bund")
("inner left" "indre venstre")
("inner right" "indre højre")
("inner top" "indre top")
("input command" "inputkommando")
("input field" "input felt")
("input options" "inputindstillinger")
("insert a computer program" "indsæt et computerprogram")
("insert a gap" "indsæt et hul")
("insert a list" "indsæt en liste")
("insert a multiple choice" "indsæt et multiple choice")
("insert a negation" "indsæt en negation")
("insert a new entry" "indsæt en ny post")
("insert a note or a floating object" "indsæt en note eller et flydende objekt")
("insert a prominent piece of text" "indsæt et fremtrædende stykke tekst")
("insert a question" "indsæt et spørgsmål")
("insert a root" "indsæt en rod")
("insert a script" "indsæt et script")
("insert a section block" "indsæt en sektionsblok")
("insert a textual operator" "indsæt en tekstoperator")
("insert above" "indsæt ovenfor")
("insert abstract" "indsæt abstrakt")
("insert an answer" "indsæt et svar")
("insert an enunciation" "indsæt en udtale")
("insert annotation" "indsæt kommentar")
("insert arcs" "indsæt buer")
("insert argument after" "indsæt argument efter")
("insert argument before" "indsæt argument før")
("insert below" "indsæt nedenfor")
("insert bibliography" "indsæt bibliografi")
("insert circles" "indsæt cirkler")
("insert closed splines" "indsæt lukkede splines")
("insert copyright and license information" "indsæt oplysninger om copyright og licens")
("insert explanatory item" "indsæt forklarende punkt")
("insert field above" "indsæt felt ovenfor")
("insert field below" "indsæt felt nedenfor")
("insert hand drawn curves" "indsæt håndtegnede kurver")
("insert large delimiters" "indsæt store afgrænsere")
("insert last name" "indsæt efternavn")
("insert left" "indsæt venstre")
("insert lines" "indsæt linjer")
("insert missing invisible operators" "indsæt manglende usynlige operatører")
("insert more names" "indsæt flere navne")
("insert multiple paragraphs" "indsæt flere afsnit")
("insert overlay after" "indsæt overlay efter")
("insert overlay before" "indsæt overlay før")
("insert particle" "indsæt partikel")
("insert plain text" "indsæt almindelig tekst")
("insert points" "indsæt punkter")
("insert polygons" "indsæt polygoner")
("insert right" "indsæt højre")
("insert similar above" "indsæt lignende ovenfor")
("insert similar below" "indsæt lignende nedenfor")
("insert similar block above" "indsæt lignende blok ovenfor")
("insert similar block below" "indsæt lignende blok nedenfor")
("insert slide after" "indsæt dias efter")
("insert slide before" "indsæt dias før")
("insert splines" "indsæt splines")
("insert subscript" "indsæt underskrift")
("insert subtable" "indsæt subtabelt")
("insert superscript" "indsæt superscript")
("insert symbol documentation" "Indsæt symbol dokumentation")
("insert template" "indsæt skabelon")
("insert text" "indsæt tekst")
("insert text field above" "indsæt tekstfelt ovenfor")
("insert text field below" "indsæt tekstfelt nedenfor")
("insert title after name" "indsæt titel efter navn")
("insert user interface related markup" "indsæt brugergrænseflade relateret markup")
("inserting control points" "indsættelse af kontrolpunkter")
("inside mathematics" "inden i matematik")
("integrate" "integrere")
("interactive command" "interaktiv kommando")
("interactive questions" "interaktive spørgsmål")
("intercharacter compression" "interkarakterkomprimering")
("intercharacter stretching" "intercharacter stretching")
("interrupted" "afbrudt")
("invalid multi-paragraph selection" "ugyldigt valg af flere afsnit")
("invalid renaming" "ugyldig omdøbning")
("invert" "invertere")
("inverted breve" "omvendt breve")
("invisible ending" "usynlig ende")
("invisible newline" "usynlig newline")
("invisible opening" "usynlig åbning")
("inwards" "indad")
("join selected cells" "slutte sig til valgte celler")
("jump in" "hoppe ind")
("junior" "junior")
("justify" "retfærdiggøre")
("keep evaluated expressions" "hold evaluerede udtryk")
("keep local" "hold lokal")
("keep remote" "holde fjernbetjening")
("keep track of source code" "holde styr på kildekoden")
("keep unfolded" "hold udfoldet")
("key manager" "key manager")
("keyboard configuration" "tastaturkonfiguration")
("laTeX errors" "laTeX-fejl")
("laptop presentations" "bærbare præsentationer")
("large brackets" "store beslag")
("large cells" "store celler")
("large displayed" "stort vist")
("large displayed fraction" "stor vist brøkdel")
("large tables" "store borde")
("last" "sidste")
("last check" "sidste kontrol")
("last difference" "sidste forskel")
("last error" "sidste fejl")
("last field" "sidste felt")
("last name" "efternavn")
("last occurrence" "sidste forekomst")
("last similar" "sidst lignende")
("lcm" "lcm")
("left axis" "venstre akse")
("left baseline" "venstre baseline")
("left bottom" "venstre bund")
("left cell border" "venstre celle kant")
("left cell padding" "polstring med venstre celle")
("left center" "venstre center")
("left click: add point; Right click: undo" "venstre klik: tilføj punkt; Højreklik: fortryd")
("left click: finish; Right click: undo" "venstre klik: slut; Højreklik: fortryd")
("left click: new object" "venstre klik: nyt objekt")
("left click: operate" "venstre klik: betjen")
("left down" "venstre nede")
("left on even pages" "tilbage på lige sider")
("left table border" "venstre tabelgrænse")
("left table padding" "venstre bordpolstring")
("left top" "venstre top")
("left up" "venstre op")
("left-right arrow" "venstre-højre pil")
("leftwards" "tilbage")
("let the environment float" "lad miljøet flyde")
("line arrows" "liniepile")
("line breaking" "liniebrud")
("line dashes" "strejestreg")
("line portion" "liniedel")
("line style" "linjestil")
("line width" "linjebredde")
("line wrapping" "linieindpakning")
("line wrapping inside cell" "linieindpakning inde i cellen")
("linear 2D" "lineær 2D")
("linear algebra" "lineær algebra")
("lines around" "linjer rundt")
("link image and copies as" "linkbillede og kopier som")
("link image as" "linkbillede som")
("link mode" "linktilstand")
("link to URL" "link til URL")
("linking tool" "linkværktøj")
("live" "live")
("live input-output" "live input-output")
("load help file" "indlæs hjælpefil")
("load remote file" "indlæse fjernfil")
("loading" "indlæsning")
("local entries" "lokale poster")
("loci" "loci")
("locus" "locus")
("locus rendering" "locus-gengivelse")
("logarithm" "logaritme")
("logarithmic" "logaritmisk")
("logarithmic base" "logaritmisk base")
("logarithms" "logaritmer")
("logging in" "log ind")
("logical and" "logisk og")
("logical implication" "logisk implikation")
("logical not" "logisk ikke")
("logical or" "logisk eller")
("login" "login")
("logout" "logout")
("long text" "lang tekst")
("look for more fonts" "kig efter flere skrifttyper")
("loops" "løkker")
("macro argument" "makroargument")
("macro definition" "makrodefinition")
("macro editor" "makroeditor")
("macro name" "makronavn")
("macros" "makroer")
("macros editor" "makroseditor")
("magnify horizontally" "forstørret vandret")
("magnify vertically" "forstørr lodret")
("main presentation style" "hovedpræsentationsstil")
("make a letter environment" "lav et brevmiljø")
("make a multi-slide presentation" "lav en præsentation med flere dias")
("make block wide" "gøre blok bred")
("make float wide" "gøre float bredt")
("make floating" "gøre flydende")
("make footnote wide" "gøre fodnote bred")
("make link" "foretag link")
("make non floating" "gør ikke flydende")
("make wide" "gøre bred")
("manila paper" "manila papir")
("marginal note" "marginal note")
("margins from width" "marginer fra bredden")
("margins on paper" "marginer på papir")
("margins on screen" "marginer på skærmen")
("marked" "markeret")
("marker" "markør")
("material" "materiale")
("math Extra" "matematik ekstra")
("math Letters" "matematiske breve")
("math Symbols" "matematiske symboler")
("mathematical output" "matematisk output")
("matrices" "matrixer")
("maximal cell height" "maksimal cellehøjde")
("maximal clustering" "maksimal klynge")
("maximal table height" "maksimal bordhøjde")
("maximal table width" "maksimal tabelbredde")
("maximum" "maksimalt")
("meander" "bugter")
("medieval" "middelalder")
("memory" "hukommelse")
("memory usage" "hukommelsesforbrug")
("menu" "menu")
("merge lines into paragraphs unless separated by blank lines" "flette linjer i afsnit, medmindre de er adskilt af tomme linjer")
("messages" "meddelelser")
("meta data" "metadata")
("metadata" "metadata")
("metal" "metal")
("middle baseline" "midterste basislinje")
("minimal cell height" "minimal cellehøjde")
("minimal cell width" "minimal cellebredde")
("minimal line separation" "minimal linjeseparation")
("minimal table height" "minimal bordhøjde")
("minimal table width" "minimal bordbredde")
("minimum" "minimum")
("mirror" "spejl")
("miscellanous" "diverse")
("mixed" "blandet")
("mode dependent icons" "ikonafhængige ikoner")
("modify bibliography" "ændre bibliografi")
("modify remote live document" "ændre eksternt live-dokument")
("module" "modul")
("module browser" "modulbrowser")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help" "mere information om GNU TeXmacs kan findes i hjælpen")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "mere information om GNU TeXmacs kan findes i menuen Hjælp-<gtr> Om")
("motion" "bevægelse")
("mouse over object" "mus over objekt")
("move" "flytte")
("move objects" "flyt objekter")
("move over object on which to operate" "bevæg over objekt, hvorpå du skal køre")
("multiline" "multiline")
("multiple choice" "multiple choice")
("multiple documents share window" "vindue med flere dokumenter deles")
("multiple root" "multiple root")
("multiplication" "multiplikation")
("named" "navngivet")
("navigation options" "navigationsindstillinger")
("never" "aldrig")
("new account" "ny konto")
("new bibliography dialogue" "ny bibliografidialog")
("new document" "nyt dokument")
("new entry" "ny post")
("new identity" "ny identitet")
("new locus" "nyt lokus")
("new macro" "ny makro")
("new passphrase" "ny adgangssætning")
("new remote directory" "nyt fjernkatalog")
("new remote file" "ny fjernfil")
("new style fonts" "skrifttyper med ny stil")
("new style page breaking" "New style side breaking")
("new version" "ny version")
("new window" "nyt vindue")
("newer version" "nyere version")
("next chunk" "næste del")
("next difference" "næste forskel")
("next error" "næste fejl")
("next field" "næste felt")
("next occurrence" "næste forekomst")
("next screen" "næste skærm")
("next similar" "næste lignende")
("no animation" "ingen animation")
("no clustering" "ingen klynge")
("no completions" "ingen færdiggørelser")
("no errors have been corrected" "ingen fejl er rettet")
("no grid" "intet gitter")
("no multiple spaces" "ingen flere mellemrum")
("no new public key in document" "ingen ny offentlig nøgle i dokumentet")
("no page break" "ingen sideskift")
("no page numbers" "ingen siderumre")
("no parent" "ingen forælder")
("no selection" "intet valg")
("no spelling errors" "ingen stavefejl")
("no spurious spaces" "ingen falske rum")
("normal loci" "normal loci")
("not allowed to remove home directory" "ikke tilladt at fjerne hjemmekatalog")
("not connected to server" "ikke tilsluttet server")
("not yet implemented" "endnu ikke implementeret")
("notebook" "notebook")
("number of polar steps" "antal polære trin")
("number of subunit steps" "antal underenhedstrin")
("numbered" "nummereret")
("numbering" "nummerering")
("numeric spreadsheet" "numerisk regneark")
("oblique" "skråt")
("odd page" "ulige side")
("odd pages" "ulige sider")
("of fingerprint" "af fingeraftryk")
("old version" "gammel version")
("older version" "ældre version")
("on the footer" "på sidefoden")
("on your system and set it up from the \"Security\" tab" "på dit system og indstil det fra fanen \"Sikkerhed\"")
("once" "en gang")
("one column" "en kolonne")
("one error has been corrected" "en fejl er rettet")
("one lower case letter, one non alpha-numeric symbol" "et lille bogstav, et ikke-alfanumerisk symbol")
("one numeric character, one upper case letter" "et numerisk tegn, et stort bogstav")
("only convert changes when re-importing" "konverter kun ændringer ved genimportering")
("only convert changes with respect to imported version" "konverter kun ændringer med hensyn til importeret version")
("only convert changes with respect to tracked version" "konverter kun ændringer med hensyn til sporet version")
("only implemented for complete subtrees" "kun implementeret for komplette undertræer")
("only keep folded" "hold kun foldet")
("only keep unfolded" "hold kun udfoldet")
("only show paragraphs with hits" "Vis kun afsnit med hits")
("only show semantic focus" "viser kun semantisk fokus")
("opacity" "opacitet")
("open bibliography" "åben bibliografi")
("open identities" "åben identitet")
("open in new window" "åben i nyt vindue")
("open key manager" "open key manager")
("open licence agreement" "åben licensaftale")
("open mailbox" "åben postkasse")
("open module browser" "åben modulbrowser")
("open symbol browser" "browser med åbent symbol")
("open tool in separate window" "åbent værktøj i separat vindue")
("operation mode" "driftstilstand")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "eller angiv den komplette sti til kommandoen \"gpg\" eller \"gpg2\"")
("order" "ordre")
("ordinary symbol" "almindeligt symbol")
("ornamented" "pyntet")
("other login" "anden login")
("other package" "anden pakke")
("outer bottom" "ydre bund")
("outer left" "ydre venstre")
("outer right" "ydre højre")
("outer top" "ydre top")
("outline" "disposition")
("outlined" "skitseret")
("outlined emboss" "skitseret prægning")
("outlined engrave" "skitseret gravering")
("output options" "outputindstillinger")
("outwards" "udad")
("oval" "oval")
("overlap" "overlapning")
("overlay" "overlay")
("overlay mode" "overlaytilstand")
("overlays" "overlays")
("overlined" "overline")
("overview of the scheme extension language" "oversigt over sprog til udvidelse af ordningen")
("padded" "polstret")
("page background" "side baggrund")
("page break after" "sideskift efter")
("page breaking algorithm" "sidebrydende algoritme")
("page format" "sideformat")
("page number" "sidetal")
("page number rendering" "gengivelse af sidetal")
("page rendering" "gengivelse af sider")
("pagedown" "pagedown")
("pageup" "pageup")
("palette" "palet")
("panorama" "panorama")
("paragraph format" "afsnitformat")
("paragraphs" "afsnit")
("parametric curve" "parametrisk kurve")
("parametric surface" "parametrisk overflade")
("parenthesis" "parentes")
("parenthesized" "parentes")
("particle" "partikel")
("passphrase decryption" "adgangssætning dekryptering")
("passphrase encryption" "adgangssætningskryptering")
("passphrase wallet facilities are not currently available" "adgangsfrase tegnebogfaciliteter er ikke tilgængelige i øjeblikket")
("passphrases are expected to have at least: 8 characters" "adgangssætninger forventes at have mindst: 8 tegn")
("passphrases mismatch" "passphrases mismatch")
("pastel" "pastel")
("pattern" "mønster")
("pattern selector" "mønstervælger")
("pause" "pause")
("pdf version number" "pdf-version nummer")
("pen" "pen")
("pen width" "penbredde")
("permanent footer" "permanent sidefod")
("permanent header" "permanent overskrift")
("permanently add to dictionary" "permanent tilføj til ordbog")
("permanently insert into dictionary" "permanent indsat i ordbogen")
("permissions" "tilladelser")
("phantom" "fantom")
("phantoms" "fantomer")
("physics and astronomy class" "fysik og astronomiklasse")
("picture" "billede")
("pine" "fyr")
("plain" "almindelig")
("plain boxes" "almindelige kasser")
("plain circles" "almindelige cirkler")
("play" "play")
("play all animations" "afspil alle animationer")
("play animation" "play-animation")
("please install GnuPG software from https://www.gnupg.org" "Installer venligst GnuPG-software fra https://www.gnupg.org")
("plot" "plot")
("plug-ins" "plug-ins")
("plural" "flertal")
("point" "punkt")
("point border" "punktgrænse")
("point size" "punktstørrelse")
("point style" "punktstil")
("polar" "polær")
("polygon" "polygon")
("pop server settings" "pop-serverindstillinger")
("portion" "portion")
("position of marginal note" "position af marginale note")
("poster formats" "plakatformater")
("poster theme" "plakatstema")
("postfix" "postfix")
("preferences for editing mathematical formulas" "præferencer til redigering af matematiske formler")
("preferences for tag" "præferencer for tag")
("prefix" "præfiks")
("presentation tool" "præsentationsværktøj")
("preserve" "bevare")
("preserve tags" "bevare tags")
("pretty" "smuk")
("pretty tree output" "smuk træudgang")
("preview" "preview")
("previous difference" "tidligere forskel")
("previous error" "forrige fejl")
("previous field" "forrige felt")
("previous occurrence" "tidligere forekomst")
("previous screen" "forrige skærm")
("previous similar" "tidligere lignende")
("primitive or macro" "primitiv eller makro")
("print buffer" "printbuffer")
("print buffer to file" "printbuffer til fil")
("print document" "udskriv dokument")
("print to file" "print til fil")
("printer setup" "printeropsætning")
("produce Pdf using native export filter" "producer Pdf ved hjælp af oprindeligt eksportfilter")
("produce Postscript using native export filter" "producerer Postscript ved hjælp af oprindeligt eksportfilter")
("program bracket matching" "programbeslags matching")
("program bracket selections" "valg af programbeslag")
("program commands" "programkommandoer")
("program interface for buffer management" "programgrænseflade til bufferstyring")
("programming routines for editing documents" "programmeringsrutiner til redigering af dokumenter")
("prominent" "prominent")
("provoke C++ error" "provokere C++ fejl")
("provoke menu error" "provokere menufejl")
("provoke scheme error" "provokere skemafejl")
("pseudo code" "pseudokode")
("public key encryption" "offentlig nøglekryptering")
("public keys" "offentlige nøgler")
("pulse" "puls")
("qt GUI only, sorry. Use \"Export selection\"" "Kun qt GUI, undskyld. Brug \"Eksporter markering\"")
("qt-widgets" "qt-widgets")
("quantifier" "kvantificeringsmiddel")
("quasi" "kvasi")
("question" "spørgsmål")
("questions only" "kun spørgsmål")
("questions with answers" "spørgsmål med svar")
("quick evaluation of formulas" "hurtig evaluering af formler")
("rank" "rang")
("raw" "rå")
("really delete user identity" "virkelig slette brugeridentitet")
("really tiny" "virkelig lille")
("rebuild translations file" "Genopbyg oversættelsesfil")
("recent" "nylig")
("recent documents" "nylige dokumenter")
("recipients" "modtagere")
("recognize" "genkende")
("recolor" "genfarve")
("rectangular" "rektangulær")
("reduce" "reducere")
("reduce trigonometric functions" "reducere trigonometriske funktioner")
("reduced margins" "reducerede marginer")
("regenerate" "regenerere")
("register" "register")
("register file" "registerfil")
("relate" "relaterer")
("relation" "forhold")
("release left button: finish editing" "frigør venstre knap: afslutt redigering")
("remote" "fjernbetjening")
("remote connections" "fjernforbindelser")
("remote control" "fjernbetjening")
("remote controllers with keyboard simulation" "fjernbetjeninger med tastatursimulering")
("remote directory" "fjernkatalog")
("remote login" "ekstern login")
("remote servers" "fjernservere")
("remote tool" "fjernværktøj")
("remove" "fjern")
("remove animation" "fjern animation")
("remove argument after" "fjern argument efter")
("remove argument before" "fjern argument før")
("remove banner" "fjern banner")
("remove database entry" "fjern databasepost")
("remove downwards" "fjerne nedad")
("remove entries" "fjern poster")
("remove entry" "fjern post")
("remove field above" "fjern felt ovenfor")
("remove field below" "fjern felt nedenfor")
("remove folded" "fjern foldet")
("remove from previous frames" "fjern fra tidligere rammer")
("remove from subsequent frames" "fjern fra efterfølgende rammer")
("remove last field" "fjern sidste felt")
("remove leftwards" "fjern til venstre")
("remove link" "fjern link")
("remove next field" "fjern næste felt")
("remove overlay after" "fjern overlejring efter")
("remove overlay before" "fjern overlejring før")
("remove previous field" "fjern forrige felt")
("remove rightwards" "fjern til højre")
("remove selected database entries" "fjerne valgte databaseposter")
("remove selected entries" "fjern valgte poster")
("remove slide after" "fjern dias efter")
("remove slide before" "Fjern dias før")
("remove superfluous invisible operators" "fjern overflødige usynlige operatører")
("remove tag" "fjern tag")
("remove this branch" "fjern denne gren")
("remove this frame" "fjern denne ramme")
("remove unfolded" "fjerne udfoldet")
("remove upwards" "fjerne opad")
("removed entries from database" "fjernede poster fra databasen")
("removed entry from database" "fjernet post fra databasen")
("rename" "omdøbe")
("rename section" "omdøbe afsnit")
("rendering" "gengivelse")
("rendering options for tag" "gengivelsesindstillinger for tag")
("replace TeXmacs styles with no LaTeX equivalents" "erstatte TeXmacs-stilarter uden LaTeX-ækvivalenter")
("replace all further occurrences" "erstatte alle yderligere forekomster")
("replace one occurrence" "erstatte en forekomst")
("replace toolbar" "udskift værktøjslinje")
("replace unrecognized styles" "erstatte ikke anerkendte stilarter")
("reset error counters" "reset fejltællere")
("resize" "ændre størrelse")
("resize objects" "ændre størrelse på objekter")
("restart TeXmacs in order to let changes take effect" "genstart TeXmacs for at lade ændringer træde i kraft")
("restart in order to let the new look and feel take effect" "genstart for at lade det nye udseende og virkning træde i kraft")
("retain" "beholde")
("retime" "retime")
("retina settings" "nethindusindstillinger")
("retrieve email" "hente e-mail")
("retrieve remote live document" "hente eksternt live-dokument")
("retrieved contents" "hentet indhold")
("retro" "retro")
("reverse" "omvendt")
("reverse ordering" "omvendt rækkefølge")
("ridged paper" "ridged paper")
("right baseline" "højre basislinje")
("right cell border" "højre cellekant")
("right cell padding" "højre cellepolstring")
("right down" "lige ned")
("right on even pages" "lige på lige sider")
("right table border" "højre bordkant")
("right table padding" "højre bordpolstring")
("right up" "lige op")
("rightwards" "til højre")
("rigid box" "stiv kasse")
("rotate" "rotere")
("rotate objects" "roter objekter")
("rough" "ru")
("rough paper" "ru papir")
("round" "rund")
("round overbrace" "rund overbrace")
("round underbrace" "rund underbrace")
("row above" "række over")
("row below" "række nedenfor")
("rows" "rækker")
("run" "kørsel")
("run current file" "kør nuværende fil")
("same names" "samme navne")
("same screen margins as on paper" "samme skærmmargen som på papir")
("sample text" "eksempeltekst")
("save auxiliary data" "gemme hjælpedata")
("save entries" "gem poster")
("save entry" "gem post")
("save image as" "Gem billede som")
("save position" "gem position")
("save remote file" "Gem fjernfil")
("saved modifications in database" "gemte ændringer i databasen")
("scheme command" "skema kommando")
("scheme developers guide" "guide til schemaudviklere")
("scheme extensions" "skemaudvidelser")
("scheme interface for the graphical mode" "skema interface til den grafiske tilstand")
("screen" "skærm")
("screen rendering" "skærm gengivelse")
("screens" "skærme")
("screenshot" "skærmbillede")
("scripting language" "scriptsprog")
("scripts" "scripts")
("search and replace" "søg og udskift")
("search in database" "søgning i database")
("search toolbar" "søgeværktøjslinje")
("second" "sekund")
("secret keys" "hemmelige nøgler")
("sections" "sektioner")
("see documentation" "se dokumentation")
("select GnuPG recipients" "vælg GnuPG-modtagere")
("select background picture" "vælg baggrundsbillede")
("select document style" "vælg dokumentstil")
("select pen" "vælg pen")
("select the action to be undertaken for each conflict" "vælg den handling, der skal gennemføres for hver konflikt")
("select view mode" "vælg visningstilstand")
("semantic correctness" "semantisk korrekthed")
("semantic editing" "semantisk redigering")
("semantic selections" "semantiske markeringer")
("semantics" "semantik")
("senior" "senior")
("serif" "serif")
("server" "server")
("server licence agreement" "serverlicensaftale")
("session commands" "sessionskommandoer")
("set default" "sæt standard")
("set difference" "indstillet forskel")
("set intersection" "sæt kryds")
("set number of columns" "sæt antal kolonner")
("set number of rows" "sæt antal rækker")
("set properties" "indstil egenskaber")
("set union" "sæt union")
("set user information" "indstil brugerinformation")
("seventh" "syvende")
("several equations" "flere ligninger")
("shadow" "skygge")
("shadowed" "skygge")
("shadowed raise" "skyggelagt hæve")
("shift" "skift")
("show all parts" "Vis alle dele")
("show current focus" "Vis aktuelt fokus")
("show full context" "Vis fuld kontekst")
("show key presses" "Vis tastetryk")
("show main document" "Vis hoveddokument")
("show memory usage" "Vis hukommelsesforbrug")
("show one part" "Vis en del")
("show panorama" "Vis panorama")
("show preamble" "Vis indledning")
("show several parts" "Vis flere dele")
("show subunits" "Vis underenheder")
("show table cells" "Vis tabelceller")
("show timings" "show timings")
("side tools" "sideværktøj")
("simple" "enkel")
("simple form" "enkel form")
("simple widget" "enkel widget")
("simplification" "forenkling")
("simplified evaluation of formulas" "forenklet evaluering af formler")
("simplified menus" "forenklede menuer")
("simplify" "forenkle")
("sine" "sinus")
("sixth" "sjette")
("size tag" "størrelse tag")
("skew" "skæv")
("skin" "hud")
("skip all" "spring alle over")
("slant" "skrå")
("slashed fraction" "skåret fraktion")
("slides" "lysbilleder")
("slow" "langsom")
("slow decrease" "langsomt fald")
("slow increase" "langsom stigning")
("small Capitals" "små hovedstæder")
("small capitals" "små hovedstæder")
("small environment box" "lille miljøboks")
("small focus" "lille fokus")
("small inline" "lille inline")
("small inline fraction" "lille inlinefraktion")
("smash" "smash")
("smooth" "glat")
("smooth end" "glat ende")
("smooth extremities" "glatte ekstremiteter")
("smooth start" "glat start")
("snap" "snap")
("snap distance" "snapafstand")
("snap to curves" "snap til kurver")
("snap to grid" "snap to grid")
("snap to grid curve" "snap til gitterkurve")
("snap to intersections of curves" "snap til skæringspunkter mellem kurver")
("snap to text borders" "snap til tekstgrænser")
("snap to text corners" "snap til teksthjørner")
("solution" "løsning")
("solution to exercise" "løsning på træning")
("solution to problem" "løsning på problem")
("solutions" "løsninger")
("sound" "lyd")
("source macros tool" "kildemakrosværktøj")
("south" "syd")
("south east" "sydøst")
("space bar in math mode" "mellemrumstast i matematiktilstand")
("space bar in text mode" "mellemrumstast i teksttilstand")
("space stretchability" "pladsstrækbarhed")
("span" "span")
("span over all columns" "spænder over alle kolonner")
("special functions" "specialfunktioner")
("special properties" "særlige egenskaber")
("specific baseline" "specifik baseline")
("specified" "specificeret")
("specify color alternation" "angiv farveveksling")
("specify how to traverse the manual" "specificer, hvordan man gennemgår manualen")
("specify semantics of a symbol or formula" "specificer semantik for et symbol eller formel")
("specify the size of the table" "angiv bordets størrelse")
("specify user identity" "specificer brugeridentitet")
("spell check" "stavekontrol")
("spline" "spline")
("split program" "delt program")
("square" "firkantet")
("square overbrace" "kvadratisk overbrace")
("square underbrace" "kvadratisk underbrace")
("stack" "stak")
("standard" "standard")
("standard Output" "standardudgang")
("standard fraction" "standardfraktion")
("star" "stjerne")
("start server" "start-server")
("statement" "erklæring")
("statistics" "statistik")
("status" "status")
("stop server" "stop-server")
("storage" "opbevaring")
("store tracking information in LaTeX files" "Gem sporingsinformation i LaTeX-filer")
("stretch factor" "strækfaktor")
("strict Ascii" "streng Ascii")
("strike through" "strejke igennem")
("structured insert above" "struktureret indsats ovenfor")
("structured insert at the left" "struktureret indsats til venstre")
("structured insert at the right" "struktureret indsats til højre")
("structured insert below" "struktureret indsats nedenfor")
("structured remove downwards" "struktureret fjerne nedad")
("structured remove leftwards" "struktureret fjerne venstre")
("structured remove rightwards" "struktureret fjerne højre side")
("structured remove upwards" "struktureret fjerne opad")
("structured variant" "struktureret variant")
("style options" "stilindstillinger")
("style parameters" "stilparametre")
("subject" "emne")
("submenu" "undermenu")
("subscript below" "abonnement nedenfor")
("subsubmenu" "subsubmenu")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtable")
("subtraction" "subtraktion")
("summarized" "opsummeret")
("superscript above" "superscript ovenfor")
("supported plug-ins" "understøttede plug-ins")
("surface" "overflade")
("inflate" "opsvulmet")
("switch to buffer" "skift til buffer")
("symbol browser" "symbol browser")
("symbol properties not found" "symbolegenskaber ikke fundet")
("symbols" "symboler")
("synchronization status" "synkroniseringsstatus")
("synchronize" "synkroniser")
("synchronize bibliographic references" "synkroniser bibliografiske referencer")
("synchronize file or directory" "synkroniser fil eller bibliotek")
("synchronize with remote server" "synkroniser med fjernserver")
("synopsis" "synopsis")
("system command" "systemkommando")
("tab-completion" "faneblad-færdiggørelse")
("tabbed" "fanebladet")
("table breaking" "brydning af bord")
("table height" "bordhøjde")
("table properties" "tabelegenskaber")
("table width" "bordbredde")
("tags with special rendering" "tags med særlig gengivelse")
("tangent" "tangens")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacs buffer forventet")
("teXmacs buffer on disk expected" "teXmacs-buffer på disk forventet")
("teXmacs database preferences" "teXmacs databasepræferencer")
("teXmacs extensions to scheme and utilities" "teXmacs udvidelser til skema og værktøjer")
("teXmacs macro" "teXmacs makro")
("teXmacs package" "teXmacs-pakke")
("teXmacs primitives" "teXmacs primitiver")
("teXmacs style" "teXmacs-stil")
("test routine" "testrutine")
("testing tree-view" "testning af træudsigt")
("text borders" "tekstgrænser")
("text box style" "tekstboksstil")
("text corners" "teksthjørner")
("text padding" "tekstpolstring")
("textual" "tekstmæssigt")
("textual operator" "tekstoperatør")
("textual spreadsheet" "tekstligt regneark")
("the TeXmacs plug-in system" "TeXmacs plug-in-system")
("theme parameters" "temaparametre")
("these collected public keys will be definitely lost" "disse indsamlede offentlige nøgler vil helt sikkert gå tabt")
("these public keys will be definitely lost" "disse offentlige nøgler vil helt sikkert gå tabt")
("these secret keys will be definitely lost" "disse hemmelige nøgler vil helt sikkert gå tabt")
("thicken" "tykkere")
("thin" "tynd")
("third" "tredje")
("this" "dette")
("this column" "denne kolonne")
("this page footer" "denne sidefod")
("this page header" "denne sidehoved")
("this page number" "dette sidetal")
("this row" "denne række")
("this style specifies page margins in the TeX way" "denne stil specificerer sidemargener på TeX-måde")
("three columns" "tre kolonner")
("three dots" "tre prikker")
("three times" "tre gange")
("through popup windows" "gennem popup-vinduer")
("through the menus" "gennem menuerne")
("thumbnails" "miniaturer")
("time evolution" "tidsudvikling")
("timings" "timings")
("title presentation options" "muligheder for titelpræsentation")
("title style" "titelstil")
("title suffix" "titelsuffiks")
("titled block" "titlen blok")
("toggle cell wrapping mode" "skift celleindpakningstilstand")
("toggle here" "skift her")
("toggle name" "skift navn")
("toggle numbering" "skift nummerering")
("toggle off" "slå fra")
("toggle on" "slå til")
("toggle specification" "skift specifikation")
("toggle titled" "skiftet titlen")
("tolerant" "tolerant")
("top baseline" "top baseline")
("top cell border" "øverste cellekant")
("top cell padding" "top cell polstring")
("top table border" "øverste bordkant")
("top table padding" "top bordplade")
("transform" "transform")
("transform cell into subtable" "transformer celle til undertekst")
("translations" "oversættelser")
("translations loaded" "oversættelser indlæst")
("transpose" "transponere")
("traversal" "traversal")
("traverse" "travers")
("triangle" "trekant")
("triangularize" "trekantet")
("trigonometric" "trigonometrisk")
("trigonometry" "trigonometri")
("turn off" "sluk")
("turn on" "tænd")
("turn on wallet" "tænd tegnebog")
("twice" "to gange")
("two columns" "to kolonner")
("type a latex command followed by return" "skriv en latex-kommando efterfulgt af returnering")
("unchanged" "uændret")
("underlined" "understreget")
("unextended" "uudvidet")
("unfold" "udfolde")
("unfold all" "udfold alle")
("unfold all fields" "udfolde alle felter")
("unfolded" "udfoldet")
("unit" "enhed")
("unit length" "enhedslængde")
("unknown secret key fingerprint" "ukendt hemmelig nøglefingeraftryk")
("unregistered file" "uregistreret fil")
("unroll" "unroll")
("unsecure script refused" "usikkert script nægtet")
("unsupported link mode" "ikke-understøttet linktilstand")
("until" "indtil")
("untitled block" "untitled block")
("up to date" "ajour")
("update buffer" "opdateringsbuffer")
("update this buffer" "opdater denne buffer")
("update web site" "opdateringswebsted")
("upight" "lodret")
("upload" "upload")
("upload file or directory" "upload fil eller bibliotek")
("upwards" "opad")
("url" "url")
("use CSS for more advanced formatting" "brug CSS til mere avanceret formatering")
("use MathML" "brug MathML")
("use as master" "brug som master")
("use extensible brackets" "brug udvidelige beslag")
("use high resolution fonts" "brug skrifter med høj opløsning")
("use high resolution icons" "brug ikoner med høj opløsning")
("use line wrapping for lines which are longer than 80 characters" "brug linieindpakning for linjer, der er længere end 80 tegn")
("use margin kerning (protrusion)" "brug margen kerning (fremspring)")
("use print dialogue" "brug udskriftsdialog")
("use protrusion" "brug fremspring")
("use relative path" "brug relativ sti")
("use retina fonts" "Brug retina-skrifttyper")
("use retina icons" "brug nethindesymboler")
("use unified toolbars" "brug forenede værktøjslinjer")
("user interface" "brugergrænseflade")
("user interface language" "sprog for brugergrænseflade")
("user preferences" "brugerpræferencer")
("users of oriental languages" "brugere af orientalske sprog")
("utf-8 with inputenc" "utf-8 med inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 med inputenc LaTeX-pakke")
("utilities" "værktøjer")
("vanish" "forsvinde")
("verbose" "verbose")
("version" "version")
("versioning tool" "versioneringsværktøj")
("vertical alignment" "lodret justering")
("vertical margins" "lodrette marginer")
("vertical space after" "lodret rum efter")
("vertical space before" "lodret rum før")
("vertical space stretchability" "lodret pladsstrækbarhed")
("visible except here" "synlig undtagen her")
("visible from here on" "synlig herfra og med")
("visible only here" "kun synlig her")
("visible until here" "synlig indtil her")
("visited loci" "besøgte loci")
("wallet" "tegnebog")
("wave" "bølge")
("weight" "vægt")
("when line wrapping" "når linieindpakning")
("when wrapping" "ved indpakning")
("whitespace" "hvidafstand")
("wide" "bred")
("wide block" "bred blokering")
("wide colored" "bredfarvet")
("wide float" "bred float")
("wide footnote" "bred fodnote")
("wide tabular" "bred tabel")
("widescreen" "widescreen")
("with newer version" "med nyere version")
("with older version" "med ældre version")
("wrap lines" "indpakningslinjer")
("writing TeXmacs bibliography styles" "at skrive TeXmacs bibliografi-stilarter")
("writing documentation" "skriftlig dokumentation")
("wrong empty passphrase" "forkert tom adgangskode")
("wrong passphrase" "forkert adgangssætning")
("year" "år")
("year, Name" "år, navn")
("you are attempting to open an encrypted file while" "du forsøger at åbne en krypteret fil mens")
("you might consider enabling the experimental" "kan du overveje at aktivere det eksperimentelle")
("you must add a bibliography file" "du skal tilføje en bibliografifil")
("you should also make sure that GnuPG is installed" "skal du også sørge for, at GnuPG er installeret")
("your personal dictionary has been modified" "din personlige ordbog er blevet ændret")
("zebra" "zebra")
("zoom" "zoom")
("zoom in" "zoom ind")
("zoom out" "zoom ud")
("zoom/unzoom objects" "zoom / fjernzoom objekter")
