
###############################################################################
##
## MODULE      : tmlasterr.m
## COPYRIGHT   : (C) 2004  Joris van der Hoeven
##
## This software falls under the GNU general public license version 3 or later.
## It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
## in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.


function tmlasterr ()
  eval ("fdisp(stderr,lasterr)","fdisp(stderr,'error')");
endfunction
