("a modifier" "")
("a series" "A 系列")
("abbreviation" "缩写")
("about" "关于")
("about menu" "关于菜单")
("above" "以上")
("abstract" "摘要")
("accent" "读音符号")
("accent above" "顶部标记")
("accent below" "底部标记")
("accept" "接受")
("accept all scripts" "接受所有脚本")
("accept no scripts" "不接受任何脚本")
("accept script" "接受脚本")
("acknowledgment" "感谢辞")
("acknowledgments" "鸣谢")
("acronym" "缩略词")
("action" "动作")
("activate" "激活")
("activate once" "仅激活一次")
("activate hidden" "激活隐藏内容")
("activation" "激活")
("acute" "")
("add branch after" "在后面添加一个")
("add branch before" "在前面添加一个")
("add package" "增加宏包")
("add style package" "增加宏包")
("add switch after" "")
("add switch before" "")
("add other package" "增加其他宏包")
("address" "地址")
("address block" "地址栏")
("adjust" "调整")
("advanced" "高级")
("advanced layout features" "高级布局特性")
("after" "之后")
("albanian" "阿尔巴尼亚语")
("algorithm" "算法")
("align cell to the bottom" "单元格向下对齐")
("align cell to the left" "单元格向左对齐")
("align cell to the right" "单元格向右对齐")
("align cell to the top" "单元格向上对齐")
("align table at base of left column" "表格左对齐")
("align table at base of middle column" "表格居中对齐")
("align table at base of origin column" "")
("align table at base of right column" "表格右对齐")
("align table at fraction bar height" "")
("align table at the base of bottom row" "")
("align table at the base of middle row" "")
("align table at the base of origin row" "")
("align table at the base of top row" "")
("align table at the bottom" "")
("align table at the center" "")
("align table at the horizontal center" "")
("align table at the left" "")
("align table at the top" "")
("align table to the right" "")
("align text to the left" "")
("align text to the right" "")
("aligned" "对齐")
("alignment" "对齐")
("all" "全部")
("allow" "允许")
("allow for macro definitions in preamble" "在导言中允许使用宏定义")
("allowed extension" "允许扩展")
("allowed reduction" "允许缩小")
("alpha release" "alpha 版本")
("also on paper" "在纸上显示")
("alt key" "alt 键")
("alternative specification" "替代规格")
("always" "总是")
("american" "美国英语")
("animation" "动画")
("animation toolbar" "动画工具栏")
("answer" "答案")
("and" "与")
("angular" "角")
("appendix" "附录")
("apply" "使用")
("apply macro" "使用宏")
("apply macro once" "仅这次使用宏")
("april" "四月")
("arab" "阿拉伯")
("arc" "圆弧")
("arch series" "arch 规格")
("archaic" "古代的")
("architecture" "结构")
("argument" "参数")
("arithmetic" "算术")
("armenian" "亚美尼亚语")
("arrow" "箭头")
("arrows" "箭头")
("article" "文章")
("as on paper" "如同在纸上一样的")
("as visual grid" "作为可视网格")
("assign" "指定")
("at fraction bar height" "在分式线高度")
("at the baseline" "在基线")
("at the bottom" "在底部")
("at the left" "在左边")
("at the middle" "在中间")
("at the right" "在右边")
("at the top" "在顶部")
("attach" "连接")
("attach buffer to which project" "连接缓冲至哪个工程")
("attach master" "关联主文件")
("august" "八月")
("author" "作者")
("authorize" "授权")
("auto" "自动")
("automatic" "自动")
("automatic content generation" "内容的自动生成")
("automatically close brackets" "自动补全括号")
("automatically generated content" "自动生成的内容")
("automatic quotes" "自动补全引号")
("automatic brackets" "自动补全括号")
("automatic correction" "自动纠正")
("automatically save" "自动保存")
("autosave" "自动保存")
("axis" "轴线")
("axiom" "公理")
("b series" "B 系列")
("back" "后退")
("background" "背景色")
("background color" "背景色")
("background colour" "背景色")
("background evaluations" "在后台运算")
("backward replace" "向上替换")
("backward search" "向上搜索")
("bad data format" "")
("balloon" "气泡")
("bar" "上划线")
("bard" "诗人")
("base" "基线")
("base level" "基准面")
("bashkirian" "巴什基尔语")
("baseline" "基线")
("basic" "基本的")
("basic communication using pipes" "基本管道通信")
("basic data types" "基本数据类型")
("basic types" "基本型态")
("be useful" "有用")
("beamer" "演示")
("become a TeXmacs developer" "成为 TeXmacs 的开发者")
("before" "之前")
("begin" "开始")
("below" "下面")
("beta release" "β 版")
("bibliography" "参考文献")
("bibliography file" "参考文献文件")
("bibliography style" "参考文献的样式文件")
("bibtex command" "bibtex 程序")
("big" "大")
("big figure" "大图片标题")
("big operator" "大运算符")
("big skip" "大间距")
("big table" "大表格")
("bitmap resolution" "位图分辨率")
("binary operation" "二元运算")
("binary relation" "二元关系")
("black" "黑色")
("blackboard bold" "黑板粗体")
("blackboard math" "黑板数学字体")
("blackletter" "黑色字母")
("blank column" "空列")
("blank row" "空行")
("block" "有框表格")
("block content" "空白内容")
("block of code" "代码块")
("blue" "蓝色")
("body" "体")
("bold" "粗体")
("book" "书籍")
("border" "边界")
("both" "两者")
("both versions" "两个版本")
("bottom" "底部")
("bottom border" "底部边界")
("bottom cell border" "底部单元格边界")
("bottom cell padding" "底部单元格填充")
("bottom margin" "下边距")
("bottom padding" "底部填充")
("bottom table border" "底部表格边界")
("bottom table padding" "底部表格填充")
("branch" "分支")
("break" "断开")
("breaking" "断行")
("breve" "短音符")
("british" "英式英语")
("broken white" "碎白")
("brown" "褐色")
("browse" "浏览")
("browse back" "后退")
("browse forward" "前进")
("browse modules documentation" "浏览模块的文档")
("browse symbols documentation" "浏览符号的文档")
("browse web" "浏览网页")
("browser" "浏览器")
("buffer" "缓冲")
("buffer management" "缓冲区管理")
("bulgarian" "保加利亚文")
("bullet" "圆点")
("bullets" "圆点")
("by" "by")
("by typing" "通过输入")
("bytes free" "0 bytes ")
("bytes used" "使用 bytes 总数")
("calculus" "微积分")
("calligraphic" "书法字体")
("cancel" "取消")
("cartesian" "直角坐标")
("case" "")
("case-insensitive search" "搜索时大小写不敏感")
("cc" "")
("cell" "单元格")
("cell background color" "单元格背景颜色")
("cell border" "单元格边框")
("cell height" "单元格高度")
("cell operation mode" "单元格操作模式")
("cell properties" "单元格属性")
("cell width" "单元格宽度")
("cells" "单元格")
("center" "居中")
("center text" "原文中间")
("centered" "居中")
("centered block" "居中有框表格")
("centered tabular" "居中无框表格")
("change border of cell" "改变单元格边框")
("change cell operation mode" "改变单元格操作模式")
("change log" "更新记录")
("change tags" "改变标记")
("change the border of the table" "改变表格边框")
("change the TeXmacs preferences" "更改TeXmacs设置")
("changes" "改变")
("chapter" "章")
("character encoding" "字符编码")
("check" "检查")
("check for updates" "检查更新")
("check for automatic updates" "检测自动更新")
("check text for spelling errors" "检查拼写")
("chinese" "简体中文")
("choice" "选择")
("circle" "圆圈")
("citation" "引用")
("cite" "引文")
("cite TeXmacs" "引用TeXmacs")
("class" "类")
("clear" "清除")
("clear all fields" "清除全部区域")
("clear font cache" "清除字体缓存")
("clear menu" "清除列表")
("clear selection" "清除选择")
("clear undo history" "清除撤销记录")
("clipped" "裁剪")
("clipped and magnified" "裁剪与放大")
("clipped and resized" "裁剪与调整大小")
("clone" "克隆")
("clone window" "克隆窗口")
("close" "退出")
("close TeXmacs" "退出程序")
("close buffer" "退出暂存区")
("close document" "关闭文档")
("close session" "关闭会话")
("close this document" "关闭当前文档")
("close window" "关闭窗口")
("closed spline" "闭合样条曲线")
("closing" "")
("closing style" "结束风格")
("code" "代码")
("color" "颜色")
("colors" "颜色")
("color of the axes" "坐标轴颜色")
("color of the units" "单元颜色")
("color of the subunits" "子单元颜色")
("column" "列")
("column contains glued items" "")
("column to the left" "列(在左侧)")
("column to the right" "列(在右侧)")
("columns" "列")
("comment" "批注")
("common formats" "常见格式")
("compact" "紧凑")
("compactification" "紧化")
("compactify" "紧凑性")
("compare" "比较")
("compatibility with other formats" "与其它格式的兼容")
("compile article" "编译文章")
("compile book" "编译书籍")
("compile buffer" "编译暂存")
("compile project" "编译工程")
("completion" "完成")
("complex" "复杂")
("complex actions" "复杂操作")
("compose" "组合")
("compress" "压缩")
("concrete" "")
("condensed" "压缩")
("condition" "条件")
("configuration" "配置")
("consoles" "控制台")
("contact" "联系")
("content" "内容")
("content tag" "内容标记")
("context dependent icons" "相关工具栏")
("continuation of" "延续")
("contribute" "参与")
("control flow" "流程控制")
("control the evaluation of expressions" "式子表现的控制")
("convention" "惯例")
("convert" "转换")
("converters" "转换器")
("converters to other data formats" "到其它格式的转换器")
("copy" "复制")
("copy text" "复制文本")
("copy to" "复制到")
("copying" "复制中")
("corollary" "推论")
("correct text" "")
("count characters" "统计字数")
("count lines" "统计行数")
("count words" "统计单词数")
("create a new document" "新建文档")
("create preamble" "生成导言")
("create subsession" "创建子会话")
("creating technical pictures" "内置作图工具")
("create web site" "生成网站")
("croatian" "克罗地亚语")
("crop" "剪裁")
("current version" "当前版本")
("cursors" "游标")
("curve" "曲线")
("custom tab" "自定义制表符")
("customizations" "定制")
("customize" "定制")
("customizing and extending the user interface" "配置和扩展用户界面")
("customizing TeXmacs" "定制 TeXmacs ")
("customizing the TeXmacs styles" "定制 TeXmacs 样式")
("custom tab" "自定义制表符")
("cut" "剪切")
("cut text" "剪切文本")
("cut to" "剪切到")
("cypriot" "塞浦路斯语")
("cyrillic" "")
("cyrillic input method" "西里尔字母语言输入法")
("cyrillic italic right" "")
("czech" "捷克语")
("dancers" "舞者")
("danish" "丹麦语")
("dark grey" "深灰")
("dash" "短线")
("dash style" "短线风格")
("dash unit" "短线单位")
("dashes" "短线")
("data" "数据")
("data conversion" "数据转换")
("data format" "数据格式")
("database" "数据库")
("database tool" "数据库工具")
("database toolbar" "数据库工具栏")
("date" "日期")
("deactivate" "关闭")
("deactivate table" "关闭表格")
("debug" "调试")
("debugging console" "调试控制台")
("debugging tool" "调试工具")
("december" "十二月")
("decimal comma" "小数逗号")
("decimal dot" "小数点")
("decorate atoms" "")
("default" "默认")
("default padding" "默认填充")
("definition" "定义")
("delete" "删除")
("delete column" "删除此行")
("delete documentation cache" "删除文档缓存")
("delete row" "删除此列")
("denominator" "分母")
("describe" "介绍")
("describe tag" "介绍标记")
("description" "描述列表")
("description aligned" "描述列表(对齐)")
("description compact" "描述列表(紧凑)")
("description dash" "描述列表(短线)")
("description long" "描述列表(细长)")
("destination" "目标")
("det" "行列式")
("detach" "脱离")
("detach master" "脱离主文件")
("detailed" "详细")
("detailed menus" "详细菜单")
("details in menus" "显示菜单")
("determinant" "行列式")
("devangari" "梵语")
("developers guide" "程序源码")
("directory" "目录")
("disable" "禁用")
("disable first indentation" "禁用首段缩进")
("disable first indentation after" "")
("disable first indentation before" "")
("disable indentation" "")
("disable indentation after" "禁止后面缩进")
("disable indentation before" "禁止前面缩进")
("deactivate" "")
("deactivate once" "")
("developer" "开发者")
("developer tool" "开发工具")
("disallow" "")
("disk" "圆盘")
("displayed formula" "行间公式")
("display style" "展示风格")
("distribute unused space" "分配未使用空隙")
("div" "")
("do not remap" "")
("document" "文档")
("document language" "文档语言")
("document format" "文档格式")
("document page format" "文档页面格式")
("document paragraph format" "文档段落格式")
("document updates run" "执行文档更新")
("document style" "文档样式")
("document styles" "文档样式")
("documentation" "文档")
("documents are trees" "树状文书")
("dot" "点")
("dots" "点")
("double stroke" "")
("down" "下")
("download" "下载")
("downwards" "往下边")
("dpi" "")
("draw image" "绘制图形")
("draw over selection" "在选择区域内绘制")
("duplicate" "副本")
("dutch" "荷兰语")
("dynamic" "演示")
("dynamic libraries" "动态链接库")
("edit" "编辑")
("edit comment" "编辑批注")
("edit comments" "编辑所有批注")
("edit table" "编辑表格")
("edit grid" "编辑网格")
("edit keyboard shortcuts" "编辑键盘快捷键")
("edit macro" "编辑宏")
("edit package" "编辑宏包")
("edit style" "编辑样式")
("edit source" "编辑源码")
("edit source tree" "编辑源码树")
("edit translations file" "编辑翻译文件")
("editing tools" "编辑工具")
("education" "教育")
("elsevier" "爱思唯尔")
("email" "电子邮件")
("emphasize" "强调")
("emphasize text" "强调文本")
("empty box" "空白的区域")
("enable change" "允许改变")
("enable first indentation" "")
("enable first indentation after" "")
("enable first indentation before" "")
("enable indentation" "允许缩进")
("enable indentation after" "允许后面缩进")
("enable indentation before" "允许前面缩进")
("encryption" "加密")
("encl" "")
("encoding" "编码")
("end" "结束")
("english" "英语")
("enter a title" "输入标题")
("enter data" "输入数据")
("entire column" "整列")
("entire row" "整行")
("entire table" "整个表格")
("enumerate" "有序列表")
("enumerate Alpha" "有序列表(大写字母)")
("enumerate Roman" "有序列表(大写罗马数字)")
("enumerate alpha" "有序列表(小写字母)")
("enumerate roman" "有序列表(小写罗马数字)")
("enumerate numeric" "有序列表(阿拉伯数字)")
("enunciation" "说明")
("env" "")
("environment" "环境")
("epilogue" "")
("equal" "等于")
("equation" "单行方程")
("equations" "多行方程")
("equivalent for" "")
("error" "错误")
("error messages" "错误信息")
("esperanto" "世界语")
("etruscan" "")
("evaluate" "求值")
("evaluate all" "全部求值")
("evaluate above" "求上面各值")
("evaluate below" "求下面各值")
("evaluate fields" "对区域求值")
("evaluate scheme expression" "执行 scheme 表达式")
("evaluation" "赋值")
("even page" "偶数页")
("even pages" "偶数页")
("even page footer" "偶数页页脚")
("even page header" "偶数页页眉")
("even page margin" "")
("even page left margin" "偶数页左边距")
("even page shift" "偶数页偏移")
("even page text" "")
("exact" "固定")
("exact horizontal" "")
("exact mode" "")
("exam" "试卷")
("example" "例")
("exclusive" "排他的")
("exclusive or" "")
("executable" "可运行")
("execute" "运行")
("execute a TeXmacs command" "运行 TeXmacs 命令")
("execute system command" "运行系统命令")
("executive" "行政")
("exercise" "练习")
("exit left" "从左边跳出")
("exit right" "从右边跳出")
("exit tag on the left" "从左边跳出")
("exit tag on the right" "从右边跳出")
("expand" "展开")
("expand inclusions" "扩展包含文件")
("expand unrecognized macros" "展开无法识别的宏命令")
("expand user-defined macros" "展开用户定义的宏命令")
("experimental" "试验")
("explained" "解释")
("export" "导出")
("export as" "转换成")
("export bibliographies as links" "将参考文献导出为链接")
("export formulas as images" "将公式转换成图像")
("export selections as" "将选中区域导出为")
("export selection as image" "将选中区域导出为图像")
("export mathematical formulas as images" "将数学公式导出为图像")
("export mathematical formulas as mathml" "将数学公式导出为MathML")
("export sessions" "导出会话")
("extend or normal" "")
("extents" "范围")
("extern " "")
("extra" "")
("extract format" "")
("family" "")
("february" "")
("field" "区域")
("figure" "图")
("file" "文件")
("file name" "文件名")
("file not found" "无此文件")
("files of type" "文件类型")
("fill color" "填充色")
("find next match" "查找下一个")
("find text" "查找文本")
("finnish" "芬兰语")
("first" "最前面")
("first comment" "第一处批注")
("first contact" "初次接触")
("first difference" "第一处差异")
("first field" "最前面的区域")
("first indentation" "首行缩进")
("first item" "")
("first page" "")
("first similar" "相似的(最前面)")
("first start" "开始第一次")
("fit to screen" "适合高度")
("fit to screen width" "适合宽度")
("fixed" "固定")
("flat" "扁平")
("flexibility" "弹性")
("flexibility factor for vertical spacing" "")
("floating algorithm" "浮动算法")
("floating figure" "浮动图形")
("floating object" "浮动对象")
("floating table" "浮动表格")
("focus" "焦点")
("focus dependent icons" "焦点工具栏")
("fold" "折叠")
("fold comments" "折叠所有批注")
("fold all fields" "折叠全部区域")
("fold input field" "折叠输入区域")
("folded" "")
("font" "字体")
("font base size" "字体基本大小")
("font dpi" "字体 dpi")
("font effects" "字体效果")
("font family" "字体族")
("font name" "字体名称")
("font selector" "字体选择器")
("font series" "字体系列")
("font shape" "字型")
("font size" "字号")
("font type" "字体类型")
("font variant" "")
("fonts" "字体")
("footer" "页脚")
("footnote" "脚注")
("for" "")
("force reloading of translations" "强制重新载入翻译文件")
("foreground" "前景色")
("foreground color" "前景色")
("foreground colour" "前景色")
("foreign" "")
("format" "格式")
("formatted and structured output" "格式化和结构化输出")
("formatted date" "格式化日期")
("formatting" "格式")
("formula" "公式")
("formula style" "公式样式")
("forward" "前进")
("forward replace" "向上替换")
("forward search" "向上搜索")
("fraction" "分式")
("frame" "框架")
("french" "法语")
("from center" "从中心")
("front matter" "前置部分")
("full manuals" "完全手册")
("full screen mode" "全屏模式")
("function" "")
("functional" "")
("further customization" "")
("future changes" "")
("GNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs 不提供任何保证")
("GNU TeXmacs falls under the GNU general public license" "GNU TeXmacs 使用 GNU 通用公共许可授权")
("general" "通用")
("general architecture of TeXmacs" "TeXmacs 的整体架构")
("general negation" "通用的否定符号")
("general note" "一般注记")
("generating font file" "字体文件制作中")
("generic" "普通")
("geometry" "几何")
("georgian" "格鲁吉亚语")
("german" "德语")
("getting started" "开始使用")
("glossary" "术语表")
("glossary entry" "术语项")
("glue" "")
("glue decorations" "")
("go" "转到")
("go to first similar tag" "跳到开始的类似标记")
("go to last similar tag" "跳到末尾的类似标记")
("go to next similar tag" "跳到后一个类似标记")
("go to previous similar tag" "跳到前一个类似标记")
("go to section" "跳到某节")
("gothic" "")
("grain" "粒度")
("graphical interface" "图形界面")
("graphical effects" "图形效果")
("graphics" "图形")
("grave" "")
("greater" "大于")
("greater or equal" "大于等于")
("greek" "希腊语")
("greek letter" "希腊字母")
("green" "绿色")
("grey" "灰色")
("grid" "网格")
("grids" "网格")
("group" "")
("group/ungroup" "分组/打散")
("gui" "界面")
("h modifier" "")
("happy typing" "")
("has been aborted" "")
("has completed its task" "")
("hat" "")
("header" "页眉")
("header bars" "顶部各栏")
("header and footer" "页眉页脚")
("hebrew" "")
("height" "高度")
("height is exactly the specified height" "")
("height is maximum of specified height and box height" "")
("height is minimum of specified height and box height" "")
("height magnification" "")
("help" "帮助")
("help me" "帮助我")
("help us" "帮助我们")
("here" "这里")
("hidden" "隐藏")
("highlight errors" "高亮错误")
("high resolution settings" "高分屏设置")
("history" "历史")
("home" "主页")
("homepage" "主页")
("horizontal" "水平")
("horizontal cell alignment" "")
("horizontal ink separation" "")
("horizontal part" "水平部分")
("horizontal position" "")
("horizontal space" "")
("horizontal alignment" "水平对齐")
("horizontally align cell to the base" "")
("horizontally center the cell" "")
("how much longer may pages become" "")
("how much shorter may pages become" "")
("huge" "巨大")
("hungarian" "匈牙利语")
("hybrid command" "")
("hyperlink" "超链接")
("hyphenation" "连字符")
("icelandic" "")
("if" "如果")
("if hyphenated" "有连字符时")
("image" "图片")
("image links" "图片链接")
("implementation" "")
("import" "导入")
("import selections as" "导入到选中区域")
("import sessions" "导入会话")
("improving the current implementation" "改进当前的实作")
("in popup windows" "在弹出窗口")
("inactive" "")
("include" "包含文件")
("include a document" "")
("include file" "")
("inclusion into TeXmacs" "")
("inclusions" "包含文件")
("indent" "缩进")
("indentation" "缩进")
("indentation flag" "对齐标签")
("index" "索引")
("index entry" "索引项")
("index level" "下标层次")
("informative flags" "非正式标记")
("inline arguments" "行内参数")
("inline code" "行内代码")
("inline formula" "行内公式")
("input mode" "输入模式")
("input options" "输入选项")
("insert" "插入")
("insert Pr" "")
("insert a TeXmacs symbol" "")
("insert a big operator" "插入大运算符")
("insert a binary operation" "插入二元运算")
("insert a binary relation" "插入二元关系")
("insert a blackboard bold character" "插入黑板字母")
("insert a bold calligraphic character" "")
("insert a bold character" "插入粗体字母")
("insert a calligraphic character" "插入书法字母")
("insert a computer program" "插入计算机程序")
("insert a condition" "")
("insert a control flow instruction" "")
("insert a fraction" "插入分式")
("insert a fraktur character" "插入哥特字母")
("insert a greek character" "插入希腊字母")
("insert a large left delimiter" "插入大开始括号")
("insert a large right delimiter" "插入大结束括号")
("insert a large separator" "插入大分隔符")
("insert a left subscript" "")
("insert a link" "插入链接")
("insert a list" "插入列表")
("insert a miscellaneous symbol" "插入杂项符号")
("insert a negation" "插入否定符号")
("insert a new branch" "")
("insert a new item" "添加一项")
("insert a note or a floating object" "插入注释或浮动对象")
("insert a numerical operation" "")
("insert a picture" "插入图片")
("insert a script" "插入上下标")
("insert a square root" "插入平方根")
("insert a table" "插入表格")
("insert a table or a matrix" "")
("insert a textual operator" "插入文本运算符")
("insert a wide symbol above" "")
("insert a wide symbol below" "")
("insert above" "插入行(在上方)")
("insert an" "")
("insert an accent" "插入重音符号")
("insert an arrow" "插入箭头符号")
("insert an environment" "插入环境")
("insert an n" "")
("insert an n-th root" "插入高次方根")
("insert an operation on tuples" "")
("insert animation" "插入动画")
("insert appendix" "")
("insert arccos" "")
("insert arcsin" "")
("insert arctan" "")
("insert arg" "")
("insert argument" "")
("insert argument after" "在后面插入参数")
("insert argument before" "在前面插入参数")
("insert author" "插入作者名")
("insert automatically generated content" "插入自动生成的内容")
("insert below" "插入行(在下方)")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "")
("insert big intersection" "")
("insert big logical and" "")
("insert big logical or" "")
("insert big product" "")
("insert big square union" "")
("insert big summation" "")
("insert big tensor product" "")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "")
("insert chapter" "")
("insert column" "")
("insert column to the left" "插入列(在左侧)")
("insert column to the right" "插入列(在右侧)")
("insert cos" "")
("insert cosh" "")
("insert cot" "")
("insert coth" "")
("insert csc" "")
("insert deg" "")
("insert det" "")
("insert dim" "")
("insert dollar" "")
("insert equation" "")
("insert executable markup" "")
("insert exp" "")
("insert field above" "在前面添加区域")
("insert field below" "在后面添加区域")
("insert text field above" "在前面添加文本区域")
("insert text field below" "在后面添加文本区域")
("insert fields" "")
("insert footnote" "")
("insert formula" "")
("insert gcd" "")
("insert hom" "")
("insert horizontal interword space" "")
("insert image" "插入图片")
("insert inactive markup" "")
("insert inf" "")
("insert input field above" "")
("insert input field below" "")
("insert ker" "")
("insert left" "插入列(在左侧)")
("insert lg" "")
("insert lim" "")
("insert liminf" "")
("insert limsup" "")
("insert ln" "")
("insert log" "")
("insert macro" "插入宏")
("insert mathematics" "插入数学")
("insert max" "插入最大值")
("insert medium horizontal space" "")
("insert medium vertical space" "")
("insert min" "插入最小值")
("insert negative horizontal space" "")
("insert new item or number" "插入新项或序号")
("insert new rows or columns" "插入新行或列")
("insert or delete rows or columns" "插入或删除行或列")
("insert plain text" "插入纯文本")
("insert right" "在右侧插入列")
("insert row" "插入行")
("insert row above" "在上方插入行")
("insert row below" "在下方插入行")
("insert sec" "插入节")
("insert section" "输入节(section) ")
("insert sharp" "")
("insert sin" "插入正弦函数 sin")
("insert sinh" "插入双曲正弦函数 sinh")
("insert small horizontal space" "")
("insert small vertical space" "")
("insert structural markup" "")
("insert subsection" "")
("insert subsubsection" "")
("insert sup" "")
("insert table" "插入表格")
("insert tan" "")
("insert tanh" "")
("insert text field" "")
("insert thick horizontal space" "")
("insert title" "插入标题")
("insert value" "")
("insertion" "嵌入")
("interactive command" "")
("interactive questions" "显示询问")
("interfacing" "用户界面")
("interfacing TeXmacs with other systems" "与其它系统交互")
("interjection" "")
("interline separation" "行间分隔")
("interline space" "行间空隔")
("internationalization" "国际化")
("interparagraph space" "段落间空隔")
("interrupt execution" "中断执行")
("introduction" "介绍")
("invisible" "不可见")
("invisible citation" "")
("irish" "")
("is running" "")
("is tuple" "")
("ispell does not respond" "")
("ispell is already busy" "")
("italian" "意大利语")
("italic" "斜体")
("italic right" "")
("itemize" "无序列表")
("itemize arrow" "无序列表(箭头)")
("itemize dot" "无序列表(圆点)")
("itemize minus" "无序列表(短线)")
("january" "")
("japanese" "日语")
("july" "")
("june" "")
("justified" "两端对齐")
("justify text" "")
("key" "")
("keyboard" "键盘")
("keyboard configuration" "键盘配置")
("keyboard equivalent" "等效快捷键")
("keyboard modifiers" "")
("keyboard shortcut" "键盘快捷键")
("keymaps" "")
("keyword" "关键字")
("keywords" "关键词")
("kill" "")
("known bugs" "已知缺陷")
("korean" "韩语")
("label" "标签")
("landscape" "横向")
("language" "语言")
("laptop presentations" "幻灯片演示")
("large" "大")
("large closing bracket" "大结束括号")
("large delimiter" "")
("large opening bracket" "大开始括号")
("large separator" "大分隔符")
("last" "最后面")
("last check" "最近一次检测")
("last comment" "最后一处批注")
("last difference" "最后一处差异")
("last field" "最后面的区域")
("last page" "")
("last similar" "相似的(最后面)")
("latex command" "LaTeX命令")
("latin" "")
("layout" "布局")
("left" "左边")
("left arrow" "")
("left border" "左端")
("left cell border" "")
("left cell padding" "")
("left margin" "左边距")
("left padding" "")
("left prime" "")
("left aligned" "左对齐")
("left slanted" "左倾斜")
("left subscript" "左下标")
("left superscript" "左上标")
("left surrounding" "")
("left table border" "")
("left table padding" "")
("leftwards" "往左边")
("legal" "法律")
("lemma" "引理")
("length" "")
("less" "")
("less or equal" "")
("letter" "信件")
("license" "许可")
("light" "细黑")
("light grey" "淡灰")
("limitations" "")
("limits" "极限")
("line" "线")
("line arrows" "线箭头")
("line break" "允许换行")
("line breaking" "断行算法")
("line properties" "线属性")
("line stretch" "")
("line width" "线宽度")
("linear algebra" "线性代数")
("link" "链接")
("link image" "链接图片")
("linking tool" "链接菜单")
("link to URL" "URL链接")
("list" "")
("list of figures" "图形目录")
("list of tables" "表格目录")
("load" "打开")
("load LaTeX file" "打开 LaTeX 文件")
("load TeX file" "打开 TeX 文件")
("load TeXmacs file" "打开 TeXmacs 文件")
("load TeXmacs style file" "打开 TeXmacs 样式文件")
("load a file" "打开文件")
("load buffer" "")
("load file" "打开文件")
("load html file" "")
("load image" "")
("load in new window" "在新窗口打开")
("load latex file" "")
("load more recent autosave file" "打开最近自动保存的文件")
("load tex file" "打开 TeX 文件")
("load verbatim file" "")
("loaded" "")
("logarithmic" "对数坐标")
("logarithmic base" "对数的底")
("logarithms" "对数")
("login" "登录")
("long" "细长")
("look and feel" "快捷键风格")
("look for more fonts" "查找更多字体")
("look up" "")
("lower border" "下端")
("m modifier" "")
("macro" "宏命令")
("macros" "宏命令")
("magenta" "紫红")
("magic" "")
("magnification" "放大比例")
("magnified" "")
("main" "主要")
("main icon bar" "主要工具栏")
("major changes" "重要改变")
("make a page insertion" "页面插入")
("make a subscript" "插入下标")
("make a superscript" "插入上标")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "")
("make grave" "")
("make hat" "")
("make label" "")
("make negation" "")
("make page reference" "")
("make reference" "")
("make slides" "展开幻灯片")
("make square root" "")
("make tilde" "")
("make title" "表题制作")
("make vector" "")
("making donations" "捐赠")
("manual" "用户手册")
("manual correction" "手动纠正")
("map to" "")
("march" "")
("margins" "边白")
("margins as on paper" "在纸上显示边白")
("master" "")
("master file" "")
("math" "数学")
("math font" "")
("math font family" "")
("math font series" "")
("math font shape" "")
("mathematical" "")
("mathematical and customized input" "数学和定制的输入")
("mathematical font" "数学字体")
("mathematical formulas" "数学公式")
("mathematical input" "数学输入")
("mathematical output" "数学输出")
("mathematical typesetting" "数学排版")
("mathematics" "数学")
("matrix" "矩阵")
("maximal" "最大")
("maximal number of columns" "行数最大值")
("maximal number of rows" "列数最大值")
("maximum mode" "")
("may" "")
("medium" "适中")
("medium skip" "中间距")
("meminfo" "")
("memory" "内存")
("memory usage" "内存占用")
("merge" "")
("messy" "")
("meta" "win")
("metadata" "元数据")
("meta key" "")
("metafont and available type" "优先使用 Metafont 字体")
("metafont bitmaps only" "仅只使用 Metafont 字体")
("middle" "居中")
("minimal" "最小")
("minimal number of columns" "行数最小值")
("minimal number of rows" "列数最小值")
("minimum mode" "")
("minus" "")
("miscellaneous" "杂项")
("miscellaneous features" "其它特性")
("mod" "")
("mode" "模式")
("mode dependent icons" "模式工具栏")
("modifier" "")
("modify cell alignment" "改变单元格对齐")
("modify cell border" "")
("modify cell padding" "")
("modify cell size" "改变单元格大小")
("modify table border" "")
("modify table padding" "")
("mongolian" "")
("more information about GNU TeXmacs can be found in the Help" "更多关于 GNU TeXmacs 的信息可查看帮助")
("mosaic" "")
("move" "移动")
("move down" "")
("move object" "")
("move to the right when finished" "输入完成后移动光标到右边")
("move up" "")
("multiline input" "多行输入")
("multiple root" "高次方根")
("mutator tags" "")
("my documents" "个人文档")
("n-th" "")
("n-th root" "")
("name" "名称")
("negation" "否定")
("never" "从不")
("new" "新建")
("new account" "新建账号")
("new buffer" "")
("new column" "添加一行")
("new document" "新建文档")
("new double page" "新起双页")
("new double page before" "新起双页(在前面)")
("new folded comment" "新建折叠批注")
("new item" "添加一项")
("new line" "新起一行")
("new macro" "新建宏")
("new number" "")
("new page" "新起一页")
("new page before" "新起一页(在前面)")
("new paragraph" "新起段落")
("new roman" "")
("new row" "")
("new table" "")
("new unfolded comment" "新建展开批注")
("new version" "新版")
("new window" "新窗口")
("next" "后一个")
("next comment" "下一处批注")
("next difference" "后一处差异")
("next field" "下一个区域")
("next line" "")
("next similar" "相似的(后一个)")
("n-th root" "高次方根")
("no" "否")
("no changes need to be saved" "没有任何更改需要保存")
("no dictionary for" "")
("no first indentation" "")
("no grid" "无网格")
("no indentation" "")
("no line break" "禁止换行")
("no matches found" "")
("no matches found for" "")
("no more matches for" "")
("no more redo information available" "")
("no more undo information available" "")
("no name" "无标题文件")
("no page break" "禁止换页")
("no page break after" "禁止换页(在后面)")
("no page break before" "禁止换页(在前面)")
("no spelling errors found in text" "")
("no style" "无样式")
("none" "无")
("normal" "标准")
("norwegian" "挪威文")
("not" "")
("not equal" "")
("not found" "")
("notation" "记法")
("note" "注记")
("november" "")
("number" "")
("number of columns" "栏数")
("number of polar steps" "极坐标步数")
("number of subunit steps" "子单元步数")
("number equation" "编号方程")
("numbered" "编号")
("numbered equation" "")
("numbered equations" "")
("numbering" "页码")
("numerator" "分子")
("numeric" "")
("objectives" "")
("occurrences" "")
("october" "")
("odd page" "奇数页")
("odd page footer" "奇数页页脚")
("odd page header" "奇数页页眉")
("odd page margin" "")
("odd page left margin" "奇数页左边距")
("odd page right margin" "奇数页右边距")
("odd page shift" "奇数页偏移")
("odd page text" "")
("off" "关闭")
("ok" "")
("old english" "")
("old slavonic" "")
("old style" "旧风格")
("old version" "旧版")
("on" "打开")
("on cells" "")
("on columns" "")
("on entire table" "")
("on rows" "")
("on the footer" "在状态栏")
("one column" "一栏")
("once" "一次")
("one spelling error has been corrected" "")
("online documentation" "")
("online help" "在线说明")
("only inline tags" "只对行内标记")
("opacity" "不透明度")
("open" "打开")
("open a document" "打开文档")
("open a new buffer" "")
("open in new window" "在新窗口打开")
("open identities" "打开身份信息")
("open module browser" "打开模块浏览器")
("open my-init-texmacs.scm" "打开my-init-texmacs.scm文件")
("open my-init-buffer.scm" "打开my-init-buffer.scm文件")
("open new window" "新开窗口")
("open on errors" "错误时弹出")
("open on warnings" "警告时弹出")
("open preferences.scm" "打开preferences.scm文件")
("open symbol browser" "打开符号浏览器")
("opening" "")
("operation mode" "操作模式")
("operation on named selection" "")
("operation on primary selection" "")
("operation on secondary selection" "")
("operation on ternary selection" "")
("optical" "")
("option" "")
("options" "")
("ok" "确认")
("or" "")
("orange" "橙色")
("orientation" "方向")
("origin" "原点")
("original welcome message" "欢迎信息")
("other" "其它")
("other pages" "其它页")
("other package" "其它宏包")
("other projects" "")
("other style" "其它样式")
("outlined roman" "")
("output options" "输出选项")
("over" "")
("overbrace" "")
("overview of the scheme extension language" "Scheme 扩展语言概览")
("overline" "上划线")
("padding" "补白")
("page" "页面")
("page bottom margin" "")
("page break" "允许换页")
("page break before" "允许换页(在前面)")
("page breaking algorithm" "分页算法")
("page height" "页面高度")
("page insertion" "页面插入")
("page layout" "页面布局")
("page number text" "设定页码文字")
("page number" "页码")
("page numbering" "页码")
("page reference" "页面参考")
("page rendering" "页面渲染")
("page right margin" "")
("page setup" "页面设置")
("page top margin" "")
("page type" "页面种类")
("page width" "页面宽度")
("palette" "调色板")
("paper" "")
("paper size" "页面尺寸")
("paper type" "页面类型")
("papyrus" "")
("paragraph" "段落")
("paragraph mode" "")
("paragraph width" "段落宽度")
("parametric curve" "参数曲线")
("parametric surface" "参数曲面")
("part" "部分")
("past changes" "")
("paste" "粘贴")
("paste from" "粘贴自")
("paste text" "粘贴文本")
("path" "")
("pdf version number" "PDF版本号")
("perform operations on cells" "对单元格操作")
("perform operations on columns" "对整列操作")
("perform operations on entire table" "对整个表格操作")
("perform operations on rows" "对整行操作")
("permanent" "")
("permanent footer" "每一页页脚")
("permanent header" "每一页页眉")
("person" "人物")
("personal dictionary has been modified" "")
("phantasy" "")
("philosophy" "哲学")
("phoenician" "")
("phonetic" "")
("pink" "粉红")
("plain block" "普通有框表格")
("plain tabular" "普通无框表格")
("planned changes" "")
("plans for the future" "未来计划")
("please" "")
("please wait" "请稍后")
("plot" "描画图形")
("plugin" "插件")
("plugins" "插件")
("plug-ins" "插件")
("plus" "")
("point" "点")
("point style" "点形状")
("polar" "极坐标")
("polish" "波兰语")
("polygon" "多边形")
("porting TeXmacs to other platforms" "移植到其它平台")
("portrait" "纵向")
("portuguese" "葡萄牙语")
("position" "")
("position float" "")
("position floating object" "")
("position the table" "改变表格位置")
("postscript" "")
("postscript image" "")
("pre" "预")
("pre-alpha release" "")
("preamble" "")
("preamble mode" "")
("preferences" "首选项")
("presentation" "")
("presentation mode" "演讲模式")
("presentation tag" "外观标记")
("presentation tool" "演示菜单")
("preserve tags" "保留标记")
("pretty tree output" "美化树状输出")
("preview" "预览")
("preview before printing" "")
("preview command" "预览程序")
("previous" "前一个")
("previous comment" "前一处批注")
("previous difference" "前一处差异")
("previous field" "前一个区域")
("previous similar" "相似的(前一个)")
("program interface for buffer management" "缓冲区管理的程序接口")
("programming routines for editing documents" "文档编辑的编程方法")
("properties" "属性")
("property" "性质")
("primary" "")
("prime" "")
("print" "打印")
("print all" "全部打印")
("print all to file" "全部打印为文件")
("print buffer" "打印缓冲区")
("print buffer to file" "打印缓冲区为文件")
("print page selection" "选择打印")
("print page selection to file" "选择打印为文件")
("print this document" "打印文档")
("print to postscript file" "印成 postscript 文件")
("printer" "打印机")
("printer dpi" "打印机DPI")
("printing command" "打印程序")
("problem" "题目")
("professional" "专业")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "程序")
("program font" "代码字体")
("program mode" "")
("programming" "")
("progressive" "渐开")
("project" "项目")
("projects" "项目计划")
("prologue" "")
("prominent" "突出")
("prompt on scripts" "")
("prompts and default input" "提示符和默认输入")
("proof" "证明")
("proportional" "比例")
("proportional typewriter" "")
("proposition" "命题")
("pseudo code" "伪代码")
("query replace" "替换文本")
("question" "问题")
("quit" "")
("question" "问题")
("quotation" "长引用")
("quote" "引用")
("range" "")
("really close it" "是否真要关闭它")
("really huge" "非常大")
("really quit" "是否真的退出")
("really tiny" "非常小")
("recent" "最近使用")
("recent documents" "最近文档")
("recover autosave file" "复元自动保存文件")
("red" "红色")
("redo" "恢复")
("redo undone changes" "恢复更改")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "")
("reduce right margin by" "")
("reduce top margin by" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "参考")
("reference guide" "参考指南")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "参考")
("regular" "正规")
("release" "")
("reload" "刷新")
("remark" "注意")
("remote" "远程")
("remote connections" "远程连接")
("remote control" "远程控制")
("remote tool" "远程工具")
("remove" "删除")
("remove all output fields" "")
("remove argument after" "删除后面参数")
("remove argument before" "删除前面参数")
("remove banner" "删除横幅")
("remove comments" "删除所有批注")
("remove downwards" "删除此行")
("remove field above" "删除上一个区域")
("remove field below" "删除下一个区域")
("remove fields" "")
("remove input field" "")
("remove input field above" "")
("remove last field" "删除最后面区域")
("remove leftwards" "删除前列")
("remove next field" "删除下一个区域")
("remove number" "")
("remove package" "取消宏包")
("remove previous field" "删除前一个区域")
("remove rightwards" "删除此列")
("remove tag" "删除标记")
("remove this branch" "删除当前这个")
("remove this column" "删除此列")
("remove this row" "删除此行")
("remove this switch" "")
("remove upwards" "删除上行")
("rename" "重命名")
("renumber this page" "修改当前页码")
("repeat" "重复")
("repeat object" "")
("replace" "替换")
("replace by" "被替换为")
("replace toolbar" "替换工具栏")
("replace unrecognized styles" "替换无法识别的样式")
("replaced" "")
("replaced one occurrence" "")
("reset" "重置")
("resize" "改变大小")
("resize object" "")
("resized" "")
("rebuild translations file" "重建翻译文件")
("retain" "保留")
("retina settings" "高分屏设置")
("retina screen settings" "高分屏设置")
("return" "")
("revert" "恢复")
("revert buffer" "")
("right" "右边")
("right arrow" "")
("right border" "右端")
("right cell border" "")
("right cell padding" "")
("right margin" "右边距")
("right padding" "")
("right aligned" "右对齐")
("right subscript" "右下标")
("right superscript" "右上标")
("right surrounding" "")
("right table border" "")
("right table padding" "")
("rightwards" "往右边")
("rigid" "刚性的")
("rigid horizontal" "")
("rigid space" "")
("romanian" "罗马尼亚语")
("root" "根")
("rotate" "旋转")
("rotate backward" "")
("rotate forward" "")
("rough" "粗糙")
("round" "圆圈")
("row" "行")
("row above" "行(在上方)")
("row below" "行(在下方)")
("row contains glued items" "")
("rows" "行")
("run" "运行")
("runic" "")
("running author" "栏外作者名")
("running title" "栏外标题")
("russian" "俄语")
("sample text" "示例文本")
("sample" "示例")
("sans serif" "")
("save" "保存")
("save TeXmacs file" "保存 TeXmacs 文件")
("save TeXmacs style file" "保存 TeXmacs 样式文件")
("save as" "另存为")
("save as LaTeX" "另存为 LaTeX 文件")
("save as TeX" "另存为 TeX 文件")
("save buffer" "保存文件")
("save buffer as" "另存为")
("save file" "保存文件")
("save html file" "存为 html 文件")
("save image" "保存图形文件")
("save latex file" "保存 LaTeX 文件")
("save tex file" "保存 TeX 文件")
("save this buffer" "保存文件")
("save this document" "保存文档")
("save verbatim file" "存为  verbatim 文件")
("saved" "保存完成")
("scheme command" "")
("scheme developers guide" "Scheme 开发指南")
("scheme extensions" "扩展语言")
("scheme interface for the graphical mode" "图形模式的 Scheme 接口")
("screen layout" "")
("screen margins" "")
("screens" "屏幕")
("script" "上下标")
("scripting language" "脚本语言")
("scripts" "脚本")
("script above" "顶标")
("script below" "底标")
("script script size" "次下标大小")
("script size" "下标大小")
("scripts not accepted" "")
("search" "查找")
("search results for" "")
("search toolbar" "搜索工具栏")
("search words in my documents" "")
("search words in the documentation" "在文档中搜索")
("search words in the source code" "在源代码中搜索")
("searching" "")
("secondary" "")
("section" "节")
("security" "安全")
("see" "参见")
("select a document style" "选择文档样式")
("select a foreground color" "选择前景颜色")
("select a language" "选择语言")
("select display or formula style" "选择公式显示样式")
("selected region" "")
("selection" "选择")
("selections" "选择")
("seminar" "会议")
("semantics" "语义")
("semantic correctness" "语义正确性")
("semantic editing" "语义编辑")
("semantic selections" "语义选择")
("sending commands to TeXmacs" "给 TeXmacs 发送命令")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "")
("september" "")
("serb" "")
("series" "字型")
("series|right" "")
("session" "会话")
("session commands" "会话命令")
("session name" "")
("session type" "")
("sessions" "会话")
("set" "")
("set background color of cell" "设定单元格背景色")
("set cell mode" "")
("set extension center" "")
("set height" "")
("set height of cell" "")
("set margins" "")
("set n" "")
("set number of columns" "设定列数")
("set number of rows" "设定行数")
("set or get environment variables" "")
("set paragraph margins" "段落边距")
("set paragraph mode" "段落对齐")
("set printer dpi" "")
("set printing command" "")
("set span" "设置合并")
("set special cell properties" "设定单元格特殊属性")
("set special table properties" "设定表格特殊属性")
("set text width" "")
("set width" "")
("set width of cell" "")
("settings" "")
("setup printer" "")
("several equations" "多行公式")
("shape" "字形")
("shift-down" "")
("shift-right" "")
("short" "简短")
("show" "显示")
("show all parts" "显示所有部分")
("show header and footer" "显示页眉页脚")
("show hidden" "显示隐藏内容")
("show key presses" "显示键盘按键")
("show memory usage" "显示内存占用")
("show on screen" "")
("show one part" "显示一部分")
("show panorama" "显示全文")
("show preamble" "显示序言")
("show several parts" "显示几部分")
("show subunits" "显示子单元")
("show timings" "显示花费时间")
("shortcuts editor" "快捷键编辑器")
("shrinking factor" "收缩比例")
("signature" "")
("simplification" "简化")
("simplified menus" "简单菜单")
("size" "大小")
("size tag" "大小标记")
("size limits" "大小限制")
("slanted" "倾斜")
("sloppy" "粗略")
("slovene" "斯洛文尼亚语")
("small" "小")
("small caps" "小体大写")
("small figure" "小图片标题")
("small skip" "小间距")
("small table" "小表格")
("solution" "解答")
("solving equations" "解方程")
("songti" "宋体")
("sound" "声音")
("source" "源码")
("source code" "程序源码")
("source macros tool" "源码菜单")
("source tags" "代码标记")
("space" "空白")
("space bar in text mode" "文本模式中的空格键")
("space bar in math mode" "数学模式中的空格键")
("space between lines" "行间空白")
("space between paragraphs" "段间空白")
("spacing" "间隔")
("spanish" "西班牙语")
("special" "特定")
("special functions" "特殊函数")
("special properties" "特殊属性")
("specific" "指定")
("specify the size of the table" "指定表格大小")
("specify user identity" "指定用户身份")
("spell" "拼写")
("spell checking complete" "拼写检查完成")
("spelling error" "拼写错误")
("spelling errors have been corrected" "拼写错误已更正")
("spline" "样条曲线")
("split" "分割")
("split session" "分割会话")
("springer" "施普林格")
("square" "方框")
("square root" "平方根")
("stack" "堆叠")
("standard" "标准")
("standard environment variables" "标准的环境变量")
("standard formats" "标准格式")
("standard TeXmacs styles" "TeXmacs 的标准样式")
("start" "开始")
("start a new chapter" "新起一章")
("start a new section" "新起一节")
("start an interactive session" "插入交互会话")
("statistics" "统计")
("status" "状态")
("status bar" "状态栏")
("storage" "存储")
("stretch" "")
("stretchable" "可拉伸")
("stretchable horizontal" "")
("stretchable vertical" "")
("stretched" "拉伸")
("stroke" "")
("strokes" "")
("strong" "加粗")
("structural" "结构化的")
("structured insert above" "在上边插入")
("structured insert below" "在下边插入")
("structured insert at the left" "在左边插入")
("structured insert at the right" "在右边插入")
("structured remove downwards" "往下删除")
("structured remove leftwards" "往左删除")
("structured remove rightwards" "往右删除")
("structured remove upwards" "往上删除")
("style" "样式")
("styles" "样式文件")
("stylesheet language" "样式文件的语言")
("sub" "子项")
("subject" "主题")
("subject classification" "主题分类号")
("submenu" "子菜单")
("subparagraph" "小段落")
("subscript" "下标")
("subsection" "小节")
("subsub" "小项")
("subsubsection" "子节")
("subtable" "子表格")
("subtitle" "副标题")
("summary" "概要")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "上标")
("surface" "曲面")
("swedish" "瑞典语")
("swiss" "")
("switch" "")
("switch to first" "跳到第前面")
("switch to formula style" "")
("switch to last" "跳到最后面")
("switch to next" "跳到下一个")
("switch to previous" "跳到前一个")
("switching and folding" "切换和折叠")
("symbol" "符号")
("system command" "")
("system environment variables" "")
("tab" "")
("tab-completion" "用制表符自动补全")
("table" "表格")
("table command" "")
("table height" "表格高度")
("table width" "表格宽度")
("table properties" "表格属性")
("table of contents" "目录")
("tables" "")
("tabular" "无框表格")
("tabular material" "表格处理")
("taiwanese" "繁体中文")
("teXmacs as an interface" "TeXmacs 的交互式界面")
("teXmacs extensions to scheme and utilities" "对 Scheme 的扩展和实用工具")
("teXmacs fonts" "TeXmacs 字体")
("teXmacs notice" "")
("teXmacs plug-ins" "TeXmacs 的插件")
("teXmacs primitives" "TeXmacs 的原语")
("teXmacs style files" "TeXmacs 的样式文件")
("textual operator" "文本运算符")
("ternary" "")
("test" "检测")
("tex" "")
("text" "文本")
("text box" "文本框")
("text box alignment" "文本框对齐")
("text box horizontal alignment" "文本框水平对齐")
("text box vertical alignment" "文本框竖直对齐")
("text font" "文本字体")
("text height correction" "文本高度修正")
("text width" "")
("texts" "")
("th century bc" "")
("th root" "")
("thai" "")
("the TeXmacs authors" "")
("the TeXmacs plug-in system" "TeXmacs 的插件系统")
("the TeXmacs format" "TeXmacs 的格式")
("the application did not send its usual startup banner" "")
("the application does not reply" "")
("the application is already running" "")
("the boxes produced by the typesetter" "排版中使用的盒子")
("the document has not been saved" "该文件尚未保存")
("the graphical user interface" "图形用户界面")
("the leaves of TeXmacs trees" "")
("the mycas example" "")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "TeXmacs 的标准样式")
("the TeXmacs authors" "作者")
("the TeXmacs format" "TeXmacs 的格式")
("theme" "主题")
("theorem" "定理")
("there are unsaved documents" "还有文件尚未保存")
("this document has not been saved" "现工作的暂存区信息尚未保存")
("this column" "此列")
("this document has been produced using" "此文档撰写于")
("this line" "")
("this page" "")
("this page footer" "当前页页脚")
("this page header" "当前页页眉")
("this row" "此行")
("three times" "三次")
("through popup windows" "通过弹出窗口")
("through the menus" "通过菜单")
("thumbnails" "缩略图")
("tilda" "")
("tilde" "")
("times" "")
("timings" "耗时")
("tiny" "细小")
("title" "标题")
("to the left" "")
("to the right" "")
("today" "今天")
("tools" "工具")
("top" "顶部")
("top border" "")
("top cell border" "")
("top cell padding" "")
("top level" "")
("top margin" "上边距")
("top padding" "")
("top table border" "")
("top table padding" "")
("transform" "变换")
("translate" "平移")
("translations" "翻译")
("tree" "树")
("triangle" "三角形")
("trigonometry" "三角函数")
("tuple" "元组")
("turkish" "土耳其文")
("tutorial" "入门教程")
("twice" "两次")
("two columns" "两栏")
("type" "类型")
("type 1 only" "仅只使用 Type1 字体")
("type 1 with metafont fallback" "优先使用 Type1 字体")
("type a latex command followed by" "")
("type body" "")
("type denominator" "")
("type numerator" "")
("type script" "")
("typesetted boxes" "")
("typewriter" "")
("typewriter small caps" "")
("typing a simple text" "输入简单文本")
("typing simple texts" "输入简单文本")
("ugaritic" "")
("ukrainian" "乌克兰语")
("underbrace" "")
("underline" "下划线")
("undo" "撤销")
("undo last changes" "撤销更改")
("unfold" "打开")
("unfold all fields" "展开全部区域")
("unfold comments" "展开所有批注")
("unit" "单位")
("unit length" "单位长度")
("up" "")
("update" "更新")
("update from web" "")
("update image links" "")
("update this buffer" "更新此缓冲区")
("update web site" "更新网站")
("upgrade" "升级")
("upper border" "上端")
("upright" "正体")
("upwards" "往上边")
("use TeXmacs" "使用 TeXmacs")
("use a black color" "")
("use a blue color" "")
("use a bold font" "使用粗体字体")
("use a brown color" "")
("use a calligraphic font" "使用书法字体")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "")
("use calligraphical font" "")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "")
("use italic font shape" "")
("use large font size" "")
("use left hand column as border" "")
("use mathml" "使用 mathml")
("use medium font series" "")
("use normal font size" "")
("use package" "")
("use paragraph width" "")
("use really huge font size" "")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "")
("use row above as border" "")
("use row below as border" "")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "")
("use small font size" "")
("use small-caps font shape" "")
("use TeXmacs" "使用 TeXmacs")
("use the blackboard bold font" "使用黑板字体")
("use the fraktur font" "使用哥特字体")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "用户手册")
("user preferences" "用户首选项")
("user provided icons" "用户工具栏")
("user interface language" "界面语言")
("users of Cyrillic languages" "西里尔语言用户")
("users of oriental languages" "东方语言用户")
("utilities" "实用")
("value" "")
("variable" "变量")
("variant" "字族")
("vector" "")
("verbatim" "纯文本")
("verse" "诗文")
("version" "版本")
("versioning tool" "版本菜单")
("vertical" "竖直")
("vertical after" "")
("vertical before" "")
("vertical cell alignment" "")
("vertical part" "竖直部分")
("vertical position" "")
("vertical space" "")
("vertical alignment" "竖直对齐")
("vertically align cell to the base" "")
("vertically center the cell" "")
("very large" "很大")
("very small" "很小")
("vietnamese" "")
("view" "查看")
("visible" "可见")
("visual grid" "可视网格")
("warning" "警告")
("web" "网站")
("welcome" "欢迎")
("welcome to GNU TeXmacs" "欢迎使用 GNU TeXmacs")
("what is new" "最近更新")
("when finished" "")
("while" "")
("white" "白色")
("whitespace" "空格")
("wide accent" "")
("wide bar" "")
("wide block" "标宽有框表格")
("wide tabular" "标宽无框表格")
("width" "宽度")
("width is exactly the specified width" "")
("width is maximum of specified width and box width" "")
("width is minimum of specified width and box width" "")
("width magnification" "")
("window" "")
("window height" "")
("window width" "")
("windows key" "")
("with" "")
("with older version" "与旧版")
("with newer version" "与新版")
("wrap lines" "自动换行")
("write a macro" "编写宏")
("write a name" "名称文本")
("write bold mathematics" "")
("write bold text" "粗体文本")
("write italic text" "斜体文本")
("write sample text" "示例文本")
("write strong text" "加粗文本")
("write typewriter text" "")
("write verbatim text" "逐字文本")
("writing data converters" "编写数据转换器")
("writing documentation" "编写插件文档")
("writing TeXmacs bibliography styles" "编写参考文献样式")
("writing your own style files" "编写自己的样式文件")
("written with TeXmacs" "使用 TeXmacs 制作")
("year" "年")
("yellow" "黄色")
("yes" "是")
("you can also obtain" "")
("your document is back in its original state" "")
("your first interface" "")
("your language" "使用语言")
("zoom" "缩放")
("zoom factor" "缩放比例")
("zoom/unzoom" "放大/缩小")
("zoom in" "放大")
("zoom out" "缩小")
("(re)build autocompletion index" "构建/重建自动补全索引")
