
###############################################################################
##
## MODULE      : starts_with.m
## DESCRIPTION : Test if a string starts with
## COPYRIGHT   : (C) 2021  Darcy Shen
##
## This software falls under the GNU general public license version 3 or later.
## It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
## in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.

function ret= starts_with (str, x)
  ret= strncmp (str, x, length (x));
endfunction
