("\"encryption\" features from the preference panel" "\"cifrado\" características del panel de preferencias")
("(Re)Build autocompletion index" "(Re) Crear índice de autocompletado")
("a series" "una serie")
("a.C.M. computing class" "a.C.M. clase de computación")
("a.M.S. subject class" "a.M.S. asignatura")
("abbreviated authors" "autores abreviados")
("abreviated authors" "autores abreviados")
("accent above" "acento arriba")
("accent below" "acento debajo")
("accept during this pass" "aceptar durante este pase")
("acknowledgments" "agradecimientos")
("activate hidden" "activar oculto")
("activate once" "activar una vez")
("activation" "activación")
("active link types" "tipos de enlaces activos")
("add" "agregar")
("add abstract information" "agregar información abstracta")
("add author information" "agregar información del autor")
("add branch after" "agregar rama después")
("add branch before" "agregar rama antes")
("add other package" "agregar otro paquete")
("add package" "agregar paquete")
("add style package" "agregar paquete de estilo")
("add title information" "agregar información del título")
("addition" "adición")
("adjust" "ajustar")
("adjust limits" "ajustar límites")
("advanced font customization" "personalización avanzada de fuentes")
("affiliation" "afiliación")
("align cell to the decimal comma" "alinear celda con la coma decimal")
("align cell to the decimal dot" "alinear celda al punto decimal")
("align table at axis" "alinear tabla en el eje")
("alignment of balloon" "alineación del globo")
("all cells" "todas las celdas")
("all data attached to this identity will be lost" "todos los datos adjuntos a esta identidad se perderán")
("all saved passphrases will be lost forever" "todas las frases guardadas se perderán para siempre")
("allow for macro definitions in preamble" "permitir macro definiciones en el preámbulo")
("allow multiple spaces" "permitir múltiples espacios")
("allow spurious spaces" "permitir espacios espurios")
("allowed page height extension" "extensión de altura de página permitida")
("allowed page height reduction" "reducción de altura de página permitida")
("allowed positions" "puestos permitidos")
("allowed positions of floating object" "posiciones permitidas de objeto flotante")
("alpha transparency" "transparencia alfa")
("also on paper" "también en papel")
("alter" "alterar")
("alternate" "alternativo")
("alternate except here" "alternativo excepto aquí")
("alternate from here on" "alternativo de aquí en adelante")
("alternate only here" "alterno solo aquí")
("alternate until here" "alterno hasta aquí")
("alternative colors" "colores alternativos")
("alternative specification" "especificación alternativa")
("always" "siempre")
("american" "americano")
("amplified" "amplificado")
("ancient" "antiguo")
("and perform casual settings from the \"Encryption\" tab" "y realiza configuraciones casuales desde la pestaña \"Cifrado\"")
("angular" "angular")
("animate" "animado")
("animate folding" "plegado animado")
("animate object" "objeto animado")
("animate objects" "objetos animados")
("animate unfolding" "despliegue animado")
("animated" "animado")
("animation" "animación")
("animation toolbar" "barra de herramientas de animación")
("annotate" "anotar")
("answer field" "campo de respuesta")
("answer to question" "respuesta a la pregunta")
("answers only" "solo respuestas")
("any" "cualquiera")
("appear" "aparecen")
("apply macro" "aplicar macro")
("apply macro once" "aplicar macro una vez")
("approximate" "aproximado")
("arc" "arco")
("arc cosine" "arco coseno")
("arc sine" "arco seno")
("arc tangent" "arco tangente")
("arch series" "series de arco")
("are you sure you want to delete collected public keys" "¿está seguro de que desea eliminar las claves públicas recopiladas")
("are you sure you want to delete selected public keys" "¿está seguro de que desea eliminar las claves públicas seleccionadas")
("are you sure you want to delete selected secret keys" "¿está seguro de que desea eliminar las claves secretas seleccionadas")
("are you sure you want to destroy the wallet" "¿estás seguro de que quieres destruir la billetera")
("art Pen" "pluma de arte")
("art frame" "marco artístico")
("arxiv category" "categoría arxiv")
("as visual grid" "como cuadrícula visual")
("aspect" "aspecto")
("attach master" "adjuntar maestro")
("attached" "adjunto")
("auto" "automático")
("auto-save file" "archivo de guardado automático")
("automatic brackets" "soportes automáticos")
("automatic content generation" "generación automática de contenido")
("automatic program brackets" "paréntesis de programa automático")
("automatic quotes" "presupuestos automáticos")
("automatically import bibliographies when opening files" "importa automáticamente bibliografías al abrir archivos")
("automatically remember all passphrases in the wallet" "recuerda automáticamente todas las frases de contraseña en la billetera")
("automatically save" "guardar automáticamente")
("autosave" "autoguardado")
("avoid spurious spaces" "evitar espacios espurios")
("axis" "eje")
("b series" "serie b")
("back" "atrás")
("background picture selector" "selector de imagen de fondo")
("backtrace errors" "errores de rastreo")
("base" "base")
("baseline" "línea de base")
("beamer" "proyector")
("beamer formats" "formatos de proyector")
("beamer theme" "tema del proyector")
("bench" "banco")
("bend bottom" "doblar el fondo")
("bend corner" "esquina doblada")
("bend diagonal" "diagonal diagonal")
("bend in" "doblarse")
("bend out" "doblarse")
("bezier" "bezier")
("bibTeX command" "comando bibTeX")
("bidirectional" "bidireccional")
("big environment box" "caja de gran entorno")
("big focus" "gran foco")
("binary operator" "operador binario")
("bitmap resolution (dpi)" "resolución de mapa de bits (ppp)")
("black floral I" "negro floral I")
("black floral II" "negro floral II")
("blackboard embold" "pizarra en relieve")
("blank column" "columna en blanco")
("blank row" "fila en blanco")
("block" "bloque")
("block content" "contenido bloqueado")
("block of code" "bloque de código")
("blur" "desenfoque")
("both versions" "ambas versiones")
("bottom baseline" "línea de base inferior")
("bottom cell border" "borde de celda inferior")
("bottom cell padding" "relleno de celda inferior")
("bottom table border" "borde inferior de la mesa")
("bottom table padding" "relleno de la mesa inferior")
("bottom tools" "herramientas inferiores")
("box" "caja")
("browse modules documentation" "examinar la documentación de los módulos")
("buffer management" "gestión del búfer")
("buffer must be on disk" "el búfer debe estar en el disco")
("buffer must have a name" "el búfer debe tener un nombre")
("build buffer" "construir búfer")
("build buffer in" "construir buffer en")
("build directory" "directorio de compilación")
("build directory in" "directorio de compilación en")
("build link pages" "páginas de enlaces de compilación")
("build-all" "construir todo")
("bump" "golpe")
("busy" "ocupado")
("cJK" "cJK")
("cJK spacing" "espaciado cJK")
("calculus" "cálculo")
("cancelled" "cancelado")
("cannot download directory to file" "no se puede descargar el directorio al archivo")
("cannot rename across different servers" "no se puede cambiar el nombre en diferentes servidores")
("cannot upload directory to file" "no se puede cargar el directorio al archivo")
("cartesian" "cartesiano")
("carved wood" "madera tallada")
("case-insensitive search" "búsqueda sin distinción entre mayúsculas y minúsculas")
("categories" "categorías")
("category" "categoría")
("cell properties" "propiedades de celda")
("cells" "células")
("center baseline" "línea de base central")
("chalk" "tiza")
("change default unit" "cambiar unidad predeterminada")
("change passphrase" "cambiar frase de contraseña")
("change permissions" "permisos de cambio")
("change step-size" "cambiar tamaño de paso")
("change tags" "etiquetas de cambio")
("change the TeXmacs preferences" "cambiar las preferencias de TeXmacs")
("change the border of the table" "cambiar el borde de la tabla")
("change the style of mathematical formulas" "cambiar el estilo de las fórmulas matemáticas")
("change wallet passphrase" "cambiar frase de contraseña de billetera")
("character contraction" "contracción del personaje")
("character encoding" "codificación de caracteres")
("character expansion" "expansión de personaje")
("check exported Pdf files for correctness" "verificar la exactitud de los archivos Pdf exportados")
("check for automatic updates" "buscar actualizaciones automáticas")
("check for updates" "buscar actualizaciones")
("checkable field" "campo marcable")
("choose background" "elegir fondo")
("choose color" "elegir color")
("cipher algorithm for passphrase encryption" "algoritmo de cifrado para el cifrado de frase de contraseña")
("circle" "círculo")
("classification" "clasificación")
("clean slate" "pizarra limpia")
("clear all fields" "borrar todos los campos")
("clear local information" "información local clara")
("clear menu" "menú claro")
("clear undo history" "borrar historial de deshacer")
("click Ok button twice to discard this warning" "haga clic en el botón Aceptar dos veces para descartar esta advertencia")
("clip" "clip")
("clipboard image format" "formato de imagen del portapapeles")
("close animation tool" "cerrar herramienta de animación")
("close document" "documento cerrado")
("close program" "cerrar programa")
("close replace tool" "herramienta de reemplazo cercano")
("close search tool" "herramienta de búsqueda cercana")
("close spell tool" "herramienta de hechizo cerrado")
("close translations to rebuild" "traducciones cercanas para reconstruir")
("closed bezier" "bezier cerrado")
("closed curve" "curva cerrada")
("closed smooth" "cerrado suave")
("closed spline" "spline cerrado")
("closing style" "estilo de cierre")
("cluster by affiliation" "agrupación por afiliación")
("collect garbage" "recoger basura")
("collected keys" "llaves recogidas")
("color of the axes" "color de los ejes")
("color of the subunits" "color de las subunidades")
("color of the units" "color de las unidades")
("colors" "colores")
("column to the left" "columna a la izquierda")
("column to the right" "columna a la derecha")
("columns" "columnas")
("column separation" "separación de columnas")
("commit" "cometer")
("commit file" "archivo de confirmación")
("common" "común")
("common formats" "formatos comunes")
("commutative diagram" "diagrama conmutativo")
("compactification" "compactación")
("compactify" "compactificar")
("compare" "comparar")
("compare with" "comparar con")
("complete bibliographic reference" "referencia bibliográfica completa")
("complex actions" "acciones complejas")
("compose" "componer")
("compound" "compuesto")
("compress" "comprimir")
("compress into toolbar" "comprimir en la barra de herramientas")
("compressed" "comprimido")
("conceal" "ocultar")
("configure look and feel" "configurar apariencia")
("confirm collected public key deletion" "confirmar eliminación de clave pública recopilada")
("confirm database entry" "confirmar entrada de base de datos")
("confirm entry" "confirmar entrada")
("confirm public key deletion" "confirmar eliminación de clave pública")
("confirm secret key deletion" "confirmar eliminación de clave secreta")
("confirm selected database entries" "confirmar entradas seleccionadas de la base de datos")
("confirm selected entries" "confirmar entradas seleccionadas")
("confirm wallet destruction" "confirmar la destrucción de la billetera")
("conservative conversion options" "opciones de conversión conservadoras")
("consoles" "consolas")
("constellation" "constelación")
("contact" "contacto")
("context aids" "ayudas contextuales")
("contextual hints" "sugerencias contextuales")
("continue" "continuar")
("continued fraction" "fracción continua")
("contour" "contorno")
("contract logarithms" "logaritmos contractuales")
("contribute" "contribuir")
("control flow" "flujo de control")
("control the evaluation of expressions" "controlar la evaluación de expresiones")
("convert" "convertir")
("converters" "convertidores")
("convertible" "descapotable")
("copy new objects to all frames" "copiar nuevos objetos a todos los marcos")
("copy new objects to previous frames" "copiar objetos nuevos a cuadros anteriores")
("copy new objects to subsequent frames" "copiar objetos nuevos en cuadros posteriores")
("copy to all frames after" "copiar a todos los cuadros después")
("copy to all frames before" "copiar a todos los cuadros antes")
("copy to all other frames" "copiar a todos los demás marcos")
("copyright" "derechos de autor")
("cork charset with TeX catcode definition in preamble" "juego de caracteres de corcho con definición de código de gato TeX en el preámbulo")
("cork with catcodes" "corcho con códigos de barras")
("correct" "correcto")
("correct all" "corregir todo")
("correct formula" "fórmula correcta")
("correct manually" "corregir manualmente")
("correct mathematical formulas" "fórmulas matemáticas correctas")
("correction" "corrección")
("cosine" "coseno")
("count characters" "caracteres de conteo")
("count lines" "líneas de conteo")
("count words" "palabras de conteo")
("create a new document" "crear un nuevo documento")
("create link" "crear enlace")
("create preamble" "crear preámbulo")
("create remote account" "crear cuenta remota")
("create remote directory" "crear directorio remoto")
("create remote file" "crear archivo remoto")
("create subprogram" "crear subprograma")
("create subsession" "crear subsesión")
("create table macro" "crear macro de tabla")
("create web site" "crear sitio web")
("creating new account" "creando una nueva cuenta")
("creating technical pictures" "creación de imágenes técnicas")
("crop" "cosecha")
("crop marks" "marcas de recorte")
("cross" "cruz")
("crossed boxes" "cajas cruzadas")
("crossed circles" "círculos cruzados")
("current user version" "versión actual del usuario")
("current version" "versión actual")
("cursor" "cursor")
("curve" "curva")
("curve intersections" "intersecciones curvas")
("curve points" "puntos de curva")
("customizations" "personalizaciones")
("customizing and extending the user interface" "personalización y ampliación de la interfaz de usuario")
("cyan" "cian")
("data" "datos")
("database entry" "entrada de base de datos")
("database tool" "herramienta de base de datos")
("database toolbar" "barra de herramientas de base de datos")
("deactivate once" "desactivar una vez")
("dead" "muertos")
("debug" "depuración")
("debugging console" "consola de depuración")
("debugging tool" "herramienta de depuración")
("decimal comma" "coma decimal")
("decimal dot" "punto decimal")
("decomposed" "descompuesto")
("decorated" "decorado")
("decorated wood" "madera decorada")
("decorative" "decorativos")
("decrease size" "disminuir tamaño")
("decrypt" "descifrar")
("decrypted" "descifrado")
("decryption" "descifrado")
("default size" "tamaño predeterminado")
("degrade" "degradar")
("degraded" "degradado")
("delete documentation cache" "borrar caché de documentación")
("delete entries" "borrar entradas")
("delete link" "eliminar enlace")
("delete selected entries in wallet" "eliminar entradas seleccionadas en la billetera")
("delete user identity" "eliminar identidad de usuario")
("deleted" "eliminado")
("describe" "describir")
("describe tag" "etiqueta de descripción")
("destroy" "destruir")
("detach master" "maestro de separación")
("detailed" "detallado")
("detailed menus" "menús detallados")
("details in menus" "detalles en los menús")
("determine margins from text width" "determinar los márgenes del ancho del texto")
("developer" "desarrollador")
("developer tool" "herramienta de desarrollador")
("device" "dispositivo")
("diamond" "diamante")
("differentiate" "diferenciar")
("digital" "digital")
("dilate" "dilatar")
("direction of progression" "dirección de progresión")
("direction of translation" "dirección de la traducción")
("disable" "deshabilitar")
("disable coloring on paper" "deshabilitar la coloración en papel")
("disable encryption" "deshabilitar cifrado")
("disabled" "deshabilitado")
("disappear" "desaparecer")
("disk" "disco")
("display style" "estilo de visualización")
("displayed formula" "fórmula mostrada")
("dissociate joined cells" "disociar células unidas")
("distill encapsulated Pdf files" "archivos Pdf encapsulados por destilación")
("distort" "distorsionar")
("distorted" "distorsionado")
("division" "división")
("document colors" "colores del documento")
("document font selector" "selector de fuente del documento")
("document language" "idioma del documento")
("document metadata" "metadatos del documento")
("document page format" "formato de página del documento")
("document paragraph format" "formato de párrafo del documento")
("document source tree preferences" "preferencias del árbol de origen del documento")
("document updates run" "actualizaciones de documentos ejecutadas")
("documents in separate windows" "documentos en ventanas separadas")
("download" "descarga")
("download file or directory" "descargar archivo o directorio")
("downwards" "hacia abajo")
("dragging" "arrastrando")
("draw" "empate")
("draw graphics" "dibujar gráficos")
("draw image" "dibujar imagen")
("draw over" "sorteo")
("draw over selection" "dibujar sobre la selección")
("drop" "caída")
("due to" "debido a")
("dynamic" "dinámico")
("eRROR" "eRROR")
("edit animation" "editar animación")
("edit groups of objects" "editar grupos de objetos")
("edit macro" "editar macro")
("edit macros" "editar macros")
("edit object properties" "editar propiedades de objeto")
("edit preamble" "editar preámbulo")
("edit source" "editar fuente")
("edit source tree" "editar árbol de origen")
("edit style" "estilo de edición")
("edit translations file" "editar archivo de traducciones")
("education" "educación")
("effect pen" "pluma de efecto")
("eigenvalues" "valores propios")
("eighth" "octavo")
("embold" "embold")
("emboss" "relieve")
("enable page breaking" "habilitar salto de página")
("enabled" "habilitado")
("encoding" "codificación")
("encrypt" "cifrar")
("encrypted" "encriptado")
("encrypted buffer" "búfer cifrado")
("encryption" "encriptación")
("encryption error" "error de cifrado")
("encryption facilities are not currently available" "instalaciones de cifrado no están disponibles actualmente")
("encryption facilities have not been enabled for TeXmacs" "instalaciones de cifrado no se han habilitado para TeXmacs")
("enforce brackets to match" "aplicar paréntesis para que coincida")
("engrave" "grabar")
("enter data" "ingresar datos")
("enter graphics" "ingresar gráficos")
("enter graphics mode" "entrar en modo gráfico")
("enter new passphrase for encryption" "ingrese una nueva frase de contraseña para el cifrado")
("enter passphrase for decryption" "ingrese la frase de contraseña para descifrar")
("enter passphrase for identity" "ingrese la frase de contraseña para la identidad")
("enter title information" "ingrese la información del título")
("entire table" "mesa entera")
("entry up to date in database" "entrada actualizada en la base de datos")
("enunciation" "enunciación")
("environment variable" "variable de entorno")
("environments" "ambientes")
("erode" "erosionar")
("error messages" "mensajes de error")
("error output" "salida de error")
("error status report" "informe de estado de error")
("error: bracket does not match" "error: el soporte no coincide")
("error: cyclic or missing chunks detected" "error: se detectaron fragmentos cíclicos o faltantes")
("error: file not found" "error: archivo no encontrado")
("error: ghostview does not seem to be installed on your system" "error: ghostview no parece estar instalado en su sistema")
("error: one of the alternatives should be filled out" "error: se debe completar una de las alternativas")
("error: only one alternatives should be filled out" "error: solo se debe completar una alternativa")
("error: should fill out name for referencing" "error: debe completar el nombre para hacer referencia")
("error: should fill out required field" "error: debe completar el campo requerido")
("escape" "escape")
("evaluable field" "campo evaluable")
("evaluate above" "evaluar arriba")
("evaluate all" "evaluar todo")
("evaluate below" "evaluar a continuación")
("evaluate fields" "evaluar campos")
("evaluate fields in order" "evaluar campos en orden")
("evaluate script" "evaluar script")
("evaluation" "evaluación")
("evaluation switch" "interruptor de evaluación")
("evaluation tag" "etiqueta de evaluación")
("even page" "página par")
("even page left margin" "margen izquierdo de página par")
("even page shift" "desplazamiento de página par")
("even pages" "páginas pares")
("events" "eventos")
("exact" "exacto")
("execution of scripts" "ejecución de scripts")
("exit graphics" "gráficos de salida")
("exit graphics mode" "salir del modo gráfico")
("exit left" "salida izquierda")
("exit right" "salir a la derecha")
("exit tag on the left" "etiqueta de salida a la izquierda")
("exit tag on the right" "etiqueta de salida a la derecha")
("expand TeXmacs macros with no LaTeX equivalents" "expandir macros TeXmacs sin equivalentes LaTeX")
("expand beamer slides" "expandir diapositivas de proyector")
("expand inclusions" "expandir inclusiones")
("expand logarithms" "expandir logaritmos")
("expand trigonometric functions" "expandir funciones trigonométricas")
("expand unrecognized macros" "expandir macros no reconocidos")
("expand user-defined macros" "expandir macros definidas por el usuario")
("expanded" "expandido")
("experimental features (to be used with care)" "características experimentales (para usar con cuidado)")
("explain" "explicar")
("explanatory item" "punto explicativo")
("explicit keystroke" "pulsación de tecla explícita")
("explicit margins" "márgenes explícitos")
("exponential" "exponencial")
("export bibliographies as links" "exportar bibliografías como enlaces")
("export bibliography" "bibliografía de exportación")
("export entries in buffer" "entradas de exportación en el búfer")
("export file" "archivo de exportación")
("export formulas as images" "exportar fórmulas como imágenes")
("export mathematical formulas as MathML" "exportar fórmulas matemáticas como MathML")
("export mathematical formulas as images" "exportar fórmulas matemáticas como imágenes")
("export selected entries" "exportar entradas seleccionadas")
("export selection" "selección de exportación")
("export selection as image" "exportar selección como imagen")
("export selections as" "selecciones de exportación como")
("export sessions" "sesiones de exportación")
("exported bibliographic entries" "entradas bibliográficas exportadas")
("exported bibliographic references" "referencias bibliográficas exportadas")
("extend" "extender")
("extend table to full paragraph width" "extender la tabla al ancho completo del párrafo")
("extended" "extendido")
("extensible left arrow" "flecha izquierda extensible")
("extensible right arrow" "flecha derecha extensible")
("extern" "externo")
("external" "externo")
("extra branch" "rama extra")
("extra interline space" "espacio extra entre líneas")
("extra name" "nombre extra")
("extract" "extracto")
("extract style file" "extraer archivo de estilo")
("extract style package" "paquete de estilo de extracto")
("factor" "factor")
("fade" "desvanecerse")
("fade in" "desvanecerse")
("fade out" "desaparecer")
("fast" "rápido")
("fast decrease" "disminución rápida")
("fast environments" "entornos rápidos")
("fast increase" "aumento rápido")
("field reference" "referencia de campo")
("fifth" "quinto")
("file saved" "archivo guardado")
("fill color" "color de relleno")
("fill out" "completar")
("filter" "filtro")
("finished collecting symbols documentation" "terminó de recoger la documentación de símbolos")
("first" "primero")
("first chunk" "primer trozo")
("first difference" "primera diferencia")
("first error" "primer error")
("first field" "primer campo")
("first occurrence" "primera aparición")
("first similar" "primer similar")
("fit" "ajuste")
("fit to height" "ajuste a la altura")
("fit to screen" "ajuste a la pantalla")
("fit to screen width" "ajuste al ancho de la pantalla")
("fit to width" "ajuste al ancho")
("five columns" "cinco columnas")
("fixed" "fijo")
("flag is off" "la bandera está apagada")
("flag is on" "la bandera está encendida")
("flatten" "aplanar")
("floating algorithm" "algoritmo flotante")
("floating phantom" "fantasma flotante")
("focus" "enfoque")
("focus dependent icons" "iconos dependientes del foco")
("fold all" "doblar todo")
("fold all fields" "doblar todos los campos")
("fold back" "doblar hacia atrás")
("follow external links" "seguir enlaces externos")
("follow inverse links" "seguir enlaces inversos")
("font customization" "personalización de fuente")
("font effects" "efectos de fuente")
("font selector" "selector de fuente")
("font type" "tipo de fuente")
("for each" "para cada uno")
("force reloading of translations" "fuerza de recarga de traducciones")
("formatting" "formateo")
("forward" "adelante")
("four columns" "cuatro columnas")
("four dots" "cuatro puntos")
("fourth" "cuarto")
("fraktur" "fraktur")
("framed" "enmarcado")
("framed theorems" "teoremas enmarcados")
("from" "de")
("from center" "desde el centro")
("front matter" "asunto principal")
("full" "completo")
("full author list" "lista completa de autores")
("full screen mode" "modo de pantalla completa")
("functional" "funcional")
("gap" "brecha")
("garbage collection" "recolección de basura")
("gaussian" "gaussiano")
("gcd" "mcd")
("general" "general")
("general note" "nota general")
("generate GnuPG key" "generar clave GnuPG")
("generated LaTeX document contains no errors" "el documento LaTeX generado no contiene errores")
("generated field" "campo generado")
("geometry" "geometría")
("get arity" "obtener arity")
("get label" "obtener etiqueta")
("get list with remote versions" "obtener lista con versiones remotas")
("global log" "registro global")
("global status" "estado global")
("glue multiple spaces" "pegar espacios múltiples")
("glyphs" "glifos")
("gnaw" "roer")
("gnawed" "roído")
("gnuPG command" "comando gnuPG")
("gnuPG decryption error" "error de descifrado de gnuPG")
("gnuPG error: buffer encryption failed" "error de gnuPG: error en el cifrado del búfer")
("gnuPG error: cannot find suitable secret key to decrypt" "error de gnuPG: no se puede encontrar la clave secreta adecuada para descifrar")
("gnuPG requires name and email to have at least 5 characters" "gnuPG requiere nombre y correo electrónico para tener al menos 5 caracteres")
("go to anchor" "ir a anclar")
("go to anchor or float" "ir a anclar o flotar")
("go to anchor or footnote" "ir al ancla o nota al pie")
("go to first similar tag" "ir a la primera etiqueta similar")
("go to float" "ir a flotar")
("go to footnote" "ir a pie de página")
("go to last similar tag" "ir a la última etiqueta similar")
("go to next similar tag" "ir a la siguiente etiqueta similar")
("go to previous similar tag" "ir a la etiqueta similar anterior")
("go to section" "ir a la sección")
("grain" "grano")
("granite" "granito")
("graphical effects" "efectos gráficos")
("graphical interface font scale" "escala de fuente de interfaz gráfica")
("graphical overlays" "superposiciones gráficas")
("graphical slides and overlays" "diapositivas gráficas y superposiciones")
("graphics" "gráficos")
("graphics geometry" "geometría gráfica")
("graphics grids" "cuadrículas gráficas")
("greyed" "gris")
("grid" "cuadrícula")
("grid curves" "curvas de cuadrícula")
("grid points" "puntos de cuadrícula")
("grid-curve intersections" "intersecciones de curva de cuadrícula")
("group of objects" "grupo de objetos")
("group/ungroup" "agrupar / desagrupar")
("group/ungroup objects" "agrupar / desagrupar objetos")
("grouped" "agrupados")
("guarantee transparent source tracking" "garantía de seguimiento de fuente transparente")
("half wide" "medio ancho")
("hand drawn" "dibujado a mano")
("handwritten" "escrito a mano")
("hangul" "hangul")
("headers" "encabezados")
("hidden" "oculto")
("high resolution settings" "ajustes de alta resolución")
("history" "historia")
("homepage" "página de inicio")
("homoglyph substitutions" "sustituciones de homoglifos")
("horizontal alignment" "alineación horizontal")
("horizontal collapse distance" "distancia de colapso horizontal")
("horizontal margins" "márgenes horizontales")
("hybrid command" "comando híbrido")
("hyphenate as" "guión como")
("icon" "icono")
("if hyphenated" "con guión")
("ignore" "ignorar")
("impact" "impacto")
("import bibliography" "bibliografía de importación")
("import database entry" "entrada de la base de datos de importación")
("import entries in buffer" "entradas de importación en el búfer")
("import entry" "entrada de importación")
("import file" "archivo de importación")
("import public keys from buffer" "importar claves públicas desde el búfer")
("import selected database entries" "importar entradas seleccionadas de la base de datos")
("import selected entries" "importar entradas seleccionadas")
("import selections as" "Importar selecciones como")
("import sessions" "sesiones de importación")
("import sophisticated objects as pictures" "importar objetos sofisticados como imágenes")
("imported bibliographic entries" "entradas bibliográficas importadas")
("in popup windows" "en ventanas emergentes")
("inanimated" "inanimados")
("inch" "pulgadas")
("incomplete entries found to be filled out" "entradas incompletas encontradas para ser completadas")
("increase size" "aumentar tamaño")
("indent paragraphs" "párrafos de sangría")
("indentation" "sangría")
("indication" "indicación")
("informative flags" "banderas informativas")
("initialize" "inicializar")
("initialize wallet" "inicializar billetera")
("initials" "iniciales")
("ink here" "tinta aquí")
("ink in" "tinta adentro")
("ink out" "sin tinta")
("inline" "en línea")
("inline args" "argumentos en línea")
("inline arguments" "argumentos en línea")
("inline code" "código en línea")
("inline content" "contenido en línea")
("inline formula" "fórmula en línea")
("inner bottom" "fondo interior")
("inner left" "interior izquierdo")
("inner right" "derecho interior")
("inner top" "parte superior interior")
("input command" "comando de entrada")
("input field" "campo de entrada")
("input options" "opciones de entrada")
("insert a computer program" "insertar un programa de computadora")
("insert a condition" "insertar una condición")
("insert a control flow instruction" "insertar una instrucción de flujo de control")
("insert a gap" "insertar un espacio")
("insert a list" "insertar una lista")
("insert a multiple choice" "inserte una opción múltiple")
("insert a negation" "insertar una negación")
("insert a new entry" "insertar una nueva entrada")
("insert a note or a floating object" "insertar una nota o un objeto flotante")
("insert a numerical operation" "insertar una operación numérica")
("insert a prominent piece of text" "inserte un texto destacado")
("insert a question" "inserte una pregunta")
("insert a root" "insertar una raíz")
("insert a script" "insertar una secuencia de comandos")
("insert a section block" "insertar un bloque de sección")
("insert a textual operation" "insertar una operación textual")
("insert a textual operator" "insertar un operador textual")
("insert above" "insertar arriba")
("insert abstract" "insertar resumen")
("insert an answer" "inserte una respuesta")
("insert an enunciation" "insertar una enunciación")
("insert an operation on tuples" "insertar una operación en tuplas")
("insert annotation" "insertar anotación")
("insert arcs" "insertar arcos")
("insert argument after" "insertar argumento después de")
("insert argument before" "insertar argumento antes")
("insert author" "insertar autor")
("insert below" "insertar abajo")
("insert bibliography" "insertar bibliografía")
("insert circles" "insertar círculos")
("insert closed splines" "insertar splines cerrados")
("insert copyright and license information" "insertar información de copyright y licencia")
("insert explanatory item" "insertar elemento explicativo")
("insert field above" "insertar campo arriba")
("insert field below" "insertar campo a continuación")
("insert hand drawn curves" "insertar curvas dibujadas a mano")
("insert large delimiters" "insertar delimitadores grandes")
("insert last name" "insertar apellido")
("insert left" "insertar a la izquierda")
("insert lines" "insertar líneas")
("insert macro" "insertar macro")
("insert missing invisible operators" "insertar operadores invisibles faltantes")
("insert more names" "insertar más nombres")
("insert multiple paragraphs" "insertar múltiples párrafos")
("insert overlay after" "insertar superposición después de")
("insert overlay before" "insertar superposición antes")
("insert particle" "insertar partícula")
("insert plain text" "insertar texto sin formato")
("insert points" "puntos de inserción")
("insert polygons" "insertar polígonos")
("insert right" "insertar a la derecha")
("insert similar above" "inserte similar arriba")
("insert similar below" "insertar similar a continuación")
("insert similar block above" "inserte un bloque similar arriba")
("insert similar block below" "inserte un bloque similar a continuación")
("insert slide after" "insertar diapositiva después")
("insert slide before" "insertar diapositiva antes")
("insert splines" "insertar splines")
("insert subscript" "insertar subíndice")
("insert subtable" "insertar subtabla")
("insert superscript" "insertar superíndice")
("insert symbol documentation" "insertar documentación de símbolo")
("insert template" "insertar plantilla")
("insert text" "insertar texto")
("insert text field above" "insertar campo de texto arriba")
("insert text field below" "insertar campo de texto a continuación")
("insert title" "insertar título")
("insert title after name" "insertar título después del nombre")
("insert user interface related markup" "insertar marcado relacionado con la interfaz de usuario")
("insert value" "valor de inserción")
("inserting control points" "inserción de puntos de control")
("inside mathematics" "dentro de las matemáticas")
("integrate" "integrar")
("interactive command" "comando interactivo")
("interactive questions" "preguntas interactivas")
("intercharacter compression" "compresión entre caracteres")
("intercharacter stretching" "estiramiento entre caracteres")
("interrupted" "interrumpido")
("invalid multi-paragraph selection" "selección de varios párrafos no válida")
("invalid renaming" "cambio de nombre no válido")
("invert" "invertir")
("inverted breve" "breve invertido")
("invisible ending" "final invisible")
("invisible newline" "nueva línea invisible")
("invisible opening" "apertura invisible")
("inwards" "hacia adentro")
("join selected cells" "unir celdas seleccionadas")
("jump in" "saltar")
("junior" "junior")
("justify" "justificar")
("keep evaluated expressions" "mantener expresiones evaluadas")
("keep local" "mantener local")
("keep remote" "mantener alejado")
("keep track of source code" "realizar un seguimiento del código fuente")
("keep unfolded" "mantener desplegado")
("key manager" "administrador clave")
("keyboard configuration" "configuración del teclado")
("laTeX errors" "errores de laTeX")
("laptop presentations" "presentaciones para laptop")
("large brackets" "paréntesis grandes")
("large cells" "células grandes")
("large displayed" "pantalla grande")
("large displayed fraction" "fracción grande mostrada")
("large tables" "mesas grandes")
("last" "último")
("last check" "último control")
("last difference" "última diferencia")
("last error" "último error")
("last field" "último campo")
("last name" "apellido")
("last occurrence" "última ocurrencia")
("last similar" "último similar")
("lcm" "mcm")
("left axis" "eje izquierdo")
("left baseline" "línea de base izquierda")
("left bottom" "parte inferior izquierda")
("left cell border" "borde de la celda izquierda")
("left cell padding" "relleno de celda izquierda")
("left center" "centro izquierda")
("left click: add point; Right click: undo" "clic izquierdo: agregar punto; clic derecho: deshacer")
("left click: finish; Right click: undo" "clic izquierdo: finalizar; clic derecho: deshacer")
("left click: new object" "clic izquierdo: nuevo objeto")
("left click: operate" "clic izquierdo: operar")
("left down" "izquierda abajo")
("left on even pages" "izquierda en páginas pares")
("left table border" "borde izquierdo de la mesa")
("left table padding" "relleno de la mesa izquierda")
("left top" "arriba a la izquierda")
("left up" "izquierda")
("left-right arrow" "flecha izquierda-derecha")
("leftwards" "hacia la izquierda")
("let the environment float" "deje que el medio ambiente flote")
("line arrows" "flechas de línea")
("line breaking" "salto de línea")
("line dashes" "guiones de línea")
("line portion" "porción de línea")
("line style" "estilo de línea")
("line width" "ancho de línea")
("line wrapping" "ajuste de línea")
("line wrapping inside cell" "ajuste de línea dentro de la celda")
("linear 2D" "2D lineal")
("linear algebra" "álgebra lineal")
("lines around" "líneas alrededor")
("link image and copies as" "imagen de enlace y copias como")
("link image as" "imagen de enlace como")
("link mode" "modo de enlace")
("link to URL" "enlace a URL")
("linking tool" "herramienta de enlace")
("live" "en vivo")
("live input-output" "entrada-salida en vivo")
("load help file" "cargar archivo de ayuda")
("load remote file" "cargar archivo remoto")
("loading" "cargando")
("local entries" "entradas locales")
("loci" "loci")
("locus" "locus")
("locus rendering" "representación de locus")
("logarithm" "logaritmo")
("logarithmic" "logarítmico")
("logarithmic base" "base logarítmica")
("logarithms" "logaritmos")
("logging in" "iniciando sesión")
("logical and" "lógico y")
("logical implication" "implicación lógica")
("logical not" "no lógico")
("logical or" "lógico o")
("login" "inicio de sesión")
("logout" "cerrar sesión")
("long macro" "macro larga")
("long text" "texto largo")
("look for more fonts" "buscar más fuentes")
("loops" "bucles")
("macro argument" "argumento macro")
("macro definition" "definición macro")
("macro editor" "editor de macros")
("macro name" "nombre macro")
("macros" "macros")
("macros editor" "editor de macros")
("magnify horizontally" "ampliar horizontalmente")
("magnify vertically" "ampliar verticalmente")
("main presentation style" "estilo de presentación principal")
("make a letter environment" "crear un entorno de letras")
("make a multi-slide presentation" "hacer una presentación de varias diapositivas")
("make block wide" "hacer bloque ancho")
("make float wide" "hacer flotar ancho")
("make floating" "hacer flotante")
("make footnote wide" "hacer amplia la nota al pie")
("make link" "hacer enlace")
("make non floating" "hacer no flotante")
("make wide" "ensanchar")
("manila paper" "papel manila")
("map arguments" "argumentos del mapa")
("marginal note" "nota marginal")
("margins from width" "márgenes del ancho")
("margins on paper" "márgenes en papel")
("margins on screen" "márgenes en pantalla")
("marked" "marcado")
("marker" "marcador")
("material" "material")
("math Extra" "matemáticas extra")
("math Letters" "Letras de matemáticas")
("math Symbols" "Símbolos matemáticos")
("mathematical font" "fuente matemática")
("mathematical output" "resultado matemático")
("matrices" "matrices")
("maximal" "máximo")
("maximal cell height" "altura máxima de la celda")
("maximal clustering" "agrupamiento máximo")
("maximal table height" "altura máxima de la mesa")
("maximal table width" "ancho de mesa máximo")
("maximum" "máximo")
("meander" "meandro")
("medieval" "medieval")
("memory" "memoria")
("memory usage" "uso de memoria")
("menu" "menú")
("merge lines into paragraphs unless separated by blank lines" "fusionar líneas en párrafos a menos que estén separadas por líneas en blanco")
("messages" "mensajes")
("meta data" "metadatos")
("metadata" "metadatos")
("metal" "metal")
("middle baseline" "línea de base media")
("minimal" "mínimo")
("minimal cell height" "altura mínima de celda")
("minimal cell width" "ancho de celda mínimo")
("minimal line separation" "separación mínima de línea")
("minimal table height" "altura mínima de la mesa")
("minimal table width" "ancho mínimo de mesa")
("minimum" "mínimo")
("mirror" "espejo")
("miscellanous" "misceláneo")
("mixed" "mixto")
("mode dependent icons" "iconos dependientes del modo")
("modify bibliography" "modificar bibliografía")
("modify remote live document" "modificar documento en vivo remoto")
("module" "módulo")
("module browser" "navegador de módulo")
("monospaced" "monoespaciado")
("more information about GNU TeXmacs can be found in the Help->About menu" "se puede encontrar más información sobre GNU TeXmacs en el menú Ayuda-> Acerca de")
("motion" "movimiento")
("mouse over object" "mouse sobre objeto")
("move objects" "mover objetos")
("move over object on which to operate" "mover sobre objeto sobre el cual operar")
("multiline" "multilínea")
("multiple choice" "opción múltiple")
("multiple documents share window" "ventana para compartir documentos múltiples")
("multiple root" "raíz múltiple")
("multiplication" "multiplicación")
("mutator tags" "etiquetas mutantes")
("named" "nombrado")
("navigation options" "opciones de navegación")
("never" "nunca")
("new account" "nueva cuenta")
("new bibliography dialogue" "diálogo de nueva bibliografía")
("new document" "nuevo documento")
("new double page" "nueva página doble")
("new double page before" "nueva página doble antes")
("new entry" "nueva entrada")
("new identity" "nueva identidad")
("new locus" "nuevo locus")
("new macro" "nueva macro")
("new passphrase" "nueva frase de contraseña")
("new remote directory" "nuevo directorio remoto")
("new remote file" "nuevo archivo remoto")
("new style fonts" "nuevas fuentes de estilo")
("new style page breaking" "salto de página de nuevo estilo")
("new version" "nueva versión")
("new window" "nueva ventana")
("newer version" "versión más nueva")
("next" "siguiente")
("next chunk" "siguiente fragmento")
("next difference" "próxima diferencia")
("next error" "siguiente error")
("next field" "siguiente campo")
("next occurrence" "próxima aparición")
("next screen" "pantalla siguiente")
("next similar" "siguiente similar")
("no animation" "sin animación")
("no clustering" "sin agrupamiento")
("no completions" "sin finalizaciones")
("no errors have been corrected" "no se han corregido errores")
("no grid" "sin cuadrícula")
("no multiple spaces" "sin espacios múltiples")
("no new public key in document" "no hay nueva clave pública en el documento")
("no page break" "sin salto de página")
("no page numbers" "sin números de página")
("no parent" "sin padre")
("no selection" "sin selección")
("no spelling errors" "sin errores ortográficos")
("no spurious spaces" "sin espacios espurios")
("normal loci" "loci normal")
("not allowed to remove home directory" "no se permite eliminar el directorio de inicio")
("not connected to server" "no conectado al servidor")
("not yet implemented" "aún no implementado")
("notebook" "cuaderno")
("number of polar steps" "número de pasos polares")
("number of subunit steps" "número de pasos de subunidad")
("numbered" "numerados")
("numbering" "numeración")
("numeric spreadsheet" "hoja de cálculo numérica")
("oblique" "oblicuo")
("odd page" "página impar")
("odd page left margin" "margen izquierdo de página impar")
("odd page right margin" "margen derecho de página impar")
("odd page shift" "cambio de página impar")
("odd pages" "páginas impares")
("of fingerprint" "de huella digital")
("old version" "versión anterior")
("older version" "versión anterior")
("on the footer" "en el pie de página")
("on your system and set it up from the \"Security\" tab" "en su sistema y configúrelo desde la pestaña \"Seguridad\"")
("once" "una vez")
("one column" "una columna")
("one error has been corrected" "se ha corregido un error")
("one lower case letter, one non alpha-numeric symbol" "una letra minúscula, un símbolo no alfanumérico")
("one numeric character, one upper case letter" "un carácter numérico, una letra mayúscula")
("only convert changes when re-importing" "solo convierte cambios al volver a importar")
("only convert changes with respect to imported version" "solo convierte cambios con respecto a la versión importada")
("only convert changes with respect to tracked version" "solo convierte cambios con respecto a la versión rastreada")
("only implemented for complete subtrees" "solo implementado para subárboles completos")
("only inline tags" "solo etiquetas en línea")
("only keep folded" "solo mantener plegado")
("only keep unfolded" "solo mantener desplegado")
("only show paragraphs with hits" "solo muestra párrafos con aciertos")
("only show semantic focus" "solo muestra enfoque semántico")
("opacity" "opacidad")
("open bibliography" "bibliografía abierta")
("open identities" "identidades abiertas")
("open in new window" "abrir en una ventana nueva")
("open key manager" "administrador de claves abiertas")
("open licence agreement" "acuerdo de licencia abierta")
("open mailbox" "abrir buzón")
("open module browser" "navegador de módulo abierto")
("open symbol browser" "navegador de símbolo abierto")
("open tool in separate window" "herramienta abierta en ventana separada")
("operation mode" "modo de operación")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "o dar la ruta completa al \"gpg\" o \"gpg2\" command")
("order" "orden")
("ordinary symbol" "símbolo ordinario")
("ornamented" "ornamentado")
("other login" "otro inicio de sesión")
("other package" "otro paquete")
("outer bottom" "fondo exterior")
("outer left" "exterior izquierdo")
("outer right" "exterior derecho")
("outer top" "parte superior externa")
("outline" "esquema")
("outlined" "delineado")
("outlined emboss" "relieve esbozado")
("outlined engrave" "grabado esbozado")
("output options" "opciones de salida")
("outwards" "hacia afuera")
("oval" "ovalado")
("overlap" "superposición")
("overlay" "superposición")
("overlay mode" "modo de superposición")
("overlays" "superposiciones")
("overlined" "sobremarcado")
("overview of the scheme extension language" "descripción general del lenguaje de extensión de esquema")
("padded" "acolchado")
("page background" "fondo de página")
("page break after" "salto de página después")
("page breaking algorithm" "algoritmo de salto de página")
("page format" "formato de página")
("page number" "número de página")
("page number rendering" "representación de número de página")
("page rendering" "representación de página")
("pagedown" "página abajo")
("pageup" "pageup")
("palette" "paleta")
("panorama" "panorama")
("paragraph format" "formato de párrafo")
("paragraphs" "párrafos")
("parametric curve" "curva paramétrica")
("parametric surface" "superficie paramétrica")
("parenthesis" "paréntesis")
("parenthesized" "entre paréntesis")
("particle" "partícula")
("passphrase decryption" "descifrado de frase de contraseña")
("passphrase encryption" "cifrado de frase de contraseña")
("passphrase wallet facilities are not currently available" "las instalaciones de billetera de frase de contraseña no están disponibles actualmente")
("passphrases are expected to have at least: 8 characters" "Se espera que frases de contraseña tengan al menos 8 caracteres")
("passphrases mismatch" "frases de contraseña no coinciden")
("pastel" "pastel")
("pattern" "patrón")
("pattern selector" "selector de patrones")
("pause" "pausa")
("pdf version number" "número de versión en pdf")
("pen" "bolígrafo")
("pen width" "ancho de la pluma")
("permanent footer" "pie de página permanente")
("permanent header" "encabezado permanente")
("permanently add to dictionary" "agregar permanentemente al diccionario")
("permanently insert into dictionary" "insertar permanentemente en el diccionario")
("permissions" "permisos")
("phantom" "fantasma")
("phantoms" "fantasmas")
("physics and astronomy class" "clase de física y astronomía")
("picture" "imagen")
("pine" "pino")
("plain" "simple")
("plain boxes" "cajas simples")
("plain circles" "círculos simples")
("play" "juego")
("play all animations" "reproducir todas las animaciones")
("play animation" "reproducir animación")
("please install GnuPG software from https://www.gnupg.org" "instale el software GnuPG desde https://www.gnupg.org")
("plot" "trama")
("plug-ins" "complementos")
("plural" "plural")
("point" "punto")
("point border" "borde de punto")
("point size" "tamaño de punto")
("point style" "estilo de punto")
("polar" "polar")
("polygon" "polígono")
("pop server settings" "configuración del servidor pop")
("portion" "porción")
("position of marginal note" "posición de nota marginal")
("poster formats" "formatos de póster")
("poster theme" "tema del póster")
("postfix" "postfix")
("preferences for editing mathematical formulas" "preferencias para editar fórmulas matemáticas")
("preferences for tag" "preferencias de etiqueta")
("prefix" "prefijo")
("presentation tag" "etiqueta de presentación")
("presentation tool" "herramienta de presentación")
("preserve" "preservar")
("preserve tags" "preservar etiquetas")
("pretty" "bonita")
("pretty tree output" "salida de árbol bonito")
("preview" "vista previa")
("previous" "anterior")
("previous difference" "diferencia anterior")
("previous error" "error anterior")
("previous field" "campo anterior")
("previous occurrence" "suceso anterior")
("previous screen" "pantalla anterior")
("previous similar" "similar anterior")
("primitive or macro" "primitivo o macro")
("print buffer" "buffer de impresión")
("print buffer to file" "imprimir buffer al archivo")
("print document" "documento impreso")
("print to file" "imprimir en archivo")
("printer setup" "configuración de la impresora")
("produce Pdf using native export filter" "producir PDF con filtro de exportación nativo")
("produce Postscript using native export filter" "producir PostScript usando el filtro de exportación nativo")
("program bracket matching" "coincidencia de soporte de programa")
("program bracket selections" "selecciones de soporte de programa")
("program commands" "comandos de programa")
("program font" "fuente del programa")
("program interface for buffer management" "interfaz de programa para la gestión del búfer")
("programming routines for editing documents" "rutinas de programación para editar documentos")
("prominent" "prominente")
("provoke C++ error" "provocar error de C ++")
("provoke menu error" "provocar error de menú")
("provoke scheme error" "error de esquema de provocación")
("pseudo code" "pseudocódigo")
("public key encryption" "cifrado de clave pública")
("public keys" "claves públicas")
("pulse" "pulso")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUI solamente, lo siento. Use \"Exportar selección\"")
("qt-widgets" "widgets qt")
("quantifier" "cuantificador")
("quasi" "cuasi")
("questions only" "solo preguntas")
("questions with answers" "preguntas con respuestas")
("quick evaluation of formulas" "evaluación rápida de fórmulas")
("rank" "rango")
("raw" "crudo")
("really delete user identity" "realmente elimina la identidad del usuario")
("really tiny" "realmente pequeño")
("rebuild translations file" "reconstruir archivo de traducciones")
("recent" "reciente")
("recent documents" "documentos recientes")
("recipients" "destinatarios")
("recognize" "reconocer")
("recolor" "volver a colorear")
("recover autosave file" "recuperar archivo de autoguardado")
("rectangular" "rectangular")
("reduce" "reducir")
("reduce trigonometric functions" "reducir funciones trigonométricas")
("reduced margins" "márgenes reducidos")
("reference guide" "guía de referencia")
("reference guide for the TeXmacs primitives" "guía de referencia para las primitivas TeXmacs")
("reference guide for the standard TeXmacs styles" "guía de referencia para los estilos estándar de TeXmacs")
("regenerate" "regenerar")
("register" "registrarse")
("register file" "archivo de registro")
("relate" "relacionar")
("relation" "relación")
("release left button: finish editing" "botón izquierdo de liberación: finalizar edición")
("remote" "remoto")
("remote connections" "conexiones remotas")
("remote control" "control remoto")
("remote controllers with keyboard simulation" "controladores remotos con simulación de teclado")
("remote directory" "directorio remoto")
("remote login" "inicio de sesión remoto")
("remote servers" "servidores remotos")
("remote tool" "herramienta remota")
("remove" "eliminar")
("remove animation" "eliminar animación")
("remove argument after" "eliminar argumento después de")
("remove argument before" "eliminar argumento antes")
("remove banner" "eliminar banner")
("remove database entry" "eliminar entrada de base de datos")
("remove downwards" "eliminar hacia abajo")
("remove entries" "eliminar entradas")
("remove entry" "eliminar entrada")
("remove field above" "eliminar campo arriba")
("remove field below" "eliminar campo a continuación")
("remove folded" "quitar plegado")
("remove from previous frames" "eliminar de fotogramas anteriores")
("remove from subsequent frames" "eliminar de fotogramas posteriores")
("remove last field" "eliminar el último campo")
("remove leftwards" "eliminar hacia la izquierda")
("remove link" "eliminar enlace")
("remove next field" "eliminar el siguiente campo")
("remove overlay after" "eliminar superposición después de")
("remove overlay before" "eliminar superposición antes")
("remove package" "eliminar paquete")
("remove previous field" "eliminar campo anterior")
("remove rightwards" "eliminar hacia la derecha")
("remove selected database entries" "eliminar entradas seleccionadas de la base de datos")
("remove selected entries" "eliminar entradas seleccionadas")
("remove slide after" "eliminar diapositiva después de")
("remove slide before" "eliminar diapositiva antes")
("remove superfluous invisible operators" "eliminar operadores invisibles superfluos")
("remove tag" "eliminar etiqueta")
("remove this branch" "eliminar esta rama")
("remove this frame" "eliminar este marco")
("remove unfolded" "eliminar desplegado")
("remove upwards" "eliminar hacia arriba")
("removed entries from database" "entradas eliminadas de la base de datos")
("removed entry from database" "entrada eliminada de la base de datos")
("rename" "renombrar")
("rename section" "renombrar sección")
("rendering" "representación")
("rendering options for tag" "opciones de representación para etiqueta")
("repeat" "repetir")
("replace TeXmacs styles with no LaTeX equivalents" "reemplazar los estilos TeXmacs sin equivalentes LaTeX")
("replace all further occurrences" "reemplazar todos los sucesos posteriores")
("replace one occurrence" "reemplazar una ocurrencia")
("replace toolbar" "reemplazar barra de herramientas")
("replace unrecognized styles" "reemplazar estilos no reconocidos")
("reset error counters" "restablecer contadores de error")
("resize" "cambiar tamaño")
("resize objects" "cambiar el tamaño de los objetos")
("restart TeXmacs in order to let changes take effect" "reiniciar TeXmacs para que los cambios surtan efecto")
("restart in order to let the new look and feel take effect" "reiniciar para que la nueva apariencia tenga efecto")
("retain" "retener")
("retime" "retime")
("retina settings" "ajustes de retina")
("retrieve email" "recuperar correo electrónico")
("retrieve remote live document" "recuperar documento en vivo remoto")
("retrieved contents" "contenido recuperado")
("retro" "retro")
("reverse" "reverso")
("reverse ordering" "orden inverso")
("ridged paper" "papel acanalado")
("right baseline" "línea de base derecha")
("right cell border" "borde de la celda derecha")
("right cell padding" "relleno de celda derecha")
("right down" "justo abajo")
("right on even pages" "justo en las páginas pares")
("right table border" "borde derecho de la mesa")
("right table padding" "relleno de la mesa derecha")
("right up" "justo arriba")
("rightwards" "hacia la derecha")
("rigid box" "caja rígida")
("rotate" "rotar")
("rotate objects" "rotar objetos")
("rough" "rugoso")
("rough paper" "papel rugoso")
("round" "redondo")
("round overbrace" "sobrebraza redonda")
("round underbrace" "underbrace redondo")
("row above" "fila arriba")
("row below" "fila debajo")
("rows" "filas")
("run" "correr")
("run current file" "ejecutar archivo actual")
("same names" "mismos nombres")
("same screen margins as on paper" "mismos márgenes de pantalla que en papel")
("sample text" "texto de muestra")
("save auxiliary data" "guardar datos auxiliares")
("save entries" "guardar entradas")
("save entry" "guardar entrada")
("save image as" "guardar imagen como")
("save position" "guardar posición")
("save remote file" "guardar archivo remoto")
("saved modifications in database" "modificaciones guardadas en la base de datos")
("scheme command" "comando de esquema")
("scheme developers guide" "guía de desarrolladores de esquemas")
("scheme extensions" "extensiones de esquema")
("scheme interface for the graphical mode" "interfaz de esquema para el modo gráfico")
("screen" "pantalla")
("screen rendering" "representación de pantalla")
("screens" "pantallas")
("screenshot" "captura de pantalla")
("scripting language" "lenguaje de script")
("scripts" "guiones")
("search and replace" "buscar y reemplazar")
("search in database" "buscar en la base de datos")
("search toolbar" "barra de herramientas de búsqueda")
("second" "segundo")
("secret keys" "claves secretas")
("sections" "secciones")
("see documentation" "ver documentación")
("select GnuPG recipients" "destinatarios seleccionados de GnuPG")
("select background picture" "seleccionar imagen de fondo")
("select document style" "seleccionar estilo de documento")
("select pen" "pluma selecta")
("select the action to be undertaken for each conflict" "seleccione la acción a emprender para cada conflicto")
("select view mode" "seleccionar modo de vista")
("semantic correctness" "corrección semántica")
("semantic editing" "edición semántica")
("semantic selections" "selecciones semánticas")
("semantics" "semántica")
("senior" "senior")
("serif" "serif")
("server" "servidor")
("server licence agreement" "acuerdo de licencia del servidor")
("session commands" "comandos de sesión")
("set default" "establecer predeterminado")
("set difference" "establecer diferencia")
("set intersection" "establecer intersección")
("set number of columns" "establecer número de columnas")
("set number of rows" "establecer número de filas")
("set or get environment variables" "establecer u obtener variables de entorno")
("set properties" "establecer propiedades")
("set union" "conjunto de unión")
("set user information" "establecer información del usuario")
("seventh" "séptimo")
("several equations" "varias ecuaciones")
("shadow" "sombra")
("shadowed" "sombreado")
("shadowed raise" "aumento sombreado")
("shift" "turno")
("short" "corto")
("show all parts" "mostrar todas las partes")
("show current focus" "mostrar foco actual")
("show full context" "mostrar contexto completo")
("show hidden" "Mostrar oculto")
("show key presses" "mostrar pulsaciones de teclas")
("show main document" "mostrar documento principal")
("show memory usage" "mostrar uso de memoria")
("show one part" "mostrar una parte")
("show panorama" "mostrar panorama")
("show preamble" "mostrar preámbulo")
("show several parts" "mostrar varias partes")
("show subunits" "mostrar subunidades")
("show table cells" "mostrar celdas de tabla")
("show timings" "horarios de espectáculos")
("side tools" "herramientas laterales")
("simple" "simple")
("simple form" "forma simple")
("simple widget" "widget simple")
("simplification" "simplificación")
("simplified evaluation of formulas" "evaluación simplificada de fórmulas")
("simplified menus" "menús simplificados")
("simplify" "simplificar")
("sine" "seno")
("sixth" "sexto")
("size tag" "etiqueta de tamaño")
("skew" "sesgo")
("skin" "piel")
("skip all" "omitir todo")
("slant" "inclinación")
("slashed fraction" "fracción cortada")
("slides" "diapositivas")
("slovene" "esloveno")
("slow" "lento")
("slow decrease" "disminución lenta")
("slow increase" "aumento lento")
("small Capitals" "capitales pequeñas")
("small capitals" "capitales pequeñas")
("small environment box" "caja de ambiente pequeño")
("small focus" "foco pequeño")
("small inline" "pequeño en línea")
("small inline fraction" "fracción en línea pequeña")
("smash" "aplastar")
("smooth" "suave")
("smooth end" "final liso")
("smooth extremities" "extremidades lisas")
("smooth start" "inicio suave")
("snap" "complemento")
("snap distance" "distancia de ajuste")
("snap to curves" "ajuste a curvas")
("snap to grid" "ajustar a la cuadrícula")
("snap to grid curve" "ajustar a la curva de cuadrícula")
("snap to intersections of curves" "ajuste a intersecciones de curvas")
("snap to text borders" "ajustar a los bordes del texto")
("snap to text corners" "ajustar a las esquinas del texto")
("solution to exercise" "solución para hacer ejercicio")
("solution to problem" "solución al problema")
("solutions" "soluciones")
("sound" "sonido")
("source" "fuente")
("source macros tool" "herramienta de macros de origen")
("source tags" "etiquetas fuente")
("south" "sur")
("south east" "sureste")
("space bar in math mode" "barra espaciadora en modo matemático")
("space bar in text mode" "barra espaciadora en modo texto")
("space stretchability" "capacidad de estiramiento espacial")
("span" "palmo")
("span over all columns" "abarcan todas las columnas")
("special functions" "funciones especiales")
("special properties" "propiedades especiales")
("specific baseline" "línea de base específica")
("specified" "especificado")
("specify color alternation" "especificar alternancia de color")
("specify how to traverse the manual" "especifique cómo recorrer el manual")
("specify semantics of a symbol or formula" "especificar semántica de un símbolo o fórmula")
("specify the size of the table" "especifique el tamaño de la tabla")
("specify user identity" "especificar identidad de usuario")
("spell check" "corrector ortográfico")
("spline" "spline")
("split program" "programa dividido")
("square" "cuadrado")
("square overbrace" "sobrebraza cuadrada")
("square underbrace" "underbrace cuadrado")
("stack" "pila")
("standard Output" "Salida estándar")
("standard TeXmacs styles" "estilos estándar de TeXmacs")
("standard environment variables" "variables de entorno estándar")
("standard formats" "formatos estándar")
("standard fraction" "fracción estándar")
("star" "estrella")
("start server" "iniciar servidor")
("statement" "declaración")
("statistics" "estadísticas")
("status" "estado")
("stop server" "detener servidor")
("storage" "almacenamiento")
("store tracking information in LaTeX files" "almacenar información de seguimiento en archivos LaTeX")
("stretch" "estiramiento")
("stretch factor" "factor de estiramiento")
("stretched" "estirado")
("strict Ascii" "Ascii estricto")
("strike through" "tachado")
("structured insert above" "inserto estructurado arriba")
("structured insert at the left" "inserto estructurado a la izquierda")
("structured insert at the right" "inserto estructurado a la derecha")
("structured insert below" "inserto estructurado a continuación")
("structured remove downwards" "eliminación estructurada hacia abajo")
("structured remove leftwards" "estructurado eliminar hacia la izquierda")
("structured remove rightwards" "eliminación estructurada hacia la derecha")
("structured remove upwards" "estructurado eliminar hacia arriba")
("structured variant" "variante estructurada")
("style options" "opciones de estilo")
("style parameters" "parámetros de estilo")
("stylesheet language" "lenguaje de hoja de estilo")
("subject" "sujeto")
("submenu" "submenú")
("subscript below" "subíndice a continuación")
("subsubmenu" "submenú")
("subsubsubmenu" "subsububmenú")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtabla")
("subtitle" "subtítulo")
("subtraction" "resta")
("summarized" "resumido")
("superscript above" "superíndice arriba")
("supported plug-ins" "complementos compatibles")
("surface" "superficie")
("inflate" "oleaje")
("swiss" "suizo")
("switch to buffer" "cambiar a búfer")
("symbol browser" "navegador de símbolos")
("symbol properties not found" "propiedades de símbolo no encontradas")
("symbols" "símbolos")
("synchronization status" "estado de sincronización")
("synchronize" "sincronizar")
("synchronize bibliographic references" "sincronizar referencias bibliográficas")
("synchronize file or directory" "sincronizar archivo o directorio")
("synchronize with remote server" "sincronizar con el servidor remoto")
("synopsis" "sinopsis")
("system command" "comando del sistema")
("tab-completion" "tabulación completa")
("tabbed" "con pestañas")
("table breaking" "romper la mesa")
("table height" "altura de la mesa")
("table properties" "propiedades de tabla")
("table width" "ancho de mesa")
("tags with special rendering" "etiquetas con representación especial")
("tangent" "tangente")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "búfer TeXmacs esperado")
("teXmacs buffer on disk expected" "búfer TeXmacs en el disco esperado")
("teXmacs database preferences" "preferencias de la base de datos de teXmacs")
("teXmacs extensions to scheme and utilities" "extensiones de TeXmacs para esquema y utilidades")
("teXmacs macro" "macro TeXmacs")
("teXmacs package" "paquete TeXmacs")
("teXmacs primitives" "primitivas TeXmacs")
("teXmacs style" "estilo TeXmacs")
("test routine" "rutina de prueba")
("testing tree-view" "prueba de vista de árbol")
("text borders" "bordes de texto")
("text box style" "estilo de cuadro de texto")
("text corners" "esquinas de texto")
("text padding" "relleno de texto")
("textual" "textual")
("textual operator" "operador textual")
("textual spreadsheet" "hoja de cálculo textual")
("the TeXmacs format" "el formato TeXmacs")
("the TeXmacs plug-in system" "el sistema de complemento TeXmacs")
("the document has not been saved" "el documento no se ha guardado")
("theme parameters" "parámetros del tema")
("these collected public keys will be definitely lost" "estas claves públicas recopiladas definitivamente se perderán")
("these public keys will be definitely lost" "estas claves públicas definitivamente se perderán")
("these secret keys will be definitely lost" "estas claves secretas definitivamente se perderán")
("thicken" "espesar")
("thin" "delgado")
("third" "tercero")
("this" "esto")
("this column" "esta columna")
("this page footer" "pie de página")
("this page header" "encabezado de esta página")
("this page number" "este número de página")
("this row" "esta fila")
("this style specifies page margins in the TeX way" "este estilo especifica márgenes de página en la forma TeX")
("three columns" "tres columnas")
("three dots" "tres puntos")
("three times" "tres veces")
("through popup windows" "a través de ventanas emergentes")
("through the menus" "a través de los menús")
("thumbnails" "miniaturas")
("time evolution" "evolución del tiempo")
("timings" "tiempos")
("title presentation options" "opciones de presentación del título")
("title style" "estilo de título")
("title suffix" "sufijo de título")
("titled block" "bloque titulado")
("toggle cell wrapping mode" "alternar modo de ajuste de celda")
("toggle here" "alternar aquí")
("toggle name" "nombre de alternar")
("toggle numbering" "numeración de alternar")
("toggle off" "alternar")
("toggle on" "alternar")
("toggle specification" "especificación de alternar")
("toggle titled" "alternar titulado")
("tolerant" "tolerante")
("top baseline" "línea de base superior")
("top cell border" "borde superior de la celda")
("top cell padding" "relleno de celda superior")
("top table border" "borde superior de la mesa")
("top table padding" "relleno de mesa superior")
("transform" "transformar")
("transform cell into subtable" "transformar celda en subtabla")
("translations" "traducciones")
("translations loaded" "traducciones cargadas")
("transpose" "transposición")
("traversal" "transversal")
("traverse" "transversal")
("triangle" "triángulo")
("triangularize" "triangularizar")
("trigonometric" "trigonométrico")
("trigonometry" "trigonometría")
("turn off" "apagar")
("turn on" "encender")
("turn on wallet" "encender billetera")
("twice" "dos veces")
("two columns" "dos columnas")
("two dots" "dos puntos")
("type a latex command followed by return" "escriba un comando de látex seguido de retorno")
("unchanged" "sin cambios")
("underlined" "subrayado")
("unevaluated argument" "argumento no evaluado")
("unevaluated value" "valor no evaluado")
("unextended" "no extendido")
("unfold" "desplegar")
("unfold all" "desplegar todo")
("unfold all fields" "desplegar todos los campos")
("unfolded" "desplegado")
("unit" "unidad")
("unit length" "longitud de la unidad")
("unknown secret key fingerprint" "huella digital de clave secreta desconocida")
("unregistered file" "archivo no registrado")
("unroll" "desenrollar")
("unsecure script refused" "secuencia de comandos no segura rechazada")
("unsupported link mode" "modo de enlace no compatible")
("until" "hasta")
("untitled block" "bloque sin título")
("up to date" "actualizado")
("update buffer" "búfer de actualización")
("update this buffer" "actualizar este búfer")
("update web site" "sitio web de actualización")
("upight" "vertical")
("upload" "subir")
("upload file or directory" "subir archivo o directorio")
("upright" "en posición vertical")
("upwards" "hacia arriba")
("url" "url")
("use CSS for more advanced formatting" "usa CSS para un formato más avanzado")
("use MathML" "usar MathML")
("use as master" "uso como maestro")
("use extensible brackets" "usar soportes extensibles")
("use high resolution fonts" "usar fuentes de alta resolución")
("use high resolution icons" "usar iconos de alta resolución")
("use line wrapping for lines which are longer than 80 characters" "usar ajuste de línea para líneas que tienen más de 80 caracteres")
("use margin kerning (protrusion)" "usar margen de margen (protrusión)")
("use print dialogue" "usar diálogo de impresión")
("use protrusion" "usar protuberancia")
("use relative path" "usar ruta relativa")
("use retina fonts" "usar fuentes retina")
("use retina icons" "usar iconos de retina")
("use unified toolbars" "usar barras de herramientas unificadas")
("user interface" "interfaz de usuario")
("user interface language" "idioma de la interfaz de usuario")
("user preferences" "preferencias del usuario")
("users of oriental languages" "usuarios de lenguas orientales")
("utf-8 with inputenc" "utf-8 con inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 con paquete inputenc LaTeX")
("utilities" "utilidades")
("vanish" "desaparecer")
("verbose" "detallado")
("version" "versión")
("versioning tool" "herramienta de versiones")
("vertical alignment" "alineación vertical")
("vertical margins" "márgenes verticales")
("vertical space after" "espacio vertical después")
("vertical space before" "espacio vertical antes")
("vertical space stretchability" "capacidad de estiramiento del espacio vertical")
("visible except here" "visible excepto aquí")
("visible from here on" "visible desde aquí")
("visible only here" "visible solo aquí")
("visible until here" "visible hasta aquí")
("visited loci" "lugares visitados")
("wallet" "billetera")
("wave" "ola")
("web" "web")
("weight" "peso")
("when line wrapping" "cuando se ajusta la línea")
("when wrapping" "al envolver")
("whitespace" "espacio en blanco")
("wide" "ancho")
("wide block" "bloque ancho")
("wide colored" "de ancho")
("wide float" "flotador ancho")
("wide footnote" "nota amplia")
("wide tabular" "tabular ancho")
("widescreen" "pantalla panorámica")
("with newer version" "con la versión más nueva")
("with older version" "con versión anterior")
("wrap lines" "líneas de ajuste")
("write a macro" "escribe una macro")
("writing TeXmacs bibliography styles" "escribir estilos de bibliografía TeXmacs")
("writing documentation" "documentación escrita")
("written with TeXmacs" "escrito con TeXmacs")
("wrong empty passphrase" "frase de contraseña vacía incorrecta")
("wrong passphrase" "frase de contraseña incorrecta")
("year" "año")
("year, Name" "año, nombre")
("you are attempting to open an encrypted file while" "está intentando abrir un archivo encriptado mientras")
("you might consider enabling the experimental" "podría considerar habilitar el experimental")
("you must add a bibliography file" "debe agregar un archivo de bibliografía")
("you should also make sure that GnuPG is installed" "también debe asegurarse de que GnuPG esté instalado")
("your personal dictionary has been modified" "su diccionario personal ha sido modificado")
("zebra" "cebra")
("zoom" "zoom")
("zoom in" "acercar")
("zoom out" "alejar")
("zoom/unzoom objects" "objetos zoom / unzoom")
