("A modifier" "модификатор A")
("GNU" "GNU")
("H modifier" "модификатор H")
("LaTeX" "LaTeX")
("M modifier" "модификатор M")
("TeX" "TeX")
("a modifier" "модификатор a")
("abbreviation" "сокращение")
("about" "о")
("about menu" "меню о")
("above" "сверху")
("abstract" "аннотация")
("accent" "accent")
("accept" "допустить")
("accept all scripts" "допустить все скрипты")
("accept no scripts" "не допускать никаких скриптов")
("accept script" "допустить скрипт")
("acknowledgment" "благодарность")
("acronym" "акроним")
("action" "действие")
("activate" "активировать")
("acute" "acute")
("add switch after" "вставить переключатель после")
("add switch before" "вставить переключатель перед")
("add package" "добавить пакет")
("address" "адрес")
("address block" "адресный блок")
("advanced" "для экспертов")
("advanced layout features" "размещение для экспертов")
("after" "после")
("albanian" "албанский")
("algorithm" "алгоритм")
("align cell to the bottom" "выровнять ячейку вниз")
("align cell to the left" "выровнять ячейку налево")
("align cell to the right" "выровнять ячейку направо")
("align cell to the top" "выровнять ячейку вверх")
("align table at base of left column" "выровнять таблицу по базовому уровню левой колонки")
("align table at base of middle column" "выровнять таблицу по базовому уровню средней колонки")
("align table at base of origin column" "выровнять таблицу по базовому уровню исходной колонки")
("align table at base of right column" "выровнять таблицу по базовому уровню правой колонки")
("align table at fraction bar height" "выровнять таблицу по высоте черты дроби")
("align table at the base of bottom row" "выровнять таблицу по базовому уровню нижней строки")
("align table at the base of middle row" "выровнять таблицу по базовому уровню средней строки")
("align table at the base of origin row" "выровнять таблицу по базовому уровню исходной строки")
("align table at the base of top row" "выровнять таблицу по базовому уровню верхней строки")
("align table at the bottom" "выровнять таблицу снизу")
("align table at the center" "выровнять таблицу по центру")
("align table at the horizontal center" "выровнять таблицу по центру горизонтально")
("align table at the left" "выровнять таблицу слева")
("align table at the top" "выровнять таблицу сверху")
("align table to the right" "выровнять таблицу справа")
("align text to the left" "выровнять текст налево")
("align text to the right" "выровнять текст направо")
("aligned" "выровненный")
("alignment" "выравнивание")
("all" "все")
("allow" "разрешить")
("allowed extension" "разрешенное расширение")
("allowed reduction" "разрешенное уменьшение")
("alpha release" "альфа версия")
("alt key" "клавиша alt")
("alternative specification" "альтернативная спецификация")
("and" "и")
("angular" "угловатый")
("appendix" "приложение")
("apply" "применить")
("april" "апрель")
("arab" "арабский")
("archaic" "древний")
("architecture" "архитектура")
("argument" "аргумент")
("arithmetic" "арифметический")
("armenian" "армянский")
("arrow" "стрелка")
("arrows" "стрелки")
("article" "статья")
("as on paper" "как на бумаге")
("assign" "присвоить")
("at fraction bar height" "на высоте черты дроби")
("at the baseline" "на базовом уровне")
("at the bottom" "снизу")
("at the left" "слева")
("at the middle" "в центре")
("at the right" "справа")
("at the top" "сверху")
("attach" "присоединить")
("attach buffer to which project" "присоединить буфер к которому проекту")
("august" "август")
("author" "автор")
("authorize" "авторизовать")
("automatic" "автоматический")
("automatic quotes" "автоматические кавычки")
("automatically close brackets" "автоматически закрывать скобки")
("automatically generated content" "автоматически сгенерированное содержание")
("autosave" "автосохранение")
("axiom" "аксиома")
("background" "фон")
("background color" "цвет фона")
("background evaluations" "фоновые вычисления")
("backward replace" "заменить назад")
("backward search" "искать назад")
("bad data format" "плохой формат данных")
("bar" "черта")
("bard" "bard")
("base level" "базовый уровень")
("bashkirian" "башкирский")
("basic" "основной")
("basic communication using pipes" "простое общение с помощью труб")
("basic data types" "основные типы данных")
("basic types" "основные типы")
("be useful" "быть полезным")
("become a TeXmacs developer" "станьте разработчиком TeXmacs")
("before" "перед")
("begin" "начало")
("below" "снизу")
("beta release" "бета версия")
("bibliography" "литература")
("bibliography file" "файл литературы")
("bibliography style" "стиль литературы")
("big" "большой")
("bibtex command" "команда bibtex")
("big figure" "большой рисунок")
("big operator" "большой оператор")
("big skip" "большой пробел")
("big table" "большая таблица")
("binary operation" "бинарная операция")
("binary relation" "бинарное отношение")
("black" "чёрный")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard мат")
("blackletter" "blackletter")
("blue" "синий")
("body" "тело")
("bold" "жирный")
("book" "книга")
("border" "граница")
("both" "оба")
("bottom" "низ")
("bottom border" "нижняя граница")
("bottom margin" "нижнее поле")
("bottom padding" "нижний заполнитель")
("branch" "ветвь")
("break" "разрыв")
("breaking" "разрывание")
("breve" "breve")
("british" "британский")
("broken white" "сломанный белый")
("brown" "коричневый")
("browse" "просматривать")
("browse web" "просматривать web")
("browser" "браузер")
("buffer" "буфер")
("bulgarian" "болгарский")
("bullet" "жирная точка")
("bullets" "жирные точки")
("by" "по")
("by typing" "вводя")
("bytes free" "байт свободно")
("bytes used" "байт использовано")
("calligraphic" "рукописный")
("cancel" "отменить")
("caps-lock key" "клавиша caps-lock")
("case" "случай")
("cc" "копия")
("cell" "ячейка")
("cell background color" "цвет фона ячейки")
("cell border" "границы ячейки")
("cell height" "высота ячейки")
("cell operation mode" "мода операции над ячейкой")
("cell width" "ширина ячейки")
("center" "центр")
("center text" "центрировать текст")
("centered" "центрированный")
("centered block" "центрированный блок")
("centered tabular" "центрированная таблица")
("change border of cell" "изменить границу ячейки")
("change cell operation mode" "изменить моду операции над ячейкой")
("change log" "журнал изменений")
("changes" "изменения")
("chapter" "глава")
("check" "check")
("check text for spelling errors" "проверить правописание")
("chinese" "китайский")
("choice" "выбор")
("citation" "лит ссылка")
("cite" "цитировать")
("class" "класс")
("clear" "очистить")
("clear selection" "убрать выделение")
("clipped" "обрезан")
("clipped and magnified" "обрезан и увеличен")
("clipped and resized" "обрезан и изменён размер")
("clone" "сдублировать")
("clone window" "сдублировать окно")
("close" "закрыть")
("close TeXmacs" "закрыть TeXmacs")
("close buffer" "закрыть буфер")
("close session" "закрыть сессию")
("close window" "закрыть окно")
("closing" "закрывание")
("code" "код")
("color" "цвет")
("column" "столбец")
("column contains glued items" "столбец содержит склеенные элементы")
("compact" "компактный")
("compatibility with other formats" "совместимость с другими форматами")
("compile article" "компилировать статью")
("compile book" "компилировать книгу")
("compile buffer" "компилировать буфер")
("compile project" "компилировать проект")
("completion" "пополнение")
("complex" "комплексный")
("compactification" "компактификация")
("compound" "составной")
("concrete" "конкретный")
("condensed" "сжатый")
("condition" "условие")
("configuration" "конфигурация")
("contact" "контакт")
("content" "содержание")
("content tag" "таг содержания")
("context dependent icons" "иконки, зависящие от контекста")
("continuation of" "продолжение")
("control flow" "управление выполнением")
("contribute" "вносите вклад")
("convention" "соглашение")
("converters" "преобразователи")
("converters to other data formats" "преобразователи в другие форматы данных")
("copy" "скопировать")
("copy text" "копировать текст")
("copy to" "копировать в")
("copying" "копирование")
("corollary" "следствие")
("correct text" "исправить текст")
("counter" "счётчик")
("create web site" "создать web сайт")
("cursors" "курсоры")
("custom tab" "custom tab")
("customize" "настроить")
("customizing TeXmacs" "настройка TeXmacs")
("customizing the TeXmacs styles" "настройка  стилей TeXmacs")
("custum tab" "custum tab")
("cut" "вырезать")
("cut text" "вырезать текст")
("cut to" "вырезать до")
("cypriot" "кипрский")
("cyrillic" "русский")
("cyrillic input method" "русский метод ввода")
("cyrillic italic right" "русский курсив")
("czech" "чешский")
("dancers" "пляшущие человечки")
("danish" "датский")
("dark grey" "тёмно-серый")
("dash" "чёрточка")
("dashes" "чёрточки")
("data conversion" "преобразование данных")
("data format" "формат данных")
("date" "дата")
("deactivate" "деактивировать")
("deactivate table" "деактивировать таблицу")
("december" "декабрь")
("decorate atoms" "декорировать атомы")
("default" "по умолчанию")
("default padding" "заполнитель по умолчанию")
("definition" "определение")
("delete" "удалить")
("delete column" "удалить колонку")
("delete row" "удалить строку")
("denominator" "знаменатель")
("description" "список с описаниями")
("destination" "назначение")
("detach" "отсоединить")
("detailed" "детальный")
("determinant" "детерминант")
("devangari" "деванагари")
("developers guide" "руководство для разработчиков")
("directory" "директория")
("disable" "запретить")
("disable first indentation" "запретить первый отступ")
("disable first indentation after" "запретить первый отступ после")
("disable first indentation before" "запретить первый отступ перед")
("disable indentation" "запретить отступ")
("disable indentation after" "запретить отступ после")
("disable indentation before" "запретить отступ перед")
("disable last indentation" "запретить последний отступ")
("disable last indentation after" "запретить последний отступ после")
("disable last indentation before" "запретить последний отступ перед")
("disallow" "запретить")
("distribute unused space" "распределить свободное пространство")
("div" "div")
("do not remap" "не перемапировать")
("document" "документ")
("document format" "формат документа")
("document style" "стиль документа")
("document styles" "стили документов")
("documentation" "документация")
("documents are trees" "документы \\ это деревья")
("dot" "точка")
("dots" "точки")
("double stroke" "двойной")
("down" "вниз")
("download" "скачать")
("dpi" "точек на дюйм")
("duplicate" "дублировать")
("dutch" "голландский")
("dynamic libraries" "динамические библиотеки")
("edit" "редактировать")
("edit source tree" "редактировать дерево исходников")
("editing tools" "средства редактирования")
("email" "email")
("emphasize" "подчеркнуть")
("emphasize text" "выделить текст")
("empty box" "пустой бокс")
("enable first indentation" "разрешить первый отступ")
("enable first indentation after" "разрешить первый отступ после")
("enable first indentation before" "разрешить первый отступ перед")
("enable indentation" "разрешить отступ")
("enable indentation after" "разрешить отступ после")
("enable indentation before" "разрешить отступ перед")
("enable last indentation" "разрешить последний отступ")
("enable last indentation after" "разрешить последний отступ после")
("enable last indentation before" "разрешить последний отступ перед")
("encl" "вложение")
("end" "конец")
("english" "английский")
("enter a title" "введите заглавие")
("enumerate" "пронумерованный список")
("enumerate|Alpha" "пронумерованный|Alpha")
("enumerate|Roman" "пронумерованный|Roman")
("enumerate|alpha" "пронумерованный|alpha")
("enumerate|roman" "пронумерованный|roman")
("env" "env")
("environment" "окружение")
("epilogue" "эпилог")
("equal" "равно")
("equation" "уравнение")
("equations" "уравнения")
("equivalent for" "эквивалент для")
("error" "ошибка")
("esperanto" "эсперанто")
("etruscan" "этрусский")
("evaluate" "вычислить")
("evaluate scheme expression" "вычислить scheme выражение")
("evaluation" "вычисление")
("even page footer" "footer чётных страниц")
("even page header" "header чётных страниц")
("even page left margin" "левые поля чётных страниц")
("even page margin" "поля чётных страниц")
("even page right margin" "правые поля чётных страниц")
("even page shift" "сдвиг чётных страниц")
("even page text" "текст чётных страниц")
("exact horizontal" "точный горизонтальный")
("exact mode" "точная мода")
("exam" "экзамен")
("example" "пример")
("exclusive" "исключительный")
("exclusive or" "исключающее или")
("executable" "выполняемая")
("execute" "выполнить")
("execute a TeXmacs command" "выполнить TeXmacs команду")
("execute system command" "выполнить системную команду")
("executive" "executive")
("exercise" "упражнение")
("expand" "раскрыть")
("explained" "объяснено")
("export" "экспортировать")
("export as" "экспортировать как")
("export bibliographies as links" "экспортировать библиографию как линки")
("extend or normal" "растянутый или нормальный")
("extern " "внешний")
("extra" "дополнительный")
("extract format" "точный формат")
("family" "семейство")
("february" "февраль")
("figure" "рисунок")
("file" "файл")
("file name" "имя файла")
("file not found" "файл не найден")
("find file" "найти файл")
("find next match" "найти следующий")
("find text" "найти текст")
("finnish" "финский")
("first contact" "первый контакт")
("first indentation" "первый отступ")
("first item" "первый элемент")
("first page" "первая страница")
("first start" "первый запуск")
("flat" "плоский")
("flexibility" "гибкость")
("flexibility factor for vertical spacing" "фактор гибкости для вертикального пробела")
("floating figure" "плавающая фигура")
("floating object" "плавающий объект")
("floating table" "плавающая таблица")
("fold" "свёртывание")
("fold input field" "свернуть поле ввода")
("folded" "свёрнутый")
("font" "шрифт")
("font base size" "основной размер шрифта")
("font dpi" "разрешение шрифта")
("font family" "семейство шрифтов")
("font name" "имя шрифта")
("font series" "серия шрифтов")
("font shape" "форма шрифта")
("font size" "размер шрифта")
("font type" "тип шрифта")
("font variant" "вариант шрифта")
("fonts" "шрифты")
("footer" "footer")
("footnote" "сноска")
("for" "для")
("for each" "для каждого")
("foreground" "цвет текста")
("foreign" "иностранный")
("format" "формат")
("formatted and structured output" "форматированный и структурный вывод")
("formatted date" "форматированная дата")
("formatting" "форматирование")
("formula" "формула")
("formula style" "стиль формулы")
("forward replace" "заменять вперёд")
("forward search" "искать вперёд")
("fraction" "дробь")
("french" "французский")
("full manuals" "полные руководства")
("full screen mode" "полноэкранная мода")
("function" "функция")
("functional" "функциональный")
("further customization" "дальнейшая настройка")
("future changes" "будущие изменения")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs не сопровождается никакими юридическими гарантиями")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs подпадает под GNU общую публичную лицензию")
("general architecture of TeXmacs" "общая архитектура TeXmacs")
("general negation" "общее отрицание")
("general note" "общая заметка")
("generating font file" "генерируется файл шрифта")
("generic" "общий")
("georgian" "грузинский")
("german" "немецкий")
("get arity" "получить арность")
("get label" "получить метку")
("getting started" "введение")
("glossary" "словарь")
("glossary entry" "словарный пункт")
("glue" "клей")
("glue decorations" "клеевые украшения")
("go" "иди")
("gothic" "готический")
("graphical interface" "графический интерфейс")
("grave" "grave")
("greater" "больше")
("greater or equal" "больше или равно")
("greek" "греческий")
("greek letter" "греческая буква")
("green" "зелёный")
("grey" "серый")
("group" "группа")
("h modifier" "модификатор h")
("happy typing" "счастливо печатать")
("has been aborted" "был прерван")
("has completed its task" "завершил свою работу")
("hat" "шляпка")
("header" "header")
("header and footer" "header и footer")
("hebrew" "еврейский")
("height" "высота")
("height is exactly the specified height" "высота точно как задана")
("height is maximum of specified height and box height" "высота большая из заданной и высоты бокса")
("height is minimum of specified height and box height" "высота меньшая из заданной и высоты бокса")
("height magnification" "растяжение высоты")
("help" "помощь")
("help me" "помогите мне")
("help us" "помогите нам")
("here" "здесь")
("home" "дом")
("horizontal" "горизонтальный")
("horizontal cell alignment" "горизонтальное выравнивание ячеек")
("horizontal ink separation" "horizontal ink separation")
("horizontal part" "горизонтальная часть")
("horizontal position" "горизонтальное положение")
("horizontal space" "растяжимый пробел")
("horizontal table alignment" "горизонтальное выравнивание таблицы")
("horizontally align cell to the base" "горизонтально выровнять ячейку по базовому уровню")
("horizontally center the cell" "горизонтально центрировать ячейку")
("how much longer may pages become" "сколь длиннее могут стать страницы")
("how much shorter may pages become" "сколь короче могут стать страницы")
("huge" "огромный")
("hungarian" "венгерский")
("hybrid command" "гибридная команда")
("hyperlink" "гиперлинк")
("hyphenation" "перенос")
("icelandic" "исландский")
("if" "если")
("image" "изображение")
("image links" "линки на изображения")
("implementation" "реализация")
("import" "импортировать")
("improving the current implementation" "улучшение текущей реализации")
("inactive" "неактивный")
("include" "включить")
("include a document" "включить документ")
("include file" "включить файл")
("inclusion into TeXmacs" "включение в TeXmacs")
("inclusions" "включения")
("indent" "отступ")
("indentation flag" "флаг отступа")
("index" "указатель")
("index entry" "пункт в указателе")
("index level" "уровень индекса")
("information flags" "информационные флаги")
("input mode" "метод ввода")
("insert" "вставить")
("insert Pr" "вставить Pr")
("insert a TeXmacs symbol" "вставить TeXmacs символ")
("insert a big operator" "вставить большой оператор")
("insert a binary operation" "вставить бинарную операцию")
("insert a binary relation" "вставить бинарное отношение")
("insert a blackboard bold character" "вставить жирный рукописный символ")
("insert a bold calligraphic character" "вставить жирный рукописный символ")
("insert a bold character" "вставить жирный символ")
("insert a calligraphic character" "вставить рукописный символ")
("insert a fraction" "вставить дробь")
("insert a fraktur character" "вставить готический символ")
("insert a greek character" "вставить греческую букву")
("insert a large left delimiter" "вставить большой левый ограничитель")
("insert a large right delimiter" "вставить большой правый ограничитель")
("insert a large separator" "вставить большой разделитель")
("insert a left subscript" "вставить левый индекс")
("insert a link" "вставить линк")
("insert a miscellaneous symbol" "вставить разнообразный символ")
("insert a new branch" "вставить новую ветвь")
("insert a new item" "вставить новый элемент")
("insert a picture" "вставить рисунок")
("insert a square root" "вставить квадратный корень")
("insert a table" "вставить таблицу")
("insert a table or a matrix" "вставить таблицу или матрицу")
("insert a wide symbol above" "вставить широкий символ выше")
("insert a wide symbol below" "вставить широкий символ ниже")
("insert an" "вставить")
("insert an accent" "вставить accent")
("insert an arrow" "вставить стрелку")
("insert an environment" "вставить окружение")
("insert an n" "вставить n")
("insert appendix" "вставить приложение")
("insert arccos" "вставить arccos")
("insert arcsin" "вставить arcsin")
("insert arctan" "вставить arctan")
("insert arg" "вставить arg")
("insert argument" "вставить аргумент")
("insert automatically generated content" "вставить автоматически сгенерированное оглавление")
("insert big contour integral" "вставить большой контурный интеграл")
("insert big coproduct" "вставить большое копроизведение")
("insert big direct sum" "вставить большую прямую сумму")
("insert big dotted point" "вставить большой круг с точкой")
("insert big integral" "вставить большой интеграл")
("insert big intersection" "вставить большое пересечение")
("insert big logical and" "вставить большое логическое и")
("insert big logical or" "вставить большое логическое или")
("insert big product" "вставить большое произведение")
("insert big square union" "вставить большое квадратное объединение")
("insert big summation" "вставить большую сумму")
("insert big tensor product" "вставить большое тензорное произведение")
("insert big union" "вставить большое объединение")
("insert big union sum" "вставить большую сумму-объединение")
("insert big vertical space" "вставить большой вертикальный пробел")
("insert chapter" "вставить главу")
("insert column" "вставить колонку")
("insert column to the left" "вставить колонку слева")
("insert column to the right" "вставить колонку справа")
("insert cos" "вставить cos")
("insert cosh" "вставить cosh")
("insert cot" "вставить cot")
("insert coth" "вставить coth")
("insert csc" "вставить csc")
("insert deg" "вставить deg")
("insert det" "вставить det")
("insert dim" "вставить dim")
("insert dollar" "вставить доллар")
("insert equation" "вставить уравнение")
("insert executable markup" "вставить исполняемую разметку")
("insert exp" "вставить exp")
("insert fields" "вставить поля")
("insert footnote" "вставить сноску")
("insert formula" "вставить формулу")
("insert gcd" "вставить gcd")
("insert hom" "вставить hom")
("insert horizontal interword space" "вставить горизонтальный межсловный промежуток")
("insert image" "вставить изображение")
("insert inactive markup" "вставить неактивную разметку")
("insert inf" "вставить inf")
("insert input field above" "вставить поле ввода выше")
("insert input field below" "вставить поле ввода ниже")
("insert ker" "вставить ker")
("insert lg" "вставить lg")
("insert lim" "вставить lim")
("insert liminf" "вставить liminf")
("insert limsup" "вставить limsup")
("insert ln" "вставить ln")
("insert log" "вставить log")
("insert macro" "вставить макро")
("insert mathematics" "вставить математику")
("insert max" "вставить max")
("insert medium horizontal space" "вставить средний горизонтальный пробел")
("insert medium vertical space" "вставить средний вертикальный пробел")
("insert min" "вставить min")
("insert negative horizontal space" "вставить отрицательный горизонтальный пробел")
("insert new item or number" "вставить новый элемент или номер")
("insert new rows or columns" "вставить новые строки или столбцы")
("insert or delete rows or columns" "вставить или удалить строки или столбцы")
("insert row" "вставить строку")
("insert row above" "вставить строку над")
("insert row below" "вставить строку под")
("insert sec" "вставить sec")
("insert section" "вставить параграф")
("insert sharp" "вставить решетку")
("insert sin" "вставить sin")
("insert sinh" "вставить sinh")
("insert small horizontal space" "вставить маленький горизонтальный пробел")
("insert small vertical space" "вставить маленький вертикальный пробел")
("insert structural markup" "вставить структурную разметку")
("insert subsection" "вставить подпараграф")
("insert subsubsection" "вставить подподпараграф")
("insert sup" "вставить sup")
("insert tan" "вставить tan")
("insert tanh" "вставить tanh")
("insert text field" "вставить текстовое поле")
("insert thick horizontal space" "вставить большой горизонтальный пробел")
("insert value" "вставить значение")
("interfacing" "интерфейс")
("interfacing TeXmacs with other systems" "создание интерфейсов TeXmacs с другими системами")
("interjection" "восклицание")
("interline separation" "межстрочное расстояние")
("interline space" "расстояние между строчками")
("internationalization" "интернационализация")
("interparagraph space" "расстояние между абзацами")
("interrupt execution" "прервать выполнение")
("introduction" "введение")
("invisible" "невидимый")
("invisible citation" "невидимая лит ссылка")
("irish" "ирландский")
("is running" "выполняется")
("is tuple" "является tuple")
("ispell does not respond" "ispell не отвечает")
("ispell is already busy" "ispell уже занят")
("italian" "итальянский")
("italic" "курсив")
("italic right" "прямой курсив")
("itemize" "список")
("january" "январь")
("japanese" "японский")
("july" "июль")
("june" "июнь")
("justified" "выровненный")
("justify text" "выровнять текст")
("keep unrecognized styles and packages" "Сохранять неопознанные стили и пакеты")
("key" "клавиша")
("keyboard" "клавиатура")
("keyboard equivalent" "клавиатурный эквивалент")
("keyboard modifiers" "клавиатурные модификаторы")
("keyboard shortcut" "клавиатурное сокращение")
("keymaps" "keymaps")
("keyword" "ключевое слово")
("keywords" "ключевые слова")
("kill" "убить")
("known bugs" "известные ошибки")
("label" "метка")
("landscape" "ландшафтная")
("language" "язык")
("large" "большой")
("large closing bracket" "большая закрывающая скобка")
("large delimiter" "большой ограничитель")
("large opening bracket" "большая открывающая скобка")
("large separator" "большой разделитель")
("last indentation" "последний отступ")
("last page" "последняя страница")
("latex command" "latex команда")
("latin" "латинский")
("layout" "размещение")
("left" "левый")
("left arrow" "левая стрелка")
("left border" "левый край")
("left margin" "левое поле")
("left padding" "левое заполнение")
("left prime" "left prime")
("left aligned" "рваный левый край")
("left slanted" "наклонённый влево")
("left subscript" "левый нижний индекс")
("left superscript" "левый верхний индекс")
("left surrounding" "левое окружение")
("legal" "legal")
("lemma" "лемма")
("length" "длина")
("less" "меньше")
("less or equal" "меньше или равно")
("letter" "письмо")
("license" "лицензия")
("light" "бледный")
("light grey" "бледно-серый")
("limitations" "ограничения")
("limits" "пределы")
("line" "строка")
("line break" "разрыв строки")
("line stretch" "растяжение строки")
("link" "линк")
("link image" "линк на изображение")
("list" "список")
("list of figures" "список рисунков")
("list of tables" "список таблиц")
("load" "загрузить")
("load LaTeX file" "загрузить LaTeX файл")
("load TeX file" "загрузить TeX файл")
("load TeXmacs file" "загрузить TeXmacs файл")
("load TeXmacs style file" "загрузить TeXmacs стилевый файл")
("load a file" "загрузить файл")
("load buffer" "загрузить буфер")
("load file" "загрузить файл")
("load html file" "загрузить html файл")
("load image" "загрузить изображение")
("load in new window" "загрузить в новое окно")
("load latex file" "загрузить LaTeX файл")
("load more recent autosave file" "загрузить более свежий autosave файл")
("load tex file" "загрузить TeX файл")
("load verbatim file" "загрузить буквальный файл")
("loaded" "загруженный")
("long" "длинный")
("look and feel" "вид и поведение")
("look up" "найти")
("lower border" "нижний край")
("m modifier" "модификатор m")
("macro" "макро")
("magenta" "фиолетовый")
("magic" "магический")
("magnification" "увеличение")
("magnified" "увеличен")
("main" "главный")
("main icon bar" "главная полоса иконок")
("major changes" "главные изменения")
("make a page insertion" "сделать вставку страницы")
("make a subscript" "сделать нижний индекс")
("make a superscript" "сделать верхний индекс")
("make acute" "сделать acute")
("make bar" "сделать черту")
("make check" "сделать check")
("make fraction" "сделать дробь")
("make grave" "сделать grave")
("make hat" "сделать шляпку")
("make label" "сделать метку")
("make negation" "сделать отрицание")
("make page reference" "сделать ссылку на страницу")
("make reference" "сделать ссылку")
("make square root" "сделать квадратный корень")
("make tilde" "сделать тильду")
("make title" "сделать заглавие")
("make vector" "сделать вектор")
("making donations" "пожертвования")
("manual" "справочник")
("map arguments" "мапировать аргументы")
("map to" "отобразить в")
("march" "март")
("margins" "поля")
("margins as on paper" "поля как на бумаге")
("markup" "разметка")
("master" "главный")
("master file" "главный файл")
("math" "мат")
("math font" "математический шрифт")
("math font family" "семейство математических шрифтов")
("math font series" "серия математических шрифтов")
("math font shape" "форма математического шрифта")
("mathematical" "математический")
("mathematical and customized input" "математический и настроенный ввод")
("mathematical font" "математический шрифт")
("mathematical formulas" "математические формулы")
("mathematical input" "математический ввод")
("mathematical typesetting" "математический набор")
("mathematics" "математика")
("matrix" "матрица")
("maximal" "максимальный")
("maximal number of columns" "максимальное число колонок")
("maximal number of rows" "максимальное число строк")
("maximum mode" "максимальная мода")
("may" "май")
("medium" "средний")
("medium skip" "средний пробел")
("meminfo" "meminfo")
("memory information" "информация о памяти")
("merge" "слить")
("messy" "messy")
("meta key" "клавиша key")
("middle" "средний")
("minimal" "минимальный")
("minimal number of columns" "минимальное число колонок")
("minimal number of rows" "минимальное число строк")
("minimum mode" "минимальная мода")
("minus" "минус")
("miscellaneous" "разнообразные")
("miscellaneous features" "разнообразные черты")
("mod" "mod")
("mode" "мода")
("modifier" "модификатор")
("modify cell alignment" "изменить выравнивание ячейки")
("modify cell border" "изменить границы ячейки")
("modify cell padding" "изменить заполнение ячейки")
("modify cell size" "изменить размер ячейки")
("modify table border" "изменить границы таблицы")
("modify table padding" "изменить заполнение таблицы")
("mongolian" "монгольский")
("more information about GNU TeXmacs can be found in the help" "больше информации о GNU TeXmacs можно найти в помощи")
("mosaic" "мозаика")
("move down" "сдвинуться вниз")
("move object" "передвинуть объект")
("move to the right when finished" "сдвинуться вправо когда сделано")
("move up" "сдвинуться вверх")
("multiline input" "многострочный ввод")
("mutator tags" "таги-мутаторы")
("my documents" "мои документы")
("n-th" "n-ый")
("n-th root" "корень n-ой степени")
("name" "имя")
("negation" "отрицание")
("next" "следующий")
("new" "новый")
("new buffer" "новый буфер")
("new column" "новый столбец")
("new double page" "новая двойная страница")
("new double page before" "новая двойная страница перед")
("new item" "новый элемент")
("new line" "новая строка")
("new number" "новый номер")
("new page" "новая страница")
("new page before" "новая страница перед")
("new paragraph" "новый абзац")
("new roman" "новый roman")
("new row" "новая строка")
("new table" "новая таблица")
("next line" "следующая строка")
("no changes need to be saved" "нет изменений, нуждающихся в сохранении")
("no dictionary for" "нет словаря для")
("no first indentation" "не делать первого отступа")
("no indentation" "без отступа")
("no last indentation" "не делать последнего отступа")
("no line break" "не разрывать строку")
("no matches found" "ничего не найдено")
("no matches found for" "ничего не найдено для")
("no more matches for" "больше ничего не найдено")
("no more redo information available" "больше нет доступной redo информации")
("no more undo information available" "больше нет доступной undo информации")
("no name" "без имени")
("no page break after" "не разрывать страницу после")
("no page break before" "не разрывать страницу перед")
("no spelling errors found in text" "в тексте не найдено ошибок правописания")
("no style" "нет стиля")
("none" "никаких")
("normal" "нормальный")
("norwegian" "норвежский")
("not" "не")
("not equal" "не равно")
("not found" "не найден")
("notation" "обозначение")
("note" "заметка")
("november" "ноябрь")
("number" "число")
("number equation" "нумеровать уравнения")
("number of columns" "число колонок")
("numbered equation" "пронумерованное уравнение")
("numbered equations" "пронумерованные уравнения")
("numerator" "числитель")
("numeric" "численный")
("objectives" "цели")
("occurrences" "occurrences")
("october" "октябрь")
("odd page footer" "footer нечётных страниц")
("odd page header" "header нечётных страниц")
("odd page left margin" "левые поля нечётных страниц")
("odd page margin" "поля нечётных страниц")
("odd page right margin" "правые поля нечётных страниц")
("odd page shift" "сдвиг нечётных страниц")
("odd page text" "текст нечётных страниц")
("off" "выкл")
("ok" "ok")
("old english" "староанглийский")
("old slavonic" "старославянский")
("old style" "старый стиль")
("on" "вкл")
("on cells" "на ячейках")
("on columns" "на колонках")
("on entire table" "на всей таблице")
("on rows" "на строках")
("one spelling error has been corrected" "одна ошибка правописания исправлена")
("online documentation" "онлайн документация")
("online help" "online помощь")
("open" "открыть")
("open a new buffer" "открыть новый буфер")
("open new window" "открыть новое окно")
("opening" "открытие")
("operation on named selection" "операция на именованном выделении")
("operation on primary selection" "операция на главном выделении")
("operation on secondary selection" "операция на вторичном выделении")
("operation on ternary selection" "операция на третичном выделении")
("optical" "оптический")
("option" "опция")
("options" "опции")
("or" "или")
("orange" "оранжевый")
("orientation" "ориентация")
("origin" "происхождение")
("original welcome message" "исходное приветствие")
("other" "другой")
("other pages" "другие страницы")
("other projects" "другие проекты")
("other style" "другой стиль")
("outlined roman" "outlined roman")
("over" "над")
("overbrace" "фигурная скобка сверху")
("overline" "черта сверху")
("padding" "заполнение")
("page" "страница")
("page bottom margin" "нижнее поле страницы")
("page break" "разрыв страницы")
("page break before" "разрыв страницы перед")
("page height" "высота страницы")
("page insertion" "вставка страницы")
("page layout" "размещение на странице")
("page number text" "текст номера страницы")
("page numbering" "нумерация страниц")
("page reference" "ссылка на страницу")
("page right margin" "правое поле страницы")
("page setup" "настройка страницы")
("page top margin" "верхнее поле страницы")
("page type" "тип страницы")
("page width" "ширина страницы")
("paper" "бумага")
("paper type" "тип бумаги")
("papyrus" "папирус")
("paragraph" "абзац")
("paragraph mode" "абзацная мода")
("paragraph width" "ширина абзаца")
("part" "часть")
("past changes" "прошлые изменения")
("paste" "вставить")
("paste from" "вставить из")
("paste text" "вставить текст")
("path" "путь")
("pattern" "образец")
("perform operations on cells" "выполнить операции на ячейках")
("perform operations on columns" "выполнить операции на колонках")
("perform operations on entire table" "выполнить операции на всей таблице")
("perform operations on rows" "выполнить операции на строках")
("permanent" "постоянный")
("person" "персона")
("personal dictionary has been modified" "личный словарь изменился")
("phantasy" "вымышленный")
("philosophy" "философия")
("phoenician" "финикийский")
("phonetic" "фонетический")
("pink" "розовый")
("plain block" "простой блок")
("plain tabular" "простая таблица")
("planned changes" "планируемые изменения")
("plans for the future" "планы на будущее")
("please" "пожалуйста")
("please wait" "пожалуйста подождите")
("plugin" "plugin")
("plugins" "plugins")
("plus" "плюс")
("polish" "польский")
("porting TeXmacs to other platforms" "перенос TeXmacs на другие платформы")
("portrait" "портретная")
("portuguese" "португальский")
("position" "положение")
("position float" "позиционировать плавающий")
("position floating object" "позиционировать плавающий объект")
("position the table" "позиционировать таблицу")
("postscript" "постскрипт")
("postscript image" "постскрипт рисунок")
("pre-alpha release" "пре-альфа версия")
("preamble" "преамбула")
("preamble mode" "мода преамбулы")
("preferences" "предпочтения")
("presentation" "выступление")
("presentation mode" "презентационная мода")
("presentation tag" "таг представления")
("preview before printing" "посмотреть перед печатью")
("preview command" "команда предварительного просмотра")
("preview with ghostview" "посмотреть, используя ghostview")
("previous" "предыдущий")
("primary" "первичный")
("prime" "prime")
("print" "печатать")
("print all" "печатать всё")
("print all to file" "печатать всё в файл")
("print page selection" "печатать выбранные страницы")
("print page selection to file" "печатать выбранные страницы в файл")
("print to postscript file" "печатать в постскрипт-файл")
("printer" "принтер")
("printer dpi" "разрешение принтера (dpi)")
("printing command" "команда печати")
("problem" "задача")
("professional" "профессионально")
("prog" "прог")
("prog font" "программный шрифт")
("prog font family" "семейство программных шрифтов")
("prog font series" "серия программных шрифтов")
("prog font shape" "форма программного шрифта")
("program" "программа")
("program mode" "программная мода")
("programming" "программирование")
("progressive" "прогрессивный")
("project" "проект")
("projects" "проекты")
("prologue" "пролог")
("prompt on scripts" "спрашивать о скриптах")
("prompts and default input" "приглашение и ввод по умолчанию")
("proof" "доказательство")
("proportional" "пропорциональный")
("proportional typewriter" "пропорциональный пишущая машинка")
("proposition" "предложение")
("quasi" "квази")
("quasiquote" "квазикавычка")
("query replace" "заменить с вопросами")
("quit" "выйти")
("quotation" "цитата")
("quote" "цитировать")
("range" "диапазон")
("really close it" "действительно закрыть его")
("really huge" "действительно огромный")
("really quit" "действительно выйти")
("red" "красный")
("redo" "redo")
("redo undone changes" "redo undone changes")
("reduce bottom margin by" "уменьшить нижнее поле на")
("reduce left margin by" "уменьшить левое поле на")
("reduce margins" "уменьшить поля")
("reduce right margin by" "уменьшить правое поле на")
("reduce top margin by" "уменьшить верхнее поле на")
("reduction even page margin" "уменьшение полей чётных страниц")
("reduction odd page margin" "уменьшение полей нечётных страниц")
("reduction page bottom margin" "уменьшение нижнего поля страницы")
("reduction page right margin" "уменьшение правого поля страницы")
("reduction page top margin" "уменьшение верхнего поля страницы")
("reference" "ссылка")
("reference guide" "справочное руководство")
("references" "ссылки")
("regular" "регулярный")
("release" "версия")
("reload" "перезагрузить")
("remark" "замечание")
("remove all output fields" "удалить все поля вывода")
("remove fields" "удалить поля")
("remove input field" "удалить поле ввода")
("remove input field above" "удалить поле ввода выше")
("remove number" "удалить номер")
("remove package" "удалить пакет")
("remove this switch" "удалить этот переключатель")
("renumber this page" "перенумеровать эту страницу")
("repeat" "повторить")
("repeat object" "повторить объект")
("replace" "заменить")
("replace by" "заменить на")
("replaced" "заменено")
("replaced one occurrence" "заменить один раз")
("reset" "переустановить")
("resize object" "изменить размер объекта")
("resized" "изменён размер")
("search results for" "результаты поиска")
("return" "вернуться")
("revert" "обратить")
("revert buffer" "восстановить буфер")
("right" "правый")
("right arrow" "правая стрелка")
("right border" "правый край")
("right margin" "правое поле")
("right padding" "правое заполнение")
("right aligned" "рваный правый край")
("right subscript" "правый нижний индекс")
("right superscript" "правый верхний индекс")
("right surrounding" "правое окружение")
("rigid" "жёсткий")
("rigid horizontal" "жёсткий горизонтальный")
("rigid space" "жёсткий пробел")
("romanian" "румынский")
("root" "корень")
("rotate backward" "вращать назад")
("rotate forward" "вращать вперёд")
("row" "строка")
("row contains glued items" "строка содержит склеенные элементы")
("runic" "рунический")
("running author" "текущий автор")
("running title" "текущее заглавие")
("russian" "русский")
("russian and Ukrainian users" "русские и украинские пользователи")
("sample" "образец")
("sans serif" "без засечек")
("save" "сохранить")
("save TeXmacs file" "сохранить TeXmacs файл")
("save TeXmacs style file" "сохранить TeXmacs стилевый файл")
("save as" "сохранить как")
("save as LaTeX" "сохранить как LaTeX")
("save as TeX" "сохранить как TeX")
("save buffer" "сохранить буфер")
("save buffer as" "сохранить буфер как")
("save file" "сохранить файл")
("save html file" "сохранить html файл")
("save image" "сохранить изображение")
("save latex file" "сохранить latex файл")
("save tex file" "сохранить tex файл")
("save this buffer" "сохранить этот буфер")
("save verbatim file" "сохранить буквальный файл")
("saved" "сохранённый")
("screen" "экран")
("screen layout" "размещение на экране")
("screen margins" "экранные поля")
("script" "индекс")
("script above" "индекс сверху")
("script below" "индекс снизу")
("script script size" "размер индекса в индексе")
("script size" "размер индекса")
("scripts not accepted" "скрипты не допускаются")
("search" "искать")
("search words in my documents" "искать слова в моих документах")
("search words in the documentation" "искать слова в документации")
("search words in the source code" "искать слова в исходниках")
("searching" "поиск")
("secondary" "вторичный")
("section" "параграф")
("security" "безопасность")
("see" "смотри")
("select a document style" "выберите стиль документа")
("select a foreground color" "выберите цвет")
("select a language" "выберите язык")
("selected region" "выделенная область")
("selection" "выделение")
("selections" "выделения")
("seminar" "семинар")
("sending commands to TeXmacs" "посылка команд TeXmacs-у")
("separation between lines" "расстояние между строчками")
("separation between paragraphs" "расстояние между абзацами")
("separator" "разделитель")
("september" "сентябрь")
("serb" "сербский")
("series" "серия")
("series|right" "series|right")
("session" "сессия")
("session name" "имя сессии")
("session type" "тип сессии")
("sessions" "сессии")
("set" "установить")
("set background color of cell" "установить цвет фона ячейки")
("set cell mode" "установить моду ячейки")
("set extension center" "установить центр расширения")
("set height" "установить высоту")
("set height of cell" "установить высоту ячейки")
("set margins" "установить поля")
("set n" "установить n")
("set paragraph margins" "установить поля абзаца")
("set paragraph mode" "установить моду абзаца")
("set printer dpi" "установить разрешение принтера (dpi)")
("set printing command" "установить команду печати")
("set span" "установить проём")
("set special cell properties" "установить специальные свойства ячейки")
("set special table properties" "установить специальные свойства таблицы")
("set text width" "установить ширину текста")
("set width" "установить ширину")
("set width of cell" "установить ширину ячейки")
("settings" "установки")
("setup printer" "настроить принтер")
("shape" "форма")
("shift-down" "shift-вниз")
("shift-right" "shift-вправо")
("short" "краткий")
("show" "показать")
("show header and footer" "показать header и footer")
("show hidden" "показать скрытое")
("show on screen" "показать на экране")
("shrinking factor" "фактор сжатия")
("signature" "подпись")
("size" "размер")
("size tag" "таг размера")
("size limits" "пределы размера")
("slanted" "наклонённый")
("sloppy" "нетщательный")
("slovene" "словенский")
("small" "маленький")
("small caps" "маленькие заглавные")
("small figure" "маленький рисунок")
("small skip" "маленький пробел")
("small table" "маленькая таблица")
("source" "исходники")
("source code" "исходный код")
("space" "пробел")
("space between lines" "расстояние между строками")
("space between paragraphs" "расстояние между абзацами")
("spacing" "пробел")
("spanish" "испанский")
("special" "специальный")
("special cell properties" "специальные свойства ячейки")
("special table properties" "специальные свойства таблицы")
("specific" "специфический")
("spell" "правописание")
("spell checking complete" "проверка правописания закончена")
("spelling error" "ошибка правописания")
("spelling errors have been corrected" "ошибки правописания исправлены")
("split" "расщепить")
("split session" "расщепить сессию")
("square root" "квадратный корень")
("stack" "стопка")
("standard" "стандартный")
("standard environment variables" "стандартные переменные окружения")
("standard TeXmacs styles" "стандартные стили TeXmacs")
("start" "начало")
("start a new chapter" "начать новую главу")
("start a new section" "начать новый параграф")
("start an interactive session" "начать интерактивную сессию")
("status bar" "полоса состояния")
("stretchable" "растяжимый")
("stretchable horizontal" "растяжимый горизонтальный")
("stretchable vertical" "растяжимый вертикальный")
("stretched" "растянутый")
("stroke" "stroke")
("strokes" "strokes")
("strong" "сильный")
("structural" "структурный")
("style" "стиль")
("styles" "стили")
("stylesheet language" "язык стилей")
("sub" "под")
("subparagraph" "подабзац")
("subscript" "нижний индекс")
("subsection" "подпараграф")
("subsub" "подпод")
("subsubsection" "подподпараграф")
("summary" "резюме")
("summary of the principal TeXmacs tags" "резюме главных тагов TeXmacs")
("superpose" "наложить")
("superposed" "наложенный")
("superscript" "верхний индекс")
("swedish" "шведский")
("switch" "переключатель")
("switch to first" "переключиться на первый")
("switch to formula style" "переключиться на формульный стиль")
("switch to last" "переключиться на последний")
("switch to next" "переключиться на следующий")
("switch to previous" "переключиться на предыдущий")
("switching and folding" "переключение и свёртывание")
("symbol" "символ")
("system environment variables" "системные переменные окружения")
("tab" "tab")
("table" "таблица")
("table command" "табличная команда")
("table of contents" "оглавление")
("tables" "таблицы")
("tabular" "табличный")
("tabular material" "табличный материал")
("teXmacs as an interface" "teXmacs как интерфейс")
("teXmacs fonts" "шрифты TeXmacs")
("teXmacs notice" "заметка TeXmacs")
("teXmacs plugins" "teXmacs plugins")
("teXmacs primitives" "примитивы TeXmacs")
("teXmacs style files" "стилевые файлы TeXmacs")
("ternary" "третичный")
("test" "проверка")
("tex" "tex")
("text" "текст")
("text font" "текстовый шрифт")
("text height correction" "поправка к высоте текста")
("text width" "ширина текста")
("texts" "тексты")
("th century bc" "века до нэ")
("th root" "корень степени")
("thai" "тайский")
("the TeXmacs authors" "авторы TeXmacs")
("the TeXmacs format" "формат TeXmacs файлов")
("the application did not send its usual startup banner" "приложение не послало своего обычного приветствия")
("the application does not reply" "приложение не отвечает")
("the application is already running" "приложение уже выполняется")
("the boxes produced by the typesetter" "боксы созданные наборщиком")
("the graphical user interface" "графический интерфейс пользователя")
("the leaves of TeXmacs trees" "листья дерева TeXmacs")
("the mycas example" "пример mycas")
("the primitive TeXmacs constructs" "примитивные конструкции TeXmacs")
("the standard TeXmacs styles" "стандартные стили TeXmacs")
("theorem" "теорема")
("there are unsaved documents" "есть несохранённые файлы")
("this document has not been saved" "этот буфер не был сохранён")
("this document has been produced using" "этот документ был создан")
("this line" "эта строка")
("this page" "эта страница")
("tilda" "тильда")
("tilde" "тильда")
("times" "times")
("timings" "время выполнения")
("tiny" "крошечный")
("title" "заглавие")
("to the left" "влево")
("to the right" "вправо")
("today" "сегодня")
("tools" "инструменты")
("top" "верх")
("top border" "верхний край")
("top level" "верхний уровень")
("top margin" "верхнее поле")
("top padding" "верхнее заполнение")
("translate" "перевести")
("tree" "дерево")
("tuple" "tuple")
("turkish" "турецкий")
("tutorial" "самоучитель")
("type" "тип")
("type a latex command followed by" "введите latex команду, после неё")
("type body" "введите тело")
("type denominator" "введите знаменатель")
("type numerator" "введите числитель")
("type script" "введите индекс")
("typesetted boxes" "набранные боксы")
("typewriter" "пишущая машинка")
("typewriter small caps" "пишущая машинка маленькие заглавные")
("typing a simple text" "печатанье простого текста")
("typing simple texts" "печатанье простых текстов")
("ugaritic" "угаритский")
("ukrainian" "украинский")
("underbrace" "фигурная скобка снизу")
("underline" "подчёркивание")
("undo" "undo")
("undo last changes" "undo последние изменения")
("unevaluated argument" "невычисленный аргумент")
("unevaluated value" "невычисленное значение")
("unquote" "раскавычить")
("up" "вверх")
("update" "обновить")
("update from web" "обновить с web")
("update image links" "обновить линки на изображения")
("upper border" "верхний край")
("upright" "прямой")
("use TeXmacs" "используйте TeXmacs")
("use a black color" "использовать чёрный цвет")
("use a blue color" "использовать синий цвет")
("use a bold font" "использовать жирный шрифт")
("use a brown color" "использовать коричневый цвет")
("use a calligraphic font" "использовать рукописный шрифт")
("use a green color" "использовать зелёный цвет")
("use a grey color" "использовать серый цвет")
("use a magenta color" "использовать фиолетовый цвет")
("use a orange color" "использовать оранжевый цвет")
("use a pink color" "использовать розовый цвет")
("use a red color" "использовать красный цвет")
("use a sans serif font" "использовать шрифт без засечек")
("use a typewriter font" "использовать шрифт пишущая машинка")
("use a white color" "использовать белый цвет")
("use a yellow color" "использовать жёлтый цвет")
("use blackboard bold font" "использовать blackboard bold шрифт")
("use bold font series" "использовать жирную серию шрифтов")
("use calligraphical font" "использовать рукописный шрифт")
("use footnote font size" "использовать размер шрифта для примечаний")
("use fraktur font" "использовать готический шрифт")
("use huge font size" "использовать огромный размер шрифта")
("use italic font shape" "использовать курсивную форму шрифта")
("use large font size" "использовать большой размер шрифта")
("use left hand column as border" "использовать левую колонку как границу")
("use medium font series" "использовать среднюю серию шрифтов")
("use normal font size" "использовать нормальный размер шрифта")
("use package" "использовать пакет")
("use paragraph width" "использовать ширину абзаца")
("use really huge font size" "использовать действительно огромный размер шрифта")
("use right font shape" "использовать прямую форму шрифта")
("use right hand column as border" "использовать правую колонку как границу")
("use roman font family" "использовать roman семейство шрифтов")
("use row above as border" "использовать верхнюю строку как границу")
("use row below as border" "использовать нижнюю строку как границу")
("use sans serif font family" "использовать семейство шрифтов без засечек")
("use script font size" "использовать индексный размер шрифта")
("use slanted font shape" "использовать наклонную форму шрифта")
("use small capitals" "использовать маленькие заглавные")
("use small font size" "использовать маленький размер шрифта")
("use small-caps font shape" "использовать форму шрифта маленькие заглавные")
("use the blackboard bold font" "использовать blackboard bold шрифт")
("use the fraktur font" "использовать готический шрифт")
("use tiny font font size" "использовать крошечный размер шрифта")
("use typewriter font family" "использовать семейство шрифтов пишущая машинка")
("use very large font size" "использовать очень большой размер шрифта")
("user manual" "пуководство пользователя")
("user provided icons" "иконки, предоставленные пользователем")
("users of Cyrillic languages" "пользователи кириллических языков")
("value" "значение")
("variable" "переменная")
("variant" "вариант")
("vector" "вектор")
("verbatim" "буквально")
("verse" "стихотворение")
("vertical" "вертикальный")
("vertical after" "вертикальный после")
("vertical before" "вертикальный перед")
("vertical cell alignment" "вертикальное выравнивание ячейки")
("vertical part" "вертикальная часть")
("vertical position" "вертикальное положение")
("vertical space" "вертикальный пробел")
("vertical table alignment" "вертикальное выравнивание таблицы")
("vertically align cell to the base" "вертикально выровнять ячейку по базовому уровню")
("vertically center the cell" "вертикально центрировать ячейку")
("very large" "очень большой")
("very small" "очень маленький")
("vietnamese" "вьетнамский")
("view" "вид")
("visible" "видимый")
("warning" "предупреждение")
("web" "web")
("welcome" "добро пожаловать")
("welcome to GNU TeXmacs" "добро пожаловать в GNU TeXmacs")
("what is new" "что нового")
("when finished" "когда сделано")
("while" "пока")
("white" "белый")
("wide accent" "широкий accent")
("wide bar" "шарокая черта")
("width" "ширина")
("width is exactly the specified width" "ширина точно как задана")
("width is maximum of specified width and box width" "ширина большая из заданной и ширины бокса")
("width is minimum of specified width and box width" "ширина меньшая из заданной и ширины бокса")
("width magnification" "растяжение ширины")
("window" "окно")
("window height" "высота окна")
("window width" "ширина окна")
("windows key" "клавиша windows")
("with" "с")
("write a name" "писать имя")
("write bold mathematics" "писать жирную математику")
("write bold text" "писать жирный текст")
("write italic text" "писать курсивный текст")
("write sample text" "писать пример текста")
("write strong text" "писать сильный текст")
("write typewriter text" "писать текст на пишущей машинке")
("write verbatim text" "писать буквальный текст")
("writing data converters" "написание преобразователей данных")
("writing your own style files" "написание своих стилевых файлов")
("written with TeXmacs" "написано на TeXmacs")
("yellow" "жёлтый")
("you can also obtain" "вы можете также получить")
("your document is back in its original state" "ваш документ возвращён в исходное состояние")
("your first interface" "ваш первый интерфейс")
("your language" "ваш язык")
