("a modifier" "")
("a series" "")
("abbreviation" "簡寫")
("about" "關於")
("about menu" "關於功能表")
("above" "以上")
("abstract" "摘要")
("accent" "標記")
("accent above" "上方標記")
("accent below" "下方標記")
("accept" "接受")
("accept all scripts" "接受所有指令稿")
("accept no scripts" "不接受指令稿")
("accept script" "接受指令稿")
("acknowledgment" "感謝辭")
("acknowledgments" "感謝辭")
("acronym" "縮寫")
("action" "動作")
("activate" "啟動")
("activate once" "啟動啟動")
("activate hidden" "隱藏内容")
("activation" "啟動")
("acute" "加強")
("add branch after" "於後面新增一個")
("add branch before" "於前面新增一個")
("add package" "增加函式庫")
("add style package" "增加樣本函式庫")
("add switch after" "於後面切換")
("add switch before" "於前面切換")
("add other package" "增加其他函式庫")
("address" "住址")
("address block" "地域")
("adjust" "調整")
("advanced" "進階")
("advanced layout features" "進階布局特徵")
("after" "之後")
("albanian" "")
("algorithm" "演算法")
("align cell to the bottom" "向下對齊")
("align cell to the left" "向左對齊")
("align cell to the right" "向右對齊")
("align cell to the top" "向上對齊")
("align table at base of left column" "表格對齊左邊")
("align table at base of middle column" "表格對齊中間")
("align table at base of origin column" "")
("align table at base of right column" "表格對齊右邊")
("align table at fraction bar height" "")
("align table at the base of bottom row" "")
("align table at the base of middle row" "")
("align table at the base of origin row" "")
("align table at the base of top row" "")
("align table at the bottom" "表格向下對齊")
("align table at the center" "表格對齊中間")
("align table at the horizontal center" "表格對齊水平中間")
("align table at the left" "表格向左對齊")
("align table at the top" "表格向上對齊")
("align table to the right" "表格向右對齊")
("align text to the left" "向左對齊")
("align text to the right" "向右對齊")
("aligned" "對齊")
("alignment" "對齊")
("all" "全部")
("allow" "同意")
("allow for macro definitions in preamble" "允許使用事先定義巨集指令")
("allowed extension" "允許擴充")
("allowed reduction" "允許簡化")
("alpha release" "alpha 版本")
("also on paper" "書面顯示")
("alt key" "alt 鍵")
("alternative specification" "替代規格")
("always" "總是")
("american" "美語")
("animation" "動畫")
("animation toolbar" "動畫工具列")
("answer" "答案")
("and" "和")
("angular" "角度的")
("appendix" "附錄")
("apply" "使用")
("apply macro" "使用巨集指令")
("apply macro once" "使用巨集指令")
("april" "四月")
("arab" "")
("arc" "圓弧")
("arch series" "")
("archaic" "古代的")
("architecture" "架構")
("argument" "參數")
("arithmetic" "算術")
("armenian" "")
("arrow" "箭頭")
("arrows" "箭頭")
("article" "文章")
("as on paper" "如同書面")
("as visual grid" "如同網格")
("assign" "指定")
("at fraction bar height" "")
("at the baseline" "基線")
("at the bottom" "底部")
("at the left" "左邊")
("at the middle" "中間")
("at the right" "右邊")
("at the top" "上方")
("attach" "連結")
("attach buffer to which project" "")
("attach master" "連結主文件")
("august" "八月")
("author" "作者")
("authorize" "授權")
("automatic" "自動")
("automatic content generation" "自動產生的的內容")
("automatically close brackets" "自動補齊結束括號")
("automatically generated content" "自動生成的内容")
("automatic quotes" "自動補齊引號")
("automatic brackets" "自動補齊括號")
("automatic correction" "自動修正")
("automatically save" "自動存檔")
("autosave" "自動存檔")
("axis" "座標軸")
("axiom" "")
("b series" "")
("back" "後退")
("background" "背景")
("background color" "背景色")
("background colour" "背景色")
("background evaluations" "幕後運算")
("backward replace" "取代前者")
("backward search" "往上搜尋")
("bad data format" "錯誤資料格式")
("bar" "上頂線")
("bard" "")
("base" "基線")
("base level" "基本:)")
("bashkirian" "")
("baseline" "基線")
("basic" "基本的")
("basic communication using pipes" "基本並行通訊")
("basic data types" "基本資料型態")
("basic types" "基本型態")
("be useful" "有用")
("beamer" "")
("become a TeXmacs developer" "成為 TeXmacs 的開發者")
("before" "之前")
("begin" "開始")
("below" "以下")
("beta release" "β 版")
("bibliography" "參考文獻")
("bibliography file" "參考文獻檔案")
("bibliography style" "參考文獻的格式")
("bibtex command" "bibtex 指令")
("big" "大")
("big figure" "大圖")
("big operator" "大運算符號")
("big skip" "大的間隔")
("big table" "大表格")
("bitmap resolution" "點矩陣解析度")
("binary operation" "二元運算")
("binary relation" "二元關係")
("black" "黑色")
("blackboard bold" "粗黑體")
("blackboard math" "粗黑數學體")
("blackletter" "黑色字")
("blank column" "空白行")
("blank row" "空白列")
("block content" "區塊内容")
("block of code" "程式碼區塊")
("blue" "藍色")
("body" "")
("bold" "粗黑")
("book" "書籍")
("border" "邊界")
("both" "兩者")
("both versions" "兩個版本")
("bottom" "底部")
("bottom border" "底部邊界")
("bottom cell border" "底部單元邊界")
("bottom cell padding" "內縮底部單元")
("bottom margin" "下底邊線")
("bottom padding" "下底內縮")
("bottom table border" "底部表格邊界")
("bottom table padding" "底部表格內縮")
("branch" "分支")
("break" "中斷")
("breaking" "斷行")
("breve" "短促音")
("british" "英式英語")
("broken white" "")
("brown" "棕色")
("browse" "瀏覽")
("browse back" "回看")
("browse forward" "繼續觀看")
("browse modules documentation" "瀏覽模組內容")
("browse web" "網頁瀏覽")
("browser" "瀏覽程式")
("buffer" "暫存區")
("bulgarian" "保加力亞文")
("bullet" "實心圓點")
("bullets" "實心圓點")
("by" "由")
("by typing" "使用輸入")
("bytes free" "零位元組 ")
("bytes used" "使用位元組總數")
("calculus" "微積分")
("calligraphic" "書法體")
("cancel" "取消")
("cartesian" "直角座標")
("case" "")
("cc" "")
("cell" "單元")
("cell background color" "單元背景顏色")
("cell border" "單元邊框")
("cell height" "單元高度")
("cell operation mode" "單元操作模式")
("cell width" "單元寬度")
("cells" "單元")
("center" "中心")
("center text" "文章中間對齊")
("centered" "中間對齊")
("centered block" "對齊中間區塊")
("centered tabular" "對齊中間表格")
("change border of cell" "改變單元邊框")
("change cell operation mode" "改變單元操作模式")
("change log" "更新記錄")
("change tags" "改變標記")
("change the border of the table" "改變表格邊框")
("change the TeXmacs preferences" "更改 TeXmacs 設定")
("changes" "更新")
("chapter" "章")
("character encoding" "文字編碼")
("check" "檢查")
("check for updates" "更新檢查")
("check for automatic updates" "檢查是否自動更新")
("check text for spelling errors" "拼字檢查")
("chinese" "簡體中文")
("choice" "選擇")
("circle" "圆圈")
("citation" "引用")
("cite" "引述")
("class" "類別")
("clear" "清除")
("clear all fields" "清除全部")
("clear menu" "清除列表")
("clear selection" "放棄選擇")
("clear undo history" "清除撤銷紀錄")
("clipped" "裁切")
("clipped and magnified" "裁切放大")
("clipped and resized" "裁切調整大小大小")
("clone" "複製")
("clone window" "複製視窗")
("close" "結束")
("close TeXmacs" "結束 TeXmacs")
("close buffer" "結束暫存區")
("close document" "關閉")
("close session" "結束工作")
("close this document" "關閉目前工作檔")
("close window" "關閉視窗")
("closed spline" "關閉曲線")
("closing" "關閉中")
("closing style" "取消 樣式")
("code" "程式碼")
("color" "顏色")
("colors" "顏色")
("color of the axes" "座標軸顏色")
("color of the units" "單元顏色")
("color of the subunits" "子單元顏色")
("column" "行")
("column contains glued items" "")
("column to the left" "行(在左侧)")
("column to the right" "行(在右侧)")
("columns" "行")
("common formats" "一般格式")
("compact" "緊緻")
("compactification" "緊緻")
("compactify" "緊緻")
("compare" "相較")
("compatibility with other formats" "和其他格式相容")
("compile article" "文章編譯")
("compile book" "書籍編譯")
("compile buffer" "編譯暫存")
("compile project" "編譯工作")
("completion" "完成")
("complex" "複雜")
("complex actions" "複雜的操作")
("compose" "组合")
("compress" "壓縮")
("concrete" "具體")
("condensed" "壓縮")
("condition" "")
("configuration" "設定")
("consoles" "控制台")
("contact" "條件")
("content" "內容")
("content tag" "內容標籤")
("context dependent icons" "內容相關圖示")
("continuation of" "延續")
("contribute" "參與")
("control flow" "流程控制")
("control the evaluation of expressions" "式子表現的控制")
("convention" "慣例")
("convert" "轉換")
("converters" "轉換工具")
("converters to other data formats" "轉換成其它格式")
("copy" "複製")
("copy text" "複製內文")
("copy to" "複製到")
("copying" "複製中")
("corollary" "系")
("correct text" "更正文章")
("count characters" "統計字元數")
("count lines" "統計行數")
("count words" "統計字數")
("create a new document" "新增檔案")
("create preamble" "新增導言")
("create subsession" "新增子編程")
("creating technical pictures" "新增圖形")
("create web site" "新增網站")
("croatian" "")
("crop" "剪裁")
("current version" "目前版本")
("cursors" "游標")
("curve" "曲線")
("custom tab" "圖示調整")
("customize" "調整")
("customizing and extending the user interface" "調整使用者介面")
("customizing TeXmacs" "調整 TeXmacs ")
("customizing the TeXmacs styles" "調整 TeXmacs 格式")
("cut" "去除")
("cut text" "去除內容")
("cut to" "搬移內容")
("cypriot" "")
("cyrillic" "")
("cyrillic input method" "cyrillic 輸入法")
("cyrillic italic right" "")
("czech" "捷克語")
("dancers" "舞者")
("danish" "丹麥語")
("dark grey" "深灰色")
("dash" "短線")
("dash style" "短線格式")
("dash unit" "短線單位")
("dashes" "短線")
("data conversion" "資料轉換")
("data format" "資料格式")
("database" "資料庫")
("database tool" "資料庫工具")
("database toolbar" "資料庫工具列")
("date" "日期")
("deactivate" "關閉")
("deactivate table" "關閉表格")
("debug" "除錯")
("debugging tool" "除錯工具")
("december" "十二月")
("decimal comma" "小數逗點")
("decimal dot" "小數點")
("decorate atoms" "")
("default" "內定")
("default padding" "內定內縮")
("definition" "定義")
("delete" "刪除")
("delete column" "刪除此行")
("delete documentation cache" "删除暫存文件")
("delete row" "刪除此列")
("denominator" "分母")
("describe" "介绍")
("describe tag" "介绍標籤")
("description" "描述")
("description aligned" "描述列表 (對齊)")
("description compact" "描述列表 (緊緻)")
("description dash" "描述列表 (短線)")
("description long" "描述列表 (長線)")
("destination" "目的")
("det" "行列式")
("detach" "解除")
("detach master" "解除主文件")
("detailed" "細節")
("determinant" "行列式")
("detailed menus" "詳細目錄")
("details in menus" "目錄細節")
("devangari" "")
("developers guide" "開發者導引")
("directory" "目錄")
("disable" "取消")
("disable first indentation" "取消首度內縮")
("disable first indentation after" "取消之後內縮")
("disable first indentation before" "取消之前內縮")
("disable indentation" "取消內縮")
("disable indentation after" "取消此目標之後內縮")
("disable indentation before" "取消此目標之前內縮")
("deactivate" "解除")
("deactivate once" "解除一次")
("developer" "開發者")
("developer tool" "開發工具")
("disallow" "拒絕")
("disk" "圓盤")
("displayed formula" "數學公式顯示")
("display style" "顯示格式")
("distribute unused space" "分配未使用空間")
("div" "")
("do not remap" "")
("document" "文件")
("document format" "文件格式")
("document style" "文件格式")
("document styles" "文件格式")
("documentation" "說明書")
("documents are trees" "樹狀文件")
("dot" "點")
("dots" "點")
("double stroke" "雙重點擊")
("down" "往下")
("download" "下載")
("downwards" "往下")
("dpi" "")
("draw image" "製圖")
("draw over selection" "選擇製圖")
("duplicate" "複製")
("dutch" "荷蘭語")
("dynamic" "動態的")
("dynamic libraries" "動態函式庫")
("edit" "編輯")
("edit table" "編輯表格")
("edit grid" "編輯網格")
("edit macro" "編輯巨集指令")
("edit style" "編輯樣式")
("edit source" "編輯原始碼")
("edit source tree" "編輯樹狀內容")
("edit translations file" "編輯翻譯文件")
("editing tools" "編輯工具")
("education" "教育")
("elsevier" "")
("email" "電子郵件")
("emphasize" "強調")
("emphasize text" "強調性內容")
("empty box" "空白的區域")
("enable change" "允許更改")
("enable first indentation" "啟動前段內縮")
("enable first indentation after" "從之後內縮")
("enable first indentation before" "從之前內縮")
("enable indentation" "內縮")
("enable indentation after" "從之後內縮")
("enable indentation before" "從之前內縮")
("encl" "")
("encoding" "編碼")
("end" "結束")
("english" "英語")
("enter a title" "輸入標題")
("enter data" "輸入資料")
("entire column" "整行")
("entire row" "整列")
("entire table" "表格全部")
("enumerate" "有序列舉")
("enumerate Alpha" "有序列表(大寫字母)")
("enumerate Roman" "有序列表(大寫羅馬數字)")
("enumerate alpha" "有序列表(小寫字母)")
("enumerate roman" "有序列表(小寫羅馬數字)")
("enumerate numeric" "有序列表(阿拉伯數字)")
("enunciation" "說明")
("env" "")
("environment" "環境")
("epilogue" "")
("equal" "等於")
("equation" "方程式")
("equations" "方程式組")
("equivalent for" "")
("error" "錯誤")
("error messages" "錯誤訊息")
("esperanto" "")
("etruscan" "")
("evaluate" "求值")
("evaluate all" "全部求值")
("evaluate above" "求上面各值")
("evaluate below" "求下面各值")
("evaluate fields" "求值區域")
("evaluate scheme expression" "對 scheme 式求值")
("evaluation" "取值")
("even page footer" "偶數頁數註腳")
("even page header" "偶數頁數標題")
("even page margin" "偶數頁數邊框")
("even page left margin" "偶數頁數左邊框")
("even page shift" "偶數頁偏移")
("even page text" "偶數頁內容")
("exact" "固定")
("exact horizontal" "")
("exact mode" "")
("exam" "試卷")
("example" "例")
("exclusive" "例外")
("exclusive or" "例外或是")
("executable" "可執行")
("execute" "執行")
("execute a TeXmacs command" "執行 TeXmacs 指令")
("execute system command" "執行系統指令")
("executive" "")
("exercise" "練習")
("exit left" "從左邊退出")
("exit right" "從右邊退出")
("exit tag on the left" "從左標籤退出")
("exit tag on the right" "從右標籤退出")
("expand" "展開")
("expand inclusions" "擴大包含文件")
("expand unrecognized macros" "展開無法辨識巨集指令")
("expand user-defined macros" "展開自訂的巨集指令")
("experimental" "試驗")
("explained" "說明")
("export" "轉換輸出")
("export as" "轉換成")
("export bibliographies as links" "將参考文獻轉換成連結")
("export formulas as images" "將公式轉換成圖形")
("export selection as image" "將選擇區域轉換成圖形")
("export sessions" "")
("extend or normal" "")
("extents" "範圍")
("extern " "外部")
("extra" "特別")
("extract format" "")
("family" "類別")
("february" "二月")
("field" "欄位置")
("figure" "圖")
("file" "檔案")
("file name" "檔名")
("file not found" "無此檔案")
("files of type" "文件類型")
("fill color" "填充色")
("find next match" "尋找下一筆資料")
("find text" "尋找內容")
("finnish" "芬蘭語")
("first" "最前面")
("first contact" "首次接觸")
("first difference" "首次差異")
("first field" "最前面的區域")
("first indentation" "首次對齊位置")
("first item" "首項")
("first page" "首頁")
("first similar" "相似的(最前面)")
("first start" "首次開始")
("fit to screen" "依螢幕尺寸調整")
("fit to screen width" "調適寬度")
("fixed" "固定")
("flat" "扁平")
("flexibility" "彈性")
("flexibility factor for vertical spacing" "")
("floating algorithm" "浮動演算法")
("floating figure" "浮動圖形")
("floating object" "浮動物件")
("floating table" "浮動表格")
("focus" "焦點")
("focus dependent icons" "焦點圖示")
("fold" "折疊")
("fold all fields" "折叠全部區域")
("fold input field" "折叠輸入區域")
("folded" "可折疊的")
("font" "字型")
("font base size" "字型基本大小")
("font dpi" "")
("font effects" "字型效果")
("font family" "字型種類")
("font name" "字型")
("font series" "字型系列")
("font shape" "字型")
("font size" "字型大小")
("font type" "字型類別")
("font variant" "字型變形")
("fonts" "字型")
("footer" "頁脚")
("footnote" "注釋")
("for" "")
("force reloading of translations" "重新載入翻譯檔")
("foreground" "前景")
("foreground color" "前景色")
("foreground colour" "前景色")
("foreign" "")
("format" "格式")
("formatted and structured output" "格式化和結構化輸出")
("formatted date" "格式化日期")
("formatting" "格式中")
("formula" "公式")
("formula style" "公式樣式")
("forward" "往前")
("forward replace" "向上替換")
("forward search" "向上搜尋")
("fraction" "分式")
("frame" "框架")
("french" "法文")
("from center" "從中心")
("front matter" "前置部分")
("full manuals" "完全手冊")
("full screen mode" "全螢幕模式")
("function" "")
("functional" "")
("further customization" "")
("future changes" "")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs 無任何保證")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs 使用 GNU
general public license 授權.")
("general architecture of TeXmacs" "TeXmacs架構")
("general negation" "")
("general note" "一般注記")
("generating font file" "字型檔案製作中")
("generic" "一般")
("geometry" "幾何")
("georgian" "")
("german" "德文")
("getting started" "開始")
("glossary" "詞彙")
("glossary entry" "詞彙項")
("glue" "緊密")
("glue decorations" "緊密標記")
("go" "移到")
("go to first similar tag" "跳到最近類似的標籤")
("go to last similar tag" "跳到最後類似的標籤")
("go to next similar tag" "跳到下一個類似的標籤")
("go to previous similar tag" "跳到之前類似的標籤")
("go to section" "跳到章節")
("gothic" "")
("grain" "顆粒")
("graphical interface" "圖形界面")
("graphical effects" "圖形效果")
("graphics" "圖形")
("grave" "")
("greater" "大于")
("greater or equal" "大于等于")
("greek" "")
("greek letter" "希臘字母")
("green" "綠色")
("grey" "灰色")
("grid" "網格")
("grids" "網格")
("group" "")
("group/ungroup" "分组/打散")
("gui" "圖形介面")
("h modifier" "")
("happy typing" "娛樂輸入")
("has been aborted" "已取消")
("has completed its task" "")
("hat" "")
("header" "標題")
("header bars" "上端選項")
("header and footer" "標題與註釋")
("hebrew" "")
("height" "高度")
("height is exactly the specified height" "")
("height is maximum of specified height and box height" "")
("height is minimum of specified height and box height" "")
("height magnification" "")
("help" "說明")
("help me" "幫忙")
("help us" "請幫助我們")
("here" "此處")
("hidden" "隱藏")
("highlight errors" "顯著錯誤")
("high resolution settings" "高解析度設定設")
("history" "歷史")
("home" "")
("homepage" "首頁")
("horizontal" "水平")
("horizontal cell alignment" "")
("horizontal ink separation" "")
("horizontal part" "水平部分")
("horizontal position" "")
("horizontal space" "水平空間")
("horizontal alignment" "水平對齊")
("horizontally align cell to the base" "")
("horizontally center the cell" "")
("how much longer may pages become" "")
("how much shorter may pages become" "")
("huge" "巨大")
("hungarian" "匈牙利語")
("hybrid command" "組合指令")
("hyperlink" "連結")
("hyphenation" "語法")
("icelandic" "")
("if" "")
("if hyphenated" "如有連字符")
("image" "圖")
("image links" "圖形連結")
("implementation" "")
("import" "輸入")
("import sessions" "輸入章節")
("improving the current implementation" "改善目前的實作")
("in popup windows" "在彈出窗口")
("inactive" "關閉")
("include" "包含文件")
("include a document" "加入文件")
("include file" "加入檔案")
("inclusion into TeXmacs" "加入 TeXmacs")
("inclusions" "包含部分部分")
("indent" "內縮")
("indentation" "內縮")
("indent" "")
("indentation flag" "內縮標籤")
("index" "索引")
("index entry" "索引項")
("index level" "下標層")
("informative flags" "非正式標籤")
("inline arguments" "行内参数")
("inline code" "行内程式碼")
("inline formula" "行内公式")
("input mode" "輸入模式")
("input options" "輸入選項")
("insert" "輸入")
("insert Pr" "輸入 Pr")
("insert a TeXmacs symbol" "輸入 TeXmacs 符號")
("insert a big operator" "插入大算符")
("insert a binary operation" "插入二元運算")
("insert a binary relation" "插入二元關係")
("insert a blackboard bold character" "插入黑板體字母")
("insert a bold calligraphic character" "插入粗體書法字")
("insert a bold character" "插入粗體字")
("insert a calligraphic character" "插入書法字")
("insert a computer program" "插入計算機程序")
("insert a condition" "插入條件式")
("insert a control flow instruction" "")
("insert a fraction" "插入分式")
("insert a fraktur character" "插入歌德體字母")
("insert a greek character" "插入希臘字母")
("insert a large left delimiter" "插入大左邊開始括號")
("insert a large right delimiter" "插入大右邊結束括號")
("insert a large separator" "插入大分隔符")
("insert a left subscript" "插入左邊下標")
("insert a link" "插入連結")
("insert a list" "插入列表")
("insert a miscellaneous symbol" "插入符號")
("insert a negation" "插入否定符號")
("insert a new branch" "")
("insert a new item" "添加一項")
("insert a note or a floating object" "插入注解或浮動物件")
("insert a numerical operation" "插入數值計算")
("insert a picture" "插入圖片")
("insert a script" "插入上下標")
("insert a square root" "插入平方根")
("insert a table" "插入表格")
("insert a table or a matrix" "插入表格矩陣或矩陣")
("insert a textual operator" "插入文本算符")
("insert a wide symbol above" "")
("insert a wide symbol below" "")
("insert above" "插入行(在上方)")
("insert an" "")
("insert an accent" "插入重音符號")
("insert an arrow" "插入箭頭符號")
("insert an environment" "插入環境")
("insert an n" "")
("insert an n-th root" "插入高次方根")
("insert an operation on tuples" "")
("insert animation" "插入動畫")
("insert appendix" "")
("insert arccos" "")
("insert arcsin" "")
("insert arctan" "")
("insert arg" "")
("insert argument" "")
("insert argument after" "在後面插入參數")
("insert argument before" "在前面插入參數")
("insert author" "插入作者名")
("insert automatically generated content" "插入自動生成的内容")
("insert below" "插入行(在下方)")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "")
("insert big intersection" "")
("insert big logical and" "")
("insert big logical or" "")
("insert big product" "")
("insert big square union" "")
("insert big summation" "")
("insert big tensor product" "")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "")
("insert chapter" "")
("insert column" "")
("insert column to the left" "插入列(在左侧)")
("insert column to the right" "插入列(在右侧)")
("insert cos" "")
("insert cosh" "")
("insert cot" "")
("insert coth" "")
("insert csc" "")
("insert deg" "")
("insert det" "")
("insert dim" "")
("insert dollar" "")
("insert equation" "")
("insert executable markup" "")
("insert exp" "")
("insert field above" "在前面添加區域")
("insert field below" "在後面添加區域")
("insert text field above" "在前面添加文本區域")
("insert text field below" "在後面添加文本區域")
("insert fields" "")
("insert footnote" "")
("insert formula" "")
("insert gcd" "")
("insert hom" "")
("insert horizontal interword space" "")
("insert image" "插入圖片")
("insert inactive markup" "")
("insert inf" "")
("insert input field above" "")
("insert input field below" "")
("insert ker" "")
("insert left" "插入列(在左側)")
("insert lg" "")
("insert lim" "")
("insert liminf" "")
("insert limsup" "")
("insert ln" "")
("insert log" "")
("insert macro" "插入巨集")
("insert mathematics" "插入數學")
("insert max" "插入最大值")
("insert medium horizontal space" "")
("insert medium vertical space" "")
("insert min" "插入最小值")
("insert negative horizontal space" "")
("insert new item or number" "插入新項或序號")
("insert new rows or columns" "插入新行或列")
("insert or delete rows or columns" "插入或删除行或列")
("insert plain text" "插入纯文本")
("insert right" "在右側插入列")
("insert row" "插入列")
("insert row above" "在上方插入列")
("insert row below" "在下方插入列")
("insert sec" "插入節")
("insert section" "輸入節(section) ")
("insert sharp" "")
("insert sin" "插入正弦函數 sin")
("insert sinh" "插入双曲正弦函數 sinh")
("insert small horizontal space" "")
("insert small vertical space" "")
("insert structural markup" "")
("insert subsection" "")
("insert subsubsection" "")
("insert sup" "")
("insert table" "插入表格")
("insert tan" "")
("insert tanh" "")
("insert text field" "")
("insert thick horizontal space" "")
("insert title" "插入標題")
("insert value" "")
("insertion" "嵌入")
("interactive command" "")
("interactive questions" "詢問")
("interfacing" "介面")
("interfacing TeXmacs with other systems" "和其它系统交互")
("interjection" "")
("interline separation" "行間分隔")
("interline space" "行間空隔")
("internationalization" "國際化")
("interparagraph space" "段落時間空隔")
("interrupt execution" "停止執行")
("introduction" "介绍")
("invisible" "不可見")
("invisible citation" "")
("irish" "")
("is running" "執行中")
("is tuple" "")
("ispell does not respond" "")
("ispell is already busy" "")
("italian" "意大利語")
("italic" "斜體")
("italic right" "")
("itemize" "無序列舉")
("itemize arrow" "無序列表(箭頭)")
("itemize dot" "無序列表(圓點)")
("itemize minus" "無序列表(短線)")         
("january" "")
("japanese" "日文")
("july" "")
("june" "")
("justified" "對齊")
("justify text" "內文對齊")
("key" "")
("keyboard" "鍵盤")
("keyboard configuration" "鍵盤配置")
("keyboard equivalent" "等同鍵盤")
("keyboard modifiers" "")
("keyboard shortcut" "鍵盤快捷鍵")
("keymaps" "")
("keyword" "關鍵字")
("keywords" "關鍵語")
("kill" "去除")
("known bugs" "已知臭蟲")
 ("korean" "")        
("label" "標籤")
("landscape" "横向")
("language" "言語")
("laptop presentations" "演講模式")
("large" "大")
("large closing bracket" "大結束括號")
("large delimiter" "")
("large opening bracket" "大開始括號")
("large separator" "大分隔符")
("last" "最後面")
("last check" "最近一次檢查")
("last difference" "最後面差異")
("last field" "最後面區域")
("last page" "")
("last similar" "最後的相似")
("latex command" "")
("latin" "")
("layout" "布局")
("left" "左邊")
("left arrow" "")
("left border" "左端")
("left cell border" "")
("left cell padding" "")
("left margin" "左端空白")
("left padding" "")
("left prime" "")
("left aligned" "左對齊")
("left slanted" "左傾斜")
("left subscript" "左下標")
("left superscript" "左上標")
("left surrounding" "")
("left table border" "")
("left table padding" "")
("leftwards" "往左邊")
("legal" "法律")
("lemma" "引理")
("length" "長度")
("less" "少於")
("less or equal" "不多於")
("letter" "書信")
("license" "授權")
("light" "細長")
("light grey" "淺灰")
("limitations" "限制")
("limits" "極限")
("line" "直線")
("line arrows" "箭頭直線")
("line break" "換行")
("line properties" "直線屬性")
("line stretch" "")
("line width" "直線寬度")
("linear algebra" "線性代數")
("link" "連結")
("link image" "圖形連結")
("linking tool" "連結工具")        
("list" "")
("list of figures" "圖形目錄")
("list of tables" "表格目錄")
("load" "開啟")
("load LaTeX file" "開啟 LaTex 檔案")
("load TeX file" "開啟 TeX 檔案")
("load TeXmacs file" "載入 TeXmacs 文件")
("load TeXmacs style file" "載入 TeXmacs 格式檔案")
("load a file" "開啟檔案")
("load buffer" "")
("load file" "開啟檔案")
("load html file" "開啟 HTML 檔案")
("load image" "載入圖形")
("load in new window" "另開視窗")
("load latex file" "開啟 LaTex 檔案")
("load more recent autosave file" "開啟最近自動保存的檔案")
("load tex file" "開啟 TeX 檔案")
("load verbatim file" "")
("loaded" "已載入")
("logarithmic" "對數座標")
("logarithmic base" "對數基底")
("logarithms" "對數")
("long" "細長")
("look and feel" "看似")
("look up" "")
("lower border" "下端")
("m modifier" "")
("macro" "巨集命令")
("macros" "巨集命令")         
("magenta" "紫红")
("magic" "")
("magnification" "放大比例")
("magnified" "")
("main" "")
("main icon bar" "主選單")
("major changes" "主要改變")
("make a page insertion" "頁面插入")
("make a subscript" "新增下標")
("make a superscript" "新增上標")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "")
("make grave" "")
("make hat" "")
("make label" "")
("make negation" "")
("make page reference" "")
("make reference" "")
("make slides" "製作投影片")
("make square root" "新增根號")
("make tilde" "")
("make title" "製作主題")
("make vector" "新增向量")
("making donations" "捐贈")
("manual" "使用說明")
("map to" "")
("march" "")
("margins" "空白端")
("margins as on paper" "如同在纸上空白端")
("master" "")
("master file" "主要文件")
("math" "數學")
("math font" "數學字型")
("math font family" "數學字型種類")
("math font series" "數學字型群")
("math font shape" "")
("mathematical" "數學的")
("mathematical and customized input" "慣用數學的輸入")
("mathematical font" "數學字型")
("mathematical formulas" "數學公式")
("mathematical input" "數學輸入")
("mathematical output" "數學輸出")
("mathematical typesetting" "數學排版")
("mathematics" "數學")
("matrix" "矩陣")
("maximal" "最大")
("maximal number of columns" "最大行數")
("maximal number of rows" "最大列數")
("maximum mode" "")
("may" "")
("medium" "普通")
("medium skip" "普通距離")
("meminfo" "")
("memory" "記憶體")
("memory usage" "記憶體使用狀況")
("merge" "")
("messy" "")
("meta" "")
("metadata" "元數據")
("meta key" "")
("metafont and available type" "使用 Metafont 字體")
("metafont bitmaps only" "只使用 Metafont 字體")
("middle" "居中")
("minimal" "最小")
("minimal number of columns" "行數最小值")
("minimal number of rows" "列數最小值")
("minimum mode" "")
("minus" "")
("miscellaneous" "雜項")
("miscellaneous features" "其它特性")
("mod" "")
("mode" "模式")
("mode dependent icons" "模式圖示")
("modifier" "")
("modify cell alignment" "改變單元的對齊")
("modify cell border" "改變單元的邊緣")
("modify cell padding" "改變單元的縮排")
("modify cell size" "改變單元的大小")
("modify table border" "改變表格的邊緣")
("modify table padding" "改變表格的縮排")
("mongolian" "")
("more information about GNU TeXmacs can be found in the Help" "進一步有關 GNU 
TeXmacs 的資料可參考 Help 說明")
("mosaic" "")
("move" "移動")
("move down" "往下移動")
("move object" "移動物件")
("move to the right when finished" "結束後移動到最右邊")
("move up" "往上移動")
("multiline input" "多行輸入")
("multiple root" "高次方根")
("mutator tags" "")
("my documents" "個人文件")
("n-th" "")
("n-th root" "")
("name" "名稱")
("negation" "否定")
("never" "從不")         
("new" "新增")
("new buffer" "新增緩衝區")
("new column" "新增一行")
("new document" "新增文件")         
("new double page" "新增雙頁")
("new double page before" "新增雙頁(在前面)")
("new item" "新增一項")
("new line" "新增一行")
("new number" "")
("new page" "新增一頁")
("new page before" "新增一頁(在前面)")
("new paragraph" "新增段落")
("new roman" "")
("new row" "")
("new table" "")
("new version" "新版")
("new window" "新視窗")
("next" "下一個")
("next line" "下一行")
("next similar" "下一個相似的")
("n-th root" "高次方根")
("no" "否")         
("no changes need to be saved" "沒有任何變更需要保存")
("no dictionary for" "不提供字典檔")
("no first indentation" "")
("no grid" "無網格")
("no indentation" "無縮排")
("no line break" "禁止跳行")
("no matches found" "")
("no matches found for" "")
("no more matches for" "")
("no more redo information available" "")
("no more undo information available" "")
("no name" "未命名檔案")
("no page break" "禁止換頁")
("no page break after" "之後禁止換頁")
("no page break before" "之前禁止換頁")
("no spelling errors found in text" "")
("no style" "無樣式")
("none" "無")
("normal" "標準")
("norwegian" "挪威文")
("not" "")
("not equal" "")
("not found" "")
("notation" "記法")
("note" "")
("november" "")
("number" "")
("number of columns" "列的數目")
("number of polar steps" "極座標步數")
("number of subunit steps" "子單位步數")
("number equation" "編號方程式")
("numbered" "編號")
("numbered equation" "編號方程式")
("numbered equations" "編號方程式")
("numbering" "編號")
("numerator" "分子")
("numeric" "數值")
("objectives" "")
("occurrences" "")
("october" "")
("odd page footer" "奇數頁頁脚")
("odd page header" "奇數頁頁首")
("odd page margin" "")
("odd page left margin" "奇數頁左邊距")
("odd page right margin" "奇數頁右邊距")
("odd page shift" "奇數頁偏移")
("odd page text" "")
("off" "關")
("ok" "")
("old english" "")
("old slavonic" "")
("old style" "舊格式")
("old version" "舊版")
("on" "打開")
("on cells" "")
("on columns" "")
("on entire table" "")
("on rows" "")
("on the footer" "在頁脚")
("one column" "一行")
("one spelling error has been corrected" "")
("online documentation" "")
("online help" "線上說明")
("only inline tags" "行内標籤")
("opacity" "不透明度")
("open" "開啟")
("open a document" "開啟檔案")
("open a new buffer" "")
("open new window" "新開視窗")
("open module browser" "開啟模組瀏覽器")
("open my-init-texmacs.scm" "開啟 my-init-texmacs.scm")
("open my-init-buffer.scm" "開啟 my-init-buffer.scm")
("open new window" "開啟新視窗")
("open preferences.scm" "開啟 preferences.scm")
("open symbol browser" "開啟符號瀏覽器")
("opening" "")
("operation mode" "操作模式")
("operation on named selection" "")
("operation on primary selection" "")
("operation on secondary selection" "")
("operation on ternary selection" "")
("optical" "")
("option" "")
("options" "")
("ok" "確認")
("or" "")
("orange" "橙色")
("orientation" "方向")
("origin" "原點")
("original welcome message" "歡迎")
("other" "其它")
("other pages" "其它頁")
("other package" "其它檔案")
("other projects" "")
("other style" "其它格式")
("outlined roman" "")
("output options" "輸出選項")
("over" "")
("overbrace" "")
("overview of the scheme extension language" "Scheme 語言概觀")
("overline" "上畫線")
("padding" "補白")
("page" "頁")
("page bottom margin" "")
("page break" "換頁")
("page break before" "換頁(在前面)")
("page height" "")
("page insertion" "新增頁")
("page layout" "頁面布局")
("page number text" "頁面編碼文字")
("page numbering" "頁數")
("page reference" "頁面参考")
("page right margin" "")
("page setup" "設定頁面")
("page top margin" "頁面上縁")
("page type" "頁面種類")
("page width" "頁面寬長")
("palette" "調色盤")
("paper" "")
("paper type" "頁面類型")
("papyrus" "")
("paragraph" "段落")
("paragraph mode" "")
("paragraph width" "段落寬度")
("parametric curve" "參數曲線")
("parametric surface" "參數曲面")
("part" "部分")
("past changes" "")
("paste" "貼上")
("paste from" "從貼過來")
("paste text" "黏貼文字")
("path" "")
("perform operations on cells" "執行單元格操作")
("perform operations on columns" "整列操作")
("perform operations on entire table" "整表格操作")
("perform operations on rows" "整列操作")
("permanent" "")
("permanent footer" "頁脚")
("permanent header" "頁首")
("person" "人物")
("personal dictionary has been modified" "")
("phantasy" "")
("philosophy" "哲學")
("phoenician" "")
("phonetic" "")
("pink" "粉红")
("plain block" "有框表格(普通)")
("plain tabular" "無框表格(普通)")
("planned changes" "")
("plans for the future" "未來計劃")
("please" "")
("please wait" "請稍後")
("plot" "畫圖")
("plugin" "外掛")
("plugins" "外掛")
("plug-ins" "外掛")
("plus" "")
("point" "點")
("point style" "點格式")
("polar" "極座標")
("polish" "波蘭語")
("polygon" "多邊形")
("porting TeXmacs to other platforms" "移植到其它平台")
("portrait" "縱向")
("portuguese" "葡萄牙語")
("position" "")
("position float" "")
("position floating object" "")
("position the table" "表格位置")
("postscript" "")
("postscript image" "")
("pre" "預")
("pre-alpha release" "")
("preamble" "")
("preamble mode" "")
("preferences" "設定(preferences)")
("presentation" "演講")
("presentation mode" "演講模式")
("presentation tag" "演講標籤")
("presentation tool" "演講工具列")
("preserve tags" "保留標籤")
("pretty tree output" "美化樹狀輸出")
("preview" "預覽")
("preview before printing" "")
("preview command" "預覽指令")
("previous" "前一个")
("previous difference" "上次差異")
("previous field" "前一個區域")
("previous similar" "前一個相似的")
("program interface for buffer management" "緩衝區管理介面")
("programming routines for editing documents" "檔案編輯方法")
("properties" "屬性")
("property" "屬性")
("primary" "")
("prime" "")
("print" "列印")
("print all" "全部列印")
("print all to file" "儲存檔案")
("print buffer" "列印緩衝區")
("print buffer to file" "儲存緩衝區為檔案")           
("print page selection" "選擇列印")
("print page selection to file" "")
("print this document" "列印檔案")           
("print to postscript file" "儲存成 postscript 檔案")
("printer" "印表機")
("printer dpi" "")
("printing command" "")
("problem" "問題")
("professional" "專業")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "程序")
("program font" "程式碼字體")
("program mode" "")
("programming" "")
("progressive" "漸進的")
("project" "專案")
("projects" "專案")
("prologue" "")
("prompt on scripts" "")
("prompts and default input" "提示號和內設輸入")
("proof" "證明")
("proportional" "比例")
("proportional typewriter" "")
("proposition" "命題")
("pseudo code" "準代碼")
("query replace" "替換")
("question" "問題")
("quit" "")
("question" "問題")
("quotation" "引用")
("quote" "")
("range" "")
("really close it" "是否真要關閉")
("really huge" "非常大")
("really quit" "是否退出")
("really tiny" "非常小")
("recent" "最近使用")
("recent documents" "最近檔案")
("recover autosave file" "恢復自動保存檔案")
("red" "")
("redo" "恢復")
("redo undone changes" "恢復更改")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "")
("reduce right margin by" "")
("reduce top margin by" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "参考")
("reference guide" "参考指南")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("reference" "參考")
("reference guide" "參考導引")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "參考")
("regular" "正规")
("release" "")
("reload" "重新載入")
("remark" "注意")
("remote" "遠端")
("remote connections" "遠端連結")
("remote control" "遠端控制")
("remote tool" "遠端工具")
("remove" "删除")
("remove all output fields" "")
("remove argument after" "删除後面參數")
("remove argument before" "删除前面參數")
("remove banner" "删除横幅")
("remove downwards" "删除此行")
("remove field above" "删除上一個區域")
("remove field below" "删除下一個區域")
("remove fields" "")
("remove input field" "")
("remove input field above" "")
("remove last field" "删除最後面區域")
("remove leftwards" "删除前列")
("remove next field" "删除下一個區域")
("remove number" "")
("remove package" "取消程式庫")
("remove previous field" "删除前一個區域")
("remove rightwards" "删除此列")
("remove tag" "删除標籤")
("remove this branch" "删除此段")
("remove this column" "删除此行")
("remove this row" "删除此列")
("remove this switch" "")
("remove upwards" "删除上行")
("renumber this page" "修改頁碼")
("repeat" "重複")
("repeat object" "")
("replace" "取代")
("replace by" "被取代")
("replace toolbar" "替換工具列")
("replace unrecognized styles" "取代未能辨識格式")
("replaced" "")
("replaced one occurrence" "")
("reset" "")
("resize" "改變大小")
("resize object" "")
("resized" "")
("search results for" "")
("search toolbar" "搜索工具列")
("rebuild translations file" "重建翻譯文件")
("retain" "保留")
("return" "")
("revert" "恢復")
("revert buffer" "")
("right" "")
("right arrow" "")
("right border" "右端")
("right cell border" "")
("right cell padding" "")
("right margin" "右邊距")
("right padding" "")
("right aligned" "對齊右邊")
("right subscript" "右下標")
("right superscript" "右上標")
("right surrounding" "")
("right table border" "")
("right table padding" "")
("rightwards" "往右邊")
("rigid" "鋼性的")
("rigid horizontal" "")
("rigid space" "")
("romanian" "羅馬尼亞語")
("root" "根")
("rotate" "旋轉")
("rotate backward" "")
("rotate forward" "")
("rough" "粗糙")
("round" "圆圈")
("row" "列")
("row above" "列(在上方)")
("row below" "列(在下方)")
("row contains glued items" "")
("rows" "列")
("run" "執行")
("runic" "")
("running author" "製作作者名稱")
("running title" "製作標題")
("russian" "俄語")
("sample" "示例")
("sans serif" "")
("save" "存檔")
("save TeXmacs file" "存成 TeXmacs 檔")
("save TeXmacs style file" "存成 TeXmacs 格式檔")
("save as" "另存新檔")
("save as LaTeX" "另存為 LaTeX 檔案")
("save as TeX" "另存為 TeX 檔案")
("save buffer" "儲存暫存檔")
("save buffer as" "另存暫存檔為")
("save file" "儲存檔案")
("save html file" "存為 html 檔案")
("save image" "儲存圖形檔")
("save latex file" "儲存 LaTeX 檔案")
("save tex file" "儲存 TeX 檔案")
("save this buffer" "儲存暫存區資料")
("save verbatim file" "存為  verbatim 檔案")
("saved" "儲存完成")
("scheme command" "")
("scheme developers guide" "Scheme 開發人指南")           
("scheme extensions" "scheme 擴充")
("scheme interface for the graphical mode" "Scheme 圖形界面模式")
("screen layout" "螢幕佈局")
("screen margins" "螢幕邊框")
("screens" "螢幕")
("script" "上下標")
("scripts" "脚本")
("script above" "上標")
("script below" "下標")
("script script size" "上下標大小")
("script size" "上下標大小")
("scripts not accepted" "")
("search" "搜尋")
("search words in my documents" "在本文中搜尋")
("search words in the documentation" "在本文中搜尋")
("search words in the source code" "")
("searching" "搜尋")
("secondary" "")
("section" "節")
("security" "安全")
("see" "參考")
("select a document style" "選擇文章格式")
("select a foreground color" "選擇前景顏色")
("select a language" "語言選擇")
("select display or formula style" "選擇一般或公式格式")
("selected region" "")
("selection" "選擇")
("selections" "選擇")
("seminar" "會議")
("semantics" "語意")
("semantic correctness" "語意校正")
("semantic editing" "語意編輯")
("semantic selections" "語意選擇")
("sending commands to TeXmacs" "傳送 TeXmacs 命令")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "")
("september" "")
("serb" "")
("series" "種類")
("series|right" "")
("session" "行程")
("session commands" "行程命令")
("session name" "")
("session type" "")
("sessions" "行程")
("set" "")
("set background color of cell" "設定單元背景色")
("set cell mode" "")
("set extension center" "")
("set height" "")
("set height of cell" "")
("set margins" "")
("set n" "")
("set number of columns" "設定行數")
("set number of rows" "設定列數")
("set or get environment variables" "")
("set paragraph margins" "設定段落邊距")
("set paragraph mode" "設定段落模式")
("set printer dpi" "")
("set printing command" "")
("set span" "設定分開")
("set special cell properties" "設定單元格屬性")
("set special table properties" "設定表格特殊屬性")
("set text width" "")
("set width" "")
("set width of cell" "")
("settings" "")
("setup printer" "")
("several equations" "多行公式模式")
("shape" "型類")
("shift-down" "")
("shift-right" "")
("short" "簡短的")
("show" "顯示")
("show all parts" "顯示全部")
("show header and footer" "顯示頁主題頁脚")
("show hidden" "顯示隱藏內容")
("show memory usage" "顯示使用記憶體大小")
("show on screen" "")
("show one part" "顯示部分")
("show panorama" "顯示全文")
("show preamble" "顯示序言")
("show several parts" "顯示大部分")
("show subunits" "顯示子單元")
("show timings" "顯示執行時間")
("shrinking factor" "縮小比例")
("signature" "")
("simplification" "簡化")
("simplified menus" "簡化選單")           
("size" "大小")
("size tag" "大小標籤")
("size limits" "大小限制")
("slanted" "傾斜")
("sloppy" "粗略")
("slovene" "")
("small" "小")
("small caps" "小體大寫")
("small figure" "小圖")
("small skip" "小間距")
("small table" "小表格")
("solution" "解答")
("solving equations" "解方程")
("songti" "宋體")
("sound" "聲音")
("source" "源碼")
("source code" "源碼")
("source macros tool" "源碼巨集指令工具列")
("source tags" "源碼標籤")           
("space" "空白")
("space between lines" "行間空白")
("space between paragraphs" "段落間空白")
("spacing" "空白距離")
("spanish" "西班牙語")
("special" "特定")
("special functions" "特殊函數")
("special properties" "特殊属性")
("specific" "指定")
("spell" "拼字")
("spell checking complete" "拼字檢查完成")
("spelling error" "拼字錯誤")
("spelling errors have been corrected" "拼字錯誤更正完成")
("split" "分割")
("split session" "分割進程")
("springer" "")
("square" "方形")
("square root" "平方根")
("stack" "堆叠")
("standard" "標準")
("standard environment variables" "內設環境變數")
("standard formats" "標準格式")
("standard TeXmacs styles" "TeXmacs 標準格式")
("start" "開始")
("start a new chapter" "新增一章")
("start a new section" "新增一節")
("start an interactive session" "啟動互動進程")
("statistics" "統計")
("status" "狀態")
("status bar" "狀態選項")
("stretch" "")
("stretchable" "可延伸")
("stretchable horizontal" "")
("stretchable vertical" "")
("stretched" "延伸")
("stroke" "")
("strokes" "")
("strong" "粗體")
("structural" "結構化的")
("structured insert above" "在上邊插入")
("structured insert below" "在下邊插入")
("structured insert at the left" "在左邊插入")
("structured insert at the right" "在右邊插入")
("structured remove downwards" "往下删除")
("structured remove leftwards" "往左删除")
("structured remove rightwards" "往右删除")
("structured remove upwards" "往上删除")
("style" "格式")
("styles" "格式")
("stylesheet language" "格式化語言")
("sub" "子項")
("subject classification" "主題分類")
("subparagraph" "小段落")
("subscript" "下標")
("subsection" "小節(sub)")
("subsub" "")
("subsubsection" "小小節(subsub)")
("subtable" "子表格")
("subtitle" "次標題")
("summary" "概要")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "上標")
("swedish" "瑞典語")
("swiss" "")
("switch" "")
("switch to first" "跳到前面")
("switch to formula style" "")
("switch to last" "跳到最後面")
("switch to next" "跳到下一個")
("switch to previous" "跳到前一個")
("switching and folding" "切換和折叠")
("symbol" "符號")
("system command" "")
("system environment variables" "")
("tab" "制表符")
("tab-completion" "自動補齊")
("table" "表格")
("table command" "")
("table of contents" "章節目錄")
("tables" "")
("tabular" "")
("tabular material" "")
("taiwanese" "台灣話")
("teXmacs as an interface" "TeXmacs 的交互式介面")
("teXmacs extensions to scheme and utilities" "TeXmacs 提供的 Scheme 和工具")
("teXmacs fonts" "TeXmacs 字體")
("teXmacs notice" "")
("teXmacs plug-ins" "TeXmacs 的外掛")
("teXmacs primitives" "TeXmacs 的原語言")
("teXmacs style files" "TeXmacs 的更是文件")
("textual operator" "文本運算元")
("ternary" "")
("test" "測試")
("tex" "")
("text" "文書")
("text box" "文書")
("text box alignment" "文書框對齊")
("text box horizontal alignment" "文書框水平對齊")
("text box vertical alignment" "文書框垂直對齊")
("text font" "文書字型")
("text height correction" "內文高度修正")
("text width" "")
("texts" "")
("th century bc" "")
("th root" "")
("thai" "")
("the TeXmacs authors" "")
("the TeXmacs plug-in system" "TeXmacs 的外掛系统")
("the TeXmacs format" "TeXmacs 的格式")
("the application did not send its usual startup banner" "")
("the application does not reply" "")
("the application is already running" "")
("the boxes produced by the typesetter" "排版中使用的四周")
("the buffer has not been saved" "暫存區資料尚未儲存")
("the graphical user interface" "使用者圖形界面")
("the leaves of TeXmacs trees" "")
("the mycas example" "")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "TeXmacs 內設格式")
("the TeXmacs authors" "作者")
("the TeXmacs format" "TeXmacs 的格式")
("theorem" "定理")
("there are unsaved files" "檔案尚未儲存")
("this buffer has not been saved" "暫存區資料尚未儲存")
("this column" "此行")          
("this document has been produced using" "此文件由製作")
("this line" "")
("this page" "")
("this page footer" "目前頁面頁腳")
("this page header" "目前頁面頁首")
("this row" "此列")
("thumbnails" "縮圖")
("tilda" "")
("tilde" "")
("times" "")
("tiny" "細小")
("title" "標題")
("to the left" "")
("to the right" "")
("today" "本日")
("tools" "工具列")
("top" "頂部")
("top border" "")
("top cell border" "")
("top cell padding" "")
("top level" "")
("top margin" "上邊距")
("top padding" "")
("top table border" "")
("top table padding" "")
("transform" "變換")
("translate" "平移")
("translations" "翻譯")
("tree" "樹枝狀")
("trigonometry" "三角函數")
("tuple" "組合")
("turkish" "土耳其文")
("tutorial" "示範說明")
("two columns" "兩行")
("type" "类型")
("type 1 only" "使用 Type1 字體")
("type 1 with metafont fallback" "優先使用 Type1 字體")
("type a latex command followed by" "")
("type body" "")
("type denominator" "")
("type numerator" "")
("type script" "")
("typesetted boxes" "")
("typewriter" "")
("typewriter small caps" "")
("typing a simple text" "輸入文字")
("typing simple texts" "輸入文字")
("ugaritic" "")
("ukrainian" "烏克蘭語")
("underbrace" "")
("underline" "")
("undo" "放棄")
("undo last changes" "放棄更改")
("unfold" "取消摺疊")
("unfold all fields" "展開全部區域")
("unit" "單位")
("unit length" "單位程度")           
("up" "")
("update" "更新")
("update from web" "")
("update image links" "")
("update this buffer" "更新資料")
("update web site" "更新網站")
("upgrade" "更新")
("upper border" "上端")
("upright" "正體")
("upwards" "往上邊")
("use TeXmacs" "使用 TeXmacs")
("use a black color" "")
("use a blue color" "")
("use a bold font" "使用粗體字")
("use a brown color" "")
("use a calligraphic font" "使用書法體")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "")
("use calligraphical font" "")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "")
("use italic font shape" "")
("use large font size" "")
("use left hand column as border" "")
("use mathml" "使用 mathml")
("use medium font series" "")
("use normal font size" "")
("use package" "")
("use paragraph width" "")
("use really huge font size" "")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "")
("use row above as border" "")
("use row below as border" "")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "")
("use small font size" "")
("use small-caps font shape" "")
("use TeXmacs" "使用 TeXmacs")
("use the blackboard bold font" "使用黑板字")
("use the fraktur font" "使用歌德字體")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "使用手册")
("user preferences" "使用者設定")
("user provided icons" "使用者提供圖示")
("user interface language" "介面語言")
("users of Cyrillic languages" "俄語系使用者")
("users of oriental languages" "東方語言使用者")
("utilities" "功能列")
("value" "")
("variable" "變數")
("variant" "種類")
("vector" "")
("verbatim" "")
("verse" "韻文")
("version" "版本")
("versioning tool" "版本工具列")          
("vertical" "垂直")
("vertical after" "")
("vertical before" "")
("vertical cell alignment" "")
("vertical part" "垂直部分")
("vertical position" "")
("vertical space" "")
("vertical alignment" "垂直對齊")
("vertically align cell to the base" "")
("vertically center the cell" "")
("very large" "很大")
("very small" "很小")
("vietnamese" "")
("view" "檢視")
("visible" "")
("visual grid" "可見網格")           
("warning" "警告")
("web" "網路")
("welcome" "歡迎")
("welcome to GNU TeXmacs" "歡迎使用 GNU TeXmacs")
("what is new" "最近更新")
("when finished" "")
("while" "")
("white" "白色")
("whitespace" "空格")
("wide accent" "")
("wide bar" "")
("width" "寬")
("width is exactly the specified width" "")
("width is maximum of specified width and box width" "")
("width is minimum of specified width and box width" "")
("width magnification" "")
("window" "")
("window height" "")
("window width" "")
("windows key" "")
("with" "")
("with older version" "和舊版")
("with newer version" "和新版")
("wrap lines" "自動換行")
("write a macro" "編寫巨集指令")
("write a name" "命名")
("write bold mathematics" "")
("write bold text" "輸入粗體字")
("write italic text" "輸入斜體字")
("write sample text" "輸入示範")
("write strong text" "輸入加強字")
("write typewriter text" "")
("write verbatim text" "")
("writing data converters" "輸入資料轉換器")
("writing documentation" "輸入檔案")
("writing TeXmacs bibliography styles" "輸入 TeXmacs 文獻格式")
("writing your own style files" "輸入格式檔案")
("written with TeXmacs" "使用 TeXmacs 製作")
("yellow" "")
("you can also obtain" "")
("your document is back in its original state" "")
("your first interface" "")
("your language" "使用語言")
("zoom" "縮放")
("zoom/unzoom" "放大/縮小")
("zoom in" "放大")
("zoom out" "縮小")
("(re)build autocompletion index" "(重新) 製作完整索引")
