("abbreviation" "абревiатура")
("about menu" "меню про")
("about" "про")
("above" "зверху")
("abstract" "анотацiя")
("accent" "акцент")
("accept all scripts" "дозволити всi скрипти")
("accept no scripts" "не дозволяти нiяких скриптiв")
("accept script" "дозволити скрипт")
("accept" "прийняти")
("acknowledgment" "ознайомлення")
("acronym" "акронiм")
("action" "дiя")
("activate" "активувати")
("acute" "acute")
("address block" "блок адреси")
("address" "адреса")
("add switch after" "додати перемикач пiсля")
("add switch before" "додати перемикач перед")
("advanced layout features" "розширенi можливостi розмiщення")
("advanced" "розширене")
("after" "пiсля")
("algorithm" "алгоритм")
("align cell to the bottom" "вирiвняти комiрку вниз")
("align cell to the left" "вирiвняти комiрку лiворуч")
("align cell to the right" "вирiвняти комiрку праворуч")
("align cell to the top" "вирiвняти комiрку вверх")
("alignment" "вирiвнювання")
("align table at base of left column" "вирiвняти таблицю по базовому рiвню лiвого стовпчика")
("align table at base of middle column" "вирiвняти таблицю по базовому рiвню середнього стовпчика")
("align table at base of origin column" "вирiвняти таблицю по базовому рiвню вихiдного стовпчика")
("align table at base of right column" "вирiвняти таблицю по базовому рiвню правого стовпчика")
("align table at fraction bar height" "вирiвняти таблицю по висотi риски дробу")
("align table at the base of bottom row" "вирiвняти таблицю по базовому рiвню нижнього рядка")
("align table at the base of middle row" "вирiвняти таблицю по базовому рiвню середнього рядка")
("align table at the base of origin row" "вирiвняти таблицю по базовому рiвню вихiдного рядка")
("align table at the base of top row" "вирiвняти таблицю по базовому рiвню верхнього рядка")
("align table at the bottom" "вирiвняти таблицю знизу")
("align table at the center" "вирiвняти таблицю по центру")
("align table at the horizontal center" "вирiвняти таблицю по центру горизонтально")
("align table at the left" "вирiвняти таблицю лiворуч")
("align table at the top" "вирiвняти таблицю зверху")
("align table to the right" "вирiвняти таблицю поруч")
("align text to the left" "вирiвняти текст лiворуч")
("align text to the right" "вирiвняти текст праворуч")
("allowed extension" "дозволенi розширення")
("allowed reduction" "дозволене зменшення")
("allow" "дозволити")
("all" "всi")
("alpha release" "альфа версiя")
("alt key" "клавiша alt")
("A modifier" "модифiкатор A")
("and" "i")
("appendix" "аплiкацiя")
("apply" "застосувати")
("april" "квiтень")
("arab" "арабська")
("archaic" "древнiй")
("architecture" "архiтектура")
("argument" "аргумент")
("arithmetic" "арифметичний")
("armenian" "вiрменська")
("arrows" "стрiлки")
("arrow" "стрiлка")
("article" "стаття")
("as on paper" "як на паперi")
("assign" "призначити")
("at fraction bar height" "на висотi риски дробу")
("attach buffer to which project" "долучити буфер до якого проекту")
("attach" "долучити")
("at the baseline" "на рiвнi основноЁ лiнiЁ")
("at the bottom" "знизу")
("at the left" "лiворуч")
("at the middle" "у центрi")
("at the right" "поруч")
("at the top" "зверху")
("august" "серпень")
("authorize" "авторизувати")
("author" "автор")
("automatically generated content" "автоматично генерований контент")
("automatic" "автоматичний")
("axiom" "аксiома")
("background color" "колiр тла")
("background" "тло")
("backward replace" "замiнити назад")
("backward search" "шукати назад")
("bad data format" "поганий формат даних")
("bard" "bard")
("bar" "смужка")
("base level" "базовий рiвень")
("bashkirian" "башкирский")
("basic data types" "базовi типи даних")
("basic types" "базовi типи")
("basic" "базовий")
("become a TeXmacs developer" "як стати розробником TeXmacs")
("before" "перед")
("begin" "початок")
("below" "знизу")
("beta release" "бета версiя")
("be useful" "будьте корисними")
("bibliography file" "файл лiтератури")
("bibliography style" "стиль лiтератури")
("bibliography" "лiтература")
("big figure" "великий малюнок")
("big operator" "великий оператор")
("big skip" "великий пробiл")
("big table" "велика таблиця")
("big" "великий")
("binary operation" "бiнарна операцiя")
("binary relation" "двiйкове вiдношення")
("blackboard bold" "рукописний жирний")
("blackboard math" "рукописний математичний")
("blackletter" "blackletter")
("black" "чорний")
("blue" "синiй")
("body" "тiло")
("bold" "жирний")
("book" "книга")
("border" "межа")
("both" "обо№")
("bottom border" "нижня межа")
("bottom margin" "нижн№ поле")
("bottom padding" "нижнiй заповнювач")
("bottom" "низ")
("branch" "галузь")
("breaking" "розбиваю")
("break" "розрив")
("breve" "breve")
("british" "британський")
("brown" "коричневий")
("browser" "переглядач")
("browse web" "перегляд Тенет")
("browse" "перегляд")
("buffer" "буфер")
("bullets" "точки")
("bullet" "точка")
("bytes free" "байт вiльно")
("bytes used" "байт використано")
("by typing" "вводячи")
("by" "по")
("calligraphic" "рукописний")
("cancel" "скасувати")
("caps-lock key" "клавiша caps-lock")
("case" "випадок")
("cc" "cc")
("cell background color" "колiр тла комiрки")
("cell border" "межi комiрки")
("cell height" "висота комiрки")
("cell operation mode" "режим операцiЁ над комiркою")
("cell width" "ширина комiрки")
("cell" "комiрка")
("centered block" "центрований блок")
("centered tabular" "центрована таблиця")
("centered" "центрований")
("center text" "центрувати текст")
("center" "центр")
("change border of cell" "змiнити межу комiрки")
("change cell operation mode" "змiнити режим операцiЁ над комiркою")
("change log" "журнал змiн")
("changes" "змiни")
("chapter" "глава")
("check" "перевiрка")
("check text for spelling errors" "перевiрити правопис тексту")
("chinese" "китайський")
("choice" "вибiр")
("citation" "цитування")
("cite" "цитата")
("class" "клас")
("clear selection" "забрати вiдмiтку")
("clear" "очистити")
("clipped and magnified" "обрiзаний i збiльшений")
("clipped and resized" "обрiзаний i змiнений розмiр")
("clipped" "обрiзаний")
("clone window" "здублювати вiкно")
("clone" "здублювати")
("close buffer" "закрити буфер")
("close session" "закрити сесiю")
("close TeXmacs" "закрити TeXmacs")
("close window" "закрити вiкно")
("close" "закрити")
("closing" "закриваю")
("code" "код")
("color" "колiр")
("column contains glued items" "стовпець мiстить скле№нi елементи")
("column" "стовпець")
("compatibility with other formats" "сумiснiсть з iншими форматами")
("compile article" "скомпiлювати статтю")
("compile book" "скомпiлювати книгу")
("compile buffer" "cкомпiлювати буфер")
("compile project" "cкомпiлювати проект")
("complex" "комплексний")
("concrete" "конкретний")
("condensed" "стиснутий")
("condition" "умова")
("configuration" "конфiгурацiя")
("content tag" "тег вмiсту")
("context dependent icons" "iконки, що залежать вiд контексту")
("continuation of" "продовження")
("convention" "угода")
("converters to other data formats" "конвертори у iншi формати даних")
("copying" "копiювання")
("copy text" "копiювати текст")
("copy to" "копiювати у")
("copy" "скопiювати")
("corollary" "наслiдок")
("correct text" "виправити текст")
("cursors" "курсори")
("customizing TeXmacs" "налаштування TeXmacs")
("customizing the TeXmacs styles" "налаштування стилiв TeXmacs")
("custom tab" "змiнна табуляцiя")
("custum tab" "змiнна табуляцiя")
("cut text" "вирiзати текст")
("cut to" "вирiзати до")
("cut" "вирiзати")
("cypriot" "кiпрський")
("cyrillic input method" "метод вводу кирилицi")
("cyrillic italic right" "кириличний курсив вправо")
("cyrillic" "кириличний")
("czech" "чеський")
("dancers" "танцюристи")
("dashes" "риски")
("dash" "риска")
("data conversion" "перетворення даних")
("data format" "формат даних")
("date" "дата")
("deactivate table" "деактивувати таблицю")
("deactivate" "деактивувати")
("december" "грудень")
("decorate atoms" "декорування атомiв")
("default padding" "заповнювач по замовчуванню")
("default" "по замовчуванню")
("definition" "визначення")
("delete column" "видалити колонку")
("delete row" "видалити рядок")
("delete" "видалити")
("denominator" "знаменник")
("description" "опис")
("destination" "призначення")
("detach" "вiд'№днати")
("determinant" "детермiнант")
("devangari" "деванагари")
("developers guide" "керiвництво розробника")
("directory" "каталог")
("disable first indentation after" "заборонити перший вiдступ пiсля")
("disable first indentation before" "заборонити перший вiдступ перед")
("disable first indentation" "заборонити перший вiдступ")
("disable indentation after" "заборонити вiдступ пiсля")
("disable indentation before" "заборонити вiдступ перед")
("disable indentation" "заборонити вiдступ")
("disable last indentation after" "заборонити останнiй вiдступ пiсля")
("disable last indentation before" "заборонити останнiй вiдступ перед")
("disable last indentation" "заборонити останнiй вiдступ")
("disallow" "заборонити")
("distribute unused space" "розподiлити вiльний промiжок")
("div" "подiлити")
("documentation" "документацiя")
("document format" "формат документу")
("documents are trees" "документи № деревами")
("document styles" "стилi документiв")
("document style" "стиль документа")
("document" "документ")
("dots" "крапки")
("dot" "крапка")
("double stroke" "подвiйний")
("down" "вниз")
("dpi" "точок на дюйм")
("duplicate" "дублювати")
("dutch" "голандський")
("dynamic libraries" "динамiчнi бiблiотеки")
("editing tools" "утилiти редагування")
("edit" "редагувати")
("email" "ел. пошта")
("emphasize text" "вiдмiтити текст")
("emphasize" "видiлення")
("empty box" "порожнiй бокс")
("enable first indentation after" "дозволити перший вiдступ пiсля")
("enable first indentation before" "дозволити перший вiдступ перед")
("enable first indentation" "дозволити перший вiдступ")
("enable indentation after" "дозволити вiдступ пiсля")
("enable indentation before" "дозволити вiдступ перед")
("enable indentation" "дозволити вiдступ")
("enable last indentation after" "дозволити останнiй вiдступ пiсля")
("enable last indentation before" "дозволити останнiй вiдступ перед")
("enable last indentation" "дозволити останнiй вiдступ")
("encl" "encl")
("end" "кiнець")
("english" "англiйський")
("enter a title" "введiть заголовок")
("enumerate|alpha" "прономерований|alpha")
("enumerate|Alpha" "прономерований|Alpha")
("enumerate|roman" "прономерований|roman")
("enumerate|Roman" "прономерований|Roman")
("enumerate" "прономерований список")
("env" "env")
("environment" "оточення")
("epilogue" "епiлог")
("equal" "дорiвню№")
("equations" "рiвняння")
("equation" "рiвняння")
("equivalent for" "еквiвалентно")
("error" "помилка")
("etruscan" "етруський")
("evaluate scheme expression" "обчислити scheme вираз")
("evaluate" "обчислити")
("even page footer" "парний пiдвал сторiнки")
("even page header" "парна шапка сторiнки")
("even page margin" "поля парних сторiнок")
("even page text" "парний текст сторiнки")
("exact horizontal" "точний горизонтальний")
("exact mode" "точний режим")
("example" "приклад")
("exam" "exam")
("exclusive or" "або, що виключа№")
("exclusive" "виключний")
("executable" "що викону№ться")
("execute a TeXmacs command" "виконати TeXmacs команду")
("execute system command" "виконати системну команду")
("execute" "виконати")
("executive" "executive")
("exercise" "вправа")
("expand" "розширити")
("explained" "пояснено")
("export as" "експортувати як")
("export" "експортувати")
("extend or normal" "розтягнутий або нормальний")
("extern " "зовнiшнiй")
("extract format" "точний формат")
("extra" "екстра")
("family" "сiмейство")
("february" "лютий")
("figure" "малюнок")
("file name" "iм'я файлу")
("file not found" "файл не знайдено")
("file" "файл")
("find next match" "знайти наступний")
("find text" "знайти текст")
("first contact" "перше знайомство")
("first indentation" "перший вiдступ")
("first item" "перший елемент")
("first page" "перша сторiнка")
("first start" "перший старт")
("flat" "плоский")
("flexibility factor for vertical spacing" "фактор гнучкостi для вертикального простору")
("flexibility" "гнучкiсть")
("floating figure" "плаваюча фiгура")
("floating object" "плаваючий об'№кт")
("floating table" "плаваюча таблиця")
("folded" "скручений")
("fold" "скрутка")
("font base size" "базовий розмiр шрифта")
("font dpi" "роздiльнiсть шрифта")
("font family" "сiмейство шрифтiв")
("font name" "iм'я шрифта")
("font series" "серiя шрифтiв")
("font shape" "фiгура шрифта")
("font size" "розмiр шрифта")
("fonts" "шрифти")
("font variant" "варiант шрифта")
("font" "шрифт")
("footer" "пiдвал")
("footnote" "виноска")
("foreground" "колiр тексту")
("foreign" "iноземний")
("formatted date" "форматована дата")
("format" "формат")
("formula style" "стиль формули")
("formula" "формула")
("forward replace" "замiняти уперед")
("forward search" "шукати уперед")
("for" "для")
("fraction" "дрiб")
("french" "французький")
("full manuals" "повнi керiвництва")
("function" "функцiя")
("further customization" "подальшi налаштування")
("future changes" "майбутнi змiни")
("general architecture of TeXmacs" "загальна архiтектура TeXmac-а")
("general negation" "загальне заперечення")
("generating font file" "генерую файл з шрифтом")
("generic" "типовий")
("georgian" "грузинський")
("german" "нiмецький")
("getting started" "уведення")
("glossary entry" "словниковий пункт")
("glossary" "словник")
("glue decorations" "кле№нi прикраси")
("glue" "клей")
("GNU" "GNU")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs не супроводжу№ться нiякими юридичними гарантiями")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs пiдпада№ пiд загальну публiчну лiцензiю GNU")
("gothic" "готичний")
("go" "перейти")
("graphical interface" "графiчний iнтерфейс")
("grave" "grave")
("greater or equal" "бiльше або дорiвню№")
("greater" "бiльше")
("greek letter" "грецька буква")
("greek" "грецький")
("green" "зелений")
("grey" "сiрий")
("group" "група")
("happy typing" "щасливе друкування")
("has been aborted" "був перерваний")
("has completed its task" "завершив свою роботу")
("hat" "капелюшок")
("header and footer" "шапка i пiдвал")
("header" "шапка")
("hebrew" "№врейський")
("height is exactly the specified height" "висота точно як задана")
("height is maximum of specified height and box height" "висота бiльша вiд заданоЁ i висоти бокса")
("height is minimum of specified height and box height" "висота менша вiд заданоЁ i висоти бокса")
("height magnification" "розтягання висоти")
("height" "висота")
("help me" "допоможiть менi")
("help us" "допоможiть нам")
("help" "допомога")
("here" "тут")
("H modifier" "модифiкатор H")
("home" "домiвка")
("horizontal cell alignment" "горизонтальне вирiвнювання комiрок")
("horizontal ink separation" "horizontal ink separation")
("horizontally align cell to the base" "горизонтально вирiвняти комiрку по базовому рiвню")
("horizontally center the cell" "горизонтально центрувати комiрки")
("horizontal part" "горизонтальна частина")
("horizontal position" "горизонтальне мiсцезнаходження")
("horizontal space" "горизонтальний промiжок")
("horizontal table alignment" "горизонтальне вирiвнювання таблицi")
("horizontal" "горизонтальний")
("how much longer may pages become" "наскiльки довгими можуть бути сторiнки")
("how much shorter may pages become" "наскiльки короткими можуть бути сторiнки")
("huge" "величезний")
("hungarian" "угорський")
("hyperlink" "посилання")
("hyphenation" "перенос")
("icelandic" "iсландський")
("if" "якщо")
("image links" "посилання на зображення")
("image" "зображення")
("implementation" "реалiзацiя")
("import" "iмпортувати")
("improving the current implementation" "покращення поточноЁ реалiзацiЁ")
("inactive" "неактивний")
("include a document" "ввiмкнути документ")
("include file" "ввiмкнути файл")
("include" "ввiмкнути")
("inclusion into TeXmacs" "включення в TeXmacs")
("inclusions" "включення")
("indentation flag" "перемикач вiдступу")
("indent" "вiдступ")
("index entry" "пункт у покажчику")
("index level" "рiвень iндексу")
("index" "покажчик")
("insert a big operator" "вставити великий оператор")
("insert a binary operation" "вставити двiйкову операцiю")
("insert a binary relation" "вставити двiйкове вiдношення")
("insert a blackboard bold character" "вставити рукописний жирний символ")
("insert a bold calligraphic character" "вставити жирний калiграфiчний символ")
("insert a bold character" "вставити жирний символ")
("insert a calligraphic character" "вставити калiграфiчний символ")
("insert a fraction" "вставити дрiб")
("insert a fraktur character" "вставити буквицю")
("insert a greek character" "вставити грецьку букву")
("insert a large left delimiter" "вставити великий лiвий обмежник")
("insert a large right delimiter" "вставити великий правий обмежник")
("insert a large separator" "вставити великий роздiльник")
("insert a left subscript" "вставити лiвий iндекс")
("insert a link" "вставити посилання")
("insert a miscellaneous symbol" "вставити якийсь iнший символ")
("insert an accent" "вставити акцент")
("insert an arrow" "вставити стрiлку")
("insert an environment" "вставити оточення")
("insert a new branch" "вставити нову гiлку")
("insert a new item" "вставити новий елемент")
("insert an n" "вставити n")
("insert an" "вставити")
("insert a picture" "вставити малюнок")
("insert appendix" "вставити апендикс")
("insert arccos" "вставити arccos")
("insert arcsin" "вставити arcsin")
("insert arctan" "вставити arctan")
("insert argument" "вставити аргумент")
("insert arg" "вставити arg")
("insert a square root" "вставити квадратний корiнь")
("insert a table or a matrix" "вставити таблицю або матрицю")
("insert a table" "вставити таблицю")
("insert a TeXmacs symbol" "вставити символ TeXmacs-а")
("insert automatically generated content" "вставити автоматично згенерований вмiст")
("insert big contour integral" "вставити великий контурний iнтеграл")
("insert big coproduct" "вставити великий копродюсер")
("insert big direct sum" "вставити велику пряму суму")
("insert big dotted point" "вставити велике коло з крапкою")
("insert big integral" "вставити великий iнтеграл")
("insert big intersection" "вставити велике перетинання")
("insert big logical and" "вставити велике логiчне i")
("insert big logical or" "вставити велике логiчне або")
("insert big product" "вставити великий добуток")
("insert big square union" "вставити велике квадратне об'№днання")
("insert big summation" "вставити велику суму")
("insert big tensor product" "вставити великий тензорний добуток")
("insert big union sum" "вставити велику суму-об'№днання")
("insert big union" "вставити велике об'№днання")
("insert big vertical space" "вставити великий вертикальний промiжок")
("insert chapter" "вставити главу")
("insert column to the left" "вставити колонку лiворуч")
("insert column to the right" "вставити колонку праворуч")
("insert column" "вставити колонку")
("insert cosh" "вставити cosh")
("insert cos" "вставити cos")
("insert coth" "вставити coth")
("insert cot" "вставити cot")
("insert csc" "вставити csc")
("insert deg" "вставити deg")
("insert det" "вставити det")
("insert dim" "вставити dim")
("insert dollar" "вставити долар")
("insert equation" "вставити рiвняння")
("insert executable markup" "вставити виконавчу розмiтку")
("insert exp" "вставити exp")
("insert footnote" "вставити виноску")
("insert formula" "вставити формулу")
("insert gcd" "вставити gcd")
("insert hom" "вставити hom")
("insert horizontal interword space" "вставити горизонтальний мiжслiвний промiжок")
("insert image" "вставити зображення")
("insert inactive markup" "вставити неактивну розмiтку")
("insert inf" "вставити inf")
("insert ker" "вставити ker")
("insert lg" "вставити lg")
("insert liminf" "вставити liminf")
("insert limsup" "вставити limsup")
("insert lim" "вставити lim")
("insert ln" "вставити ln")
("insert log" "вставити log")
("insert mathematics" "вставити математику")
("insert max" "вставити max")
("insert medium horizontal space" "вставити середнiй горизонтальний промiжок")
("insert medium vertical space" "вставити середнiй вертикальний промiжок")
("insert min" "вставити min")
("insert negative horizontal space" "вставити негативний горизонтальний промiжок")
("insert new item or number" "вставити новий елемент або номер")
("insert new rows or columns" "вставити новi рядки або стовпцi")
("insert or delete rows or columns" "вставити або видалити рядки або стовпцi")
("insert Pr" "вставити Pr")
("insert row above" "вставити рядок над")
("insert row below" "вставити рядок пiд")
("insert row" "вставити рядок")
("insert section" "вставити параграф")
("insert sec" "вставити sec")
("insert sharp" "вставити грати")
("insert sinh" "вставити sinh")
("insert sin" "вставити sin")
("insert small horizontal space" "вставити маленький горизонтальний промiжок")
("insert small vertical space" "вставити маленький вертикальний промiжок")
("insert structural markup" "вставити структурну розмiтку")
("insert subsection" "вставити пiдпараграф")
("insert subsubsection" "вставити пiдпiдпараграф")
("insert sup" "вставити sup")
("insert tanh" "вставити tanh")
("insert tan" "вставити tan")
("insert thick horizontal space" "вставити великий горизонтальний промiжок")
("insert" "вставити")
("interfacing TeXmacs with other systems" "вза№модiя TeXmac-а з вашою системою")
("interfacing" "вза№модiя")
("interjection" "вигук")
("interline separation" "iнтерлiн'яж")
("interline space" "промiжок мiж рядками")
("internationalization" "iнтерналiзацiя")
("interparagraph space" "промiжок мiж параграфами")
("interrupt execution" "вiдмiнити виконання")
("introduction" "уведення")
("invisible citation" "невидиме цитування")
("invisible" "невидимий")
("irish" "iрландський")
("ispell does not respond" "ispell не вiдповiда№")
("ispell is already busy" "ispell вже зайнятий")
("is running" "викону№ться")
("is tuple" "№ tuple")
("italian" "iталiйський")
("italic right" "правий курсив")
("italic" "курсив")
("itemize" "список")
("january" "сiчень")
("japanese" "японський")
("july" "липень")
("june" "червень")
("justified" "вирiвняний")
("justify text" "вирiвняти текст")
("keyboard equivalent" "клавiатурний еквiвалент")
("keyboard modifiers" "модифiкатори клавiатури")
("keyboard shortcut" "клавiатурне скорочення")
("keyboard" "клавiатура")
("keymaps" "мапи клавiш")
("keywords" "ключовi слова")
("keyword" "ключове слово")
("key" "клавiша")
("kill" "убити")
("known bugs" "вiдомi помилки")
("label" "мiтка")
("landscape" "ландшафтна")
("language" "мова")
("large closing bracket" "велика закриваюча дужка")
("large delimiter" "великий обмежник")
("large opening bracket" "велика вiдкриваюча дужка")
("large separator" "великий роздiльник")
("large" "великий")
("last indentation" "останнiй вiдступ")
("last page" "остання сторiнка")
("latex command" "команда latex")
("LaTeX" "LaTeX")
("latin" "латинський")
("layout" "розмiщення")
("left border" "лiвий край")
("left margin" "лiве поле")
("left padding" "лiве заповнення")
("left prime" "left prime")
("left aligned" "рваний лiвий край")
("left slanted" "лiвий похилий")
("left subscript" "лiвий нижнiй iндекс")
("left superscript" "лiвий верхнiй iндекс")
("left surrounding" "лiве оточення")
("left" "лiвий")
("legal" "legal")
("lemma" "лема")
("length" "довжина")
("less or equal" "меньше або дорiвню№")
("less" "меньше")
("letter" "лист")
("license" "лiцензiя")
("light" "блiдий")
("limitations" "обмеження")
("limits" "лiмiти")
("line break" "розрив рядки")
("line stretch" "розтягання рядки")
("line" "рядок")
("link image" "посилання на зображення")
("link" "посилання")
("list of figures" "список малюнкiв")
("list of tables" "список таблиць")
("list" "список")
("load a file" "завантажити файл")
("load buffer" "завантажити буфер")
("loaded" "завантажений")
("load file" "завантажити файл")
("load html file" "завантажити файл з HTML")
("load image" "завантажити зображення")
("load in new window" "завантажити у нове вiкно")
("load latex file" "завантажити LaTeX файл")
("load LaTeX file" "завантажити LaTeX файл")
("load more recent autosave file" "завантажити бiльш свiжий автозбережений файл")
("load tex file" "завантажити файл TeX")
("load TeX file" "завантажити файл TeX")
("load TeXmacs file" "завантажити файл TeXmacs")
("load TeXmacs style file" "завантажити файл стилю TeXmacs")
("load verbatim file" "завантажити буквальний файл")
("load" "завантажити")
("long" "довгий")
("look and feel" "вигляд та поведiнка")
("look up" "знайти")
("lower border" "нижнiй край")
("macro" "макро")
("magenta" "фiолетовий")
("magic" "магiчний")
("magnification" "збiльшення")
("magnified" "збiльшений")
("main icon bar" "головна смужка iконок")
("main" "головний")
("major changes" "головнi змiни")
("make acute" "зробити acute")
("make a page insertion" "зробити вставку сторiнки")
("make a subscript" "зробити нижнiй iндекс")
("make a superscript" "зробити верхнiй iндекс")
("make bar" "зробити смужку")
("make check" "зробити check")
("make fraction" "зробити дрiб")
("make grave" "зробити grave")
("make hat" "зробити капелюшок")
("make label" "зробити мiтку")
("make negation" "зробити заперечення")
("make page reference" "зробити посилання на сторiнку")
("make reference" "зробити посилання")
("make square root" "зробити квадратний корiнь")
("make tilde" "зробити тильду")
("make title" "зробити заголовок")
("make vector" "зробити вектор")
("making donations" "надання допомоги")
("manual" "керiвництво")
("map to" "вiдобразити у")
("march" "березень")
("margins as on paper" "поля як на паперi")
("margins" "поля")
("master file" "головний файл")
("master" "головний")
("mathematical formulas" "математичнi формули")
("mathematical typesetting" "математичний набiр")
("mathematical" "математичний")
("mathematics" "математика")
("math font family" "сiмейство математичних шрифтiв")
("math font series" "серiя математичних шрифтiв")
("math font shape" "форма математичного шрифту")
("math font" "математичний шрифт")
("math" "мат")
("matrix" "матриця")
("maximal number of columns" "максимальне число колонок")
("maximal number of rows" "максимальне число рядкiв")
("maximum mode" "максимальна мода")
("may" "травень")
("medium skip" "середнiй пробiл")
("medium" "середнiй")
("meminfo" "meminfo")
("merge" "злити")
("messy" "messy")
("meta key" "мета-клавiша")
("middle" "середнiй")
("minimal number of columns" "мiнiмальне число колонок")
("minimal number of rows" "мiнiмальне число рядкiв")
("minimum mode" "мiнiмальна мода")
("minus" "мiнус")
("miscellaneous" "рiзноманiтнi")
("M modifier" "модифiкатор M")
("mode" "мода")
("modifier" "модифiкатор")
("modify cell alignment" "змiнити вирiвнювання комiрки")
("modify cell border" "змiнити вигляд меж комiрки")
("modify cell padding" "змiнити заповнення комiрки")
("modify cell size" "змiнити розмiр комiрки")
("modify table border" "змiнити вигляд меж таблицi")
("modify table padding" "змiнити заповнення таблицi")
("mod" "модуль")
("mongolian" "монгольська")
("more information about GNU TeXmacs can be found in the help" "бiльше iнформацiЁ про GNU TeXmacs можна знайти у допомозi")
("mosaic" "мозаЁка")
("move down" "зрушитися вниз")
("move object" "пересунути об'№кт")
("move to the right when finished" "зрушитися вправо коли зроблено")
("move up" "зрушитися вверх")
("name" "iм'я")
("negation" "заперечення")
("new buffer" "новий буфер")
("new column" "новий стовпець")
("new item" "новий елемент")
("new line" "новий рядок")
("new number" "новий номер")
("new page before" "нова сторiнка поперед")
("new page" "нова сторiнка")
("new paragraph" "новий параграф")
("new roman" "новий roman")
("new row" "новий рядок")
("new table" "нова таблиця")
("new" "новий")
("next line" "наступний рядок")
("no changes need to be saved" "нема змiн, що потребують збереження")
("no dictionary for" "нема словника для")
("no first indentation" "не робити першого вiдступу")
("no indentation" "без вiдступу")
("no last indentation" "не робити останнього вiдступу")
("no line break" "не розривати рядок")
("no matches found" "нiчого не знайдено")
("no more matches for" "бiльше нiчого не знайдено")
("no more redo information available" "бiльше нема доступноЁ iнформацiЁ для повернення")
("no more undo information available" "бiльше нема доступноЁ iнформацiЁ для вiдновлення")
("no name" "без назви")
("none" "жодного")
("no page break after" "не розривати сторiнку пiсля")
("no page break before" "не розривати сторiнку перед")
("normal" "нормальний")
("no spelling errors found in text" "у текстi не знайдено помилок правопису")
("no style" "нема стилю")
("notation" "нотацiя")
("not equal" "не дорiвню№")
("note" "замiтка")
("not found" "не знайдений")
("not" "не")
("november" "листопад")
("n-th" "n-ий")
("n-th root" "корiнь n-оЁ ступеня")
("numbered equations" "прономерованi рiвняння")
("numbered equation" "пронумероване рiвняння")
("number of columns" "число колонок")
("number" "число")
("numerator" "чисельник")
("numeric" "чисельний")
("objectives" "цiлi")
("occurrences" "occurrences")
("october" "жовтень")
("odd page footer" "пiдвал непарних сторiнок")
("odd page header" "шапка непарних сторiнок")
("odd page margin" "поля непарних сторiнок")
("odd page text" "текст непарних сторiнок")
("off" "вимк")
("ok" "гаразд")
("old english" "староанглiйский")
("old slavonic" "старославянский")
("old style" "старий стиль")
("on cells" "на комiрках")
("on columns" "на колонках")
("on entire table" "на усiй таблицi")
("one spelling error has been corrected" "одна помилка правопису виправлена")
("online documentation" "документацiя у Тенетах")
("online help" "допомога у Тенетах")
("on rows" "на рядках")
("on" "вмк")
("open a new buffer" "вiдкрити новий буфер")
("opening" "вiдкриваю")
("open new window" "вiдкрити нове вiкно")
("open" "вiдкрити")
("operation on named selection" "операцiя над iменованим видiленям")
("operation on primary selection" "операцiя над головним видiленям")
("operation on secondary selection" "операцiя над вторинним видiленям")
("operation on ternary selection" "операцiя на третинним видiленям")
("optical" "оптичний")
("options" "опцiЁ")
("option" "опцiя")
("orange" "жовтогарячий")
("orientation" "орi№нтацiя")
("original welcome message" "оригiнальне привiтальне повiдомлення")
("origin" "походження")
("or" "або")
("other" "iнший")
("other pages" "iншi сторiнки")
("other projects" "iншi проекти")
("other style" "iнший стиль")
("outlined roman" "outlined roman")
("over" "над")
("padding" "заповнення")
("page bottom margin" "нижн№ поле сторiнки")
("page break before" "розрив сторiнки попереду")
("page break" "розрив сторiнки")
("page height" "висота сторiнки")
("page insertion" "вставка сторiнки")
("page layout" "розмiщення на сторiнцi")
("page reference" "посилання на сторiнку")
("page right margin" "праве поле сторiнки")
("page top margin" "верхн№ поле сторiнки")
("page type" "тип сторiнки")
("page width" "ширина сторiнки")
("page" "сторiнка")
("paper type" "тип папера")
("paper" "папiр")
("papyrus" "папiрус")
("paragraph mode" "режим параграфу")
("paragraph width" "ширина параграфу")
("paragraph" "параграф")
("part" "частина")
("past changes" "минулi змiни")
("paste from" "вставити з")
("paste text" "вставити текст")
("paste" "вставити")
("path" "шлях")
("perform operations on cells" "виконати операцiЁ над комiрками ")
("perform operations on columns" "виконати операцiЁ над колонками")
("perform operations on entire table" "виконати операцiЁ над усi№ю таблицею")
("perform operations on rows" "виконати операцiЁ над рядками")
("permanent" "постiйний")
("personal dictionary has been modified" "особистий словник змiнився")
("person" "персона")
("phantasy" "phantasy")
("philosophy" "фiлософiя")
("phoenician" "фiнiкiйська")
("phonetic" "фонетичний")
("pink" "рожевий")
("plain block" "простий блок")
("plain tabular" "проста таблиця")
("planned changes" "запланованi змiни")
("plans for the future" "плани на майбутн№")
("please wait" "будь ласка зачекайте")
("please" "будь ласка")
("plus" "плюс")
("polish" "польська")
("porting TeXmacs to other platforms" "перенесення TeXmacs на iншi платформи")
("portrait" "портретна")
("portuguese" "португальська")
("position floating object" "позицiонований плаваючий об'№кт")
("position float" "позицiононований плаваючий")
("position the table" "позицiюнувати таблицю")
("position" "мiсцезнаходження")
("postscript image" "постскрипт малюнок")
("postscript" "постскрипт")
("pre-alpha release" "пре-альфа версiя")
("preamble mode" "режим преамбули")
("preamble" "преамбула")
("preferences" "уподобання")
("presentation mode" "режим презентацiЁ")
("preview before printing" "подивитися перед друкуванням")
("preview with ghostview" "подивитися, використовуючи ghostview")
("primary" "первинний")
("prime" "prime")
("print all to file" "друкувати усi у файл")
("print all" "друкувати усi")
("printer dpi" "роздiльна здатнiсть принтера (dpi)")
("printer" "друкарка")
("printing command" "команда друку")
("print page selection to file" "друкувати обранi сторiнки у файл")
("print page selection" "друкувати обранi сторiнки")
("print to postscript file" "друкувати у постскрипт-файл")
("print" "друкувати")
("problem" "проблема")
("professional" "професiйно")
("prog font family" "сiмейство програмних шрифтiв")
("prog font series" "серiя програмних шрифтiв")
("prog font shape" "форма програмного шрифту")
("prog font" "програмний шрифт")
("programming" "програмування")
("program mode" "програмний режим")
("program" "програма")
("progressive" "прогресивний")
("prog" "програмний")
("projects" "проекти")
("project" "проект")
("prologue" "пролог")
("prompt on scripts" "запитувати про скрипти")
("proof" "доказ")
("proportional typewriter" "пропорцiйний друкарська машинка")
("proportional" "пропорцiйний")
("proposition" "пропозицiя")
("query replace" "замiнити з пiдтвердженням")
("quit" "вийти")
("quotation" "цитата")
("quote" "цитувати")
("range" "дiапазон")
("really huge" "дiйсно величезний")
("really quit" "дiйсно вийти")
("redo" "повернути")
("redo undone changes" "повернутi вiдмiненi змiни")
("reduce bottom margin by" "зменшити нижн№ поле на")
("reduce left margin by" "зменшити лiве поле на")
("reduce margins" "зменшити поля")
("reduce right margin by" "зменшити праве поле на")
("reduce top margin by" "зменшити верхн№ поле на")
("reduction even page margin" "зменшення полiв парних сторiнок")
("reduction odd page margin" "зменшення полiв непарних сторiнок")
("reduction page bottom margin" "зменшення нижнього поля сторiнки")
("reduction page right margin" "зменшення правого поля сторiнки")
("reduction page top margin" "зменшення верхнього поля сторiнки")
("red" "червоний")
("references" "посилання")
("reference" "посилання")
("regular" "регулярний")
("release" "версiя")
("reload" "перечитати")
("remark" "зауваження")
("remove this switch" "вилучити цей перемикач")
("repeat object" "повторити об'№кт")
("replace by" "замiнити на")
("replaced one occurrence" "замiнити один раз")
("replaced" "замiнено")
("replace" "замiнити")
("reset" "переустановити")
("resized" "змiнений розмiр")
("resize object" "змiнити розмiр об'№кта")
("return" "повернутися")
("revert buffer" "вiдновити буфер")
("revert" "повернути")
("right border" "правий край")
("right margin" "праве поле")
("right padding" "праве заповнення")
("right aligned" "рваний правий край")
("right subscript" "правий нижнiй iндекс")
("right superscript" "правий верхнiй iндекс")
("right surrounding" "праве оточення")
("right" "правий")
("rigid horizontal" "жорсткий горизонтальний")
("rigid space" "жорсткий промiжок")
("rigid" "жорсткий")
("romanian" "румунський")
("root" "корiнь")
("rotate backward" "повернути взад")
("rotate forward" "повернути вперед")
("row contains glued items" "рядок мiстить скле№нi елементи")
("row" "рядок")
("runic" "рунiчний")
("running author" "бiжучий автор")
("running title" "бiжучий заголовок")
("russian and Ukrainian users" "користувачi з кириличною абеткою")
("russian" "росiйська")
("sample" "зразок")
("sans serif" "без зарубок")
("save as LaTeX" "зберегти як LaTeX")
("save as TeX" "зберегти як TeX")
("save as" "зберегти як")
("save buffer as" "зберегти буфер як")
("save buffer" "зберегти буфер")
("saved" "збережений")
("save file" "зберегти файл")
("save html file" "зберегти html файл")
("save image" "зберегти зображення")
("save latex file" "зберегти latex файл")
("save tex file" "зберегти tex файл")
("save TeXmacs file" "зберегти файл TeXmacs")
("save TeXmacs style file" "зберегти файл стилю TeXmacs ")
("save this buffer" "зберегти цей буфер")
("save verbatim file" "зберегти буквальний файл")
("save" "зберегти")
("screen layout" "розмiщення на екранi")
("screen margins" "екраннi поля")
("script above" "iндекс зверху")
("script below" "iндекс знизу")
("script" "iндекс")
("script script size" "розмiр iндексу у iндексi")
("script size" "розмiр iндексу")
("scripts not accepted" "скрипти не допускаються")
("searching" "пошук")
("search" "шукати")
("secondary" "вторинний")
("section" "параграф")
("security" "безпека")
("see" "дивись")
("select a document style" "виберiть стиль документа")
("select a foreground color" "виберiть колiр")
("select a language" "виберiть мову")
("selected region" "видiлена область")
("selections" "вiдмiтки")
("selection" "вiдмiтка")
("seminar" "семiнар")
("separation between lines" "вiдстань мiж рядками")
("separation between paragraphs" "вiдстань мiж параграфами")
("separator" "роздiльник")
("september" "вересень")
("series|right" "series|right")
("series" "серiя")
("session name" "iм'я сесiЁ")
("sessions" "сесiЁ")
("session type" "тип сесiЁ")
("session" "сесiя")
("set background color of cell" "встановити колiр тла комiрки")
("set cell mode" "встановити режим комiрки")
("set extension center" "встановити центр розширення")
("set height of cell" "встановити висоту комiрки")
("set height" "встановити висоту")
("set margins" "встановити поля")
("set n" "встановити n")
("set paragraph margins" "встановити поля параграфу")
("set paragraph mode" "встановити режим параграфу")
("set printer dpi" "встановити роздiльну здатнiсть друкарки (dpi)")
("set printing command" "встановити команду друку")
("set span" "встановити пропуск")
("set special cell properties" "встановити спецiальнi властивостi комiрки")
("set special table properties" "встановити спецiальнi властивостi таблицi")
("set text width" "встановити ширину тексту")
("settings" "установки")
("setup printer" "налаштувати принтер")
("set width of cell" "встановити ширину комiрки")
("set width" "встановити ширину")
("set" "встановити")
("shape" "форма")
("shift-down" "shift-вниз")
("shift-right" "shift-вправо")
("show header and footer" "показати header i footer")
("show on screen" "показати на екранi")
("show" "показати")
("shrinking factor" "фактор стисненя")
("signature" "пiдпис")
("size limits" "межi розмiру")
("size" "розмiр")
("slanted" "похилий")
("sloppy" "грязний")
("small caps" "маленькi заголовнi")
("small figure" "маленький малюнок")
("small skip" "маленький пробiл")
("small table" "маленька таблиця")
("small" "маленький")
("source code" "джерельний код")
("space between lines" "промiжок мiж рядками")
("space between paragraphs" "промiжок мiж параграфами")
("space" "пробiл")
("spacing" "простiр")
("spanish" "iспанський")
("special cell properties" "спецiальнi властивостi комiрки")
("special table properties" "спецiальнi властивостi таблицi")
("special" "спецiальний")
("specific" "специфiчний")
("spell checking complete" "перевiрка правопису закiнчена")
("spelling errors have been corrected" "помилки правопису виправленi")
("spelling error" "помилка правопису")
("spell" "правопис")
("split" "розщепити")
("square root" "квадратний корiнь")
("start a new chapter" "почати нову главу")
("start a new section" "почати новий параграф")
("start an interactive session" "почати iнтерактивну сесiю")
("start" "початок")
("status bar" "рядок стану")
("stretchable horizontal" "розтяжний горизонтальний")
("stretchable vertical" "розтяжний вертикальний")
("stretchable" "розтяжний")
("strokes" "штрихи")
("stroke" "штрих")
("strong" "строгий")
("structural" "структурований")
("styles" "стилi")
("style" "стиль")
("subparagraph" "пiдпараграф")
("subscript" "нижнiй iндекс")
("subsection" "пiдпараграф")
("subsubsection" "пiдпiдпараграф")
("subsub" "пiдпiд")
("sub" "пiд")
("summary" "коротко")
("superposed" "перекритий")
("superpose" "перекриття")
("superscript" "верхнiй iндекс")
("swedish" "шведський")
("switching and folding" "перемикання i скручування")
("switch to first" "перемикнути на перший")
("switch to formula style" "переключитися на формульний стиль")
("switch to last" "перемикнути на останнiй")
("switch to next" "перемикнути на наступний")
("switch to previous" "перемикнути на попереднiй")
("switch" "перемикач")
("symbol" "символ")
("system environment variables" "системнi змiннi середовища")
("table command" "таблична команда")
("table of contents" "змiст")
("tables" "таблицi")
("table" "таблиця")
("tab" "tab")
("tabular material" "табличний метерiал")
("tabular" "табличний")
("ternary" "третинний")
("test" "перевiрка")
("teXmacs as an interface" "teXmacs як iнтерфейс")
("teXmacs fonts" "шрифти teXmacs")
("teXmacs notice" "примiтки teXmacs")
("tex" "tex")
("TeX" "TeX")
("text font" "текстовий шрифт")
("text height correction" "виправлення висоти тексту")
("texts" "тексти")
("text width" "ширина тексту")
("text" "текст")
("thai" "тайська")
("th century bc" "столiття до н.е.")
("the application did not send its usual startup banner" "аплiкацiя не послала свого звичайного вiтання")
("the application does not reply" "аплiкацiя не вiдповiда№")
("the application is already running" "аплiкацiя вже викону№ться")
("the boxes produced by the typesetter" "областi набранi набiрником")
("the graphical user interface" "графiчний iнтерфейс користувача")
("the leaves of TeXmacs trees" "залишки дерев TeXmacs-а")
("the mycas example" "приклад \"mycas\"")
("theorem" "теорема")
("the primitive TeXmacs constructs" "примiтивнi конструкцiЁ TeXmacs-а")
("there are unsaved documents" "№ незбереженi файли")
("the standard TeXmacs styles" "стандартнi стилi TeXmacs-а")
("the TeXmacs authors" "автори TeXmacs")
("this document has been produced using" "цей документ був створений з використанням")
("this line" "цей рядок")
("this page" "ця сторiнка")
("th root" "корiнь ступеня")
("tilda" "тильда")
("tilde" "тильда")
("times" "помножити")
("tiny" "малюсiнький")
("title" "заголовок")
("today" "сьогоднi")
("tools" "iнструменти")
("top border" "верхнiй край")
("top level" "верхнiй рiвень")
("top margin" "верхн№ поле")
("top padding" "верхн№ заповнення")
("top" "верх")
("to the left" "влiво")
("to the right" "вправо")
("translate" "перевести")
("tree" "дерево")
("tuple" "tuple")
("turkish" "турецька")
("tutorial" "навчальний курс")
("type a latex command followed by" "введiть latex команду, пiсля неЁ")
("type body" "введiть тiло")
("type denominator" "введiть знаменник")
("type numerator" "введiть чисельник")
("type script" "введiть iндекс")
("typesetted boxes" "набранi бокси")
("typewriter small caps" "друкарська машинка маленькi заголовнi")
("typewriter" "друкарська машинка")
("type" "тип")
("typing a simple text" "ввiд простого тексту")
("typing simple texts" "ввiд простих текстiв")
("ugaritic" "угаритська")
("ukrainan" "украЁнська")
("ukrainian" "украЁнська")
("undo last changes" "вiдмiнити останнi змiни")
("undo" "вiдмiнити")
("update from web" "оновлення з Тенет")
("update image links" "оновити посилання на зображення")
("update" "оновити")
("upper border" "верхнiй край")
("up" "вверх")
("use a black color" "використовувати чорний колiр")
("use a blue color" "використовувати синiй колiр")
("use a bold font" "вжити жирний шрифт")
("use a brown color" "використовувати коричневий колiр")
("use a calligraphic font" "використовувати рукописний шрифт")
("use a green color" "використовувати зелений колiр")
("use a grey color" "використовувати сiрий колiр")
("use a magenta color" "використовувати фiолетовий колiр")
("use a orange color" "використовувати жовтогарячий колiр")
("use a pink color" "використовувати рожевий колiр")
("use a red color" "використовувати червоний колiр")
("use a sans serif font" "використовувати шрифт без зарубок")
("use a typewriter font" "використовувати шрифт друкарська машинка")
("use a white color" "використовувати бiлий колiр")
("use a yellow color" "використовувати жовтий колiр")
("use blackboard bold font" "використовувати blackboard bold шрифт")
("use bold font series" "використовувати жирну серiю шрифтiв")
("use calligraphical font" "використовувати рукописний шрифт")
("use footnote font size" "використовувати розмiр шрифту для примiток")
("use fraktur font" "використовувати готичний шрифт")
("use huge font size" "використовувати величезний розмiр шрифту")
("use italic font shape" "використовувати курсивну форму шрифту")
("use large font size" "використовувати великий розмiр шрифту")
("use left hand column as border" "використовувати лiву колонку як межу")
("use medium font series" "використовувати середню серiю шрифтiв")
("use normal font size" "використовувати нормальний розмiр шрифту")
("use package" "використовувати пакет")
("use paragraph width" "використовувати ширину параграфу")
("use really huge font size" "використовувати дiйсно величезний розмiр шрифту")
("use right font shape" "використовувати пряму форму шрифту")
("use right hand column as border" "використовувати праву колонку як межу")
("user manual" "керiвництво користувача")
("use roman font family" "використовувати roman сiмейство шрифтiв")
("use row above as border" "використовувати верхнiй рядок як межу")
("use row below as border" "використовувати нижнiй рядок як межу")
("user provided icons" "iконки, наданi користувачем")
("use sans serif font family" "використовувати сiмейство шрифтiв без зарубок")
("use script font size" "використовувати iндексний розмiр шрифту")
("use slanted font shape" "використовувати похилу форму шрифту")
("use small capitals" "використовувати маленькi заголовнi")
("use small-caps font shape" "використовувати форму шрифту маленькi заголовнi")
("use small font size" "використовувати маленький розмiр шрифту")
("use TeXmacs" "використання TeXmacs")
("use the blackboard bold font" "використовувати blackboard bold шрифт")
("use the fraktur font" "використовувати готичний шрифт")
("use tiny font font size" "використовувати малюсiнький розмiр шрифту")
("use typewriter font family" "використовувати сiмейство шрифтiв друкарська машинка")
("use very large font size" "використовувати дуже великий розмiр шрифту")
("value" "значення")
("variable" "змiнна")
("variant" "варiант")
("vector" "вектор")
("verbatim" "буквально")
("verse" "вiрш")
("vertical after" "вертикальний пiсля")
("vertical before" "вертикальний перед")
("vertical cell alignment" "вертикальне вирiвнювання комiрки")
("vertically align cell to the base" "вертикально вирiвняти комiрку по базовому рiвню")
("vertically center the cell" "вертикально центрувати комiрку")
("vertical part" "вертикальна частина")
("vertical position" "вертикальне мiсцезнаходження")
("vertical space" "вертикальний промiжок")
("vertical table alignment" "вертикальне вирiвнювання таблицi")
("vertical" "вертикальний")
("very large" "дуже великий")
("very small" "дуже маленький")
("vietnamese" "в'№тнамська")
("view" "вигляд")
("visible" "видимий")
("warning" "попередження")
("welcome to GNU TeXmacs" "ласкаво просимо у GNU TeXmacs")
("welcome" "ласкаво просимо")
("what is new" "що нового")
("when finished" "коли зроблено")
("while" "поки")
("white" "бiлий")
("wide accent" "широкий accent")
("width is exactly the specified width" "ширина точно як задана")
("width is maximum of specified width and box width" "ширина бiльша з заданоЁ i ширини бокса")
("width is minimum of specified width and box width" "ширина менша з заданоЁ i ширини бокса")
("width magnification" "розтягання ширини")
("width" "ширина")
("window height" "висота вiкна")
("windows key" "клавiша вiндовс")
("window width" "ширина вiкна")
("window" "вiкно")
("with" "з")
("write a name" "писати iм'я")
("write bold mathematics" "писати жирну математику")
("write bold text" "писати жирний текст")
("write italic text" "писати курсивний текст")
("write sample text" "писати приклад тексту")
("write strong text" "писати сильний текст")
("write typewriter text" "писати текст як на друкарськiй машинцi")
("write verbatim text" "писати буквальний текст")
("writing data converters" "написання конвертерiв даних")
("writing your own style files" "написання ваших власних файлiв зi стилями")
("yellow" "жовтий")
("you can also obtain" "ви можете також отримати")
("your document is back in its original state" "ваш документ повернений у вихiдний стан")
("your first interface" "ваш перший iнтерфейс")
