("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("about" "om")
("above" "över")
("abstract" "abstract")
("accent" "accent")
("activate" "aktivera")
("acute" "acute")
("address" "adress")
("advanced" "avancerad")
("after" "efter")
("all" "allt")
("alpha release" "alpha version")
("appendix" "appendix")
("apply" "tillämpa")
("april" "april")
("arab" "arabiskt")
("archaic" "archaiskt")
("architecture" "arkitektur")
("armenian" "armeniskt")
("arrow" "pil")
("article" "artikel")
("as on paper" "som på pappret")
("assign" "tilldela")
("attach" "bifoga")
("attach buffer to which project" "bifoga buffert till projekt")
("august" "augusti")
("author" "författare")
("automatic" "automatiskt")
("axiom" "axiom")
("background color" "bakgrundsfärg")
("bad data format" "felaktik dataformat")
("bar" "bar")
("bard" "bard")
("base level" "bas nivå")
("bashkirian" "bashkirsiskt")
("basic" "basic")
("basic types" "grundläggande datatyper")
("be useful" "var nyttig")
("before" "före")
("begin" "börja")
("below" "under")
("beta release" "beta version")
("bibliography" "bibliografi")
("bibliography file" "bibliografi fil")
("bibliography style" "bibliografi stil")
("big operator" "stor operator")
("big skip" "stort extraavstånd")
("binary operation" "biná operation")
("binary relation" "binär relation")
("black" "svart")
("blackboard bold" "svarta tavlan fet")
("blackboard math" "svarta tavlan matte")
("blackletter" "blackletter")
("blue" "blått")
("body" "kropp")
("bold" "fet")
("book" "bok")
("bottom" "botten")
("bottom margin" "nedre kant")
("branch" "gren")
("break" "stopp")
("breve" "breve")
("brown" "brunt")
("buffer" "buffert")
("by" "av")
("by typing" "genom att skriva")
("bytes free" "bytes lediga")
("bytes used" "bytes använt")
("calligraphic" "kalligrafiskt")
("center" "centrum")
("centered" "centrerad")
("changes" "ändringar")
("chapter" "kapitel")
("check" "check")
("citation" "citat")
("class" "klass")
("clear" "rensa")
("clipped" "klippt")
("clipped and magnified" "klippt och förstorad")
("clipped and resized" "klippt och förändrad i storlek")
("clone" "klona")
("clone window" "klona fönster")
("close" "avsluta")
("close TeXmacs" "stäng av TeXmacs")
("close buffer" "radera buffertt")
("close window" "stäng fönster")
("color" "färg")
("column" "kolumn")
("column contains glued items" "kolumn innehåller hoplistrade delar")
("compile buffer" "kompilera buffert")
("compile project" "kompilera projekt")
("concrete" "konkret")
("condensed" "tätt")
("copy" "kopiera")
("copying" "copyright")
("corollary" "corollar")
("cursors" "cursors")
("cut" "klipp ut")
("cypriot" "cypriotiskt")
("cyrillic" "kyrilliskt")
("cyrillic italic right" "kyrilliskt kursivt höger")
("dancers" "dansare")
("december" "december")
("default" "förinställning")
("definition" "definition")
("delete" "radera")
("denominator" "nämnare")
("description" "beskrivning")
("detach" "avskilj")
("devangari" "devangari")
("disable indentation" "indrag av")
("disable indentation after" "indrag av efter")
("disable indentation before" "indrag av före")
("document" "dokument")
("document style" "dokumentstil")
("document styles" "documentstil")
("dot" "punkt")
("double stroke" "dubbelstreckat")
("down" "ner")
("dpi" "dpi")
("dutch" "holländska")
("edit" "redigera")
("empty box" "empty box")
("enable indentation" "indrag på")
("enable indentation after" "indrag på efter")
("enable indentation before" "indrag på före")
("end" "sluta")
("english" "engelska")
("enumerate" "uppräkna")
("enumerate|Alpha" "Alpha")
("enumerate|Roman" "Roman")
("enumerate|alpha" "alpha")
("enumerate|roman" "roman")
("env" "env")
("environment" "omgivning")
("epilogue" "epilog")
("equation" "ekvation")
("equations" "ekvationer")
("error" "fel")
("etruscan" "etruskiskt")
("evaluate scheme expression" "evaluate scheme expression")
("even page margin" "jämna sidors kant")
("exact horizontal" "exakt horisontellt")
("example" "exempel")
("execute" "utför")
("execute a TeXmacs command" "utför ett TeXmacs kommando")
("execute system command" "utför systemkommando")
("executive" "executive")
("exercise" "övningsuppgift")
("export" "exportera")
("extend or normal" "utvigat eller normalt")
("family" "familj")
("february" "februari")
("figure" "figur")
("file" "fil")
("file name" "filnamn")
("file not found" "kan inte hitta filen")
("first indentation" "första indrag")
("first item" "fórsta post")
("first page" "första sida")
("flat" "platt")
("font" "teckensnitt")
("font base size" "typsnitt basstorlek")
("font dpi" "typsnitt dpi")
("font family" "typsnittsfamilj")
("font series" "typsnittsserie")
("font shape" "typsnittsutseende")
("font size" "typsnitt storlek")
("foreign" "utändskt")
("formula" "formel")
("formula style" "formelstil")
("fraction" "fraction")
("french" "franska")
("function" "function")
("future changes" "planerade förändringar")
("general negation" "allmän negation")
("georgian" "georgiskt")
("german" "tyska")
("getting started" "komma igång")
("glossary" "glossar")
("glue" "glue")
("gothic" "gotiskt")
("graphical interface" "grafiskt gränssnitt")
("grave" "grave")
("greek" "grekiskt")
("greek letter" "grekisk bokstav")
("green" "grönt")
("grey" "grått")
("group" "grupp")
("hat" "hat")
("hebrew" "hebräiskt")
("height" "höjd")
("height magnification" "höjdfórstoring")
("help" "hjälp")
("help me" "hjälp mig")
("horizontal ink separation" "horisontell bläck separation")
("horizontal position" "horisontell position")
("horizontal space" "horisontelt mellanslag")
("huge" "jättestort")
("hyperlink" "hyperlänk")
("hyphenation" "hyphenation")
("icelandic" "isländskt")
("image" "bild")
("implementation" "implementation")
("import" "importera")
("inactive" "inaktiv")
("indent" "indent")
("indentation flag" "indragsflagga")
("index" "index")
("index level" "index nivå")
("insert" "foga in")
("insert Pr" "foga in Pr")
("insert a TeXmacs symbol" "foga in en TeXmacs symbol")
("insert a left subscript" "foga in vänster subscript")
("insert a new branch" "goga in ny gren")
("insert appendix" "foga in appendix")
("insert arccos" "foga in arccos")
("insert arcsin" "foga in arcsin")
("insert arctan" "foga in arctsn")
("insert arg" "foga in arg")
("insert argument" "foga in argument")
("insert big contour integral" "foga in stort kontur integraltecken")
("insert big coproduct" "foga in stort coprodukttecken")
("insert big direct sum" "foga in stort direkt summatecken")
("insert big dotted point" "foga in stor dotted point")
("insert big integral" "foga in stort integraltecken ")
("insert big intersection" "foga in stort snittecken")
("insert big logical and" "foga in logiskt och")
("insert big logical or" "foga in logiskt eller")
("insert big product" "foga in stort produkttecken")
("insert big square union" "foga in stort kantigt uniontecken")
("insert big summation" "foga in stort summatecken")
("insert big tensor product" "foga in stor tensorprodukt")
("insert big union" "foga in stort uniontecken")
("insert big union sum" "foga in stort union summatecken")
("insert big vertical space" "foga in tjock verticalt mellanslag")
("insert chapter" "foga in kapitel")
("insert cos" "foga in cos")
("insert cosh" "foga in cosh")
("insert cot" "foga in cot")
("insert coth" "foga in coth")
("insert csc" "foga in csc")
("insert deg" "foga in deg")
("insert det" "foga in det")
("insert dim" "foga in dim")
("insert dollar" "foga in dollar")
("insert equation" "foga in ekvation")
("insert exp" "foga in exp")
("insert formula" "foga in formel")
("insert gcd" "foga in gcd")
("insert hom" "foga in hom")
("insert horizontal interword space" "foga in horisontellt interword mellanslag")
("insert inf" "foga in inf")
("insert ker" "foga in ker")
("insert lg" "foga in lg")
("insert lim" "foga in")
("insert liminf" "foga in liminf")
("insert limsup" "foga in limsup")
("insert ln" "foga in ln")
("insert log" "foga in log")
("insert max" "foga in max")
("insert medium horizontal space" "foga in mellanstort horisontellt mellanslag")
("insert medium vertical space" "foga in mellanstort vertikalt mellanslag")
("insert min" "foga in min")
("insert negative horizontal space" "foga in negativt horisontellt mellanslag")
("insert new item or number" "foga in ny post eller nummer")
("insert sec" "foga in sec")
("insert section" "foga in avsnitt")
("insert sharp" "foga in sharp")
("insert sin" "foga in sin")
("insert sinh" "foga in sinh")
("insert small horizontal space" "foga in letet horisontellt mellanslag")
("insert small vertical space" "foga in litet vertikalt mellanslag")
("insert subsection" "foga in underavsnitt")
("insert subsubsection" "foga in underunderavsnitt")
("insert sup" "foga in sup")
("insert tan" "foga in tan")
("insert tanh" "foga in tanh")
("insert thick horizontal space" "foga in tjockt horisontellt mellanslag")
("interline space" "radavstånd")
("interparagraph space" "avstånd mellan avsnitt")
("introduction" "introduction")
("invisible citation" "osynlig citat")
("irish" "irlándskt")
("italic" "kursivt")
("italic right" "kursivt höger")
("itemize" "specificera")
("january" "januari")
("july" "juli")
("june" "juni")
("justified" "utjämnad")
("keyboard" "tangentbord")
("keymaps" "tangenter")
("kill" "döda")
("known bugs" "bekanta fel")
("label" "etikett")
("landscape" "landskap")
("language" "språk")
("large" "stort")
("large closing bracket" "large closing bracket")
("large delimiter" "large delimiter")
("large opening bracket" "large opening bracket")
("large separator" "large seperator")
("last indentation" "sista indrag")
("last page" "sista sida")
("latex command" "latex kommando")
("latin" "latin")
("layout" "uppsättning")
("left" "vänster")
("left border" "vänstra begränsning")
("left margin" "vänster kant")
("left aligned" "vänsterjusterad")
("left slanted" "lutat åt vänster")
("left subscript" "subscript vänster")
("left superscript" "superscript vänster")
("legal" "legal")
("lemma" "lemma")
("letter" "letter")
("license" "licens")
("light" "smalt")
("limitations" "begränsningar")
("line" "linje")
("line break" "stoppa rad")
("line stretch" "radtöjning")
("link" "länk")
("list" "lista")
("list of figures" "figurlista")
("list of tables" "tabelllista")
("load" "öppna")
("load LaTeX file" "öppna LaTeX fil")
("load TeX file" "öppna TeX fil")
("load TeXmacs file" "ladda TeXmacs fil")
("load TeXmacs style file" "ladda TeXmacs stylefil")
("load html file" "ladda html fil")
("load in new window" "öppna i nytt fönster")
("load latex file" "ladda latex fil")
("load more recent autosave file" "ladda nyare autosave fil")
("load tex file" "ladda tex fil")
("load verbatim file" "ladda verbatim fil")
("loaded" "laddat")
("long" "lång")
("lower border" "nedra begränsning")
("magenta" "magenta")
("magic" "magiskt")
("magnification" "förstoring")
("magnified" "förstorad")
("make acute" "skapa acute")
("make bar" "skapa bar")
("make check" "skapa check")
("make fraction" "skapa fraction")
("make grave" "skapa grave")
("make hat" "skapa hat")
("make label" "skapa etikett")
("make negation" "skapa negation")
("make reference" "skapa referens")
("make square root" "skapa kvadratrot")
("make tilde" "skapa tilde")
("make title" "skapa titel")
("make vector" "skapa vector")
("march" "mars")
("margins" "kanter")
("math" "matte")
("math font" "math typsnitt")
("math font family" "math typsnittsfamilj")
("math font series" "math typsnittsserie")
("math font shape" "math typsnittsutseende")
("mathematical" "matematiskt")
("mathematics" "matematik")
("matrix" "matris")
("may" "maj")
("medium" "mellan")
("medium skip" "mellan extraavstånd")
("meminfo" "meminfo")
("messy" "rörigt")
("middle" "middle")
("minus" "minus")
("miscellaneous" "blandat")
("mode" "modus")
("mongolian" "mongoliskt")
("mosaic" "mosaic")
("move down" "flytta ner")
("move object" "flytta objekt")
("move to the right when finished" "flytta åt höger när klart")
("move up" "flytta upp")
("n-th" "n-th")
("n-th root" "n-rot")
("name" "namn")
("negation" "negation")
("new" "ny")
("new column" "ny kolumn")
("new item" "ny post")
("new line" "ny rad")
("new number" "nytt nummer")
("new page" "ny sida")
("new paragraph" "nytt stycke")
("new roman" "new roman")
("new row" "ny rad")
("new table" "ny tabell")
("next line" "nästa rad")
("no" "nej")
("no changes need to be saved" "inge förändringar behöver sparas")
("no first indentation" "inget första indrag")
("no last indentation" "inget sista indrag")
("no line break" "inget radstopp")
("no name" "inget namn")
("no page break after" "ingen sidostopp efter")
("no page break before" "ingen sidostopp före")
("none" "ingen")
("normal" "normalt")
("not found" "inte hittat")
("note" "notis")
("november" "november")
("numbered equation" "numererad ekvation")
("numbered equations" "numererade ekvationer")
("numerator" "täljare")
("numeric" "numersikt")
("objectives" "mål")
("october" "oktober")
("odd page margin" "udda sidors kant")
("off" "av")
("old english" "gammaldags engelskt")
("old slavonic" "gammaldags slaviskt")
("on" "på")
("open new window" "öppna nytt fönster")
("optical" "optiskt")
("option" "option")
("options" "optioner")
("orange" "orange")
("orientation" "orientering")
("other" "annat")
("other projects" "andra projekt")
("outlined roman" "outlined roman")
("page" "sida")
("page bottom margin" "sidans nedre kant")
("page break" "stoppa sida")
("page height" "sidhöjd")
("page layout" "siduppsättning")
("page right margin" "sidans högra kan")
("page top margin" "sidans övre kant")
("page type" "sidtyp")
("page width" "sidbredd")
("paper" "papper")
("paper type" "pappersstorlek")
("papyrus" "papyrus")
("paragraph" "paragraf")
("paragraph mode" "paragraf modus")
("paragraph width" "paragrafbredd")
("part" "del")
("past changes" "förändringar sedan förra versionen")
("paste" "klistra in")
("path" "sökväg")
("phantasy" "fantasi")
("phoenician" "phöniciskt")
("phonetic" "fonetiskt")
("pink" "rosa")
("please" "snälla")
("portrait" "porträtt")
("position" "position")
("postscript" "postscript")
("postscript image" "postscript bild")
("pre-alpha release" "pre-alpha version")
("preamble" "präambel")
("preview before printing" "visa före utskrift")
("preview with ghostview" "visa mha ghostscript")
("print" "skriv ut")
("print all" "skriv ut allt")
("print all to file" "print all to file")
("print page selection" "skriv ut urval")
("print page selection to file" "print page selection to file")
("print to postscript file" "spara som postscript fil")
("printer dpi" "skrivarens upplösning")
("printing command" "utskriftskommando")
("professional" "professionellt")
("prog" "prog")
("prog font" "prog typsnitt")
("prog font family" "prog typsnittsfamilj")
("prog font series" "prog typsnittsserie")
("prog font shape" "prog typsnittsutseende")
("program" "programm")
("program mode" "programmod")
("project" "projekt")
("projects" "projekt")
("prologue" "prolog")
("proof" "bevis")
("proportional typewriter" "proportionell skrivmaskin")
("proposition" "proposition")
("quit" "avsluta")
("quotation" "quotation")
("quote" "citat")
("really huge" "gigantiskt")
("really quit" "verkligen avsluta")
("red" "rött")
("reduce bottom margin by" "förminska nedra kant med")
("reduce left margin by" "förminska vänstra kant med")
("reduce margins" "förminska kanter")
("reduce right margin by" "förminska högra kant med")
("reduce top margin by" "förminska övra kant med")
("reduction even page margin" "minska jämna sidors kant")
("reduction odd page margin" "minska udda sidor kant")
("reduction page bottom margin" "minska sidans nedre kant")
("reduction page right margin" "minska sidans högra kant")
("reduction page top margin" "minska sidans övre kant")
("reference" "referens")
("references" "referenser")
("release" "version")
("remark" "kommentar")
("reset" "reset")
("resize object" "ändra objektets storlek")
("resized" "förändrad storlek")
("return" "return")
("revert buffer" "revert buffer")
("right" "höger")
("right border" "högra begränsning")
("right margin" "höger kant")
("right aligned" "högerjusterad")
("right subscript" "subscript höger")
("right superscript" "superscript höger")
("rigid" "stel")
("rigid horizontal" "stelt horizontal")
("rigid space" "stelt mellanslag")
("romanian" "rumänska")
("root" "rot")
("row" "rad")
("row contains glued items" "rad innehåller hoplistrade delar")
("runic" "runsten")
("sans serif" "sans serif")
("save" "spara")
("save TeXmacs file" "spara TeXmacs fil")
("save TeXmacs style file" "spara TeXmacs style fil")
("save as" "spara som")
("save as LaTeX" "spara som LaTeX")
("save as TeX" "spara som TeX")
("save html file" "spara html fil")
("save latex file" "spara latex fil")
("save tex file" "spara tex fil")
("save verbatim file" "spara verbatim fil")
("saved" "sparat")
("screen layout" "bildskärmslayout")
("screen margins" "skärmkanter")
("script" "script")
("script above" "script över")
("script below" "script under")
("script script size" "skript skript storlek")
("script size" "skript storlek")
("section" "avsnitt")
("selected region" "utvald region")
("selection" "utval")
("seminar" "seminar")
("separation between lines" "radavstånd")
("separation between paragraphs" "avstånd mellan avsnitt")
("separator" "separator")
("september" "september")
("series" "serie")
("series|right" "höger")
("session" "session")
("set" "ställ in")
("set margins" "ställ in kanter")
("set n" "ställ in n")
("set printer dpi" "ställ in skrivarens dpiupplösning")
("set printing command" "ställ in utskriftskommando")
("set text width" "ställ in textbredd")
("setup printer" "skrivarinställningar")
("shape" "form")
("shift-down" "shift-ner")
("shift-right" "shift-höger")
("show header and footer" "visa header och footer")
("shrinking factor" "förminskningsfaktor")
("size" "storlek")
("slanted" "snett")
("small" "lite")
("small caps" "små bokstäver")
("small skip" "litet extraavstånd")
("space" "mellanslag")
("spacing" "avstånd")
("special" "special")
("specific" "specifikt")
("split" "dela")
("square root" "kvadratrot")
("start" "börja")
("stretchable" "töjbart")
("stretchable horizontal" "töjbart horisontellt")
("stretchable vertical" "töjbart vertikalt")
("style" "stil")
("styles" "stil")
("subscript" "subscript")
("subsection" "underavsnitt")
("subsubsection" "underunderavsnitt")
("superscript" "superscript")
("swedish" "svenska")
("switch to formula style" "byt till formelstil")
("symbol" "symbol")
("tab" "tabulator")
("table" "tabell")
("table of contents" "innehållsförteckning")
("tabular" "tabulera")
("test" "testa")
("tex" "tex")
("text" "text")
("text font" "text typsnitt")
("text width" "textbredd")
("th century bc" "th century bc")
("th root" "th rot")
("thai" "thailändskt")
("theorem" "teorem")
("there are unsaved documents" "det finns icke-sparade filer")
("this line" "denna rad")
("tilda" "tilda")
("tilde" "tilde")
("tiny" "pyttelite")
("title" "titel")
("top" "topp")
("top level" "top nivå")
("top margin" "övre kant")
("tree" "träd")
("turkish" "turkiskt")
("type" "typ")
("type a latex command followed by" "slå in latex kommando som följs av")
("type body" "slå in kropp")
("type denominator" "slå in nämnaren")
("type numerator" "slå in täljaren")
("type script" "slå in skript")
("typewriter" "skrivmaskin")
("typewriter small caps" "skrivmaskin små bokstäver")
("ugaritic" "ugaritiskt")
("undo" "ångra")
("up" "upp")
("update" "uppdatera")
("upper border" "övra begränsning")
("use a black color" "använd svart färg")
("use a blue color" "använd blå färg")
("use a brown color" "använd brun färg")
("use a green color" "använd grön färg")
("use a grey color" "använd grå färg")
("use a magenta color" "använd magenta färg")
("use a orange color" "använd orange färg")
("use a pink color" "använd rosa färg")
("use a red color" "använd röd färg")
("use a white color" "använd vit färg")
("use a yellow color" "använd gul färg")
("use blackboard bold font" "använd blackboard typsnitt")
("use bold font series" "använd fet typsnittsserie")
("use calligraphic font" "använd kalligrafiskt typsnitt")
("use footnote font size" "använd fotnot fontstorlek")
("use fraktur font" "använd fraktur typsnitt")
("use huge font size" "använd gigantisk fontstorlek")
("use italic font shape" "använd kursivt typsnittsutseende")
("use large font size" "använd stor fontstorle")
("use medium font series" "använd medium typsnittsserie")
("use normal font size" "använd normal fontstorlek")
("use package" "använd paket")
("use really huge font size" "använd jättegigantiskt storlek")
("use right font shape" "använd rätt typsnittsutseende")
("use roman font family" "använd roman typsnittsfamilj")
("use sans serif font family" "använd serif typsnittsfamilj")
("use script font size" "använd skript fontstorlek")
("use slanted font shape" "använd snett typsnittsutseende")
("use small font size" "använd liten fontstorlek")
("use small-caps font shape" "använd small-caps typsnittsutseende")
("use tiny font font size" "använd pyttefontstorlek")
("use typewriter font family" "använd skrivmaskin typsnittsfamilj")
("use very large font size" "använd jättestor fonstorlek")
("vector" "vector")
("verbatim" "ordagrant")
("verse" "vers")
("vertical after" "vertikalt efter")
("vertical before" "vertikalt fóre")
("vertical position" "vertical position")
("vertical space" "vertikalt mellanslag")
("very large" "mycket stort")
("very small" "mycket lite")
("vietnamese" "vietnamesiskt")
("warning" "varning")
("welcome" "välkommen")
("welcome to TeXmacs" "välkommen till TeXmacs")
("when finished" "när klart")
("white" "vitt")
("wide accent" "wide accent")
("width" "bredd")
("width magnification" "breddförstoring")
("window height" "fönsterhöjd")
("window width" "fönsterbredd")
("yellow" "gult")
("yes" "ja")
("you can also obtain" "du kan också få")
