("\"encryption\" features from the preference panel" "偏好設置 面板中的1個 加密功能")
("(Re)Build autocompletion index" "（重新）生成自動完成索引")
("a.C.M. computing class" "A.C.M。計算類")
("a.M.S. subject class" "碩士課程")
("abbreviated authors" "名 縮寫作者")
("abreviated authors" "名 縮寫作者")
("accept during this pass" "在此通行證期間接受")
("active link types" "個 活動鏈接類型")
("add" "個 添加")
("add abstract information" "添加抽象信息")
("add author information" "添加作者信息")
("add title information" "個 添加標題信息")
("addition" "增加")
("adjust limits" "調整極限")
("advanced font customization" "高級字體定制")
("affiliation" "從屬關係")
("align cell to the decimal comma" "將單元格與小數點對齊")
("align cell to the decimal dot" "將單元格與小數點對齊")
("align table at axis" "將工作台對準軸")
("alignment of balloon" "氣球的對準")
("all cells" "個 所有單元格")
("all data attached to this identity will be lost" "與此身份關聯的所有數據都將丟失")
("all saved passphrases will be lost forever" "所有保存的密碼短語將永遠丟失")
("allowed page height extension" "個 允許的頁面高度擴展")
("allowed page height reduction" "允許頁面高度減少")
("allowed positions" "個 允許的職位")
("allowed positions of floating object" "個 浮動對象的允許位置")
("alpha transparency" "個 alpha透明度")
("alter" "個 更改")
("alternate" "個 備用")
("alternate except here" "這裡除外")
("alternate from here on" "個 從這裡開始的備用")
("alternate only here" "僅在這裡替代")
("alternate until here" "直到這里為止")
("amplified" "放大")
("and perform casual settings from the \"Encryption\" tab" "並通過 加密 選項卡執行臨時設置")
("animate" "個 動畫")
("animate folding" "動畫折疊")
("animate unfolding" "動畫展開")
("animated" "個 動畫")
("annotate" "個 註釋")
("answer field" "個 答案字段")
("answer to question" "個 問題的答案")
("answers only" "個 僅答案")
("any" "個 任意")
("appear" "出現")
("approximate" "大約")
("arc cosine" "個 弧餘弦")
("arc sine" "個 弧形正弦")
("arc tangent" "個 弧線切線")
("are you sure you want to delete collected public keys" "您確定要刪除收集的公共密鑰")
("are you sure you want to delete selected public keys" "確定要刪除所選的公共密鑰")
("are you sure you want to delete selected secret keys" "確定要刪除所選的秘密密鑰")
("are you sure you want to destroy the wallet" "您確定要銷毀錢包")
("art frame" "個 藝術框架")
("arxiv category" "arxiv類別")
("aspect" "個 方面")
("auto" "自動")
("auto-save file" "個 自動保存文件")
("automatic program brackets" "個 自動程序括號")
("automatically import bibliographies when opening files" "打開文件時自動導入書目")
("automatically remember all passphrases in the wallet" "自動記住錢包中的所有密碼短語")
("backtrace errors" "個 回溯錯誤")
("beamer formats" "種 波束格式")
("beamer theme" "個 光束主題")
("bench" "個 長凳")
("bend bottom" "彎曲底部")
("bend corner" "個 彎角")
("bend diagonal" "對角彎曲")
("bend in" "彎曲")
("bend out" "彎曲")
("bezier" "個 貝塞爾曲線")
("bibTeX command" "個 bibTeX命令")
("bidirectional" "個 雙向")
("big environment box" "大環境箱")
("big focus" "個 大重點")
("binary operator" "個 二進制運算符")
("bitmap resolution (dpi)" "位圖分辨率（dpi）")
("black floral I" "黑花我")
("black floral II" "黑花II")
("blackboard embold" "個 黑板框")
("block" "個 塊")
("blur" "模糊")
("bottom baseline" "個 最低基準")
("bottom tools" "個 底部工具")
("box" "個 盒子")
("buffer management" "個 緩衝區管理")
("buffer must be on disk" "緩衝區必須在磁盤上")
("buffer must have a name" "緩衝區必須有一個名稱")
("build buffer" "個 構建緩衝區")
("build buffer in" "在其中建立緩衝區")
("build directory" "個 構建目錄")
("build directory in" "在其中建立目錄")
("build link pages" "個 構建鏈接頁面")
("build-all" "個 全部構建")
("bump" "顛簸")
("busy" "忙")
("cJK" "cJK")
("cJK spacing" "cJK間距")
("cancelled" "個 已取消")
("cannot download directory to file" "無法將目錄下載到文件")
("cannot rename across different servers" "無法在不同服務器上重命名")
("cannot upload directory to file" "無法將目錄上傳到文件")
("caps-lock key" "個 大寫鎖定鍵")
("carved wood" "木雕")
("case-insensitive search" "個 不區分大小寫的搜索")
("categories" "個 類別")
("category" "個 類別")
("cell properties" "個 單元格屬性")
("change default unit" "更改默認單位")
("change passphrase" "個 更改密碼")
("change step-size" "更改步長")
("change the style of mathematical formulas" "更改數學公式的樣式")
("character contraction" "字符收縮")
("character expansion" "字符擴展")
("checkable field" "個 可檢查字段")
("cipher algorithm for passphrase encryption" "密碼短語加密的密碼算法")
("classification" "個 分類")
("clean slate" "個 乾淨的石板")
("clear local information" "個 清除本地信息")
("click Ok button twice to discard this warning" "兩次單擊 \"確定\" 按鈕以放棄此警告")
("clip" "個 剪輯")
("clipboard image format" "剪貼板圖像格式")
("close animation tool" "個 關閉動畫工具")
("close program" "個 關閉程序")
("close replace tool" "關閉替換工具")
("close search tool" "個 關閉搜索工具")
("close spell tool" "個 關閉拼寫工具")
("close translations to rebuild" "要重建的緊密翻譯")
("closed bezier" "個 封閉式貝塞爾曲線")
("closed curve" "個 閉合曲線")
("closed smooth" "封閉式平滑")
("cluster by affiliation" "從屬關係集群")
("collect garbage" "收集垃圾")
("collected keys" "個 已收集的密鑰")
("column separation" "列分離")
("commit file" "個 提交文件")
("common" "常見")
("commutative diagram" "交換圖")
("complete bibliographic reference" "完整書目參考")
("compound" "個 化合物")
("compress into toolbar" "壓縮到工具欄")
("compressed" "壓縮")
("conceal" "個 隱藏")
("configure look and feel" "配置外觀")
("confirm database entry" "確認數據庫條目")
("confirm entry" "確認輸入")
("confirm selected database entries" "個 確認選定的數據庫條目")
("confirm selected entries" "個 確認選定的條目")
("conservative conversion options" "個 保守的轉換選項")
("constellation" "個 星座")
("context aids" "個 上下文輔助工具")
("contextual hints" "個 上下文提示")
("continue" "個 繼續")
("continued fraction" "連續分數")
("contour" "個 輪廓")
("contract logarithms" "個 合同對數")
("convertible" "個 可轉換")
("copyright" "個 版權")
("cork charset with TeX catcode definition in preamble" "在序言中帶有TeX目錄定義的軟木字符集")
("correct" "個 正確")
("correct all" "個 全部糾正")
("correct formula" "正確公式")
("correct manually" "個 手動更正")
("correct mathematical formulas" "個 正確的數學公式")
("correction" "個 更正")
("cosine" "餘弦")
("create link" "個 創建鏈接")
("create remote directory" "個 創建遠程目錄")
("create remote file" "個 創建遠程文件")
("create subprogram" "創建子程序")
("create table macro" "創建表宏")
("creating new account" "個 創建新帳戶")
("crop marks" "個 裁剪標記")
("cross" "個 叉號")
("crossed boxes" "個 交叉框")
("crossed circles" "個 交叉的圓圈")
("current user version" "個 當前用戶版本")
("cursor" "個 光標")
("curve intersections" "個 曲線交叉路口")
("curve points" "個 曲線點")
("customizations" "個 自定義")
("custum tab" "個 custum標籤")
("data" "個 數據")
("database entry" "個 數據庫條目")
("dead" "個 死亡")
("debugging console" "個 調試控制台")
("decomposed" "個 已分解")
("decorated" "個 已裝飾")
("decorated wood" "裝飾木")
("decrease size" "減小尺寸")
("decrypt" "個 解密")
("default size" "默認大小")
("degrade" "降級")
("degraded" "個 降級")
("delete entries" "個 刪除條目")
("delete link" "刪除鏈接")
("deleted" "個 已刪除")
("destroy" "個 破壞")
("determine margins from text width" "個 從文本寬度確定邊距")
("device" "個 設備")
("diamond" "鑽石")
("differentiate" "差異化")
("dilate" "膨脹")
("direction of progression" "前進方向")
("direction of translation" "翻譯方向")
("disable coloring on paper" "在紙上禁用著色")
("disable encryption" "禁用加密")
("disappear" "消失")
("dissociate joined cells" "個 分離連接的細胞")
("distort" "失真")
("distorted" "失真")
("division" "部門")
("document font selector" "文檔字體選擇器")
("document language" "個 文檔語言")
("document page format" "個 文檔頁面格式")
("document paragraph format" "文檔段落格式")
("document updates run" "運行文檔更新")
("dragging" "拖動")
("draw over" "個 透支")
("drop" "下降")
("due to" "由於")
("eRROR" "eRROR")
("edit animation" "個 編輯動畫")
("edit groups of objects" "個 對象的編輯組")
("edit macros" "個 編輯宏")
("edit preamble" "編輯序言")
("effect pen" "效果筆")
("eigenvalues" "個 特徵值")
("eighth" "第八")
("embold" "個 血栓")
("emboss" "浮雕")
("enable page breaking" "啟用分頁")
("encrypt" "個 加密")
("encryption" "個 加密")
("encryption facilities are not currently available" "個 加密工具當前不可用")
("encryption facilities have not been enabled for TeXmacs" "尚未為TeXmacs啟用加密功能")
("enforce brackets to match" "個 使括號匹配")
("engrave" "刻")
("enter graphics" "個 輸入圖形")
("enter graphics mode" "進入圖形模式")
("enter new passphrase for encryption" "輸入新的密碼短語進行加密")
("enter passphrase for decryption" "輸入解密密碼")
("enter passphrase for identity" "輸入身份驗證密碼")
("enter title information" "個 輸入標題信息")
("entry up to date in database" "在數據庫中輸入最新信息")
("enumerate|Alpha" "枚舉| Alpha")
("enumerate|Roman" "枚舉|羅馬")
("enumerate|alpha" "個 枚舉| alpha")
("enumerate|roman" "枚舉|羅馬")
("environment variable" "個 環境變量")
("environments" "個 環境")
("erode" "侵蝕")
("error output" "個 錯誤輸出")
("error status report" "個 錯誤狀態報告")
("error: bracket does not match" "個 錯誤：括號不匹配")
("error: cyclic or missing chunks detected" "錯誤：檢測到循環或丟失的塊")
("error: file not found" "錯誤：找不到文件")
("error: ghostview does not seem to be installed on your system" "錯誤：您的系統上似乎未安裝ghostview")
("error: one of the alternatives should be filled out" "錯誤：應填寫備選方案之一")
("error: only one alternatives should be filled out" "錯誤：應僅填寫一種替代方法")
("error: should fill out name for referencing" "錯誤：應填寫引用名稱")
("error: should fill out required field" "錯誤：應填寫必填字段")
("evaluable field" "個 可評估字段")
("evaluate fields in order" "按順序評估字段")
("evaluate script" "評估腳本")
("evaluation switch" "個 評估開關")
("evaluation tag" "個 評估標籤")
("even page" "偶數頁")
("even pages" "個 偶數頁")
("events" "個 事件")
("execution of scripts" "腳本執行")
("exit graphics" "個 退出圖形")
("exit graphics mode" "個 退出圖形模式")
("expand TeXmacs macros with no LaTeX equivalents" "擴展沒有LaTeX等效項的TeXmacs宏")
("expand beamer slides" "個 擴展投影儀幻燈片")
("expand logarithms" "個 展開對數")
("expand trigonometric functions" "個 展開三角函數")
("expanded" "擴展")
("experimental features (to be used with care)" "個 實驗功能（要小心使用）")
("explain" "個 解釋")
("explanatory item" "解釋性的項目")
("explicit keystroke" "個 明確的擊鍵")
("explicit margins" "個 明確的邊距")
("exponential" "指數")
("export bibliography" "出口書目")
("export entries in buffer" "在緩衝區中導出條目")
("export file" "個 導出文件")
("export mathematical formulas as MathML" "將數學公式導出為MathML")
("export mathematical formulas as images" "將數學公式導出為圖像")
("export selected entries" "個 導出所選條目")
("export selection" "個 出口選擇")
("export selections as" "個 導出選擇為")
("exported bibliographic entries" "個 導出的書目條目")
("exported bibliographic references" "個 導出的書目參考")
("extend" "個 擴展")
("extended" "個 擴展")
("extensible left arrow" "個 可擴展的左箭頭")
("extensible right arrow" "可擴展的向右箭頭")
("extern" "外部")
("external" "外部")
("extra branch" "額外的分店")
("extra interline space" "額外的行間空間")
("extra name" "全名")
("extract" "摘錄")
("extract style file" "提取樣式文件")
("extract style package" "提取樣式包")
("factor" "個 因子")
("fade" "漸變")
("fade in" "淡入")
("fade out" "淡出")
("fast" "個 快速")
("fast decrease" "快速減少")
("fast environments" "個 快速環境")
("fast increase" "快速增長")
("field reference" "現場參考")
("fifth" "第五")
("file saved" "個 文件已保存")
("fill out" "填寫")
("filter" "個 過濾器")
("find file" "查找文件")
("finished collecting symbols documentation" "收集符號的完成文檔")
("first chunk" "個 第一塊")
("first error" "個 第一個錯誤")
("first occurrence" "個 首次出現")
("five columns" "個 五欄")
("flag is off" "標誌已關閉")
("flag is on" "標誌已打開")
("flatten" "變平")
("floating phantom" "浮動幻影")
("fold all" "個 全部折疊")
("fold back" "向後折疊")
("follow external links" "跟隨外部鏈接")
("follow inverse links" "遵循反向鏈接")
("font selector" "字體選擇器")
("for each" "每 個")
("four columns" "個 四列")
("four dots" "個 四個點")
("fourth" "第四")
("fraktur" "fraktur")
("framed" "個 帶框")
("from" "來自")
("full" "滿")
("full author list" "個 完整作者列表")
("gap" "空白")
("garbage collection" "垃圾收集")
("gaussian" "個 高斯")
("gcd" "gcd")
("generated LaTeX document contains no errors" "生成的LaTeX文檔不包含錯誤")
("generated field" "個 生成的字段")
("get arity" "得到善意")
("get label" "獲取標籤")
("get list with remote versions" "獲取帶有遠程版本的列表")
("glyphs" "個 字形")
("gnaw" "gna")
("gnawed" "被咬")
("gnuPG command" "個 gnuPG命令")
("gnuPG error: buffer encryption failed" "gnuPG錯誤：緩衝區加密失敗")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG錯誤：找不到合適的密鑰進行解密")
("gnuPG requires name and email to have at least 5 characters" "gnuPG要求名稱和電子郵件至少包含5個字符")
("go to anchor" "個 錨點")
("go to anchor or float" "停住或漂浮")
("go to anchor or footnote" "轉到錨點或腳註")
("go to float" "浮起來")
("go to footnote" "轉到腳註")
("granite" "個 花崗岩")
("graphical interface font scale" "圖形界面字體比例")
("graphics geometry" "個 圖形幾何")
("graphics grids" "個 圖形網格")
("greyed" "灰色")
("grid curves" "個 網格曲線")
("grid points" "個 網格點")
("grid-curve intersections" "個 網格曲線交叉點")
("group of objects" "個 對象組")
("grouped" "個 分組組")
("guarantee transparent source tracking" "保證透明源跟踪")
("half wide" "半寬")
("hand drawn" "手繪")
("headers" "個 標題")
("homoglyph substitutions" "個 象形文字替換")
("horizontal collapse distance" "水平塌陷距離")
("horizontal margins" "個 水平邊距")
("horizontal table alignment" "個 水平表對齊")
("hyphenate as" "個 連字符為")
("icon" "個 圖標")
("ignore" "忽略")
("impact" "個 影響")
("import bibliography" "進口書目")
("import database entry" "導入數據庫條目")
("import entries in buffer" "緩衝區中的導入條目")
("import entry" "個 導入條目")
("import file" "個 導入文件")
("import selected database entries" "導入選定的數據庫條目")
("import selected entries" "個 導入所選條目")
("import selections as" "將導入內容作為")
("import sophisticated objects as pictures" "將復雜的對像作為圖片導入")
("imported bibliographic entries" "年 導入的書目條目")
("inanimated" "無生命")
("inch" "英寸")
("incomplete entries found to be filled out" "個 發現填寫不完整的條目")
("increase size" "增加尺寸")
("indent paragraphs" "縮進段落")
("indication" "指示")
("initialize" "初始化")
("ink here" "在這里墨水")
("ink in" "墨水中")
("ink out" "墨水用完")
("inline" "內聯")
("inline content" "個 內聯內容")
("inner bottom" "內底")
("inner left" "左內")
("inner right" "右內")
("inner top" "內頂")
("input command" "個 輸入命令")
("input field" "輸入字段")
("insert a gap" "插入間隙")
("insert a multiple choice" "插入多項選擇")
("insert a new entry" "插入新條目")
("insert a prominent piece of text" "插入突出的文本")
("insert a question" "個 插入問題")
("insert a root" "插入根")
("insert a section block" "插入節塊")
("insert a textual operation" "插入文本操作")
("insert abstract" "插入摘要")
("insert an answer" "插入答案")
("insert an enunciation" "插入一個發音")
("insert annotation" "個 插入註釋")
("insert copyright and license information" "個 插入版權和許可信息")
("insert explanatory item" "插入說明性項目")
("insert large delimiters" "插入大定界符")
("insert last name" "插入姓氏")
("insert missing invisible operators" "插入缺少的不可見運算符")
("insert more names" "個 插入更多名稱")
("insert particle" "個 插入粒子")
("insert similar above" "在上面插入類似內容")
("insert similar below" "在下面插入類似內容")
("insert similar block above" "在上面插入類似的塊")
("insert similar block below" "在下面插入類似的塊")
("insert subtable" "個 插入子表")
("insert symbol documentation" "插入符號文檔")
("insert template" "個 插入模板")
("insert title after name" "在名稱後插入標題")
("insert user interface related markup" "插入與用戶界面相關的標記")
("inserting control points" "個 插入控制點")
("integrate" "集成")
("intercharacter compression" "個 字符間壓縮")
("intercharacter stretching" "字符拉伸")
("interrupted" "個 中斷")
("invalid multi-paragraph selection" "個 無效的多段選擇")
("invalid renaming" "無效的重命名")
("invert" "反轉")
("inverted breve" "個 倒置短邊")
("invisible ending" "個 看不見的結尾")
("invisible newline" "個 不可見的換行符")
("invisible opening" "無形開口")
("join selected cells" "個 加入所選單元格")
("jump in" "跳入")
("junior" "初級")
("keep evaluated expressions" "個 保留求值表達式")
("keep local" "個 保持本地狀態")
("keep remote" "個 保持遠程 狀態")
("keep track of source code" "跟踪源代碼")
("keep unfolded" "保持展開")
("large cells" "個 大單元格")
("large displayed" "大顯示")
("large displayed fraction" "個 大的顯示分數")
("large tables" "個 大桌子")
("last error" "個 上一個錯誤")
("last name" "個 姓氏")
("last occurrence" "個 最後一次出現")
("lcm" "厘米")
("left axis" "個 左軸")
("left baseline" "個 左基線")
("left bottom" "左下")
("left center" "左中")
("left click: add point; Right click: undo" "左鍵單擊：添加點；右鍵單擊：撤消")
("left click: finish; Right click: undo" "左鍵單擊：完成；右鍵單擊：撤消")
("left click: new object" "左鍵單擊：新對象")
("left click: operate" "左鍵單擊：操作")
("left down" "左下")
("left on even pages" "個 留在偶數頁上")
("left top" "左上")
("left up" "左上")
("left-right arrow" "個 左右箭頭")
("let the environment float" "讓環境浮動")
("line breaking" "個 換行符")
("line wrapping" "換行")
("linear 2D" "線性2D")
("lines around" "條 周圍的行")
("link image and copies as" "鏈接圖像並將其複制為")
("link image as" "將圖片鏈接為")
("link mode" "鏈接模式")
("link to URL" "個 URL鏈接")
("live" "個 直播")
("live input-output" "個 實時輸入輸出")
("load help file" "個 加載幫助文件")
("load remote file" "個 加載遠程文件")
("loading" "個 正在加載")
("local entries" "個 本地條目")
("loci" "loci")
("locus" "位置")
("locus rendering" "位置繪製")
("logarithm" "對數")
("logging in" "個 正在登錄")
("logical and" "邏輯與")
("logical implication" "邏輯含義")
("logical not" "邏輯不")
("logical or" "邏輯或")
("login" "登錄")
("logout" "註銷")
("long macro" "個 長宏")
("long text" "個 長文本")
("loops" "個 循環")
("macro argument" "個 宏參數")
("macro definition" "宏定義")
("macro name" "宏名稱")
("magnify horizontally" "水平放大")
("magnify vertically" "垂直放大")
("main presentation style" "主要的介紹方式")
("make a letter environment" "建信環境")
("make a multi-slide presentation" "個 進行多幻燈片演示")
("make floating" "使浮動")
("make link" "建立鏈接")
("make non floating" "使非浮動")
("manila paper" "馬尼拉紙")
("map arguments" "個 地圖參數")
("marginal note" "邊注")
("margins from width" "個 寬邊距")
("margins on paper" "紙上邊距")
("margins on screen" "屏幕上的邊距")
("marked" "已標記")
("material" "材料")
("matrices" "個 矩陣")
("maximal cell height" "最大像元高度")
("maximal clustering" "個 最大聚類")
("maximal table height" "最大工作台高度")
("maximal table width" "個 最大表格寬度")
("maximum" "最大")
("meander" "曲折")
("menu" "菜單")
("merge lines into paragraphs unless separated by blank lines" "除非另有空白行，否則將行合併為段落")
("messages" "個 消息")
("meta data" "個 元數據")
("metal" "個 金屬")
("middle baseline" "個 中間基準")
("minimal cell height" "個 最小像元高度")
("minimal cell width" "最小像元寬度")
("minimal line separation" "最小行間距")
("minimal table height" "最小工作台高度")
("minimal table width" "最小表格寬度")
("minimum" "最低")
("mirror" "鏡子")
("miscellanous" "其他")
("modify remote live document" "修改遠程實時文檔")
("module" "模塊")
("monospaced" "個 等距")
("more information about GNU TeXmacs can be found in the Help->About menu" "可以​​在 \"幫助\"->\"關於\" 菜單中找到有關GNU TeXmacs的更多信息")
("more information about GNU TeXmacs can be found in the help" "可以在幫助中找到有關GNU TeXmacs的更多信息")
("motion" "個 運動")
("mouse over object" "鼠標移到對像上")
("move objects" "個 移動對象")
("move over object on which to operate" "移至要操作的對象")
("multiline" "多行")
("multiple choice" "個 多項選擇")
("multiplication" "乘法")
("navigation options" "個 導航選項")
("new account" "個 新帳戶")
("new bibliography dialogue" "新書目對話")
("new entry" "個 新條目")
("new identity" "個 新身份")
("new locus" "個 新軌跡")
("new macro" "新宏")
("new passphrase" "個 新密碼")
("new remote directory" "新的遠程目錄")
("new remote file" "新的遠程文件")
("new style fonts" "個 新樣式字體")
("new style page breaking" "個 新樣式分頁符")
("newer version" "較新版本")
("next chunk" "個 下一塊")
("next error" "下一個錯誤")
("next occurrence" "次 下一次發生")
("next screen" "下一個屏幕")
("no clustering" "無聚類")
("no completions" "個 未完成")
("no errors have been corrected" "未糾正任何錯誤")
("no new public key in document" "文檔中沒有新的公共密鑰")
("no page numbers" "無頁碼")
("no parent" "個 沒有父母")
("no selection" "無選擇")
("no spelling errors" "無拼寫錯誤")
("normal loci" "個 正常基因座")
("not allowed to remove home directory" "不允許刪除主目錄")
("not connected to server" "未連接到服務器")
("not yet implemented" "尚未實施")
("notebook" "筆記本")
("numeric spreadsheet" "個 數字電子表格")
("odd page" "個 奇數頁")
("odd pages" "個 奇數頁")
("of fingerprint" "指紋")
("older version" "舊版本")
("on your system and set it up from the \"Security\" tab" "在您的系統上，並通過 安全 選項卡進行設置")
("one error has been corrected" "一個錯誤已更正")
("one lower case letter, one non alpha-numeric symbol" "一個小寫字母，一個非字母數字符號")
("one numeric character, one upper case letter" "一個數字字符，一個大寫字母")
("only convert changes when re-importing" "僅在重新導入時才轉換更改")
("only convert changes with respect to imported version" "僅轉換相對於導入版本的更改")
("only convert changes with respect to tracked version" "僅轉換相對於跟踪版本的更改")
("only implemented for complete subtrees" "僅針對完整的子樹實現")
("only keep folded" "僅保持折疊")
("only keep unfolded" "僅保持展開")
("only show semantic focus" "僅顯示語義焦點")
("open bibliography" "開放書目")
("open identities" "個 開放身份")
("open key manager" "個 開放密鑰管理器")
("open licence agreement" "開放許可協議")
("open mailbox" "打開郵箱")
("open tool in separate window" "在單獨的窗口中打開工具")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "或給出 \"gpg\" 或 \"gpg2\" 命令的完整路徑")
("order" "命令")
("ordinary symbol" "普通符號")
("ornamented" "個 已裝飾")
("other login" "其他登錄名")
("outer bottom" "外底")
("outer left" "左外")
("outer right" "右外")
("outer top" "外頂")
("outline" "個 大綱")
("outlined" "個 概述")
("outlined emboss" "輪廓浮雕")
("outlined engrave" "輪廓刻")
("oval" "橢圓形")
("overlap" "個 重疊")
("overlay" "疊加層")
("overlays" "個 疊加層")
("overlined" "個 帶上劃線的")
("padded" "填充")
("page background" "個 頁面背景")
("page break after" "個 分頁後")
("page breaking algorithm" "個 分頁算法")
("page number" "個 頁碼")
("page number rendering" "個 頁碼渲染")
("page rendering" "個 頁面呈現")
("panorama" "全景")
("paragraphs" "個 段")
("parenthesis" "個 括號")
("parenthesized" "帶括號")
("particle" "個 粒子")
("passphrase encryption" "個 密碼加密")
("passphrase wallet facilities are not currently available" "個 密碼錢包功能目前不可用")
("passphrases are expected to have at least: 8 characters" "個 密碼短語至少應包含：8個字符")
("passphrases mismatch" "個 密碼不匹配")
("pastel" "個 粉彩")
("pattern" "個 模式")
("pause" "個 暫停")
("pen width" "筆寬")
("permanently add to dictionary" "永久添加到字典")
("permanently insert into dictionary" "永久插入字典")
("permissions" "個 權限")
("phantom" "個 幻像")
("phantoms" "個 幻像")
("physics and astronomy class" "物理與天文學班")
("picture" "圖片")
("pine" "松樹")
("plain" "純文本")
("plain boxes" "個 普通框")
("plain circles" "個 普通圈子")
("play" "次 播放")
("play animation" "個 播放動畫")
("please install GnuPG software from https://www.gnupg.org" "請從https://www.gnupg.org安裝GnuPG軟件")
("plural" "複數")
("pop server settings" "個 pop服務器設置")
("position of marginal note" "註解的位置")
("poster formats" "個 海報格式")
("poster theme" "海報主題")
("postfix" "個 後綴")
("preferences for editing mathematical formulas" "編輯數學公式的首選項")
("preferences for tag" "個 標籤首選項")
("prefix" "個 前綴")
("preserve" "個 保留")
("preview with ghostview" "個 ghostview預覽")
("previous error" "個 先前的錯誤")
("previous occurrence" "個 以前的事件")
("previous screen" "個 上一個屏幕")
("primitive or macro" "原始或宏")
("print to file" "個 打印到文件")
("printer setup" "打印機設置")
("program bracket matching" "個 程序支架匹配")
("program bracket selections" "個 程序括號選擇")
("program commands" "個 程序命令")
("provoke C++ error" "引發C ++錯誤")
("provoke menu error" "引髮菜單錯誤")
("provoke scheme error" "挑釁方案錯誤")
("public key encryption" "個 公鑰加密")
("public keys" "個 公鑰")
("pulse" "脈衝")
("qt GUI only, sorry. Use \"Export selection\"" "僅qt GUI，對不起。使用 \"導出選擇\"")
("qt-widgets" "個 qt小部件")
("quantifier" "量化工具")
("quasi" "準")
("questions only" "個 僅限問題")
("questions with answers" "有疑問的問題")
("quick evaluation of formulas" "公式的快速評估")
("rank" "等級")
("raw" "原始")
("really delete user identity" "確實刪除用戶身份")
("recipients" "個 收件人")
("recognize" "識別")
("rectangular" "矩形")
("reduce" "減少")
("reduce trigonometric functions" "減少三角函數")
("reduced margins" "減少的利潤")
("regenerate" "重新生成")
("register file" "註冊文件")
("relate" "個 相關")
("relation" "個 關係")
("release left button: finish editing" "釋放左鍵：完成編輯")
("remote controllers with keyboard simulation" "帶有鍵盤模擬的遠程控制器")
("remote directory" "遠程目錄")
("remote servers" "個 遠程服務器")
("remove database entry" "刪除數據庫條目")
("remove entries" "個 刪除條目")
("remove entry" "刪除條目")
("remove folded" "刪除折疊")
("remove link" "刪除鏈接")
("remove selected database entries" "刪除選定的數據庫條目")
("remove selected entries" "刪除選定的條目")
("remove superfluous invisible operators" "個 刪除多餘的不可見運算符")
("remove unfolded" "已展開")
("removed entries from database" "從數據庫中刪除了條目")
("removed entry from database" "從數據庫中刪除了條目")
("rename" "重命名")
("rename section" "重命名部分")
("replace TeXmacs styles with no LaTeX equivalents" "替換沒有LaTeX等效項的TeXmacs樣式")
("replace all further occurrences" "替換所有後續出現的事件")
("replace one occurrence" "替換一個事件")
("reset error counters" "個 重置錯誤計數器")
("resize objects" "個 調整對像大小")
("restart TeXmacs in order to let changes take effect" "重新啟動TeXmacs以使更改生效")
("restart in order to let the new look and feel take effect" "重新啟動以使新外觀生效")
("retime" "重定時")
("retina settings" "個 視網膜設置")
("retrieve email" "檢索電子郵件")
("retrieve remote live document" "檢索遠程實時文檔")
("retrieved contents" "個 已檢索內容")
("reverse" "反向")
("reverse ordering" "反向排序")
("ridged paper" "山脊紙")
("right baseline" "個 正確的基準")
("right down" "右下")
("right on even pages" "在偶數頁上正確")
("right up" "正確起來")
("rigid box" "個 硬盒")
("rotate objects" "個 旋轉對象")
("rough paper" "粗糙紙")
("round overbrace" "個 圓形大括號")
("round underbrace" "個 圓形底括號")
("run current file" "運行當前文件")
("same names" "個 同名")
("same screen margins as on paper" "與紙上的屏幕邊距相同")
("sample text" "個 示例文字")
("save auxiliary data" "保存輔助數據")
("save entries" "個 保存條目")
("save entry" "個 保存條目")
("save image as" "將圖像另存為")
("save position" "個 保存位置")
("save remote file" "個 保存遠程文件")
("saved modifications in database" "數據庫中保存的修改")
("screen" "屏幕")
("screen rendering" "屏幕渲染")
("screenshot" "截圖")
("scripting language" "個 腳本語言")
("search and replace" "搜索並替換")
("second" "秒")
("secret keys" "個 秘密密鑰")
("sections" "個 部分")
("see documentation" "請參閱文檔")
("select pen" "選擇筆")
("select the action to be undertaken for each conflict" "為每次沖突選擇要採取的行動")
("select view mode" "個 選擇視圖模式")
("senior" "高級")
("serif" "個 serif")
("server" "個 服務器")
("set default" "設置默認值")
("set difference" "設置差異")
("set intersection" "個 設置交集")
("set properties" "個 設置屬性")
("set union" "設置工會")
("set user information" "個 設置用戶信息")
("seventh" "第七")
("shadow" "個 陰影")
("shadowed" "陰影")
("shadowed raise" "個 陰影加薪")
("shift" "個 班次")
("show current focus" "顯示當前焦點")
("show full context" "顯示全文")
("show key presses" "個 顯示按鍵")
("show main document" "顯示主文件")
("show table cells" "個 顯示表格單元格")
("side tools" "個 輔助工具")
("simple" "簡單")
("simplified evaluation of formulas" "公式的簡化求值")
("simplify" "簡化")
("sine" "正弦")
("sixth" "第六")
("skew" "歪斜")
("skip all" "全部跳過")
("slant" "偏斜")
("slashed fraction" "斜線分數")
("slides" "個 幻燈片")
("slow" "慢")
("slow decrease" "緩慢減少")
("slow increase" "緩慢增加")
("small capitals" "個 小首都")
("small environment box" "個 小環境箱")
("small focus" "小焦點")
("small inline" "個 小內聯")
("small inline fraction" "較小的行內分數")
("smash" "粉碎")
("smooth" "流暢")
("smooth end" "平滑結束")
("smooth extremities" "個 平滑的肢體")
("smooth start" "順利啟動")
("snap" "個 快照")
("snap distance" "捕捉距離")
("snap to curves" "個 捕捉到曲線")
("snap to grid" "捕捉到網格")
("snap to grid curve" "捕捉到網格曲線")
("snap to intersections of curves" "捕捉到曲線的交點")
("snap to text borders" "捕捉到文本邊框")
("snap to text corners" "捕捉到文本角")
("solution to exercise" "運動解決方案")
("solution to problem" "解決問題")
("solutions" "個 解決方案")
("south" "南")
("south east" "東南")
("space bar in math mode" "數學模式下的空格鍵")
("space bar in text mode" "文本模式下的空格鍵")
("space stretchability" "空間伸縮性")
("span" "跨度")
("span over all columns" "跨越所有列")
("special cell properties" "個 特殊單元格屬性")
("special table properties" "個 特殊表屬性")
("specific baseline" "個 特定基準")
("specify color alternation" "指定顏色交替")
("specify how to traverse the manual" "指定如何遍歷手冊")
("specify semantics of a symbol or formula" "指定符號或公式的語義")
("spell check" "個 拼寫檢查")
("split program" "個 拆分程序")
("square overbrace" "個 方形大括號")
("square underbrace" "個 方形底括號")
("standard Output" "標準輸出")
("standard fraction" "標準分數")
("star" "個 星級")
("start server" "個 啟動服務器")
("statement" "聲明")
("stop server" "個 停止服務器")
("storage" "存儲")
("store tracking information in LaTeX files" "在LaTeX文件中存儲跟踪信息")
("stretch factor" "拉伸因子")
("strict Ascii" "個 嚴格的Ascii")
("strike through" "strike through")
("structured variant" "結構化變體")
("style options" "樣式選項")
("style parameters" "個 樣式參數")
("subject" "個 主題")
("submenu" "子菜單")
("subscript below" "個 下標")
("subsubmenu" "個 子菜單")
("subsubsubmenu" "子子菜單")
("subsubsubsubmenu" "個 subsubsubsubmenu")
("subtraction" "減")
("summarized" "摘要")
("superscript above" "上方標")
("supported plug-ins" "個 受支持的插件")
("inflate" "膨脹")
("switch to buffer" "切換到緩衝區")
("symbol properties not found" "未找到符號屬性")
("symbols" "個 符號")
("synchronize" "個 同步")
("synchronize bibliographic references" "同​​步書目參考")
("synchronize with remote server" "與遠程服務器同步")
("synopsis" "個 簡介")
("tabbed" "個 帶標籤的")
("table breaking" "破表")
("table height" "工作台高度")
("table properties" "個 表屬性")
("table width" "個 工作台寬度")
("tags with special rendering" "個 具有特殊渲染的標籤")
("tangent" "正切")
("teXmacs DTD" "個 teXmacs DTD")
("teXmacs buffer expected" "個 預期teXmacs緩衝區")
("teXmacs buffer on disk expected" "預期磁盤上的teXmacs緩衝區")
("teXmacs macro" "個 teXmacs宏")
("teXmacs package" "個 teXmacs程序包")
("teXmacs plugins" "個 teXmacs插件")
("teXmacs style" "teXmacs樣式")
("test routine" "測試例程")
("testing tree-view" "測試樹狀視圖")
("text borders" "個 文本邊框")
("text box style" "文本框樣式")
("text corners" "個 文本角")
("textual" "文字")
("textual spreadsheet" "文本電子表格")
("theme parameters" "個 主題參數")
("these collected public keys will be definitely lost" "這些收集的公鑰肯定會丟失")
("these public keys will be definitely lost" "這些公鑰肯定會丟失")
("these secret keys will be definitely lost" "這些秘密密鑰肯定會丟失")
("thicken" "變厚")
("third" "第三")
("this" "此")
("this page number" "此頁碼")
("this style specifies page margins in the TeX way" "此樣式以TeX方式指定頁邊距")
("three columns" "個 三列")
("three dots" "個 三個點")
("through popup windows" "通過彈出窗口")
("through the menus" "通過菜單")
("time evolution" "時間演變")
("timings" "個 時間")
("title presentation options" "個 標題顯示選項")
("title style" "標題樣式")
("title suffix" "個 標題後綴")
("titled block" "個 標題欄")
("toggle cell wrapping mode" "切換單元格包裹模式")
("toggle here" "在此處切換")
("toggle off" "關閉")
("toggle on" "打開")
("tolerant" "寬容")
("top baseline" "個 最高基準")
("transform cell into subtable" "將單元格轉換為子表")
("translations loaded" "個 已加載翻譯")
("transpose" "個 移調")
("traversal" "遍歷")
("traverse" "個 遍歷")
("triangle" "三角形")
("triangularize" "三角化")
("trigonometric" "三角")
("turn off" "關閉")
("turn on" "打開")
("two dots" "個 兩個點")
("type a latex command followed by return" "鍵入一個乳膠命令，然後返回")
("underlined" "帶下劃線的")
("unevaluated argument" "未經評估的論點")
("unevaluated value" "個 未評估的價值")
("unfold all" "個 全部展開")
("unknown secret key fingerprint" "年 未知密鑰指紋")
("unregistered file" "個 未註冊文件")
("unroll" "年 展開")
("unsecure script refused" "年 不安全的腳本被拒絕")
("unsupported link mode" "不受支持的鏈接模式")
("until" "直到 為止")
("untitled block" "個 無標題的方塊")
("up to date" "最新")
("update buffer" "更新緩衝區")
("upight" "upight")
("upload" "上傳")
("use CSS for more advanced formatting" "使用CSS進行更高級的格式設置")
("use MathML" "年 使用MathML")
("use as master" "年 用作主人")
("use extensible brackets" "年 使用可擴展括號")
("use line wrapping for lines which are longer than 80 characters" "對超過80個字符的行使用換行")
("use margin kerning (protrusion)" "使用邊距字距調整（突出）")
("use protrusion" "使用突起")
("use relative path" "使用相對路徑")
("user interface" "個 用戶界面")
("utf-8 with inputenc LaTeX package" "帶有inputenc LaTeX軟件包的UTF-8")
("vanish" "消失")
("verbose" "詳細")
("vertical margins" "個 垂直邊距")
("vertical space after" "之後的垂直空間")
("vertical space before" "之前的垂直空間")
("vertical space stretchability" "垂直空間可拉伸性")
("vertical table alignment" "垂直表對齊")
("visible except here" "除了這裡可見")
("visible from here on" "從這裡開始可見")
("visible only here" "僅在此處可見")
("visible until here" "直到這裡可見")
("visited loci" "個 訪問過的所在地")
("wallet" "錢包")
("wave" "波")
("weight" "重量")
("when line wrapping" "換行時")
("wide" "寬")
("wide block" "個 寬幅廣告")
("wide colored" "個 彩色")
("wide float" "寬幅浮動")
("wide footnote" "註腳")
("wide tabular" "個 寬表格")
("widescreen" "寬屏")
("wrong empty passphrase" "錯誤的空密碼")
("wrong passphrase" "個 錯誤的密碼短語")
("year" "年")
("you are attempting to open an encrypted file while" "您正在嘗試同時打開加密文件")
("you might consider enabling the experimental" "您可以考慮啟用實驗性功能")
("you must add a bibliography file" "您必須添加書目文件")
("you should also make sure that GnuPG is installed" "您還應確保已安裝GnuPG")
("your personal dictionary has been modified" "您的個人詞典已被修改")
