("a modifier" "")
("a series" "")
("abbreviation" "省略表現")
("about" "以下について")
("about menu" "メニューについて")
("above" "")
("abstract" "要約")
("accent" "")
("accept" "")
("accept all scripts" "")
("accept no scripts" "")
("accept script" "")
("acknowledgment" "謝辞")
("acronym" "")
("action" "")
("activate" "")
("activate once" "")
("activate hidden" "")
("activation" "")
("acute" "")
("add package" "パッケージを加える")
("add switch after" "")
("add switch before" "")
("address" "住所")
("address block" "")
("advanced" "")
("advanced layout features" "")
("after" "")
("albanian" "")
("algorithm" "算法(アルゴリズム)")
("align cell to the bottom" "")
("align cell to the left" "")
("align cell to the right" "")
("align cell to the top" "")
("align table at base of left column" "")
("align table at base of middle column" "")
("align table at base of origin column" "")
("align table at base of right column" "")
("align table at fraction bar height" "")
("align table at the base of bottom row" "")
("align table at the base of middle row" "")
("align table at the base of origin row" "")
("align table at the base of top row" "")
("align table at the bottom" "")
("align table at the center" "")
("align table at the horizontal center" "")
("align table at the left" "")
("align table at the top" "")
("align table to the right" "")
("align text to the left" "")
("align text to the right" "")
("aligned" "")
("alignment" "整列")
("all" "")
("allow" "")
("allowed extension" "")
("allowed reduction" "")
("alpha release" "")
("alt key" "")
("alternative specification" "")
("american" "英語(アメリカ)")
("and" "")
("angular" "")
("appendix" "")
("apply" "")
("apply macro" "")
("apply macro once" "")
("april" "")
("arab" "")
("arch series" "")
("archaic" "")
("architecture" "")
("argument" "")
("arithmetic" "")
("armenian" "")
("arrow" "")
("arrows" "")
("article" "論文")
("as on paper" "")
("assign" "")
("at fraction bar height" "")
("at the baseline" "")
("at the bottom" "")
("at the left" "")
("at the middle" "")
("at the right" "")
("at the top" "")
("attach" "")
("attach buffer to which project" "")
("august" "")
("author" "著者")
("authorize" "")
("automatic" "自動")
("automatically close brackets" "")
("automatically generated content" "")
("automatic quotes" "")
("autosave" "自動保存")
("axis" "")
("axiom" "公理")
("b series" "")
("background" "")
("background color" "")
("background evaluations" "")
("backward replace" "")
("backward search" "")
("bad data format" "")
("bar" "")
("bard" "")
("base level" "")
("bashkirian" "")
("basic" "")
("basic communication using pipes" "")
("basic data types" "基本データ型")
("basic types" "基本型")
("be useful" "")
("become a TeXmacs developer" "TeXmacsの開発者になる")
("before" "")
("begin" "")
("below" "")
("beta release" "β版")
("bibliography" "参考文献")
("bibliography file" "参考文献ファイル")
("bibliography style" "参考文献のスタイル")
("big" "大きく")
("big figure" "大きい図")
("big operator" "大きい演算子")
("big skip" "大きい空行")
("big table" "大きい表")
("binary operation" "2項演算")
("binary relation" "2項関係")
("black" "黒")
("blackboard bold" "")
("blackboard math" "")
("blackletter" "")
("blue" "青")
("body" "")
("bold" "ボールド")
("book" "本")
("border" "")
("both" "")
("bottom" "")
("bottom border" "")
("bottom cell border" "")
("bottom cell padding" "")
("bottom margin" "")
("bottom padding" "")
("bottom table border" "")
("bottom table padding" "")
("branch" "分岐")
("break" "")
("breaking" "")
("breve" "")
("british" "英語(英国)")
("broken white" "")
("brown" "")
("browse" "調べる(browse)")
("browse web" "")
("browser" "")
("buffer" "")
("bulgarian" "")
("bullet" "")
("bullets" "")
("by" "")
("by typing" "")
("bytes free" "bytesが空き領域")
("bytes used" "bytesを利用済")
("calligraphic" "")
("cancel" "キャンセル(中断)")
("caps-lock key" "")
("case" "")
("cc" "")
("cell" "")
("cell background color" "")
("cell border" "")
("cell height" "")
("cell operation mode" "")
("cell width" "")
("center" "中心")
("center text" "テキストを中心へ")
("centered" "")
("centered block" "")
("centered tabular" "")
("change border of cell" "")
("change cell operation mode" "")
("change log" "")
("changes" "")
("chapter" "章")
("check" "検査")
("check text for spelling errors" "")
("chinese" "中国語")
("choice" "選択")
("citation" "引用")
("cite" "")
("class" "")
("clear" "消す")
("clear selection" "")
("clipped" "")
("clipped and magnified" "")
("clipped and resized" "")
("clone" "")
("clone window" "同じウインドーを作成")
("close" "閉じる")
("close TeXmacs" "TeXmacsを閉じる")
("close buffer" "バッファ(入力領域)を閉じる")
("close session" "セッション(実行)を停止する")
("close window" "ウインドウを閉じる")
("closing" "閉じています")
("closing style" "")
("code" "コード")
("color" "色")
("column" "列")
("column contains glued items" "")
("common formats" "")
("compact" "")
("compactification" "")
("compactify" "")
("compatibility with other formats" "")
("compile article" "論文のコンパイル")
("compile book" "本のコンパイル")
("compile buffer" "")
("compile project" "")
("completion" "補間")
("complex" "")
("concrete" "")
("condensed" "")
("condition" "")
("configuration" "構成")
("contact" "")
("content" "内容")
("content tag" "内容の印")
("context dependent icons" "文脈依存アイコン")
("continuation of" "以下の続き")
("contribute" "寄与する")
("control the evaluation of expressions" "式の評価を制御")
("convention" "")
("converters to other data formats" "他のデータ形式への変換")
("copy" "コピー")
("copy text" "テキストをコピー")
("copy to" "以下へコピー")
("copying" "コピーしています")
("corollary" "系")
("correct text" "")
("create web site" "ウエブサイトを作る")
("cursors" "カーソル")
("custom tab" "")
("customizing TeXmacs" "TeXmacsをお好みに変更")
("customizing the TeXmacs styles" "TeXmacsスタイルをお好みに変更")
("custum tab" "")
("cut" "切取")
("cut text" "テキストの切取")
("cut to" "以下へ切取")
("cypriot" "")
("cyrillic" "")
("cyrillic input method" "")
("cyrillic italic right" "")
("czech" "チェコスロバキア語")
("dancers" "")
("danish" "デンマーク語")
("dark grey" "")
("dash" "")
("dashes" "")
("data conversion" "")
("data format" "")
("date" "日付")
("deactivate" "")
("deactivate table" "")
("december" "")
("decorate atoms" "")
("default" "既定")
("default padding" "")
("definition" "定義")
("delete" "")
("delete column" "")
("delete row" "")
("denominator" "分母")
("description" "記述法")
("destination" "")
("detach" "")
("detailed" "詳しい")
("determinant" "行列式")
("devangari" "")
("developers guide" "開発者のガイド")
("directory" "ディレクトリ")
("disable" "無効")
("disable first indentation" "")
("disable first indentation after" "")
("disable first indentation before" "")
("disable indentation" "")
("disable indentation after" "")
("disable indentation before" "")
("deactivate" "")
("deactivate once" "")
("disallow" "")
("distribute unused space" "")
("div" "")
("do not remap" "")
("document" "文書")
("document format" "文書フォーマット")
("document style" "文書")
("document styles" "文書スタイル")
("documentation" "")
("documents are trees" "文書は木です")
("dot" "")
("dots" "")
("double stroke" "")
("down" "")
("download" "ダウンロード")
("dpi" "")
("duplicate" "")
("dutch" "オランダ語")
("dynamic libraries" "")
("edit" "編集")
("edit source tree" "ソース木を編集")
("editing tools" "道具を編集")
("email" "電子メール")
("emphasize" "強調")
("emphasize text" "テキストを強調")
("empty box" "空っぽの箱")
("enable first indentation" "")
("enable first indentation after" "")
("enable first indentation before" "")
("enable indentation" "")
("enable indentation after" "")
("enable indentation before" "")
("encl" "")
("end" "")
("english" "英語")
("enter a title" "表題を入力")
("enumerate" "列挙")
("enumerate|Alpha" "")
("enumerate|Roman" "")
("enumerate|alpha" "")
("enumerate|roman" "")
("env" "")
("environment" "環境")
("epilogue" "")
("equal" "等しい")
("equation" "式")
("equations" "式達")
("equivalent for" "")
("error" "エラー")
("esperanto" "")
("etruscan" "")
("evaluate" "評価")
("evaluate scheme expression" "scheme表現を評価")
("even page footer" "")
("even page header" "")
("even page margin" "")
("even page left margin" "")
("even page shift" "")
("even page text" "")
("exact horizontal" "")
("exact mode" "")
("exam" "試験")
("example" "例")
("exclusive" "排他的")
("exclusive or" "")
("executable" "実行可能")
("execute" "実行")
("execute a TeXmacs command" "TeXmacsのコマンドを実行")
("execute system command" "システムのコマンドを実行")
("executive" "")
("exercise" "練習")
("expand" "展開")
("explained" "")
("export" "他形式出力(エクスポート)")
("export as" "")
("extend or normal" "")
("extern " "")
("extra" "")
("extract format" "")
("family" "")
("february" "")
("figure" "図")
("file" "ファイル")
("file name" "ファイルの名前")
("file not found" "ファイルがありません")
("find next match" "次に一致するものを探す")
("find text" "テキストを探す")
("finnish" "フィンランド語")
("first contact" "")
("first indentation" "始めの字下げ")
("first item" "")
("first page" "")
("first start" "始めての開始")
("flat" "")
("flexibility" "柔軟性")
("flexibility factor for vertical spacing" "")
("floating figure" "図(場所は適当)")
("floating object" "オブジェクト(場所は適当)")
("floating table" "表(場所は適当)")
("fold" "折り畳み")
("fold input field" "")
("folded" "折り畳まれた")
("font" "フォント(字体)")
("font base size" "フォント(字体)の基本サイズ")
("font dpi" "")
("font family" "")
("font name" "")
("font series" "")
("font shape" "")
("font size" "")
("font type" "")
("font variant" "")
("fonts" "")
("footer" "")
("footnote" "脚注")
("for" "")
("foreground" "")
("foreign" "")
("format" "書式")
("formatted and structured output" "")
("formatted date" "")
("formatting" "")
("formula" "公式")
("formula style" "")
("forward replace" "")
("forward search" "")
("fraction" "分数")
("french" "フランス語")
("full manuals" "完全な説明書")
("function" "")
("functional" "")
("further customization" "")
("future changes" "")
("gNU TeXmacs comes without any form of legal warranty" "GNU TeXmacs は無保証です")
("gNU TeXmacs falls under the GNU general public license" "GNU TeXmacs は GNU general public license の元で開発されております.")
("general architecture of TeXmacs" "")
("general negation" "")
("general note" "")
("generating font file" "フォントファイルを作成中")
("generic" "一般な(generic)")
("georgian" "")
("german" "ドイツ語")
("getting started" "")
("glossary" "用例解説")
("glossary entry" "")
("glue" "")
("glue decorations" "")
("go" "移る")
("gothic" "")
("graphical interface" "")
("grave" "")
("greater" "")
("greater or equal" "")
("greek" "")
("greek letter" "")
("green" "")
("grey" "")
("group" "")
("h modifier" "")
("happy typing" "")
("has been aborted" "")
("has completed its task" "")
("hat" "ハット")
("header" "ヘッダー")
("header and footer" "")
("hebrew" "")
("height" "高さ")
("height is exactly the specified height" "")
("height is maximum of specified height and box height" "")
("height is minimum of specified height and box height" "")
("height magnification" "")
("help" "ヘルプ")
("help me" "")
("help us" "私たちに助力")
("here" "")
("hidden" "")
("home" "ホーム")
("homepage" "ホームページ")
("horizontal" "")
("horizontal cell alignment" "")
("horizontal ink separation" "")
("horizontal part" "")
("horizontal position" "")
("horizontal space" "")
("horizontal table alignment" "")
("horizontally align cell to the base" "")
("horizontally center the cell" "")
("how much longer may pages become" "")
("how much shorter may pages become" "")
("huge" "")
("hungarian" "ハンガリー語")
("hybrid command" "")
("hyperlink" "")
("hyphenation" "")
("icelandic" "")
("if" "")
("image" "イメージ")
("image links" "")
("implementation" "")
("import" "他形式入力(インポート)")
("improving the current implementation" "")
("inactive" "")
("include" "")
("include a document" "")
("include file" "")
("inclusion into TeXmacs" "")
("inclusions" "")
("indent" "")
("indentation flag" "")
("index" "索引")
("index entry" "")
("index level" "")
("informative flags" "")
("inline arguments" "")
("input mode" "")
("insert" "挿入")
("insert Pr" "")
("insert a TeXmacs symbol" "")
("insert a big operator" "")
("insert a binary operation" "")
("insert a binary relation" "")
("insert a blackboard bold character" "")
("insert a bold calligraphic character" "")
("insert a bold character" "")
("insert a calligraphic character" "")
("insert a condition" "")
("insert a control flow instruction" "")
("insert a fraction" "")
("insert a fraktur character" "")
("insert a greek character" "")
("insert a large left delimiter" "")
("insert a large right delimiter" "")
("insert a large separator" "")
("insert a left subscript" "")
("insert a link" "")
("insert a miscellaneous symbol" "")
("insert a new branch" "")
("insert a new item" "")
("insert a numerical operation" "")
("insert a picture" "")
("insert a square root" "")
("insert a table" "")
("insert a table or a matrix" "")
("insert a textual operation" "")
("insert a wide symbol above" "")
("insert a wide symbol below" "")
("insert an" "")
("insert an accent" "")
("insert an arrow" "")
("insert an environment" "")
("insert an n" "")
("insert an operation on tuples" "")
("insert appendix" "")
("insert arccos" "")
("insert arcsin" "")
("insert arctan" "")
("insert arg" "")
("insert argument" "")
("insert author" "")
("insert automatically generated content" "")
("insert big contour integral" "")
("insert big coproduct" "")
("insert big direct sum" "")
("insert big dotted point" "")
("insert big integral" "")
("insert big intersection" "")
("insert big logical and" "")
("insert big logical or" "")
("insert big product" "")
("insert big square union" "")
("insert big summation" "")
("insert big tensor product" "")
("insert big union" "")
("insert big union sum" "")
("insert big vertical space" "")
("insert chapter" "")
("insert column" "")
("insert column to the left" "")
("insert column to the right" "")
("insert cos" "")
("insert cosh" "")
("insert cot" "")
("insert coth" "")
("insert csc" "")
("insert deg" "")
("insert det" "")
("insert dim" "")
("insert dollar" "")
("insert equation" "")
("insert executable markup" "")
("insert exp" "")
("insert fields" "")
("insert footnote" "")
("insert formula" "")
("insert gcd" "")
("insert hom" "")
("insert horizontal interword space" "")
("insert image" "")
("insert inactive markup" "")
("insert inf" "")
("insert input field above" "")
("insert input field below" "")
("insert ker" "")
("insert lg" "")
("insert lim" "")
("insert liminf" "")
("insert limsup" "")
("insert ln" "")
("insert log" "")
("insert macro" "")
("insert mathematics" "")
("insert max" "")
("insert medium horizontal space" "")
("insert medium vertical space" "")
("insert min" "")
("insert negative horizontal space" "")
("insert new item or number" "")
("insert new rows or columns" "")
("insert or delete rows or columns" "")
("insert row" "")
("insert row above" "")
("insert row below" "")
("insert sec" "")
("insert section" "節(section)の挿入")
("insert sharp" "")
("insert sin" "")
("insert sinh" "")
("insert small horizontal space" "")
("insert small vertical space" "")
("insert structural markup" "")
("insert subsection" "")
("insert subsubsection" "")
("insert sup" "")
("insert tan" "")
("insert tanh" "")
("insert text field" "")
("insert thick horizontal space" "")
("insert title" "")
("insert value" "")
("interactive command" "")
("interfacing" "インターフェース")
("interfacing TeXmacs with other systems" "")
("interjection" "")
("interline separation" "")
("interline space" "")
("internationalization" "")
("interparagraph space" "")
("interrupt execution" "")
("introduction" "")
("invisible" "")
("invisible citation" "")
("irish" "")
("is running" "")
("is tuple" "")
("ispell does not respond" "")
("ispell is already busy" "")
("italian" "イタリア語")
("italic" "")
("italic right" "")
("itemize" "箇条書き")
("january" "")
("japanese" "日本語")
("july" "")
("june" "")
("justified" "")
("justify text" "")
("key" "")
("keyboard" "キーボード")
("keyboard equivalent" "")
("keyboard modifiers" "")
("keyboard shorthand" "")
("keymaps" "")
("keyword" "キーワード")
("keywords" "キーワード達")
("kill" "")
("known bugs" "")
("label" "ラベル")
("landscape" "")
("language" "言語")
("large" "")
("large closing bracket" "")
("large delimiter" "")
("large opening bracket" "")
("large separator" "")
("last page" "")
("latex command" "")
("latin" "")
("layout" "")
("left" "")
("left arrow" "")
("left border" "左の端")
("left cell border" "")
("left cell padding" "")
("left margin" "左余白")
("left padding" "")
("left prime" "")
("left aligned" "")
("left slanted" "")
("left subscript" "")
("left superscript" "")
("left surrounding" "")
("left table border" "")
("left table padding" "")
("legal" "")
("lemma" "補題")
("length" "")
("less" "")
("less or equal" "")
("letter" "手紙")
("license" "")
("light" "")
("light grey" "")
("limitations" "")
("limits" "")
("line" "")
("line break" "")
("line stretch" "")
("link" "リンク")
("link image" "")
("list" "")
("list of figures" "図一覧")
("list of tables" "表一覧")
("load" "読み込み")
("load LaTeX file" "LaTeXファイルを読み込む")
("load TeX file" "TeXファイルを読み込む")
("load TeXmacs file" "TeXmacsファイルを読み込む")
("load TeXmacs style file" "")
("load a file" "")
("load buffer" "")
("load file" "ファイルを読み込む")
("load html file" "HTMLファイルを読み込む")
("load image" "")
("load in new window" "")
("load latex file" "LaTeXファイルを読み込む")
("load more recent autosave file" "もっと最近の自動保存されたファイルを読込む")
("load tex file" "TeXファイルを読込む")
("load verbatim file" "")
("loaded" "")
("long" "")
("look and feel" "")
("look up" "")
("lower border" "下の端")
("m modifier" "")
("macro" "")
("magenta" "")
("magic" "")
("magnification" "拡大率")
("magnified" "")
("main" "")
("main icon bar" "主アイコンバー")
("major changes" "")
("make a page insertion" "")
("make a subscript" "")
("make a superscript" "")
("make acute" "")
("make bar" "")
("make check" "")
("make fraction" "")
("make grave" "")
("make hat" "")
("make label" "")
("make negation" "")
("make page reference" "")
("make reference" "")
("make square root" "")
("make tilde" "")
("make title" "題名作成")
("make vector" "")
("making donations" "")
("manual" "説明書")
("map to" "")
("march" "")
("margins" "余白(マージン)")
("margins as on paper" "")
("master" "")
("master file" "")
("math" "")
("math font" "")
("math font family" "")
("math font series" "")
("math font shape" "")
("mathematical" "")
("mathematical and customized input" "")
("mathematical font" "")
("mathematical formulas" "")
("mathematical input" "")
("mathematical typesetting" "")
("mathematics" "数学")
("matrix" "行列")
("maximal" "")
("maximal number of columns" "")
("maximal number of rows" "")
("maximum mode" "")
("may" "")
("medium" "")
("medium skip" "")
("meminfo" "")
("merge" "")
("messy" "")
("meta key" "")
("middle" "")
("minimal" "")
("minimal number of columns" "")
("minimal number of rows" "")
("minimum mode" "")
("minus" "")
("miscellaneous" "")
("miscellaneous features" "")
("mod" "")
("mode" "")
("modifier" "")
("modify cell alignment" "")
("modify cell border" "")
("modify cell padding" "")
("modify cell size" "")
("modify table border" "")
("modify table padding" "")
("mongolian" "")
("more information about GNU TeXmacs can be found in the Help" "ヘルプをご覧になればより詳しい使い方をご覧になれます")
("mosaic" "")
("move down" "")
("move object" "")
("move to the right when finished" "")
("move up" "")
("multiline input" "")
("mutator tags" "")
("my documents" "")
("n-th" "")
("n-th root" "")
("name" "名前")
("negation" "")
("new" "新規作成")
("new buffer" "")
("new column" "")
("new double page" "")
("new double page before" "")
("new item" "新しい箇条書きの要素")
("new line" "")
("new number" "")
("new page" "")
("new page before" "")
("new paragraph" "")
("new roman" "")
("new row" "")
("new table" "")
("next" "")
("next line" "")
("no" "いいえ")
("no changes need to be saved" "保存が必要な変更ありません")
("no dictionary for" "")
("no first indentation" "")
("no indentation" "")
("no line break" "")
("no matches found" "")
("no matches found for" "")
("no more matches for" "")
("no more redo information available" "")
("no more undo information available" "")
("no name" "")
("no page break after" "")
("no page break before" "")
("no spelling errors found in text" "")
("no style" "")
("none" "")
("normal" "")
("norwegian" "")
("not" "")
("not equal" "")
("not found" "")
("notation" "記法")
("note" "ノート")
("november" "")
("number" "")
("number of columns" "列の数")
("number equation" "")
("numbered equation" "")
("numbered equations" "")
("numerator" "分子")
("numeric" "")
("objectives" "")
("occurrences" "")
("october" "")
("odd page footer" "")
("odd page header" "")
("odd page margin" "")
("odd page left margin" "")
("odd page right margin" "")
("odd page shift" "")
("odd page text" "")
("off" "")
("ok" "いいですよ(OK)")
("old english" "")
("old slavonic" "")
("old style" "")
("on" "")
("on cells" "")
("on columns" "")
("on entire table" "")
("on rows" "")
("one spelling error has been corrected" "")
("online documentation" "")
("online help" "オンラインのヘルプ")
("only inline tags" "")
("open" "")
("open a new buffer" "")
("open new window" "新しいウインドーを開く")
("opening" "")
("operation on named selection" "")
("operation on primary selection" "")
("operation on secondary selection" "")
("operation on ternary selection" "")
("optical" "")
("option" "")
("options" "")
("or" "")
("orange" "")
("orientation" "")
("origin" "")
("original welcome message" "")
("other" "他の")
("other pages" "")
("other projects" "")
("other style" "")
("outlined roman" "")
("over" "")
("overbrace" "")
("overline" "")
("padding" "")
("page" "頁")
("page bottom margin" "")
("page break" "")
("page break before" "")
("page height" "")
("page insertion" "")
("page layout" "")
("page number text" "")
("page numbering" "")
("page reference" "")
("page right margin" "")
("page setup" "ページの設定")
("page top margin" "")
("page type" "")
("page width" "")
("paper" "")
("paper type" "")
("papyrus" "")
("paragraph" "段落")
("paragraph mode" "")
("paragraph width" "")
("part" "部分")
("past changes" "")
("paste" "貼る")
("paste from" "以下から貼る")
("paste text" "")
("path" "")
("perform operations on cells" "")
("perform operations on columns" "")
("perform operations on entire table" "")
("perform operations on rows" "")
("permanent" "")
("person" "")
("personal dictionary has been modified" "")
("phantasy" "")
("philosophy" "")
("phoenician" "")
("phonetic" "")
("pink" "")
("plain block" "")
("plain tabular" "")
("planned changes" "")
("plans for the future" "")
("please" "")
("please wait" "おまち下さい")
("plugin" "")
("plugins" "")
("plus" "")
("polish" "ポーランド語")
("porting TeXmacs to other platforms" "")
("portrait" "")
("portuguese" "ポルトガル語")
("position" "")
("position float" "")
("position floating object" "")
("position the table" "")
("postscript" "")
("postscript image" "")
("pre-alpha release" "")
("preamble" "")
("preamble mode" "")
("preferences" "設定(preferences)")
("presentation" "発表")
("presentation mode" "")
("presentation tag" "発表用の印")
("preview before printing" "")
("preview command" "")
("preview with ghostview" "")
("previous" "")
("primary" "")
("prime" "")
("print" "印刷")
("print all" "")
("print all to file" "")
("print page selection" "")
("print page selection to file" "")
("print to postscript file" "")
("printer" "")
("printer dpi" "")
("printing command" "")
("problem" "問題")
("professional" "")
("prog" "")
("prog font" "")
("prog font family" "")
("prog font series" "")
("prog font shape" "")
("program" "")
("program font" "")
("program mode" "")
("programming" "")
("progressive" "")
("project" "")
("projects" "プロジェクト")
("prologue" "")
("prompt on scripts" "")
("prompts and default input" "")
("proof" "証明")
("proportional" "")
("proportional typewriter" "")
("proposition" "命題")
("query replace" "")
("quit" "")
("quotation" "引用")
("quote" "")
("range" "")
("really close it" "")
("really huge" "")
("really quit" "")
("recover autosave file" "自動保存のファイルを復元")
("red" "")
("redo" "もう一度やる")
("redo undone changes" "")
("reduce bottom margin by" "")
("reduce left margin by" "")
("reduce margins" "")
("reduce right margin by" "")
("reduce top margin by" "")
("reduction even page margin" "")
("reduction odd page margin" "")
("reduction page bottom margin" "")
("reduction page right margin" "")
("reduction page top margin" "")
("reference" "参照")
("reference guide" "詳細説明")
("reference guide for the TeXmacs primitives" "")
("reference guide for the standard TeXmacs styles" "")
("references" "")
("regular" "")
("release" "")
("reload" "")
("remark" "注意")
("remove all output fields" "")
("remove fields" "")
("remove input field" "")
("remove input field above" "")
("remove number" "")
("remove package" "パッケージを取り除く")
("remove this switch" "")
("renumber this page" "")
("repeat" "")
("repeat object" "")
("replace" "置換")
("replace by" "")
("replaced" "")
("replaced one occurrence" "")
("reset" "")
("resize object" "")
("resized" "")
("search results for" "")
("return" "")
("revert" "反対向")
("revert buffer" "")
("right" "")
("right arrow" "")
("right border" "右の端")
("right cell border" "")
("right cell padding" "")
("right margin" "右余白")
("right padding" "")
("right aligned" "")
("right subscript" "")
("right superscript" "")
("right surrounding" "")
("right table border" "")
("right table padding" "")
("rigid" "")
("rigid horizontal" "")
("rigid space" "")
("romanian" "ルーマニア語")
("root" "根")
("rotate backward" "")
("rotate forward" "")
("row" "")
("row contains glued items" "")
("runic" "")
("running author" "欄外著者名")
("running title" "欄外表題")
("russian" "ロシア語")
("sample" "")
("sans serif" "")
("save" "保存")
("save TeXmacs file" "")
("save TeXmacs style file" "")
("save as" "名前をつけて保存")
("save as LaTeX" "LaTeXとして保存")
("save as TeX" "TeXとして保存")
("save buffer" "バッファ(作業領域)を保存")
("save buffer as" "バッファ(作業領域)を名前を付けて保存")
("save file" "ファイルを保存")
("save html file" "htmlファイルを保存")
("save image" "イメージを保存")
("save latex file" "LaTeXファイルを保存")
("save tex file" "TeXファイルを保存")
("save this buffer" "このバッファ(作業領域)を保存")
("save verbatim file" "")
("saved" "保存(書き込み)完了")
("scheme command" "")
("screen layout" "")
("screen margins" "")
("script" "")
("script above" "")
("script below" "")
("script script size" "")
("script size" "")
("scripts not accepted" "")
("search" "探索")
("search words in my documents" "")
("search words in the documentation" "")
("search words in the source code" "")
("searching" "")
("secondary" "")
("section" "節")
("security" "")
("see" "")
("select a document style" "")
("select a foreground color" "")
("select a language" "")
("selected region" "")
("selection" "")
("selections" "選択")
("seminar" "セミナー")
("sending commands to TeXmacs" "")
("separation between lines" "")
("separation between paragraphs" "")
("separator" "")
("september" "")
("serb" "")
("series" "列")
("series|right" "")
("session" "セッション")
("session name" "")
("session type" "")
("sessions" "")
("set" "")
("set background color of cell" "")
("set cell mode" "")
("set extension center" "")
("set height" "")
("set height of cell" "")
("set margins" "")
("set n" "")
("set or get environment variables" "")
("set paragraph margins" "")
("set paragraph mode" "")
("set printer dpi" "")
("set printing command" "")
("set span" "")
("set special cell properties" "")
("set special table properties" "")
("set text width" "")
("set width" "")
("set width of cell" "")
("settings" "")
("setup printer" "")
("shape" "")
("shift-down" "")
("shift-right" "")
("short" "")
("show" "")
("show header and footer" "")
("show hidden" "")
("show on screen" "")
("shrinking factor" "縮小率")
("signature" "")
("size" "")
("size limits" "")
("slanted" "")
("sloppy" "")
("slovene" "スロバキア語")
("small" "")
("small caps" "")
("small figure" "小さい図")
("small skip" "")
("small table" "")
("source code" "ソースコード")
("source tags" "")
("space" "空白")
("space between lines" "")
("space between paragraphs" "")
("spacing" "空白作成法")
("spanish" "スペイン語")
("special" "")
("special cell properties" "")
("special table properties" "")
("specific" "")
("spell" "綴り方")
("spell checking complete" "")
("spelling error" "")
("spelling errors have been corrected" "")
("split" "")
("split session" "")
("square root" "平方根")
("standard environment variables" "")
("standard formats" "")
("standard TeXmacs styles" "")
("start" "開始")
("start a new chapter" "")
("start a new section" "")
("start an interactive session" "")
("status bar" "状態バー")
("stretch" "")
("stretchable" "")
("stretchable horizontal" "")
("stretchable vertical" "")
("stretched" "")
("stroke" "")
("strokes" "")
("strong" "")
("structural" "")
("style" "スタイル")
("styles" "")
("stylesheet language" "")
("sub" "")
("subparagraph" "小段落")
("subscript" "下添字")
("subsection" "小節(sub)")
("subsub" "")
("subsubsection" "小小節(subsub)")
("subtitle" "")
("summary" "")
("summary of the principal TeXmacs tags" "")
("superpose" "")
("superposed" "")
("superscript" "上添字")
("swedish" "スエーデン語")
("swiss" "")
("switch" "")
("switch to first" "")
("switch to formula style" "")
("switch to last" "")
("switch to next" "")
("switch to previous" "")
("switching and folding" "")
("symbol" "")
("system command" "")
("system environment variables" "")
("tab" "")
("table" "表")
("table command" "")
("table of contents" "目次")
("tables" "")
("tabular" "")
("tabular material" "")
("teXmacs as an interface" "")
("teXmacs fonts" "")
("teXmacs notice" "TeXmacsからのお知らせ")
("teXmacs plugins" "")
("teXmacs style files" "")
("ternary" "")
("test" "")
("tex" "")
("text" "文書")
("text font" "")
("text height correction" "")
("text width" "")
("texts" "文書達")
("th century bc" "")
("th root" "")
("thai" "")
("the TeXmacs authors" "")
("the TeXmacs format" "")
("the application did not send its usual startup banner" "")
("the application does not reply" "")
("the application is already running" "")
("the boxes produced by the typesetter" "")
("the document has not been saved" "バッファ(作業領域)はまだ保存されていません")
("the graphical user interface" "")
("the leaves of TeXmacs trees" "")
("the mycas example" "")
("the primitive TeXmacs constructs" "")
("the standard TeXmacs styles" "")
("theorem" "定理")
("there are unsaved documents" "保存されていないファイルがあります")
("this document has not been saved" "このバッファ(作業領域)はまだ保存されていません")
("this document has been produced using" "この文書は次を用いて作成されました")
("this line" "")
("this page" "")
("this page footer" "")
("this page header" "")
("tilda" "")
("tilde" "チルダー")
("times" "")
("tiny" "")
("title" "題名")
("to the left" "")
("to the right" "")
("today" "本日")
("tools" "道具")
("top" "")
("top border" "")
("top cell border" "")
("top cell padding" "")
("top level" "")
("top margin" "")
("top padding" "")
("top table border" "")
("top table padding" "")
("translate" "")
("tree" "")
("tuple" "")
("turkish" "")
("tutorial" "入門的説明")
("type" "")
("type a latex command followed by" "")
("type body" "")
("type denominator" "")
("type numerator" "")
("type script" "")
("typesetted boxes" "")
("typewriter" "")
("typewriter small caps" "")
("typing a simple text" "")
("typing simple texts" "")
("ugaritic" "")
("ukrainian" "ウクライナ語")
("underbrace" "")
("underline" "")
("undo" "やりなおす(undo)")
("undo last changes" "")
("up" "")
("update" "更新")
("update from web" "")
("update image links" "")
("upper border" "上の端")
("upright" "")
("use TeXmacs" "")
("use a black color" "")
("use a blue color" "")
("use a bold font" "")
("use a brown color" "")
("use a calligraphic font" "")
("use a green color" "")
("use a grey color" "")
("use a magenta color" "")
("use a orange color" "")
("use a pink color" "")
("use a red color" "")
("use a sans serif font" "")
("use a typewriter font" "")
("use a white color" "")
("use a yellow color" "")
("use blackboard bold font" "")
("use bold font series" "")
("use calligraphical font" "")
("use footnote font size" "")
("use fraktur font" "")
("use huge font size" "")
("use italic font shape" "")
("use large font size" "")
("use left hand column as border" "")
("use medium font series" "")
("use normal font size" "")
("use package" "")
("use paragraph width" "")
("use really huge font size" "")
("use right font shape" "")
("use right hand column as border" "")
("use roman font family" "")
("use row above as border" "")
("use row below as border" "")
("use sans serif font family" "")
("use script font size" "")
("use slanted font shape" "")
("use small capitals" "")
("use small font size" "")
("use small-caps font shape" "")
("use the blackboard bold font" "")
("use the fraktur font" "")
("use tiny font font size" "")
("use typewriter font family" "")
("use very large font size" "")
("user manual" "")
("user provided icons" "ユーザ提供アイコン")
("users of Cyrillic languages" "")
("value" "")
("variable" "")
("variant" "種類")
("vector" "")
("verbatim" "そのまま(verbatim)")
("verse" "韻文")
("vertical" "")
("vertical after" "")
("vertical before" "")
("vertical cell alignment" "")
("vertical part" "")
("vertical position" "")
("vertical space" "")
("vertical table alignment" "")
("vertically align cell to the base" "")
("vertically center the cell" "")
("very large" "")
("very small" "")
("vietnamese" "")
("view" "みえ方")
("visible" "")
("warning" "警告")
("web" "ウエブ(電網)")
("welcome" "ご挨拶")
("welcome to GNU TeXmacs" "GNU TeXmacs の世界へようこそ")
("what is new" "")
("when finished" "")
("while" "")
("white" "")
("wide accent" "広いアクセント")
("wide bar" "")
("width" "幅")
("width is exactly the specified width" "")
("width is maximum of specified width and box width" "")
("width is minimum of specified width and box width" "")
("width magnification" "")
("window" "")
("window height" "")
("window width" "")
("windows key" "")
("with" "")
("write a macro" "")
("write a name" "")
("write bold mathematics" "")
("write bold text" "")
("write italic text" "")
("write sample text" "")
("write strong text" "")
("write typewriter text" "")
("write verbatim text" "")
("writing data converters" "")
("writing your own style files" "")
("written with TeXmacs" "TeXmacsで書かれています")
("yellow" "黄色")
("yes" "はい")
("you can also obtain" "")
("your document is back in its original state" "")
("your first interface" "")
("your language" "")
