("\"encryption\" features from the preference panel" "\"funkce ˛ifrování\" z panelu preferencí")
("(Re)Build autocompletion index" "(Re) Vytvo°ení indexu automatického dopl¬ování")
("a modifier" "modifikátor")
("a series" "série")
("a.C.M. computing class" "a.C.M. výpoŁetní t°ída")
("a.M.S. subject class" "a.M.S. p°edmĄtová t°ída")
("abbreviated authors" "zkrácených autor·")
("abreviated authors" "zkrácených autor·")
("accent above" "p°ízvuk vý˛e")
("accent below" "p°ízvuk níşe")
("accept during this pass" "p°ijmout bĄhem tohoto pr·chodu")
("acknowledgments" "potvrzení")
("activate hidden" "aktivovat skryté")
("activate once" "aktivovat jednou")
("activation" "aktivace")
("active link types" "aktivních typ· odkaz·")
("add" "p°idat")
("add abstract information" "p°idat abstraktní informace")
("add author information" "p°idat informace o autorovi")
("add branch after" "p°idat vĄtev po")
("add branch before" "p°idat vĄtve p°ed")
("add other package" "p°idat dal˛í balíŁek")
("add package" "p°idat balíŁek")
("add style package" "p°idat balíŁek styl·")
("add title information" "p°idat informace o názvu")
("addition" "sŁítání")
("adjust" "upravit")
("adjust limits" "upravit limity")
("advanced font customization" "pokroŁilé úpravy písma")
("affiliation" "p°idruşení")
("align cell to the decimal comma" "zarovnat bu¬ku s desetinnou Łárkou")
("align cell to the decimal dot" "zarovnat bu¬ku s desetinnou teŁkou")
("align table at axis" "zarovnat tabulku na ose")
("aligned" "zarovnáno")
("alignment of balloon" "zarovnání balónu")
("all cells" "v˛echny bu¬ky")
("all data attached to this identity will be lost" "v˛echna data p°ipojená k této identitĄ budou ztracena")
("all saved passphrases will be lost forever" "v˛echny uloşené p°ístupové fráze budou navşdy ztraceny")
("allow for macro definitions in preamble" "umoş¬ují definice maker v preambuli")
("allowed page height extension" "povolené roz˛í°ení o vý˛ku stránky")
("allowed page height reduction" "povolené sníşení vý˛ky stránky")
("allowed positions" "povolených pozic")
("allowed positions of floating object" "povolené polohy plovoucího objektu")
("alpha transparency" "alfa pr·hlednost")
("also on paper" "také na papí°e")
("alter" "zmĄnit")
("alternate" "alternativní")
("alternate except here" "s výjimkou zde")
("alternate from here on" "st°ídavĄ odtud")
("alternate only here" "pouze zde")
("alternate until here" "aş dosud")
("alternative specification" "alternativní specifikace")
("always" "vşdy")
("american" "americký")
("amplified" "zesíleno")
("and perform casual settings from the \"Encryption\" tab" "a prove¤te náhodná nastavení na kartĄ \"˛ifrování\"")
("angular" "úhlové")
("animate" "animovat")
("animate folding" "skládací animace")
("animate unfolding" "rozvíjející se animace")
("animated" "animovaných")
("animation" "animace")
("animation toolbar" "panel nástroj· pro animaci")
("annotate" "anotovat")
("answer" "odpovĄ¤")
("answer field" "pole odpovĄdi")
("answer to question" "odpovĄ¤ na otázku")
("answers only" "Pouze odpovĄdí")
("any" "libovolných")
("appear" "Objeví se")
("apply macro" "pouşít makro")
("apply macro once" "pouşít makro jednou")
("approximate" "p°iblişná")
("arc" "oblouk")
("arc cosine" "arc cosine")
("arc sine" "arc sine")
("arc tangent" "arc tangens")
("arch series" "oblouková °ada")
("are you sure you want to delete collected public keys" "Opravdu chcete smazat shromáşdĄné ve°ejné klíŁe")
("are you sure you want to delete selected public keys" "jste si jisti, şe chcete smazat vybrané ve°ejné klíŁe")
("are you sure you want to delete selected secret keys" "Opravdu chcete smazat vybrané tajné klíŁe")
("are you sure you want to destroy the wallet" "jste si jisti, şe chcete zniŁit penĄşenku")
("art frame" "umĄleckých rám·")
("arxiv category" "kategorie arxiv")
("as visual grid" "jako vizuální m°íşka")
("aspect" "aspekt")
("attach master" "p°ipojit master")
("auto" "auto")
("auto-save file" "automaticky ukládat soubor")
("automatic brackets" "automatických závorek")
("automatic content generation" "automatické generování obsahu")
("automatic program brackets" "automatické programové závorky")
("automatic quotes" "automatických nabídek")
("automatically close brackets" "automaticky zav°ít závorky")
("automatically import bibliographies when opening files" "automaticky importovat bibliografie p°i otevírání soubor·")
("automatically remember all passphrases in the wallet" "automaticky si pamatuje v˛echna p°ístupová fráze v penĄşence")
("automatically save" "automaticky uloşit")
("autosave" "automatické ukládání")
("axis" "osa")
("b series" "Série b")
("back" "zpĄt")
("background evaluations" "hodnocení pozadí")
("backtrace errors" "chyb zpĄtného sledování")
("base" "základna")
("baseline" "základní linie")
("basic communication using pipes" "základní komunikace pomocí potrubí")
("beamer" "beamer")
("beamer formats" "beamer formát·")
("beamer theme" "beamerové téma")
("bench" "lavice")
("bend bottom" "ohnuté dno")
("bend corner" "roh ohybu")
("bend diagonal" "úhlop°íŁka")
("bend in" "ohyb")
("bend out" "ohnout")
("bezier" "bezier")
("bibTeX command" "p°íkaz bibTeX")
("bidirectional" "obousmĄrný")
("big environment box" "velký environmentální box")
("big focus" "velké zamĄ°ení")
("binary operator" "binární operátor")
("bitmap resolution (dpi)" "bitmapové rozli˛ení (dpi)")
("black floral I" "Łerné kvĄtinové I")
("black floral II" "Łerný kvĄtinový II")
("blackboard embold" "tabule se vyklopí")
("blank column" "prázdný sloupec")
("blank row" "prázdný °ádek")
("block" "blok")
("block content" "obsah bloku")
("block of code" "blok kódu")
("blur" "rozmazání")
("both versions" "obĄ verze")
("bottom baseline" "spodní základní linie")
("bottom cell border" "dolní hranice bu¬ky")
("bottom cell padding" "výpl¬ spodní bu¬ky")
("bottom table border" "dolní okraj tabulky")
("bottom table padding" "výpl¬ spodní tabulky")
("bottom tools" "spodních nástroj·")
("box" "krabiŁka")
("broken white" "zlomená bílá")
("browse back" "procházet zpĄt")
("browse forward" "procházet vp°ed")
("browse modules documentation" "dokumentace k procházení modul·")
("buffer management" "správa vyrovnávacích pamĄtí")
("buffer must be on disk" "buffer musí být na disku")
("buffer must have a name" "buffer musí mít jméno")
("build buffer" "build buffer")
("build buffer in" "build buffer in")
("build directory" "build directory")
("build directory in" "build directory in")
("build link pages" "vytvo°it odkazové stránky")
("build-all" "build-all")
("bump" "rána")
("busy" "zaneprázdnĄn")
("cJK" "cJK")
("cJK spacing" "mezery cJK")
("calculus" "poŁet")
("cancelled" "zru˛eno")
("cannot download directory to file" "nelze stáhnout adresá° do souboru")
("cannot rename across different servers" "nelze p°ejmenovat na r·zných serverech")
("cannot upload directory to file" "nelze nahrát adresá° do souboru")
("cartesian" "karteziánský")
("carved wood" "vy°ezávané d°evo")
("case-insensitive search" "vyhledávání bez rozli˛ování velkých a malých písmen")
("categories" "kategorií")
("category" "kategorie")
("cell properties" "vlastností bunĄk")
("cells" "bunĄk")
("change default unit" "zmĄnit výchozí jednotku")
("change passphrase" "zmĄnit p°ístupové fráze")
("change step-size" "zmĄnit velikost kroku")
("change tags" "zmĄnit znaŁky")
("change the TeXmacs preferences" "zmĄnit p°edvolby TeXmacs")
("change the border of the table" "zmĄnit okraj tabulky")
("change the style of mathematical formulas" "zmĄnit styl matematických vzorc·")
("character contraction" "kontrakce znak·")
("character encoding" "kódování znak·")
("character expansion" "roz˛í°ení znak·")
("check for updates" "zkontrolovat aktualizace")
("checkable field" "za˛krtnutelné pole")
("cipher algorithm for passphrase encryption" "˛ifrovací algoritmus pro ˛ifrování heslem")
("circle" "kruh")
("classification" "klasifikace")
("clean slate" "Łistá b°idlice")
("clear all fields" "vymazat v˛echna pole")
("clear local information" "jasné místní informace")
("clear menu" "jasné menu")
("clear undo history" "vymazat historii zpĄt")
("click Ok button twice to discard this warning" "dvojitým kliknutím na tlaŁítko OK toto varování zru˛íte")
("clip" "klip")
("clipboard image format" "formát obrazu schránky")
("close animation tool" "nástroj pro blízkou animaci")
("close document" "blízký dokument")
("close program" "blízký program")
("close replace tool" "nástroj pro výmĄnu zav°ít")
("close search tool" "nástroj pro blízké vyhledávání")
("close spell tool" "nástroj pro blízké kouzlo")
("close translations to rebuild" "úzkých p°eklad· k p°estavbĄ")
("closed bezier" "uzav°ený bezier")
("closed curve" "uzav°ená k°ivka")
("closed smooth" "uzav°eno hladce")
("closed spline" "uzav°ená spline")
("closing style" "uzavírací styl")
("cluster by affiliation" "seskupení podle p°idruşení")
("collect garbage" "sbírat odpadky")
("color of the axes" "barva os")
("color of the subunits" "barva podjednotek")
("color of the units" "barva jednotek")
("colors" "barev")
("column to the left" "sloupec vlevo")
("column to the right" "sloupec vpravo")
("columns" "sloupc·")
("column separation" "oddĄlení sloupc·")
("commit file" "soubor odevzdání")
("common" "spoleŁných")
("common formats" "bĄşné formáty")
("commutative diagram" "komutativní diagram")
("compact" "kompaktních")
("compactification" "kompaktizace")
("compactify" "kompaktizovat")
("complete bibliographic reference" "úplný bibliografický odkaz")
("completion" "dokonŁení")
("complex actions" "sloşitých akcí")
("compose" "sloşit")
("compound" "slouŁenina")
("compress" "komprimovat")
("compress into toolbar" "komprimovat do panelu nástroj·")
("compressed" "komprimováno")
("conceal" "skrytí")
("configure look and feel" "Konfigurovat vzhled a dojem")
("confirm database entry" "potvrzení zadání databáze")
("confirm entry" "potvrzení zadání")
("confirm selected database entries" "potvrdit vybrané poloşky databáze")
("confirm selected entries" "potvrdit vybrané poloşky")
("conservative conversion options" "konzervativní moşnosti p°evodu")
("consoles" "konzolí")
("constellation" "souhvĄzdí")
("contact" "kontakt")
("content" "obsahu")
("context aids" "kontextové pom·cky")
("contextual hints" "kontextové rady")
("continue" "pokraŁovat")
("continued fraction" "pokraŁující zlomek")
("contour" "obrys")
("contract logarithms" "smluvní logaritmy")
("contribute" "p°ispĄt")
("control flow" "°ídicí tok")
("control the evaluation of expressions" "kontrola vyhodnocování výraz·")
("convert" "konverzí")
("converters" "p°evodník·")
("convertible" "konvertibilní")
("copyright" "autorských práv")
("cork charset with TeX catcode definition in preamble" "korek s znakem TeX catcode v preambuli")
("correct" "správný")
("correct all" "opravit v˛e")
("correct formula" "správný vzorec")
("correct manually" "ruŁnĄ opravit")
("correct mathematical formulas" "správné matematické vzorce")
("correction" "korekce")
("cosine" "kosinus")
("count characters" "poŁet znak·")
("count lines" "poŁet °ádk·")
("count words" "poŁet slov")
("create a new document" "vytvo°it nový dokument")
("create link" "vytvo°it odkaz")
("create preamble" "vytvo°it preambuli")
("create remote directory" "vytvo°it vzdálený adresá°")
("create remote file" "vytvo°it vzdálený soubor")
("create subprogram" "vytvo°it podprogram")
("create subsession" "vytvo°it odbĄr")
("create table macro" "vytvo°it tabulkové makro")
("create web site" "vytvo°it web")
("creating new account" "vytvo°ení nového úŁtu")
("creating technical pictures" "vytvá°ení technických obrázk·")
("crop" "plodina")
("crop marks" "o°ezových znaŁek")
("cross" "k°íş")
("crossed boxes" "zk°íşených polí")
("crossed circles" "p°ek°íşených kruh·")
("current user version" "aktuální uşivatelská verze")
("current version" "aktuální verze")
("cursor" "kurzor")
("curve" "k°ivka")
("curve intersections" "k°işovatek k°ivek")
("curve points" "bod· k°ivky")
("customizations" "p°izp·sobení")
("customizing and extending the user interface" "p°izp·sobení a roz˛í°ení uşivatelského rozhraní")
("dark grey" "tmavĄ ˛edá")
("data" "dat")
("database entry" "poloşka databáze")
("database tool" "databázový nástroj")
("database toolbar" "panel nástroj· databáze")
("deactivate once" "deaktivovat jednou")
("dead" "mrtvých")
("debug" "ladĄní")
("debugging console" "ladicí konzole")
("debugging tool" "nástroj pro ladĄní")
("decimal comma" "desetinná Łárka")
("decimal dot" "desetinná teŁka")
("decomposed" "rozloşeno")
("decorated" "zdobené")
("decorated wood" "zdobené d°evo")
("decrease size" "zmen˛it velikost")
("decrypt" "de˛ifrovat")
("default size" "výchozí velikost")
("degrade" "degradovat")
("degraded" "degradováno")
("delete documentation cache" "vymazat mezipamĄ´ dokumentace")
("delete entries" "smazat záznamy")
("delete link" "smazat odkaz")
("deleted" "smazáno")
("describe" "popsat")
("describe tag" "popsat znaŁku")
("destroy" "zniŁit")
("detach master" "odpojit master")
("detailed" "podrobnĄ")
("detailed menus" "podrobných nabídek")
("details in menus" "podrobnosti v nabídkách")
("determine margins from text width" "urŁit okraje od ˛í°ky textu")
("developer" "vývojá°")
("developer tool" "vývojový nástroj")
("device" "za°ízení")
("diamond" "diamant")
("differentiate" "rozli˛it")
("dilate" "dilate")
("direction of progression" "smĄr postupu")
("direction of translation" "smĄr p°ekladu")
("disable" "zakázat")
("disable coloring on paper" "zakázat barvení na papí°e")
("disable encryption" "zakázat ˛ifrování")
("disappear" "zmizí")
("disk" "disk")
("display style" "styl zobrazení")
("displayed formula" "zobrazený vzorec")
("dissociate joined cells" "disociovat spojené bu¬ky")
("distort" "zkreslení")
("distorted" "zkreslené")
("division" "divize")
("do not remap" "nemapovat")
("document font selector" "selektor písma dokumentu")
("document language" "jazyk dokumentu")
("document page format" "formát stránky dokumentu")
("document paragraph format" "formát odstavce dokumentu")
("document updates run" "spu˛tĄní aktualizace dokument·")
("download" "stáhnout")
("downwards" "dol·")
("dragging" "p°etaşení")
("draw image" "nakreslit obrázek")
("draw over" "losování")
("draw over selection" "výbĄr p°es výbĄr")
("drop" "kapka")
("due to" "kv·li")
("dynamic" "dynamický")
("eRROR" "eRROR")
("edit animation" "upravit animaci")
("edit groups of objects" "editovat skupiny objekt·")
("edit macro" "upravit makro")
("edit macros" "upravit makra")
("edit preamble" "upravit preambuli")
("edit source" "upravit zdroj")
("edit source tree" "Upravit zdrojový strom")
("edit style" "styl úprav")
("edit translations file" "upravit p°ekladový soubor")
("education" "vzdĄlávání")
("effect pen" "efektové pero")
("eigenvalues" "vlastních Łísel")
("eighth" "osmý")
("embold" "embold")
("emboss" "reliéf")
("enable page breaking" "povolit p°eru˛ení stránky")
("encoding" "kódování")
("encrypt" "˛ifrování")
("encryption" "˛ifrování")
("encryption facilities are not currently available" "˛ifrovací za°ízení v souŁasné dobĄ nejsou k dispozici")
("encryption facilities have not been enabled for TeXmacs" "˛ifrovací za°ízení nebyla pro TeXmacs povolena")
("enforce brackets to match" "vynutit závorky tak, aby odpovídaly")
("engrave" "rytina")
("enter data" "zadejte data")
("enter graphics" "zadejte grafiku")
("enter graphics mode" "vstoupit do grafického reşimu")
("enter new passphrase for encryption" "zadejte nové heslo pro ˛ifrování")
("enter passphrase for decryption" "zadejte heslo pro de˛ifrování")
("enter passphrase for identity" "zadejte heslo pro identifikaci")
("enter title information" "zadejte informace o názvu")
("entire table" "celá tabulka")
("entry up to date in database" "aktuální v databázi")
("enunciation" "výpovĄ¤")
("environment variable" "promĄnná prost°edí")
("environments" "prost°edí")
("erode" "erodování")
("error messages" "chybové zprávy")
("error output" "chybový výstup")
("error status report" "zpráva o stavu chyby")
("error: bracket does not match" "chyba: závorka se neshoduje")
("error: cyclic or missing chunks detected" "chyba: byly detekovány cyklické nebo chybĄjící kousky")
("error: file not found" "chyba: soubor nebyl nalezen")
("error: ghostview does not seem to be installed on your system" "chyba: Zdá se, şe ghostview není ve va˛em systému nainstalován")
("error: one of the alternatives should be filled out" "chyba: mĄla by být vyplnĄna jedna z alternativ")
("error: only one alternatives should be filled out" "chyba: mĄla by být vyplnĄna pouze jedna alternativa")
("error: should fill out name for referencing" "chyba: mĄl by být uveden název pro odkazování")
("error: should fill out required field" "chyba: mĄlo by být vyplnĄno povinné pole")
("evaluable field" "hodnotitelné pole")
("evaluate above" "vyhodnotit vý˛e")
("evaluate all" "vyhodnotit v˛e")
("evaluate below" "vyhodnotit níşe")
("evaluate fields" "vyhodnotit pole")
("evaluate fields in order" "vyhodnotit pole v po°ádku")
("evaluate script" "vyhodnotit skript")
("evaluation" "hodnocení")
("evaluation switch" "vyhodnocovací p°epínaŁ")
("evaluation tag" "hodnotící znaŁka")
("even page" "sudá stránka")
("even page left margin" "levý okraj sudé stránky")
("even page shift" "rovnomĄrný posun stránky")
("even pages" "sudých stránek")
("events" "událostí")
("exact" "p°esných")
("execution of scripts" "provádĄní skript·")
("exit graphics" "výstupní grafika")
("exit graphics mode" "ukonŁit grafický reşim")
("exit left" "vlevo")
("exit right" "výjezd vpravo")
("exit tag on the left" "výstupní znaŁka vlevo")
("exit tag on the right" "výstupní znaŁka vpravo")
("expand TeXmacs macros with no LaTeX equivalents" "roz˛í°it makra TeXmacs bez ekvivalent· LaTeX")
("expand beamer slides" "roz˛í°it ˛mýkaŁky")
("expand inclusions" "roz˛í°it inkluze")
("expand logarithms" "rozbalte logaritmy")
("expand trigonometric functions" "roz˛í°it trigonometrické funkce")
("expand unrecognized macros" "rozbalení nerozpoznaných maker")
("expand user-defined macros" "rozbalte uşivatelská makra")
("expanded" "roz˛í°eno")
("experimental features (to be used with care)" "experimentální funkce (je t°eba pouşívat opatrnĄ)")
("explain" "vysvĄtlit")
("explanatory item" "vysvĄtlující poloşka")
("explicit keystroke" "explicitní stisknutí klávesy")
("explicit margins" "explicitní marşe")
("exponential" "exponenciální")
("export bibliographies as links" "exportovat bibliografie jako odkazy")
("export bibliography" "exportní bibliografie")
("export entries in buffer" "exportovat poloşky do vyrovnávací pamĄti")
("export file" "exportní soubor")
("export formulas as images" "exportovat vzorce jako obrázky")
("export mathematical formulas as MathML" "exportovat matematické vzorce jako MathML")
("export mathematical formulas as images" "exportovat matematické vzorce jako obrázky")
("export selected entries" "exportovat vybrané poloşky")
("export selection" "výbĄr exportu")
("export selection as image" "exportovat výbĄr jako obrázek")
("export selections as" "exportních výbĄr· jako")
("export sessions" "vývozních relací")
("exported bibliographic entries" "exportované bibliografické záznamy")
("exported bibliographic references" "exportované bibliografické odkazy")
("extend" "prodlouşit")
("extended" "roz˛í°eno")
("extensible left arrow" "roz˛i°itelná ˛ipka vlevo")
("extensible right arrow" "roz˛i°itelná pravá ˛ipka")
("extern" "vnĄ")
("external" "externí")
("extra branch" "zvlá˛tní vĄtev")
("extra interline space" "meziprostorový prostor")
("extra name" "extra jméno")
("extract" "extrakt")
("extract style file" "extrahovat soubor stylu")
("extract style package" "balíŁek styl· extrahování")
("factor" "faktor")
("fade" "vyblednutí")
("fade in" "vyblednutí")
("fade out" "vyblednutí")
("fast" "rychle")
("fast decrease" "rychlý pokles")
("fast environments" "rychlých prost°edí")
("fast increase" "rychlý nár·st")
("field reference" "reference na pole")
("fifth" "pátý")
("file saved" "soubor uloşen")
("fill color" "barva výplnĄ")
("fill out" "vyplnit")
("filter" "filtr")
("find file" "najít soubor")
("finished collecting symbols documentation" "dokumentace pro dokonŁení shromaş¤ování symbol·")
("first" "první")
("first chunk" "první kus")
("first difference" "první rozdíl")
("first error" "první chyba")
("first field" "první pole")
("first occurrence" "první výskyt")
("first similar" "první podobné")
("fit to screen" "p°izp·sobeno obrazovce")
("fit to screen width" "p°izp·sobeno ˛í°ce obrazovky")
("five columns" "pĄt sloupc·")
("fixed" "pevná")
("flag is off" "p°íznak je vypnutý")
("flag is on" "vlajka je zapnutá")
("flatten" "zplo˛tit")
("floating algorithm" "plovoucí algoritmus")
("floating phantom" "plovoucí fantom")
("focus" "zamĄ°ení")
("focus dependent icons" "ikon závislých na zaost°ení")
("fold all" "sloşit v˛e")
("fold all fields" "sloşit v˛echna pole")
("fold back" "záda zpĄt")
("fold input field" "sloşené vstupní pole")
("follow external links" "sledovat externí odkazy")
("follow inverse links" "sledovat inverzní odkazy")
("font effects" "fontové efekty")
("font selector" "selektor písma")
("font type" "typ písma")
("for each" "pro kaşdého")
("force reloading of translations" "vynucení p°ekladu p°eklad·")
("formatted and structured output" "formátovaný a strukturovaný výstup")
("formatting" "formátování")
("forward" "vp°ed")
("four columns" "Łty°i sloupce")
("four dots" "Łty°i teŁky")
("fourth" "Łtvrtý")
("fraktur" "fraktur")
("framed" "zarámováno")
("from" "z")
("from center" "od st°edu")
("front matter" "p°ední Łást")
("full" "plný")
("full author list" "úplný seznam autor·")
("full screen mode" "reşim celé obrazovky")
("functional" "funkŁní")
("gap" "mezera")
("garbage collection" "sbĄr odpadu")
("gaussian" "gaussian")
("gcd" "gcd")
("general" "obecnĄ")
("general note" "obecná poznámka")
("generated LaTeX document contains no errors" "vygenerovaný dokument LaTeX neobsahuje şádné chyby")
("generated field" "generované pole")
("geometry" "geometrie")
("get arity" "získat arity")
("get label" "získat ˛títek")
("get list with remote versions" "získat seznam se vzdálenými verzemi")
("glyphs" "glyf·")
("gnaw" "hlodat")
("gnawed" "nahlodaný")
("gnuPG command" "p°íkaz gnuPG")
("gnuPG error: buffer encryption failed" "chyba gnuPG: ˛ifrování vyrovnávací pamĄti selhalo")
("gnuPG error: cannot find suitable secret key to decrypt" "chyba gnuPG: nelze najít vhodný tajný klíŁ k de˛ifrování")
("gnuPG requires name and email to have at least 5 characters" "gnuPG vyşaduje, aby jméno a e-mail mĄly alespo¬ 5 znak·")
("go to anchor" "jít do kotvy")
("go to anchor or float" "jít na kotvu nebo plavat")
("go to anchor or footnote" "P°ejít na kotvu nebo poznámku pod Łarou")
("go to first similar tag" "p°ejít na první podobnou znaŁku")
("go to float" "go float")
("go to footnote" "p°ejdĄte na poznámku pod Łarou")
("go to last similar tag" "p°ejít na poslední podobnou znaŁku")
("go to next similar tag" "p°ejít na dal˛í podobnou znaŁku")
("go to previous similar tag" "p°ejít na p°edchozí podobnou znaŁku")
("go to section" "p°ejít do sekce")
("grain" "zrno")
("granite" "şula")
("graphical effects" "grafické efekty")
("graphical interface font scale" "mĄ°ítko písma grafického rozhraní")
("graphics" "grafika")
("graphics geometry" "grafická geometrie")
("graphics grids" "grafické sítĄ")
("greyed" "˛edĄ")
("grid" "m°íşka")
("grid curves" "m°íşkových k°ivek")
("grid points" "bod· sítĄ")
("grid-curve intersections" "pr·seŁíky k°ivek")
("group of objects" "skupina objekt·")
("group/ungroup" "skupina / ungroup")
("grouped" "seskupeno")
("guarantee transparent source tracking" "zaruŁit transparentní sledování zdroje")
("h modifier" "Modifikátor h")
("half wide" "nap·l ˛iroký")
("hand drawn" "ruŁnĄ kreslenou")
("headers" "záhlaví")
("hidden" "skrytých")
("history" "historie")
("homepage" "domovská stránka")
("homoglyph substitutions" "substituce homoglyf·")
("horizontal alignment" "vodorovné zarovnání")
("horizontal collapse distance" "vodorovná vzdálenost sbalení")
("horizontal margins" "vodorovné okraje")
("hybrid command" "hybridní p°íkaz")
("hyphenate as" "spojovník jako")
("icon" "ikona")
("if hyphenated" "je-li spojovník")
("ignore" "ignorovat")
("impact" "dopad")
("import bibliography" "import bibliografie")
("import database entry" "import databáze")
("import entries in buffer" "importovat poloşky do vyrovnávací pamĄti")
("import entry" "poloşka importu")
("import file" "importovat soubor")
("import selected database entries" "importovat vybrané poloşky databáze")
("import selected entries" "importovat vybrané poloşky")
("import selections as" "importovat výbĄr jako")
("import sessions" "relací importu")
("import sophisticated objects as pictures" "importovat sofistikované objekty jako obrázky")
("imported bibliographic entries" "importované bibliografické záznamy")
("in popup windows" "ve vyskakovacích oknech")
("inanimated" "inanimated")
("inch" "palce")
("incomplete entries found to be filled out" "neúplné záznamy byly shledány vyplnĄny")
("increase size" "zvĄt˛it velikost")
("indent paragraphs" "odstavce odstavce")
("indentation" "odsazení")
("indication" "indikace")
("informative flags" "informativní vlajky")
("initialize" "inicializovat")
("ink here" "inkoust zde")
("ink in" "inkoust in")
("ink out" "inkoust do˛el")
("inline" "inline")
("inline arguments" "vloşené argumenty")
("inline code" "vloşený kód")
("inline content" "vloşený obsah")
("inline formula" "vloşený vzorec")
("inner bottom" "vnit°ní dno")
("inner left" "vnit°ní vlevo")
("inner right" "vnit°ní právo")
("inner top" "vnit°ní vrchol")
("input command" "vstupní p°íkaz")
("input field" "vstupní pole")
("input mode" "vstupní reşim")
("input options" "moşnosti zadávání")
("insert a computer program" "vloşení poŁítaŁového programu")
("insert a condition" "vloşte podmínku")
("insert a control flow instruction" "vloşení instrukce k regulaci toku")
("insert a gap" "vloşte mezeru")
("insert a list" "vloşit seznam")
("insert a multiple choice" "vloşte více moşností")
("insert a negation" "vloşte negaci")
("insert a new entry" "vloşit nový záznam")
("insert a note or a floating object" "vloşte poznámku nebo plovoucí objekt")
("insert a numerical operation" "vloşení Łíselné operace")
("insert a prominent piece of text" "vloşte výrazný text")
("insert a question" "vloşte otázku")
("insert a root" "vloşte ko°en")
("insert a script" "vloşit skript")
("insert a section block" "vloşit blok sekce")
("insert a textual operation" "vloşte textovou operaci")
("insert a textual operator" "vloşit textový operátor")
("insert a wide symbol above" "vloşte ˛iroký symbol vý˛e")
("insert a wide symbol below" "vloşte ˛iroký symbol níşe")
("insert above" "vloşit vý˛e")
("insert abstract" "vloşit abstrakt")
("insert an answer" "vloşte odpovĄ¤")
("insert an enunciation" "vloşit výpovĄ¤")
("insert an operation on tuples" "vloşení operace na n-tice")
("insert annotation" "vloşit anotaci")
("insert author" "vloşit autora")
("insert below" "vloşit níşe")
("insert copyright and license information" "vloşte informace o autorských právech a licencích")
("insert explanatory item" "vloşit vysvĄtlující poloşku")
("insert field above" "vloşte pole nad")
("insert field below" "vloşte pole níşe")
("insert fields" "vloşte pole")
("insert input field above" "vloşte vstupní pole vý˛e")
("insert input field below" "vloşte vstupní pole níşe")
("insert large delimiters" "vloşit velké oddĄlovaŁe")
("insert last name" "vloşte p°íjmení")
("insert left" "Vloşit vlevo")
("insert macro" "vloşit makro")
("insert missing invisible operators" "vloşte chybĄjící neviditelné operátory")
("insert more names" "vloşte více jmen")
("insert particle" "vloşit Łástici")
("insert plain text" "vloşit prostý text")
("insert right" "vloşit vpravo")
("insert similar above" "vloşit podobné vý˛e")
("insert similar below" "vloşit podobné níşe")
("insert similar block above" "vloşte podobný blok vý˛e")
("insert similar block below" "vloşte podobný blok níşe")
("insert subtable" "insert subtable")
("insert symbol documentation" "vloşit dokumentaci symbol·")
("insert template" "vloşit ˛ablonu")
("insert text field" "vloşte textové pole")
("insert text field above" "vloşte textové pole vý˛e")
("insert text field below" "vloşte textové pole níşe")
("insert title" "vloşte název")
("insert title after name" "vloşte název za název")
("insert user interface related markup" "vloşit oznaŁení související s uşivatelským rozhraním")
("insert value" "vloşená hodnota")
("inserting control points" "vkládání kontrolních bod·")
("integrate" "integrovat")
("interactive command" "interaktivní p°íkaz")
("interactive questions" "interaktivních otázek")
("intercharacter compression" "komprimace mezi znaky")
("intercharacter stretching" "intercharacter streching")
("interrupted" "p°eru˛eno")
("invalid multi-paragraph selection" "neplatný výbĄr z nĄkolika odstavc·")
("invalid renaming" "neplatné p°ejmenování")
("invert" "invertovat")
("inverted breve" "obrácená váha")
("invisible ending" "neviditelný konec")
("invisible newline" "neviditelný °ádek")
("invisible opening" "neviditelné otev°ení")
("join selected cells" "p°ipojit se k vybraným bu¬kám")
("jump in" "skoŁit")
("junior" "junior")
("keep evaluated expressions" "zachovat hodnocené výrazy")
("keep local" "udrşujte místní")
("keep remote" "udrşet dálku")
("keep track of source code" "sledovat zdrojový kód")
("keep unfolded" "stále se rozvíjí")
("keyboard configuration" "konfigurace klávesnice")
("laptop presentations" "prezentací v notebooku")
("large cells" "velkých bunĄk")
("large displayed" "zobrazováno ve velkém")
("large displayed fraction" "velká zobrazená frakce")
("large tables" "velkých stol·")
("last" "poslední")
("last difference" "poslední rozdíl")
("last error" "poslední chyba")
("last field" "poslední pole")
("last name" "p°íjmení")
("last occurrence" "poslední výskyt")
("last similar" "last like")
("lcm" "lcm")
("left arrow" "˛ipka vlevo")
("left axis" "levá osa")
("left baseline" "levá základní linie")
("left bottom" "vlevo dole")
("left cell border" "levý okraj bu¬ky")
("left cell padding" "výpl¬ levé bu¬ky")
("left center" "vlevo uprost°ed")
("left click: add point; Right click: undo" "kliknĄte levým tlaŁítkem: p°idat bod; pravé kliknutí: vrátit zpĄt")
("left click: finish; Right click: undo" "levé kliknutí: dokonŁení; pravé kliknutí: zpĄt")
("left click: new object" "levé kliknutí: nový objekt")
("left click: operate" "kliknutí levým tlaŁítkem: ovládání")
("left down" "vlevo dol·")
("left on even pages" "zbývá na sudých stránkách")
("left table border" "levý okraj tabulky")
("left table padding" "výpl¬ levého stolu")
("left top" "vlevo naho°e")
("left up" "vlevo nahoru")
("left-right arrow" "˛ipka doleva a doprava")
("leftwards" "doleva")
("let the environment float" "nechte prost°edí plovoucí")
("light grey" "svĄtle ˛edá")
("line breaking" "p°eru˛ení °ádku")
("line wrapping" "zalomení °ádku")
("linear 2D" "lineární 2D")
("linear algebra" "lineární algebra")
("lines around" "°ádk· kolem")
("link image and copies as" "propojit obrázek a kopírovat jako")
("link image as" "obrázek odkazu jako")
("link mode" "reşim propojení")
("link to URL" "odkaz na URL")
("linking tool" "propojovací nástroj")
("live" "şivĄ")
("live input-output" "şivý vstup-výstup")
("load help file" "naŁíst soubor nápovĄdy")
("load remote file" "naŁíst vzdálený soubor")
("loading" "naŁítání")
("local entries" "místních záznam·")
("loci" "loci")
("locus" "lokus")
("locus rendering" "vykreslování lokus·")
("logarithm" "logaritmus")
("logarithmic" "logaritmický")
("logarithmic base" "logaritmická základna")
("logarithms" "logaritmy")
("logging in" "p°ihlá˛ení")
("logical and" "logicky a")
("logical implication" "logická implikace")
("logical not" "logicky ne")
("logical or" "logicky nebo")
("login" "p°ihlá˛ení")
("logout" "odhlá˛ení")
("long macro" "dlouhé makro")
("long text" "dlouhý text")
("look for more fonts" "hledat více písem")
("loops" "smyŁek")
("m modifier" "Modifikátor m")
("macro argument" "argument makro")
("macro definition" "definice makra")
("macro name" "název makra")
("macros" "maker")
("magnify horizontally" "horizontálnĄ zvĄt˛it")
("magnify vertically" "vertikálnĄ zvĄt˛it")
("main presentation style" "hlavní styl prezentace")
("make a letter environment" "vytvo°it prost°edí pro dopisy")
("make a multi-slide presentation" "vytvo°it vícenásobnou prezentaci")
("make floating" "plovoucí")
("make link" "vytvo°it odkaz")
("make non floating" "uŁinit neplovoucí")
("manila paper" "manilský papír")
("map arguments" "argumenty mapy")
("marginal note" "marginální nota")
("margins from width" "okraje od ˛í°ky")
("margins on paper" "okraje na papí°e")
("margins on screen" "okraje na obrazovce")
("marked" "oznaŁeno")
("material" "materiál")
("mathematical and customized input" "matematický a p°izp·sobený vstup")
("mathematical font" "matematické písmo")
("mathematical input" "matematický vstup")
("mathematical output" "matematický výstup")
("matrices" "matric")
("maximal" "maximální")
("maximal cell height" "maximální vý˛ka bu¬ky")
("maximal clustering" "maximální shlukování")
("maximal table height" "maximální vý˛ka stolu")
("maximal table width" "maximální ˛í°ka stolu")
("maximum" "maximum")
("meander" "meandr")
("memory" "pamĄ´")
("memory usage" "vyuşití pamĄti")
("menu" "nabídka")
("merge lines into paragraphs unless separated by blank lines" "slouŁit °ádky do odstavc·, pokud nejsou oddĄleny prázdnými °ádky")
("messages" "zpráv")
("meta data" "metadat")
("metadata" "metadat")
("metal" "kov")
("middle baseline" "st°ední základní linie")
("minimal" "minimální")
("minimal cell height" "minimální vý˛ka bu¬ky")
("minimal cell width" "minimální ˛í°ka bu¬ky")
("minimal line separation" "minimální oddĄlení Łar")
("minimal table height" "minimální vý˛ka stolu")
("minimal table width" "minimální ˛í°ka stolu")
("minimum" "minimum")
("mirror" "zrcadlo")
("miscellaneous features" "r·zné funkce")
("miscellanous" "r·zné")
("mode dependent icons" "ikon závislých na reşimu")
("modify remote live document" "úprava vzdáleného şivého dokumentu")
("module" "modul")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help" "více informací o GNU TeXmacs naleznete v nápovĄdĄ")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "")
("more information about GNU TeXmacs can be found in the Help-<less>gtr<gtr>About menu" "více informací o GNU TeXmacs najdete v nabídce NápovĄda - <less>gtr<gtr>")
("motion" "pohyb")
("mouse over object" "mouse over object")
("move" "tah")
("move objects" "p°esouvat objekty")
("move over object on which to operate" "pohyb po objektu, na kterém se má pracovat")
("multiline" "multiline")
("multiline input" "více°ádkový vstup")
("multiple choice" "více moşností")
("multiple root" "více ko°en·")
("multiplication" "násobení")
("mutator tags" "znaŁek mutátor·")
("my documents" "moje dokumenty")
("navigation options" "moşností navigace")
("never" "nikdy")
("new account" "nový úŁet")
("new bibliography dialogue" "nový bibliografický dialog")
("new document" "nový dokument")
("new double page" "nová dvojitá stránka")
("new double page before" "nová dvojitá stránka p°ed")
("new entry" "nová poloşka")
("new identity" "nová identita")
("new locus" "nový lokus")
("new macro" "nové makro")
("new passphrase" "nové p°ístupové fráze")
("new remote directory" "nový vzdálený adresá°")
("new remote file" "nový vzdálený soubor")
("new style fonts" "nových styl· písem")
("new style page breaking" "nový styl stránky lámání")
("new version" "nová verze")
("new window" "nové okno")
("newer version" "novĄj˛í verze")
("next" "dal˛í")
("next chunk" "dal˛í kus")
("next difference" "dal˛í rozdíl")
("next error" "dal˛í chyba")
("next field" "dal˛í pole")
("next occurrence" "dal˛í výskyt")
("next screen" "dal˛í obrazovka")
("next similar" "dal˛í podobné")
("no clustering" "bez shlukování")
("no completions" "bez dokonŁení")
("no errors have been corrected" "nebyly opraveny şádné chyby")
("no grid" "bez m°íşky")
("no matches found for" "nenalezeny şádné výsledky pro")
("no new public key in document" "şádný nový ve°ejný klíŁ v dokumentu")
("no page break" "bez p°eru˛ení stránky")
("no page numbers" "şádná Łísla stránek")
("no parent" "şádný rodiŁ")
("no selection" "bez výbĄru")
("no spelling errors" "şádné pravopisné chyby")
("normal loci" "normální loci")
("not allowed to remove home directory" "není dovoleno odebrat domovský adresá°")
("not connected to server" "není p°ipojen k serveru")
("not yet implemented" "dosud neimplementováno")
("notebook" "notebook")
("number of polar steps" "poŁet polárních krok·")
("number of subunit steps" "poŁet podjednotkových krok·")
("numbering" "Łíslování")
("numeric spreadsheet" "numerická tabulka")
("odd page" "lichá stránka")
("odd page left margin" "lichý okraj liché stránky")
("odd page right margin" "pravý okraj liché stránky")
("odd page shift" "lichý posun stránky")
("odd pages" "lichých stránek")
("of fingerprint" "otisk· prst·")
("old version" "stará verze")
("older version" "star˛í verze")
("on the footer" "na zápatí")
("on your system and set it up from the \"Security\" tab" "ve va˛em systému a nastavte jej na kartĄ \"ZabezpeŁení\"")
("one column" "jeden sloupec")
("one error has been corrected" "jedna chyba byla opravena")
("one lower case letter, one non alpha-numeric symbol" "jedno malé písmeno, jeden nealfanumerický symbol")
("one numeric character, one upper case letter" "jeden Łíselný znak, jedno velké písmeno")
("only convert changes when re-importing" "p°evést zmĄny pouze p°i opĄtovném importu")
("only convert changes with respect to imported version" "p°evádí pouze zmĄny s ohledem na importovanou verzi")
("only convert changes with respect to tracked version" "p°evádí pouze zmĄny s ohledem na sledovanou verzi")
("only implemented for complete subtrees" "implementováno pouze pro úplné podstromy")
("only inline tags" "pouze vloşené znaŁky")
("only keep folded" "pouze udrşovat sloşené")
("only keep unfolded" "pouze rozloşte")
("only show semantic focus" "zobrazit pouze sémantické zamĄ°ení")
("opacity" "nepr·hlednost")
("open bibliography" "otev°ená bibliografie")
("open identities" "otev°ených identit")
("open in new window" "otev°ít v novém oknĄ")
("open licence agreement" "otev°ená licenŁní smlouva")
("open mailbox" "otev°ená po˛tovní schránka")
("open module browser" "otev°ený prohlíşeŁ modul·")
("open symbol browser" "prohlíşeŁ otev°ených symbol·")
("open tool in separate window" "otev°ít nástroj v samostatném oknĄ")
("operation mode" "provozní reşim")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "nebo zadejte úplnou cestu k \"gpg\" nebo \"gpg2\" command")
("order" "objednávka")
("ordinary symbol" "obyŁejný symbol")
("ornamented" "ozdobený")
("other login" "jiné p°ihlá˛ení")
("other package" "dal˛í balíŁek")
("outer bottom" "vnĄj˛í dno")
("outer left" "vlevo")
("outer right" "vnĄj˛í pravý")
("outer top" "vnĄj˛í vrchol")
("outline" "osnovy")
("outlined" "nastínil")
("outlined emboss" "nastínil reliéf")
("outlined engrave" "nastínĄné rytí")
("output options" "moşnosti výstupu")
("oval" "ovál")
("overbrace" "overbrace")
("overlap" "p°ekrývání")
("overlay" "p°ekrytí")
("overlays" "p°ekryvy")
("overline" "overline")
("overlined" "podtrşeno")
("overview of the scheme extension language" "p°ehled jazyka pro roz˛í°ení schématu")
("padded" "polstrovaný")
("page background" "pozadí stránky")
("page break after" "konec stránky po")
("page breaking algorithm" "algoritmus p°eru˛ení stránky")
("page number" "Łíslo stránky")
("page number rendering" "vykreslování Łísla stránky")
("page rendering" "vykreslování stránky")
("page setup" "nastavení stránky")
("palette" "paleta")
("panorama" "panorama")
("paragraphs" "odstavc·")
("parametric curve" "parametrická k°ivka")
("parametric surface" "parametrická plocha")
("parenthesis" "závorka")
("parenthesized" "parenthesized")
("particle" "Łástice")
("passphrase encryption" "˛ifrování pomocí p°ístupové fráze")
("passphrase wallet facilities are not currently available" "za°ízení pro penĄşenku p°ístupové fráze v souŁasné dobĄ nejsou k dispozici")
("passphrases are expected to have at least: 8 characters" "OŁekává se, şe p°ístupové fráze budou mít alespo¬: 8 znak·")
("passphrases mismatch" "nesoulad p°ístupových frází")
("pastel" "pastel")
("pattern" "vzor")
("pause" "pauza")
("pen width" "˛í°ka pera")
("permanent footer" "permanentní zápatí")
("permanent header" "trvalá záhlaví")
("permanently add to dictionary" "trvale p°idat do slovníku")
("permanently insert into dictionary" "trvale vloşit do slovníku")
("permissions" "oprávnĄní")
("phantom" "p°ízrak")
("phantoms" "p°ízrak·")
("physics and astronomy class" "t°ída fyziky a astronomie")
("picture" "obrázek")
("pine" "borovice")
("plain" "holý")
("plain boxes" "obyŁejných krabic")
("plain circles" "prostých kruh·")
("play" "p°ehrávání")
("play animation" "p°ehrát animaci")
("please install GnuPG software from https://www.gnupg.org" "nainstalujte prosím software GnuPG z https://www.gnupg.org")
("plot" "spiknutí")
("plug-ins" "zásuvných modul·")
("plugin" "plugin")
("plugins" "plugin·")
("plural" "mnoşné Łíslo")
("point" "bod")
("polar" "polární")
("polygon" "polygon")
("pop server settings" "nastavení popového serveru")
("position of marginal note" "pozice okrajové noty")
("poster formats" "plakátových formát·")
("poster theme" "plakátové téma")
("postfix" "postfix")
("preferences for editing mathematical formulas" "p°edvoleb pro úpravu matematických vzorc·")
("preferences for tag" "p°edvoleb pro znaŁku")
("prefix" "p°edpona")
("presentation" "prezentace")
("presentation tag" "prezentaŁní znaŁka")
("presentation tool" "prezentaŁní nástroj")
("preserve" "zachovat")
("preserve tags" "zachovat znaŁky")
("pretty tree output" "pĄkný stromový výstup")
("preview" "náhled")
("preview command" "p°íkaz pro náhled")
("previous" "p°edchozí")
("previous difference" "p°edchozí rozdíl")
("previous error" "p°edchozí chyba")
("previous field" "p°edchozí pole")
("previous occurrence" "p°edchozí výskyt")
("previous screen" "p°edchozí obrazovka")
("previous similar" "p°edchozí podobné")
("primitive or macro" "primitivních nebo makro")
("print buffer" "tiskový buffer")
("print buffer to file" "tiskový buffer do souboru")
("print to file" "tisk do souboru")
("printer setup" "nastavení tiskárny")
("program bracket matching" "shodování závorek programu")
("program bracket selections" "výbĄrových závorek")
("program commands" "programových p°íkaz·")
("program font" "programové písmo")
("program interface for buffer management" "programové rozhraní pro správu vyrovnávací pamĄti")
("programming routines for editing documents" "programovací rutiny pro úpravy dokument·")
("prominent" "prominentních")
("prompts and default input" "výzvy a výchozí zadání")
("provoke C++ error" "provokuje chybu C ++")
("provoke menu error" "provokovat chybu v nabídce")
("provoke scheme error" "provokovat chybu schématu")
("pseudo code" "pseudokód")
("pulse" "puls")
("qt GUI only, sorry. Use \"Export selection\"" "Pouze qt GUI, promi¬te. Pouşijte \"Export selection\"")
("qt-widgets" "qt-widgets")
("quantifier" "kvantifikátor")
("quasi" "kvazi")
("question" "otázka")
("questions only" "pouze otázek")
("questions with answers" "otázek s odpovĄ¤mi")
("quick evaluation of formulas" "rychlé vyhodnocení vzorc·")
("rank" "pozice")
("raw" "surových")
("really delete user identity" "opravdu smazat identitu uşivatele")
("really tiny" "opravdu maliŁkých")
("rebuild translations file" "znovu sestavit p°ekladový soubor")
("recent" "nedávných")
("recent documents" "posledních dokument·")
("recipients" "p°íjemc·")
("recognize" "rozpoznat")
("recover autosave file" "obnovit automaticky uloşený soubor")
("rectangular" "obdélníkový")
("reduce" "zmen˛it")
("reduce trigonometric functions" "sníşit trigonometrické funkce")
("reduced margins" "sníşené marşe")
("reference guide" "referenŁní p°íruŁka")
("reference guide for the TeXmacs primitives" "referenŁní p°íruŁka pro primitivy TeXmacs")
("reference guide for the standard TeXmacs styles" "referenŁní p°íruŁka pro standardní styly TeXmacs")
("regenerate" "regenerovat")
("register file" "registrovat soubor")
("relate" "souvisejí")
("relation" "vztah")
("release left button: finish editing" "uvolnĄte levé tlaŁítko: dokonŁení úprav")
("remote" "vzdálených")
("remote connections" "vzdálených p°ipojení")
("remote control" "dálkové ovládání")
("remote directory" "vzdálený adresá°")
("remote servers" "vzdálených server·")
("remote tool" "vzdálený nástroj")
("remove" "odebrat")
("remove all output fields" "odebrat v˛echna výstupní pole")
("remove banner" "odebrat banner")
("remove database entry" "odebrat poloşku databáze")
("remove downwards" "odstranit dol·")
("remove entries" "odebrat poloşky")
("remove entry" "odstranit záznam")
("remove field above" "odstranit pole vý˛e")
("remove field below" "odebrat pole níşe")
("remove fields" "odebrat pole")
("remove folded" "odstranit sloşené")
("remove input field" "odebrat vstupní pole")
("remove input field above" "odstranit vstupní pole vý˛e")
("remove last field" "odebrat poslední pole")
("remove leftwards" "odstranit doleva")
("remove link" "odebrat odkaz")
("remove next field" "odebrat dal˛í pole")
("remove package" "odebrat balíŁek")
("remove previous field" "odebrat p°edchozí pole")
("remove rightwards" "odstranit doprava")
("remove selected database entries" "odebrat vybrané poloşky databáze")
("remove selected entries" "odebrat vybrané poloşky")
("remove superfluous invisible operators" "odstranit nadbyteŁné neviditelné operátory")
("remove tag" "odebrat znaŁku")
("remove this branch" "odstranit tuto vĄtev")
("remove unfolded" "odstranit rozvinuté")
("remove upwards" "odstranit nahoru")
("removed entries from database" "odstranĄné poloşky z databáze")
("removed entry from database" "odstranĄná poloşka z databáze")
("rename" "p°ejmenovat")
("rename section" "p°ejmenovat sekci")
("repeat" "opakování")
("replace TeXmacs styles with no LaTeX equivalents" "nahrazení styl· TeXmacs bez ekvivalent· LaTeX")
("replace all further occurrences" "nahradit v˛echny dal˛í výskyty")
("replace one occurrence" "nahradit jeden výskyt")
("replace toolbar" "nahradit panel nástroj·")
("replace unrecognized styles" "nahradit nerozpoznané styly")
("resize" "zmĄna velikosti")
("resize objects" "zmĄna velikosti objekt·")
("restart TeXmacs in order to let changes take effect" "restartujte TeXmacs, aby se zmĄny projevily")
("restart in order to let the new look and feel take effect" "restartujte, aby se nový vzhled a dojem projevil")
("retain" "zachovat")
("retime" "retime")
("retina settings" "nastavení sítnice")
("retrieve email" "naŁíst e-mail")
("retrieve remote live document" "naŁíst vzdálený şivý dokument")
("retrieved contents" "naŁtený obsah")
("reverse" "obrácenĄ")
("reverse ordering" "zpĄtné °azení")
("ridged paper" "rýhovaný papír")
("right arrow" "˛ipka vpravo")
("right baseline" "pravá základní Łára")
("right cell border" "hranice pravé bu¬ky")
("right cell padding" "polstrování pravé bu¬ky")
("right down" "vpravo dol·")
("right on even pages" "p°ímo na sudých stránkách")
("right table border" "pravý okraj stolu")
("right table padding" "pravé polstrování stolu")
("right up" "nahoru")
("rightwards" "vpravo")
("rigid box" "tuhá krabice")
("rotate" "otáŁet")
("rotate objects" "otáŁet objekty")
("rough" "hrubý")
("rough paper" "surový papír")
("round" "kulatých")
("round overbrace" "kulatý overbrace")
("round underbrace" "kulatá spodní plocha")
("row above" "°ádek nad")
("row below" "°ádek níşe")
("rows" "°ádk·")
("run" "bĄh")
("run current file" "spustit aktuální soubor")
("same names" "stejných jmen")
("same screen margins as on paper" "stejné okraje obrazovky jako na papí°e")
("sample text" "ukázkový text")
("save auxiliary data" "uloşit pomocná data")
("save entries" "uloşit záznamy")
("save entry" "uloşit záznam")
("save image as" "uloşit obrázek jako")
("save position" "uloşit polohu")
("save remote file" "uloşit vzdálený soubor")
("saved modifications in database" "uloşené zmĄny v databázi")
("scheme command" "p°íkazový °ádek")
("scheme developers guide" "p°íruŁka pro vývojá°e program·")
("scheme extensions" "roz˛í°ení schémat")
("scheme interface for the graphical mode" "rozhraní schématu pro grafický reşim")
("screen" "obrazovka")
("screen rendering" "vykreslování obrazovky")
("screens" "obrazovek")
("screenshot" "screenshot")
("scripting language" "skriptovací jazyk")
("scripts" "skript·")
("search and replace" "hledat a nahradit")
("search results for" "výsledk· vyhledávání")
("search toolbar" "panel nástroj· vyhledávání")
("search words in my documents" "hledat slova v mých dokumentech")
("search words in the documentation" "hledat slova v dokumentaci")
("search words in the source code" "hledat slova ve zdrojovém kódu")
("second" "sekund")
("sections" "sekcí")
("see documentation" "viz dokumentace")
("select pen" "select pen")
("select the action to be undertaken for each conflict" "vyberte akci, která má být provedena pro kaşdý konflikt")
("select view mode" "reşim výbĄru zobrazení")
("semantic correctness" "sémantická správnost")
("semantic editing" "sémantická úprava")
("semantic selections" "sémantických výbĄr·")
("semantics" "sémantika")
("sending commands to TeXmacs" "posílání p°íkaz· TeXmacs")
("senior" "senior")
("serif" "serif")
("server" "server")
("session commands" "p°íkaz· relace")
("set default" "nastavit výchozí")
("set difference" "nastavit rozdíl")
("set intersection" "nastavit pr·nik")
("set number of columns" "nastavit poŁet sloupc·")
("set number of rows" "nastavit poŁet °ádk·")
("set or get environment variables" "nastavit nebo získat promĄnné prost°edí")
("set properties" "nastavit vlastnosti")
("set union" "set union")
("set user information" "nastavit informace o uşivateli")
("seventh" "sedmý")
("several equations" "nĄkolik rovnic")
("shadow" "stín")
("shadowed" "stínované")
("shadowed raise" "stínované zvý˛ení")
("shift" "posun")
("short" "krátký")
("show all parts" "zobrazit v˛echny Łásti")
("show current focus" "zobrazit aktuální zamĄ°ení")
("show full context" "zobrazit plný kontext")
("show hidden" "zobrazit skryté")
("show key presses" "zobrazit stisknutí kláves")
("show main document" "zobrazit hlavní dokument")
("show memory usage" "zobrazit vyuşití pamĄti")
("show one part" "zobrazit jednu Łást")
("show panorama" "zobrazit panorama")
("show preamble" "zobrazit preambuli")
("show several parts" "zobrazit nĄkolik Łástí")
("show subunits" "zobrazit podjednotky")
("show table cells" "zobrazit bu¬ky tabulky")
("show timings" "zobrazit Łasování")
("side tools" "boŁní nástroje")
("simple" "jednoduchých")
("simplification" "zjednodu˛ení")
("simplified evaluation of formulas" "zjednodu˛ené hodnocení vzorc·")
("simplified menus" "zjednodu˛ených nabídek")
("simplify" "zjednodu˛it")
("sine" "sine")
("sixth" "˛estý")
("size tag" "velikostní znaŁka")
("skew" "zkosení")
("skip all" "p°eskoŁit v˛e")
("slant" "˛ikmo")
("slashed fraction" "sekaná frakce")
("slides" "diapozitiv·")
("slovene" "slovinsky")
("slow" "pomalu")
("slow decrease" "pomalý pokles")
("slow increase" "pomalý nár·st")
("small capitals" "malých mĄst")
("small environment box" "malý ekologický box")
("small focus" "malé zaost°ení")
("small inline" "malý inline")
("small inline fraction" "malý vloşený zlomek")
("smash" "rozbít")
("smooth" "hladký")
("smooth end" "hladký konec")
("smooth extremities" "hladkých konŁetin")
("smooth start" "hladký start")
("snap" "snap")
("snap distance" "vzdálenost")
("snap to curves" "zaklapnutí do k°ivek")
("snap to grid" "snap to grid")
("snap to grid curve" "k°ivka snap to grid")
("snap to intersections of curves" "zaklapnutí na pr·seŁíky k°ivek")
("snap to text borders" "ohraniŁení na text")
("snap to text corners" "zaklapnout do textových roh·")
("solution" "°e˛ení")
("solution to exercise" "°e˛ení cviŁení")
("solution to problem" "°e˛ení problému")
("solutions" "°e˛ení")
("sound" "zvuk")
("source" "zdroj")
("source macros tool" "nástroj zdrojových maker")
("source tags" "zdrojových znaŁek")
("south" "jih")
("south east" "jihovýchodnĄ")
("space bar in math mode" "mezerník v matematickém reşimu")
("space bar in text mode" "mezerník v textovém reşimu")
("space stretchability" "roztaşitelnost prostoru")
("span" "rozpĄtí")
("span over all columns" "rozpĄtí ve v˛ech sloupcích")
("special functions" "zvlá˛tních funkcí")
("special properties" "zvlá˛tních vlastností")
("specific baseline" "specifická základní linie")
("specify color alternation" "uve¤te st°ídání barev")
("specify how to traverse the manual" "urŁit, jak procházet manuálem")
("specify semantics of a symbol or formula" "uve¤te sémantiku symbolu nebo vzorce")
("specify the size of the table" "uve¤te velikost tabulky")
("spell check" "kontrola pravopisu")
("spline" "spline")
("split program" "split program")
("split session" "rozdĄlená relace")
("square" "ŁtvereŁních")
("square overbrace" "Łtvercový overbrace")
("square underbrace" "Łtvercové spodní plochy")
("stack" "stack")
("standard" "standard")
("standard Output" "standardní výstup")
("standard TeXmacs styles" "standardních styl· TeXmacs")
("standard environment variables" "standardní promĄnné prost°edí")
("standard formats" "standardních formát·")
("standard fraction" "standardní zlomek")
("star" "hvĄzd")
("start server" "start server")
("statement" "prohlá˛ení")
("statistics" "statistik")
("status" "status")
("stop server" "stop server")
("storage" "úloşi˛tĄ")
("store tracking information in LaTeX files" "ukládat informace o sledování do soubor· LaTeX")
("stretch" "úsek")
("stretch factor" "faktor roztaşení")
("stretched" "nataşený")
("strict Ascii" "p°ísná Ascii")
("strike through" "protáhnout")
("structured insert above" "strukturovaná vloşka vý˛e")
("structured insert at the left" "strukturovaná vloşka vlevo")
("structured insert at the right" "strukturovaná vloşka vpravo")
("structured insert below" "strukturovaná vloşka níşe")
("structured remove downwards" "strukturované odstranĄní dol·")
("structured remove leftwards" "strukturované odstranĄní doleva")
("structured remove rightwards" "strukturované odstranĄní vpravo")
("structured remove upwards" "strukturované odstranĄní nahoru")
("structured variant" "strukturovaná varianta")
("style options" "moşností stylu")
("style parameters" "parametr· stylu")
("stylesheet language" "jazyk styl·")
("subject" "p°edmĄt")
("submenu" "podnabídka")
("subscript below" "dolní index")
("subsubmenu" "subsubmenu")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtable")
("subtitle" "podtitul")
("subtraction" "odŁítání")
("summarized" "shrnuto")
("superscript above" "horní index")
("supported plug-ins" "podporovaných dopl¬k·")
("surface" "povrch")
("inflate" "bobtnat")
("swiss" "˛výcarský")
("switch to buffer" "p°epnout do vyrovnávací pamĄti")
("symbol properties not found" "nebyly nalezeny vlastnosti symbolu")
("symbols" "symbol·")
("synchronize" "synchronizovat")
("synchronize bibliographic references" "synchronizovat bibliografické odkazy")
("synchronize with remote server" "synchronizovat se vzdáleným serverem")
("synopsis" "synopse")
("system command" "p°íkaz systému")
("tab-completion" "dokonŁení karty")
("tabbed" "tabbed")
("table breaking" "lámání stolu")
("table height" "vý˛ka stolu")
("table properties" "vlastnosti tabulky")
("table width" "˛í°ka stolu")
("tags with special rendering" "znaŁek se zvlá˛tním vykreslením")
("tangent" "tangens")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "OŁekává se TeXmacs buffer")
("teXmacs buffer on disk expected" "OŁekává se vyrovnávací pamĄti teXmacs na disku")
("teXmacs extensions to scheme and utilities" "roz˛í°ení teXmacs o schéma a obsluşné programy")
("teXmacs macro" "makro teXmacs")
("teXmacs package" "balíŁek teXmacs")
("teXmacs plugins" "zásuvných modul· teXmacs")
("teXmacs primitives" "primitiv teXmacs")
("teXmacs style" "stylu teXmacs")
("test routine" "testovací rutina")
("testing tree-view" "testování stromového zobrazení")
("text borders" "ohraniŁení textu")
("text box style" "styl textového pole")
("text corners" "textových roh·")
("textual" "textový")
("textual operator" "textový operátor")
("textual spreadsheet" "textových tabulek")
("the TeXmacs format" "formát TeXmacs")
("the TeXmacs plug-in system" "zásuvný systém TeXmacs")
("the document has not been saved" "dokument nebyl uloşen")
("theme parameters" "parametry motivu")
("these collected public keys will be definitely lost" "tyto shromáşdĄné ve°ejné klíŁe budou definitivnĄ ztraceny")
("these public keys will be definitely lost" "tyto ve°ejné klíŁe budou definitivnĄ ztraceny")
("these secret keys will be definitely lost" "tyto tajné klíŁe budou definitivnĄ ztraceny")
("thicken" "zahu˛´ovat")
("third" "t°etí")
("this" "toto")
("this column" "tento sloupec")
("this page footer" "zápatí této stránky")
("this page header" "tato záhlaví stránky")
("this page number" "toto Łíslo stránky")
("this row" "tento °ádek")
("this style specifies page margins in the TeX way" "tento styl urŁuje okraje stránky zp·sobem TeX")
("three columns" "t°í sloupc·")
("three dots" "t°i teŁky")
("through popup windows" "p°es vyskakovací okna")
("through the menus" "v nabídkách")
("thumbnails" "miniatur")
("time evolution" "evoluce Łasu")
("timings" "naŁasování")
("title presentation options" "moşnosti prezentace titul·")
("title style" "styl nadpisu")
("title suffix" "p°ípona názvu")
("titled block" "s názvem blok")
("toggle cell wrapping mode" "reşim p°epínání bunĄk")
("toggle here" "p°epnout sem")
("toggle off" "vypnout")
("toggle on" "p°epnout na")
("tolerant" "tolerantní")
("top baseline" "horní základní linie")
("top cell border" "horní hranice bu¬ky")
("top cell padding" "výpl¬ horní bu¬ky")
("top table border" "ohraniŁení horní tabulky")
("top table padding" "polstrování stolu")
("transform" "transformace")
("transform cell into subtable" "transformovat bu¬ku do podoblasti")
("translations" "p°eklad·")
("translations loaded" "naŁtených p°eklad·")
("transpose" "transponovat")
("traversal" "traversal")
("traverse" "traverza")
("triangle" "trojúhelník")
("triangularize" "triangularize")
("trigonometric" "trigonometrický")
("trigonometry" "trigonometrie")
("turn off" "vypnout")
("turn on" "zapnout")
("two columns" "dva sloupce")
("two dots" "dvĄ teŁky")
("type a latex command followed by return" "zadejte p°íkaz latex následovaný návratem")
("underbrace" "podtrşení")
("underline" "podtrşení")
("underlined" "podtrşeno")
("unevaluated argument" "neocenĄný argument")
("unevaluated value" "nevyhodnocená hodnota")
("unfold" "rozvinout")
("unfold all" "rozvinout v˛e")
("unfold all fields" "rozloşte v˛echna pole")
("unit" "jednotka")
("unit length" "délka jednotky")
("unknown secret key fingerprint" "neznámý otisk tajného klíŁe")
("unregistered file" "neregistrovaný soubor")
("unroll" "unroll")
("unsecure script refused" "nezabezpeŁený skript byl odmítnut")
("unsupported link mode" "nepodporovaný reşim propojení")
("until" "do")
("untitled block" "nepojmenovaný blok")
("up to date" "aktuální")
("update buffer" "aktualizace buffer")
("update this buffer" "aktualizovat tento buffer")
("update web site" "aktualizovat web")
("upight" "vzestupnĄ")
("upload" "nahrát")
("upright" "vzp°ímenĄ")
("upwards" "nahoru")
("use CSS for more advanced formatting" "pouşití CSS pro pokroŁilej˛í formátování")
("use MathML" "pouşijte MathML")
("use as master" "pouşití jako master")
("use extensible brackets" "pouşijte roz˛i°itelné závorky")
("use line wrapping for lines which are longer than 80 characters" "pouşít zalomení °ádk· pro °ádky del˛í neş 80 znak·")
("use margin kerning (protrusion)" "pouşít vyrovnání okraj· (výstupek)")
("use protrusion" "pouşijte výŁnĄlek")
("use relative path" "pouşít relativní cestu")
("user interface" "uşivatelské rozhraní")
("user interface language" "jazyk uşivatelského rozhraní")
("user preferences" "uşivatelských preferencí")
("users of Cyrillic languages" "uşivatelé azbuky")
("users of oriental languages" "uşivatelé orientálních jazyk·")
("utf-8 with inputenc LaTeX package" "utf-8 s balíŁkem inputenc LaTeX")
("utilities" "nástroje")
("vanish" "zmizet")
("verbose" "podrobných")
("version" "verze")
("versioning tool" "nástroj pro vytvá°ení verzí")
("vertical alignment" "svislé zarovnání")
("vertical margins" "svislé okraje")
("vertical space after" "po svislém prostoru")
("vertical space before" "p°ed svislým prostorem")
("vertical space stretchability" "vertikální roztaşitelnost prostoru")
("visible except here" "viditelné kromĄ zde")
("visible from here on" "odtud viditelné")
("visible only here" "viditelné pouze zde")
("visible until here" "Do té doby viditelné")
("visited loci" "nav˛tívených loci")
("wallet" "penĄşenka")
("wave" "vlna")
("web" "web")
("weight" "hmotnost")
("when line wrapping" "p°i zalamování °ádk·")
("whitespace" "bílé znaky")
("wide" "˛iroký")
("wide bar" "˛iroká li˛ta")
("wide block" "˛iroký blok")
("wide colored" "˛iroko zbarvená")
("wide float" "˛iroký plovák")
("wide footnote" "˛iroká poznámka pod Łarou")
("wide tabular" "˛iroká tabulka")
("widescreen" "˛irokoúhlý")
("wrap lines" "zalomených °ádk·")
("write a macro" "napsat makro")
("writing TeXmacs bibliography styles" "psaní styl· bibliografie TeXmacs")
("writing documentation" "písemná dokumentace")
("written with TeXmacs" "psáno s TeXmacs")
("wrong empty passphrase" "nesprávné prázdné heslo")
("wrong passphrase" "nesprávná p°ístupová fráze")
("year" "roku")
("you are attempting to open an encrypted file while" "Pokou˛íte se otev°ít ˛ifrovaný soubor, zatímco")
("you might consider enabling the experimental" "m·şete zváşit povolení experimentu")
("you must add a bibliography file" "musíte p°idat bibliografický soubor")
("you should also make sure that GnuPG is installed" "mĄli byste se také ujistit, şe je nainstalován GnuPG")
("your language" "vá˛ jazyk")
("your personal dictionary has been modified" "vá˛ osobní slovník byl zmĄnĄn")
("zoom" "zoom")
("zoom in" "p°iblíşit")
("zoom out" "oddálit")
