<TeXmacs|1.99.16>

<style|<tuple|source|english>>

<\body>
  <active*|<\src-title>
    <src-package|triangle-list|1.0>

    <\src-purpose>
      Triangular list item
    </src-purpose>

    <src-copyright|2018|Joris van der Hoeven>

    <\src-license>
      This <TeXmacs> style package falls under the <hlink|GNU general public
      license|$TEXMACS_PATH/LICENSE> and comes WITHOUT ANY WARRANTY
      WHATSOEVER. If you don't have this file, then write to the Free
      Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
      02110-1301, USA.
    </src-license>
  </src-title>>

  <assign|item-1|<macro|<math|<strong|<op|\<blacktriangleright\>>>>>>

  <assign|item-2|<macro|<math|<strong|<op|\<vartriangleright\>>>>>>

  <assign|item-3|<macro|<math|<strong|<op|\<minus\>>>>>>

  <assign|item-4|<macro|<math|<strong|<op|.>>>>>
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>