<TeXmacs|1.99.9>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package-dtd|greyish-combo|1.0|greyish-combo|1.0>

    <\src-purpose>
      Greyish theme for presentations and posters.
    </src-purpose>

    <src-copyright|2013--2019|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <use-package|light-combo>

  <copy-theme|greyish|light>

  <\active*>
    <\src-comment>
      Standard ornaments
    </src-comment>
  </active*>

  <assign|greyish-ornament-extra-color|dark grey>

  <assign|greyish|<value|ornament-render-title-white>>

  <assign|greyish-ornament-color|pastel grey>

  <assign|greyish-ornament-sunny-color|#e0e0e0>

  <assign|greyish-ornament-shadow-color|#a0a0a0>

  <\active*>
    <\src-comment>
      Titles
    </src-comment>
  </active*>

  <assign|greyish-title-bar-color|<macro|dark grey>>

  <assign|greyish-title-color|<macro|white>>

  <\active*>
    <\src-comment>
      Sessions
    </src-comment>
  </active*>

  <assign|greyish-input-color|#e0e0e8>

  <assign|greyish-fold-bar-color|#a0a0bc>

  <assign|greyish-fold-title-color|#e0e0e8>
</body>

<\initial>
  <\collection>
    <associate|sfactor|7>
  </collection>
</initial>