("\"encryption\" features from the preference panel" "Χαρακτηριστικά κρυπτογράφησης από τον πίνακα προτιμήσεων")
("(Re)Build autocompletion index" "Δείκτης αυτόματης συμπλήρωσης (Re))")
("a.C.M. computing class" "Κλάση υπολογιστικής A.C.M.")
("a.M.S. subject class" "a.M.S. κλάση υποκειμένου")
("abbreviated authors" "συντετμημένους συγγραφείς")
("abreviated authors" "συντομογραφημένοι συγγραφείς")
("accent above" "προφορά παραπάνω")
("accent below" "έμφαση κάτω από")
("accept during this pass" "αποδέχονται κατά τη διάρκεια αυτού του περάσματος")
("active link types" "τύποι ενεργών συνδέσμων")
("add" "προσθήκη")
("add abstract information" "προσθήκη αφηρημένων πληροφοριών")
("add author information" "Προσθήκη πληροφοριών συγγραφέα")
("add branch after" "προσθέστε υποκατάστημα μετά")
("add branch before" "προσθήκη κλάδου πριν")
("add other package" "προσθήκη άλλου πακέτου")
("add title information" "προσθήκη πληροφοριών τίτλου")
("addition" "Προσθήκη")
("adjust limits" "όρια προσαρμογής")
("advanced font customization" "προηγμένη προσαρμογή γραμματοσειράς")
("affiliation" "υπαγωγή")
("align cell to the decimal comma" "ευθυγραμμίστε το κελί με το δεκαδικό κόμμα")
("align cell to the decimal dot" "ευθυγραμμίστε την κυψέλη με την δεκαδική τελεία")
("align table at axis" "ευθυγράμμιση τραπέζι στον άξονα")
("alignment of balloon" "ευθυγράμμιση του μπαλονιού")
("all cells" "όλα τα κύτταρα")
("all data attached to this identity will be lost" "όλα τα δεδομένα που συνδέονται με αυτήν την ταυτότητα θα χαθούν")
("all saved passphrases will be lost forever" "όλες οι αποθηκευμένες passphrases θα χαθούν για πάντα")
("allowed page height extension" "επέκταση επέκτασης σελίδας")
("allowed page height reduction" "επιτρέπεται μείωση ύψους σελίδας")
("allowed positions" "επιτρεπόμενες θέσεις")
("allowed positions of floating object" "επιτρεπόμενες θέσεις πλωτού αντικειμένου")
("alpha transparency" "Διαφάνεια άλφα")
("also on paper" "επίσης σε χαρτί")
("alter" "alter")
("alternate except here" "εναλλασσόμενο εκτός από εδώ")
("alternate from here on" "εναλλάσσονται από εδώ στο")
("alternate only here" "εναλλαγή μόνο εδώ")
("alternate until here" "εναλλαγή μέχρι εδώ")
("amplified" "Ενισχυμένο")
("and perform casual settings from the \"Encryption\" tab" "και να εκτελέσετε τυχαίες ρυθμίσεις από την καρτέλα \"Κρυπτογράφηση\"")
("animate" "κινούμενα")
("animate folding" "ζωντανή αναδίπλωση")
("animate unfolding" "κινούμενο ξεδίπλωμα")
("animated" "κινούμενα")
("animation toolbar" "γραμμή εργαλείων κίνησης")
("annotate" "σχολιασμός")
("answer field" "Πεδίο απάντησης")
("answer to question" "Απάντηση στην ερώτηση")
("answers only" "Μόνο απαντήσεις")
("any" "οποιοδήποτε")
("appear" "εμφανίζονται")
("approximate" "κατά προσέγγιση")
("arc" "τόξο")
("are you sure you want to delete collected public keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε τα συλλεγμένα δημόσια κλειδιά")
("are you sure you want to delete selected public keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε επιλεγμένα δημόσια κλειδιά")
("are you sure you want to delete selected secret keys" "είστε βέβαιοι ότι θέλετε να διαγράψετε επιλεγμένα μυστικά κλειδιά")
("are you sure you want to destroy the wallet" "είστε βέβαιοι ότι θέλετε να καταστρέψετε το πορτοφόλι")
("art frame" "πλαίσιο τέχνης")
("arxiv category" "Κατηγορία arxiv")
("as visual grid" "ως οπτικό πλέγμα")
("aspect" "πτυχή")
("attach master" "επισυνάψτε κύριο")
("auto" "αυτόματα")
("auto-save file" "Αρχείο αυτόματης αποθήκευσης")
("automatic brackets" "αυτόματοι βραχίονες")
("automatic program brackets" "αυτόματοι βραχίονες προγράμματος")
("automatically import bibliographies when opening files" "αυτόματα εισάγει βιβλιογραφίες κατά το άνοιγμα αρχείων")
("automatically remember all passphrases in the wallet" "θυμάται αυτόματα όλες τις φράσεις πρόσβασης στο πορτοφόλι")
("automatically save" "αυτόματα αποθηκεύονται")
("back" "πίσω")
("backtrace errors" "Σφάλματα διεύρυνσης")
("base" "βάση")
("beamer" "Προβολέας")
("beamer formats" "Μορφές δορυφόρων")
("beamer theme" "Θέμα προβολέα")
("bench" "πάγκος")
("bend bottom" "Κατώτατη καμπή")
("bend corner" "Γωνία στροφής")
("bend diagonal" "Διάφανη καμπύλη")
("bend in" "κάμψη")
("bend out" "κάμψη έξω)")
("bezier" "bezier")
("bibTeX command" "Εντολή bibTeX")
("bidirectional" "αμφίδρομη")
("big environment box" "μεγάλο πλαίσιο περιβάλλοντος")
("big focus" "μεγάλη εστίαση")
("binary operator" "δυαδικός χειριστής")
("bitmap resolution (dpi)" "ανάλυση bitmap (dpi)")
("black floral I" "μαύρο floral I")
("black floral II" "μαύρο floral II")
("blackboard embold" "μαυροπίνακα embold")
("block" "μπλοκ")
("blur" "θαμπάδα")
("both versions" "και οι δύο εκδόσεις")
("bottom baseline" "Βασική γραμμή βάσης")
("bottom tools" "εργαλεία κάτω")
("box" "κουτί")
("browse modules documentation" "Έγγραφα τεκμηρίωσης περιηγηθείτε σε μονάδες")
("buffer management" "διαχείριση buffer")
("buffer must be on disk" "buffer πρέπει να είναι στο δίσκο")
("buffer must have a name" "buffer πρέπει να έχει όνομα)")
("build buffer" "ρυθμιστικό δημιουργίας")
("build buffer in" "buffer δημιουργίας σε")
("build directory" "build directory")
("build directory in" "δημιουργία καταλόγου σε")
("build link pages" "δημιουργία συνδέσμων σελίδων")
("build-all" "build-all")
("bump" "χτύπημα")
("cJK" "cJK")
("cJK spacing" "Απόσταση CJK")
("cancelled" "ακυρώθηκε")
("cannot download directory to file" "δεν μπορεί να κατεβάσει τον κατάλογο σε αρχείο")
("cannot rename across different servers" "Το δεν μπορεί να μετονομάσει σε διαφορετικούς διακομιστές")
("cannot upload directory to file" "δεν είναι δυνατή η φόρτωση του καταλόγου σε αρχείο")
("cartesian" "καρτεσιανό")
("carved wood" "ξυλόγλυπτο ξύλο")
("case-insensitive search" "ανίχνευση ανιχνεύσιμης περίπτωσης")
("categories" "Κατηγορίες")
("category" "Κατηγορία")
("cell properties" "κυτταρικές ιδιότητες")
("change default unit" "αλλαγή της προεπιλεγμένης μονάδας")
("change passphrase" "αλλαγή φράσης πρόσβασης")
("change step-size" "αλλαγή κλιμακίου")
("change tags" "Ετικέτες αλλαγής")
("change the style of mathematical formulas" "αλλάζουν το στυλ των μαθηματικών τύπων")
("character contraction" "Συστολή χαρακτήρων")
("character encoding" "Κωδικοποίηση χαρακτήρων")
("character expansion" "Επέκταση χαρακτήρων")
("check for updates" "έλεγχος για ενημερώσεις")
("checkable field" "πεδία διερεύνησης")
("cipher algorithm for passphrase encryption" "αλγόριθμος κρυπτογράφησης κρυπτογράφησης κωδικού πρόσβασης")
("circle" "κύκλος")
("classification" "ταξινόμηση")
("clean slate" "καθαρή σχιστόλιθος")
("clear local information" "σαφείς τοπικές πληροφορίες")
("clear menu" "καθαρό μενού")
("clear undo history" "διαγραφή ιστορικού αναίρεσης")
("click Ok button twice to discard this warning" "πατήστε το κουμπί Ok δύο φορές για να απορρίψετε αυτήν την προειδοποίηση")
("clipboard image format" "μορφή εικόνας πρόχειρου")
("close animation tool" "κοντινό εργαλείο κίνησης")
("close program" "κλείσιμο προγράμματος")
("close replace tool" "κλείστε το εργαλείο αντικατάστασης")
("close search tool" "εργαλείο στενής αναζήτησης")
("close spell tool" "κλείσιμο εργαλείο ορθογραφίας")
("close translations to rebuild" "στενές μεταφράσεις για αναδημιουργία")
("closed bezier" "κλειστό bezier")
("closed curve" "κλειστή καμπύλη")
("closed smooth" "κλειστό λείο")
("closed spline" "κλειστή σφήνα")
("cluster by affiliation" "σύμπλεγμα κατά υπαγωγή")
("collect garbage" "συλλέγουν τα σκουπίδια")
("collected keys" "συλλεγμένα κλειδιά")
("color of the axes" "χρώμα των αξόνων")
("color of the subunits" "χρώμα των υπομονάδων")
("color of the units" "χρώμα των μονάδων")
("column separation" "Διαχωρισμός στήλης")
("commit file" "αρχείο δέσμευσης")
("common" "κοινό")
("commutative diagram" "διατακτικό διάγραμμα")
("complete bibliographic reference" "πλήρης βιβλιογραφική αναφορά")
("complex actions" "σύνθετες ενέργειες")
("compound" "ένωση")
("compress" "συμπίεση")
("compress into toolbar" "συμπίεση στη γραμμή εργαλείων")
("conceal" "κρύβουν")
("configure look and feel" "ρυθμίστε την εμφάνιση και την αίσθηση")
("confirm database entry" "επιβεβαίωση εγγραφής βάσης δεδομένων")
("confirm entry" "Επιβεβαίωση εγγραφής")
("confirm selected database entries" "επιβεβαίωση επιλεγμένων καταχωρίσεων βάσης δεδομένων")
("confirm selected entries" "επιβεβαίωση επιλεγμένων καταχωρήσεων")
("conservative conversion options" "συντηρητικές επιλογές μετατροπής")
("consoles" "κονσόλες")
("constellation" "αστερισμός")
("context aids" "βοηθήματα περιβάλλοντος")
("contextual hints" "συμβουλές συμφραζομένων")
("continue" "συνέχεια")
("continued fraction" "συνεχές κλάσμα")
("contour" "περίγραμμα")
("control flow" "Ροή ελέγχου")
("convert" "μετατρέπουν")
("copyright" "πνευματικά δικαιώματα")
("correct" "σωστό")
("correct all" "διορθώστε όλες")
("correct formula" "σωστή φόρμουλα")
("correct manually" "σωστά χειροκίνητα")
("correct mathematical formulas" "σωστές μαθηματικές φόρμουλες")
("correction" "διόρθωση")
("create link" "δημιουργία συνδέσμου")
("create remote directory" "δημιουργία απομακρυσμένου καταλόγου")
("create remote file" "Δημιουργία απομακρυσμένου αρχείου")
("create subprogram" "δημιουργία υποπρογράμματος")
("create table macro" "δημιουργία πίνακα macro")
("creating new account" "δημιουργία νέου λογαριασμού")
("crop" "καλλιέργεια")
("crop marks" "σημάδια περικοπής")
("cross" "σταυρός")
("crossed boxes" "Διασταυρωμένα κουτιά")
("crossed circles" "διασταυρωμένοι κύκλοι")
("current user version" "τρέχουσα έκδοση χρήστη")
("current version" "τρέχουσα έκδοση")
("cursor" "δρομέας")
("curve intersections" "καμπύλες διασταυρώσεις")
("curve points" "σημεία καμπύλης")
("customizations" "προσαρμογές")
("customizing and extending the user interface" "προσαρμογή και επέκταση του περιβάλλοντος χρήστη")
("data" "δεδομένα")
("database entry" "εισαγωγή βάσης δεδομένων")
("database tool" "εργαλείο βάσης δεδομένων")
("database toolbar" "γραμμή εργαλείων βάσης δεδομένων")
("debug" "εντοπισμού σφαλμάτων")
("debugging console" "κονσόλα εντοπισμού σφαλμάτων")
("debugging tool" "εργαλείο εντοπισμού σφαλμάτων")
("decomposed" "αποσύνθεση")
("decorated" "διακοσμημένα")
("decorated wood" "διακοσμημένο ξύλο")
("decrease size" "μέγεθος μείωσης")
("decrypt" "αποκρυπτογράφηση")
("default size" "προεπιλεγμένο μέγεθος")
("degrade" "αποικοδόμηση")
("degraded" "υποβαθμισμένες")
("delete documentation cache" "διαγραφή της προσωρινής μνήμης τεκμηρίωσης")
("delete entries" "Διαγραφή εγγραφών")
("delete link" "διαγραφή συνδέσμου")
("destroy" "καταστρέφουν")
("detach master" "αποσυνδέστε τον κύριο")
("determine margins from text width" "καθορισμός περιθωρίων από το πλάτος κειμένου")
("developer" "προγραμματιστής")
("developer tool" "εργαλείο προγραμματιστή")
("device" "Συσκευή")
("diamond" "διαμάντι")
("dilate" "διαστολή")
("direction of progression" "κατεύθυνση της εξέλιξης")
("direction of translation" "κατεύθυνση μετάφρασης")
("disable coloring on paper" "απενεργοποιήστε το χρωματισμό σε χαρτί")
("disable encryption" "απενεργοποίηση κρυπτογράφησης")
("disappear" "εξαφανίζονται")
("disk" "δίσκος")
("display style" "στυλ εμφάνισης")
("dissociate joined cells" "αποσυνδέονται ενωμένα κύτταρα")
("distort" "στρέβλωση")
("distorted" "διαστρεβλωμένο")
("division" "διαίρεση")
("document font selector" "επιλογέας γραμματοσειράς εγγράφου")
("document page format" "μορφή σελίδας εγγράφου")
("document paragraph format" "μορφή παραγράφου εγγράφου")
("document updates run" "ενημερώσεις εγγράφων τρέχουν")
("dragging" "σύρσιμο")
("draw over" "ισοπαλία")
("drop" "Πτώση")
("due to" "λόγω")
("dynamic" "δυναμική")
("eRROR" "eRROR")
("edit animation" "επεξεργασία κινούμενης εικόνας")
("edit groups of objects" "επεξεργασία ομάδων αντικειμένων")
("edit macro" "μακροεντολή επεξεργασίας")
("edit source" "πηγή επεξεργασίας")
("edit style" "στυλ επεξεργασίας")
("edit translations file" "επεξεργασία αρχείων μεταφράσεων")
("effect pen" "Στυλό")
("eighth" "όγδοο")
("embold" "embold")
("emboss" "ανάγλυφο")
("enable page breaking" "ενεργοποίηση σπάσιμο σελίδας")
("encrypt" "κρυπτογράφηση")
("encryption" "κρυπτογράφηση")
("encryption facilities are not currently available" "εγκαταστάσεις κρυπτογράφησης δεν είναι επί του παρόντος διαθέσιμες")
("encryption facilities have not been enabled for TeXmacs" "Δεν έχουν ενεργοποιηθεί εγκαταστάσεις κρυπτογράφησης για την TeXmacs")
("enforce brackets to match" "συμμορφώνονται οι παρενθέσεις")
("engrave" "χάραξη")
("enter graphics" "εισαγωγή γραφικών")
("enter graphics mode" "εισάγετε τη λειτουργία γραφικών")
("enter new passphrase for encryption" "εισάγετε νέα φράση πρόσβασης για κρυπτογράφηση")
("enter passphrase for decryption" "εισαγάγετε τη φράση πρόσβασης για αποκρυπτογράφηση")
("enter passphrase for identity" "εισαγάγετε τη φράση πρόσβασης για την ταυτότητα")
("enter title information" "εισάγετε πληροφορίες τίτλου")
("entry up to date in database" "ενημερωμένη καταχώρηση στη βάση δεδομένων")
("environment variable" "μεταβλητή περιβάλλοντος")
("environments" "περιβάλλοντα")
("erode" "διαβρώσεις")
("error messages" "μηνύματα σφάλματος")
("error output" "Έξοδος σφάλματος")
("error status report" "αναφορά κατάστασης σφάλματος")
("error: bracket does not match" "σφάλμα: ο βραχίονας δεν ταιριάζει")
("error: cyclic or missing chunks detected" "σφάλμα: ανίχνευση κυκλικών ή λείπουν κομματιών")
("error: file not found" "σφάλμα: το αρχείο δεν βρέθηκε")
("error: ghostview does not seem to be installed on your system" "σφάλμα: το ghostview δεν φαίνεται να είναι εγκατεστημένο στο σύστημά σας")
("error: one of the alternatives should be filled out" "σφάλμα: μία από τις εναλλακτικές θα πρέπει να συμπληρωθεί")
("error: only one alternatives should be filled out" "σφάλμα: πρέπει να συμπληρωθεί μόνο μία εναλλακτική λύση")
("error: should fill out name for referencing" "σφάλμα: πρέπει να συμπληρώσετε το όνομα για την αναφορά")
("error: should fill out required field" "σφάλμα: πρέπει να συμπληρωθεί το απαιτούμενο πεδίο")
("evaluable field" "εκτιμητέο πεδίο")
("evaluate fields" "αξιολόγηση πεδίων")
("evaluate script" "αξιολόγηση δέσμης ενεργειών")
("evaluation" "αξιολόγηση")
("even page" "ομοιόμορφη σελίδα")
("even pages" "καθαρές σελίδες")
("events" "γεγονότα")
("exact" "ακριβές")
("execution of scripts" "εκτέλεση σεναρίων")
("exit graphics" "γραφικά εξόδου")
("exit graphics mode" "λειτουργία εξόδου γραφικών")
("expand TeXmacs macros with no LaTeX equivalents" "επεκτείνετε μακροεντολές TeXmacs χωρίς ισοδύναμα LaTeX")
("expand beamer slides" "διαστολή διαφανειών προβολέων")
("expand inclusions" "επέκταση εγκλείσματα")
("experimental features (to be used with care)" "πειραματικά χαρακτηριστικά (για χρήση με προσοχή)")
("explain" "εξηγεί")
("explanatory item" "επεξηγηματικό στοιχείο")
("explicit keystroke" "ρητό πληκτρολόγιο")
("explicit margins" "ρητά περιθώρια")
("export bibliographies as links" "Βιβλιογραφίες εξαγωγής ως συνδέσμους")
("export bibliography" "βιβλιογραφία εξαγωγών")
("export entries in buffer" "καταχωρήσεις εξαγωγής στο buffer")
("export file" "αρχείο εξαγωγής")
("export mathematical formulas as MathML" "εξαγωγή μαθηματικών τύπων ως MathML")
("export mathematical formulas as images" "εξαγωγή μαθηματικών τύπων ως εικόνων")
("export selected entries" "εξαγωγή επιλεγμένων καταχωρήσεων")
("export selection" "επιλογή εξαγωγής")
("export selection as image" "επιλογή εξαγωγής ως εικόνα")
("export selections as" "επιλογές εξαγωγής ως")
("export sessions" "σύνοδοι εξαγωγών")
("exported bibliographic entries" "εξαγόμενες βιβλιογραφικές καταχωρήσεις")
("exported bibliographic references" "εξαγόμενες βιβλιογραφικές αναφορές")
("extended" "εκτεταμένη")
("extensible left arrow" "εκτάσιμο αριστερό βέλος")
("extensible right arrow" "εκτάσιμο δεξιό βέλος")
("extern" "εξωτερικό")
("external" "εξωτερικό")
("extra branch" "επιπλέον υποκατάστημα")
("extra interline space" "επιπλέον διάστημα μεταξύ γραμμών")
("extra name" "επιπλέον όνομα")
("extract" "εκχύλισμα")
("fade" "ξεθωριάσει")
("fade in" "ξεθωριάζει")
("fade out" "ξεθωριάσει")
("fast" "γρήγορα")
("fast decrease" "γρήγορη μείωση")
("fast environments" "γρήγορα περιβάλλοντα")
("fast increase" "γρήγορη αύξηση")
("field reference" "πεδίο αναφοράς")
("fifth" "πέμπτο")
("file saved" "αποθηκευμένο αρχείο")
("fill color" "χρώμα πλήρωσης")
("filter" "φίλτρο")
("find file" "βρείτε αρχείο")
("finished collecting symbols documentation" "τεκμηρίωση τελικής συλλογής συμβόλων")
("first" "πρώτο")
("first chunk" "πρώτο κομμάτι")
("first difference" "πρώτη διαφορά")
("first error" "πρώτο σφάλμα")
("five columns" "πέντε στήλες")
("flag is off" "σημαία είναι απενεργοποιημένη")
("flag is on" "Η σημαία είναι ενεργοποιημένη")
("flatten" "ισοπεδώστε")
("floating phantom" "κυμαινόμενο φάντασμα")
("fold all" "φορές όλα")
("follow external links" "ακολουθούν εξωτερικούς συνδέσμους")
("follow inverse links" "ακολουθούν αντίστροφοι σύνδεσμοι")
("font effects" "εφέ γραμματοσειράς")
("font selector" "Επιλογέας γραμματοσειρών")
("for each" "για το καθένα")
("force reloading of translations" "επαναφόρτωση μεταφραστικών δυνάμεων")
("forward" "προς τα εμπρός")
("four columns" "τέσσερις στήλες")
("four dots" "τέσσερις κουκκίδες")
("fourth" "τέταρτο")
("fraktur" "fraktur")
("from" "από")
("front matter" "πρόσοψη")
("full" "πλήρης")
("full author list" "πλήρης κατάλογος συγγραφέων")
("gap" "χάσμα")
("garbage collection" "συλλογή απορριμμάτων")
("gaussian" "Gaussian")
("general" "γενικά")
("generated LaTeX document contains no errors" "το παραγόμενο έγγραφο LaTeX δεν περιέχει σφάλματα")
("generated field" "παραγόμενο πεδίο")
("geometry" "γεωμετρία")
("get arity" "πάρτε arity")
("get label" "πάρτε ετικέτα")
("get list with remote versions" "λήψη λίστας με απομακρυσμένες εκδόσεις")
("glyphs" "glyphs")
("gnaw" "gnaw")
("gnawed" "gnawed")
("gnuPG command" "εντολή gnuPG")
("gnuPG error: buffer encryption failed" "σφάλμα gnuPG: αποτυχία κρυπτογράφησης buffer")
("gnuPG error: cannot find suitable secret key to decrypt" "σφάλμα gnuPG: δεν είναι δυνατή η εύρεση κατάλληλου μυστικού κλειδιού για την αποκρυπτογράφηση")
("gnuPG requires name and email to have at least 5 characters" "gnuPG απαιτεί όνομα και email να έχουν τουλάχιστον 5 χαρακτήρες")
("go to anchor" "πηγαίνετε στην άγκυρα")
("go to anchor or float" "πηγαίνετε στην άγκυρα ή επιπλέουν")
("go to anchor or footnote" "πηγαίνετε στην άγκυρα ή στην υποσημείωση")
("go to float" "πηγαίνετε στο πλωτήρα")
("go to footnote" "πηγαίνετε στην υποσημείωση")
("go to section" "πηγαίνετε στο τμήμα")
("grain" "κόκκοι")
("granite" "γρανίτη")
("graphical effects" "γραφικά αποτελέσματα")
("graphical interface font scale" "γραφική κλίμακα κλίμακας διεπαφής")
("graphics" "γραφικά")
("graphics geometry" "γεωμετρία γραφικών")
("graphics grids" "πλέγματα γραφικών")
("grid" "Πλέγμα")
("grid curves" "καμπύλες πλέγματος")
("grid points" "σημεία πλέγματος")
("grid-curve intersections" "διατομές καμπύλης πλέγματος")
("group of objects" "ομάδα αντικειμένων")
("group/ungroup" "ομάδα / ungroup")
("guarantee transparent source tracking" "εγγυώνται διαφανή παρακολούθηση πηγών")
("half wide" "μισό πλάτος")
("hand drawn" "τραβηγμένο με το χέρι")
("headers" "κεφαλίδες")
("history" "ιστορία")
("homoglyph substitutions" "υποκαταστάσεις ομογλύφων")
("horizontal collapse distance" "οριζόντια απόσταση κατάρρευσης")
("horizontal margins" "οριζόντια περιθώρια")
("hyphenate as" "συγγενή ως")
("icon" "εικονίδιο")
("ignore" "αγνοούν")
("impact" "κρούση")
("import bibliography" "εισαγωγική βιβλιογραφία")
("import database entry" "εισαγωγή βάσης δεδομένων εισαγωγής")
("import entries in buffer" "καταχωρήσεις εισαγωγής στο buffer")
("import entry" "εισαγωγή εισαγωγής")
("import file" "αρχείο εισαγωγής")
("import selected database entries" "εισαγωγή επιλεγμένων καταχωρίσεων βάσης δεδομένων")
("import selected entries" "εισαγωγή επιλεγμένων καταχωρήσεων")
("import selections as" "επιλογές εισαγωγής ως")
("import sessions" "συνόδους εισαγωγής")
("import sophisticated objects as pictures" "εισαγάγετε εξελιγμένα αντικείμενα ως εικόνες")
("imported bibliographic entries" "εισαγόμενες βιβλιογραφικές καταχωρήσεις")
("inanimated" "άψυχοι")
("inch" "ίντσες")
("incomplete entries found to be filled out" "ελλιπείς καταχωρίσεις που βρέθηκαν να συμπληρώνονται")
("increase size" "μέγεθος αύξησης")
("indent paragraphs" "παύλες")
("indication" "Ένδειξη")
("initialize" "αρχικοποίηση")
("ink here" "μελάνι εδώ")
("ink in" "μελάνι σε")
("ink out" "μελάνι έξω")
("inline" "inline")
("inline content" "ενσωματωμένο περιεχόμενο")
("inner bottom" "εσωτερικός πυθμένας")
("inner left" "εσωτερικό αριστερό")
("inner right" "εσωτερική δεξιά")
("inner top" "εσωτερική κορυφή")
("input command" "εντολή εισόδου")
("input field" "πεδίο εισαγωγής")
("insert a gap" "εισάγετε κενό")
("insert a multiple choice" "εισαγάγετε μια πολλαπλή επιλογή")
("insert a negation" "εισαγάγετε μια άρνηση")
("insert a new entry" "εισαγάγετε μια νέα καταχώρηση")
("insert a question" "εισαγάγετε μια ερώτηση")
("insert a root" "εισαγάγετε μια ρίζα")
("insert a script" "εισαγάγετε μια δέσμη ενεργειών")
("insert a section block" "εισαγάγετε ένα τμήμα")
("insert a textual operator" "εισαγάγετε έναν τελεστή κειμένου")
("insert above" "εισαγάγετε παραπάνω")
("insert abstract" "εισαγάγετε περίληψη")
("insert an answer" "εισαγάγετε μια απάντηση")
("insert an operation on tuples" "εισαγάγετε μια λειτουργία σε πλειάδες")
("insert annotation" "εισαγάγει σχολιασμό")
("insert below" "εισαγάγετε παρακάτω")
("insert copyright and license information" "εισαγάγετε πληροφορίες πνευματικών δικαιωμάτων και αδειών χρήσης")
("insert explanatory item" "εισαγωγή επεξηγηματικού στοιχείου")
("insert large delimiters" "εισαγάγετε μεγάλους οριοθέτες")
("insert last name" "εισαγάγετε το επώνυμο")
("insert left" "εισαγάγετε αριστερά")
("insert missing invisible operators" "Εισαγάγετε τους αόρατους χειριστές")
("insert more names" "εισαγάγετε περισσότερα ονόματα")
("insert particle" "σωματίδιο εισαγωγής")
("insert plain text" "εισαγάγετε απλό κείμενο")
("insert right" "εισαγάγετε δεξιά")
("insert similar above" "εισαγάγετε παρόμοια παραπάνω")
("insert similar below" "εισάγετε παρόμοια παρακάτω")
("insert similar block above" "εισαγάγετε παρόμοιο μπλοκ παραπάνω")
("insert similar block below" "εισάγετε παρόμοιο μπλοκ παρακάτω")
("insert subtable" "εισαγάγετε υποκείμενα")
("insert symbol documentation" "τεκμηρίωση συμβόλου εισαγωγής")
("insert template" "Πρότυπο εισαγωγής")
("insert title after name" "εισάγετε τον τίτλο μετά το όνομα")
("insert user interface related markup" "εισαγάγετε σχετική σήμανση διεπαφής χρήστη")
("inserting control points" "εισαγωγής σημείων ελέγχου")
("intercharacter compression" "συμπίεση μεταξύ χαρακτήρων")
("intercharacter stretching" "διασταυρώσεις μεταξύ των χαρακτήρων")
("invalid multi-paragraph selection" "μη έγκυρη επιλογή πολλαπλών παραγράφων")
("invalid renaming" "μη έγκυρη μετονομασία")
("inverted breve" "ανεστραμμένο breve")
("invisible ending" "αόρατο τέλος")
("invisible newline" "αόρατη νέα γραμμή")
("invisible opening" "αόρατο άνοιγμα")
("join selected cells" "ενώνουν επιλεγμένα κελιά")
("junior" "junior")
("keep local" "κρατήστε το τοπικό")
("keep remote" "κρατήστε απομακρυσμένο")
("keep track of source code" "παρακολουθείτε τον πηγαίο κώδικα")
("laptop presentations" "φορητές παρουσιάσεις")
("large cells" "μεγάλα κύτταρα")
("large displayed" "μεγάλα εμφανιζόμενα")
("large displayed fraction" "μεγάλο εμφανές κλάσμα")
("large tables" "μεγάλοι πίνακες")
("last" "τελευταίο")
("last difference" "τελευταία διαφορά")
("last error" "τελευταίο σφάλμα")
("last name" "επώνυμο")
("left axis" "αριστερός άξονας")
("left baseline" "αριστερή γραμμή βάσης")
("left bottom" "αριστερό κάτω μέρος")
("left center" "αριστερό κέντρο")
("left click: add point; Right click: undo" "αριστερό κλικ: add point, δεξί κλικ: αναιρέστε")
("left click: finish; Right click: undo" "αριστερό κλικ: τερματισμός, δεξί κλικ: αναίρεση")
("left click: new object" "αριστερό κλικ: νέο αντικείμενο")
("left click: operate" "αριστερό κλικ: λειτουργία")
("left down" "αριστερά")
("left on even pages" "αριστερά σε ζυγό σελίδες")
("left top" "αριστερή κορυφή")
("left up" "αριστερά")
("left-right arrow" "αριστερό δεξί βέλος")
("let the environment float" "αφήστε το περιβάλλον να επιπλέει")
("line breaking" "Σπάσιμο γραμμής")
("line wrapping" "περιτύλιξη γραμμής")
("linear 2D" "γραμμική 2D")
("link image and copies as" "σύνδεσμος εικόνας και αντιγράφων ως")
("link image as" "σύνδεση εικόνας ως")
("link mode" "λειτουργία σύνδεσης")
("link to URL" "σύνδεσμος προς διεύθυνση URL")
("linking tool" "εργαλείο σύνδεσης")
("live" "ζωντανά")
("live input-output" "ζωντανή είσοδος-έξοδος")
("load help file" "αρχείο βοήθειας φόρτωσης")
("load remote file" "απομακρυσμένο αρχείο φόρτωσης")
("loading" "φόρτωση")
("local entries" "τοπικές καταχωρήσεις")
("loci" "τόποι")
("locus" "τόπος")
("locus rendering" "απεικόνιση τόπου")
("logarithmic" "λογαριθμική")
("logarithmic base" "λογαριθμική βάση")
("logging in" "σύνδεση")
("logical and" "λογική και")
("logical implication" "λογική συνέπεια")
("logical not" "λογικό όχι")
("logical or" "λογική ή")
("login" "σύνδεση")
("logout" "αποσύνδεση")
("long macro" "μακρά μακροεντολή")
("long text" "μεγάλο κείμενο")
("look for more fonts" "αναζητήστε περισσότερες γραμματοσειρές")
("loops" "βρόχοι")
("macro argument" "μακροεντολή")
("macro definition" "ορισμός μακροεντολής")
("macro name" "όνομα μακροεντολής")
("magnify horizontally" "μεγέθυνση οριζόντια")
("magnify vertically" "μεγέθυνση κάθετα")
("main presentation style" "κύριο στυλ παρουσίασης")
("make a letter environment" "Κάνετε ένα περιβάλλον γραμμάτων")
("make a multi-slide presentation" "πραγματοποιήστε μια παρουσίαση πολλαπλών διαφανειών")
("make floating" "να επιπλέουν")
("make link" "κάντε σύνδεση")
("make non floating" "μη επιπλέουν")
("manila paper" "χαρτί manila")
("map arguments" "επιχειρήματα χάρτη")
("margins from width" "περιθώρια από πλάτος")
("margins on paper" "περιθώρια σε χαρτί")
("margins on screen" "περιθώρια στην οθόνη")
("material" "υλικό")
("mathematical output" "μαθηματική έξοδος")
("maximal clustering" "μέγιστη συσσώρευση")
("maximum" "μέγιστο")
("meander" "μαιάνδρος")
("memory" "μνήμη")
("memory usage" "χρήση μνήμης")
("menu" "μενού")
("merge lines into paragraphs unless separated by blank lines" "συγχωνεύουν γραμμές σε παραγράφους εκτός αν χωρίζονται με κενές γραμμές")
("messages" "μηνύματα")
("meta data" "μεταδεδομένα")
("metadata" "μεταδεδομένα")
("metal" "μέταλλο")
("middle baseline" "μεσαία γραμμή αναφοράς")
("minimal line separation" "ελάχιστος διαχωρισμός γραμμής")
("minimum" "ελάχιστο")
("mirror" "καθρέφτης")
("miscellanous" "miscellanous")
("modify remote live document" "Τροποποίηση απομακρυσμένου ζωντανού εγγράφου")
("module" "ενότητα")
("monospaced" "μονοδιάστατα")
("more information about GNU TeXmacs can be found in the Help" "περισσότερες πληροφορίες σχετικά με το GNU TeXmacs μπορείτε να βρείτε στη Βοήθεια")
("more information about GNU TeXmacs can be found in the Help->About menu" "περισσότερες πληροφορίες σχετικά με το GNU TeXmacs μπορείτε να βρείτε στο μενού Help-> About")
("motion" "κίνηση")
("mouse over object" "ποντίκι πάνω από αντικείμενο")
("move objects" "μετακίνηση αντικειμένων")
("move over object on which to operate" "μετακινήστε το αντικείμενο πάνω στο οποίο θα λειτουργήσει")
("multiline" "πολλαπλών γραμμών")
("multiple choice" "πολλαπλή επιλογή")
("multiple root" "πολλαπλή ρίζα")
("multiplication" "πολλαπλασιασμός")
("navigation options" "επιλογές πλοήγησης")
("new account" "νέο λογαριασμό")
("new bibliography dialogue" "νέος διάλογος βιβλιογραφίας")
("new entry" "νέα εγγραφή")
("new identity" "νέα ταυτότητα")
("new locus" "νέος τόπος")
("new passphrase" "νέα φράση πρόσβασης")
("new remote directory" "νέο απομακρυσμένο κατάλογο")
("new remote file" "νέο απομακρυσμένο αρχείο")
("new style fonts" "γραμματοσειρές νέου στυλ")
("new style page breaking" "σπάσιμο σελίδας νέου στυλ")
("new version" "νέα έκδοση")
("new window" "νέο παράθυρο")
("newer version" "νεότερη έκδοση")
("next chunk" "επόμενο κομμάτι")
("next difference" "επόμενη διαφορά")
("next error" "επόμενο σφάλμα")
("next screen" "επόμενη οθόνη")
("no clustering" "χωρίς ομαδοποίηση")
("no completions" "δεν ολοκληρώθηκαν")
("no errors have been corrected" "δεν έχουν διορθωθεί σφάλματα")
("no grid" "χωρίς πλέγμα")
("no new public key in document" "δεν υπάρχει νέο δημόσιο κλειδί στο έγγραφο")
("no page numbers" "αριθμοί σελίδων")
("no parent" "κανένας γονέας")
("no selection" "καμία επιλογή")
("no spelling errors" "κανένα λάθος ορθογραφίας")
("normal loci" "φυσιολογικοί τόποι")
("not allowed to remove home directory" "δεν επιτρέπεται η κατάργηση του οικείου καταλόγου")
("not connected to server" "δεν είναι συνδεδεμένο με διακομιστή")
("not yet implemented" "δεν έχουν ακόμη εφαρμοστεί")
("notebook" "σημειωματάριο")
("number of polar steps" "αριθμός πολικών βημάτων")
("number of subunit steps" "αριθμός βαθμίδων υπομονάδας")
("numbering" "αρίθμηση")
("numeric spreadsheet" "Αριθμητικό υπολογιστικό φύλλο")
("odd page" "περίεργη σελίδα")
("odd pages" "περίεργες σελίδες")
("of fingerprint" "δακτυλικών αποτυπωμάτων")
("old version" "παλιά έκδοση")
("older version" "παλαιότερη έκδοση")
("on your system and set it up from the \"Security\" tab" "στο σύστημά σας και ρυθμίστε το από την καρτέλα \"Security\"")
("one error has been corrected" "διορθώθηκε ένα σφάλμα")
("one lower case letter, one non alpha-numeric symbol" "ένα μικρό γράμμα, ένα μη αλφαριθμητικό σύμβολο")
("one numeric character, one upper case letter" "ένας αριθμητικός χαρακτήρας, ένα κεφαλαίο γράμμα")
("only convert changes when re-importing" "Το μετατρέπει μόνο τις αλλαγές κατά την επανεισαγωγή")
("only convert changes with respect to imported version" "μετατρέπουν μόνο τις αλλαγές σε σχέση με την εισαγόμενη έκδοση")
("only convert changes with respect to tracked version" "μετατρέπουν μόνο τις αλλαγές σε σχέση με την παρακολούθηση της έκδοσης")
("only implemented for complete subtrees" "εφαρμόζεται μόνο για πλήρεις υποπεριοχές")
("only keep folded" "κρατάτε μόνο διπλωμένο")
("only keep unfolded" "μόνο συνεχίζουν να εκτυλίσσονται")
("only show semantic focus" "δείχνουν μόνο σημασιολογική εστίαση")
("opacity" "αδιαφάνεια")
("open bibliography" "ανοιχτή βιβλιογραφία")
("open identities" "ανοιχτές ταυτότητες")
("open in new window" "ανοίξτε σε νέο παράθυρο")
("open key manager" "διαχειριστής ανοιχτού κλειδιού")
("open licence agreement" "ανοικτή άδεια χρήσης")
("open mailbox" "ανοιχτό γραμματοκιβώτιο")
("open module browser" "πρόγραμμα περιήγησης ανοιχτής μονάδας")
("open symbol browser" "πρόγραμμα περιήγησης ανοιχτού συμβόλου")
("open tool in separate window" "ανοιχτό εργαλείο σε ξεχωριστό παράθυρο")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ή δώστε την πλήρη διαδρομή στην εντολή \"gpg\" ή \"gpg2\"")
("order" "σειρά")
("ordinary symbol" "σύνηθες σύμβολο")
("other login" "άλλες συνδέσεις")
("outer bottom" "εξωτερικός πυθμένας")
("outer left" "εξωτερικό αριστερό")
("outer right" "εξωτερική δεξιά")
("outer top" "εξωτερική κορυφή")
("outline" "περίγραμμα")
("outlined" "περιγράφονται")
("outlined emboss" "σκιαγραφημένο ανάγλυφο")
("outlined engrave" "περίγραμμα χαραγμένο")
("oval" "οβάλ")
("overlap" "αλληλοεπικάλυψη")
("overlays" "επικαλύψεις")
("overview of the scheme extension language" "επισκόπηση της γλώσσας επέκτασης του σχεδίου")
("padded" "γεμισμένο")
("page background" "φόντο σελίδας")
("page breaking algorithm" "αλγόριθμος σπάσιμο σελίδας")
("page number" "Αριθμός σελίδας")
("page number rendering" "απόδοση σελίδας")
("page rendering" "Απόδοση σελίδας")
("palette" "παλέτα")
("panorama" "πανόραμα")
("parenthesis" "παρένθεση")
("parenthesized" "παρενθέσεις")
("particle" "σωματίδιο")
("passphrase encryption" "κρυπτογράφηση κωδικού πρόσβασης")
("passphrase wallet facilities are not currently available" "εγκαταστάσεις πορτοφολιού κωδικού πρόσβασης δεν είναι επί του παρόντος διαθέσιμες")
("passphrases are expected to have at least: 8 characters" "φράσεις πρόσβασης αναμένεται να έχουν τουλάχιστον: 8 χαρακτήρες")
("passphrases mismatch" "αναντιστοιχίες φρασεών")
("pastel" "παστέλ")
("pattern" "πρότυπο")
("pause" "παύση")
("pen width" "πλάτος στυλό")
("permanent footer" "μόνιμο υποσέλιδο")
("permanent header" "μόνιμη κεφαλίδα")
("permanently add to dictionary" "προσθήκη μόνιμα στο λεξικό")
("permanently insert into dictionary" "μόνιμα εισάγετε στο λεξικό")
("permissions" "δικαιώματα")
("phantom" "φάντασμα")
("physics and astronomy class" "τάξη φυσικής και αστρονομίας")
("picture" "εικόνα")
("pine" "πεύκα")
("plain boxes" "απλά πλαίσια")
("plain circles" "απλοί κύκλοι")
("play" "παιχνίδι")
("play animation" "κινούμενα σχέδια")
("please install GnuPG software from https://www.gnupg.org" "παρακαλούμε εγκαταστήστε το λογισμικό GnuPG από https://www.gnupg.org")
("plug-ins" "plug-ins")
("plural" "πληθυντικός")
("point" "σημείο")
("polar" "πολικό")
("polygon" "πολύγωνο")
("pop server settings" "ρυθμίσεις διακομιστή ποπ")
("position of marginal note" "θέση περιθωριακής σημείωσης")
("poster formats" "μορφές αφίσας")
("poster theme" "θέμα αφίσας")
("postfix" "postfix")
("preferences for editing mathematical formulas" "προτιμήσεις για την επεξεργασία μαθηματικών τύπων")
("prefix" "πρόθεμα")
("presentation tool" "εργαλείο παρουσίασης")
("preserve" "διατηρήστε")
("preserve tags" "διατήρηση ετικετών")
("pretty tree output" "όμορφη δέντρο εξόδου")
("previous difference" "προηγούμενη διαφορά")
("previous error" "προηγούμενο σφάλμα")
("previous screen" "προηγούμενη οθόνη")
("primitive or macro" "πρωτόγονη ή μακροεντολή")
("print buffer" "buffer αποτύπωσης")
("print buffer to file" "buffer για εκτύπωση σε αρχείο")
("print to file" "εκτύπωση σε αρχείο")
("printer setup" "ρύθμιση εκτυπωτή")
("program bracket matching" "αντιστοίχιση βραχίονα προγράμματος")
("program bracket selections" "επιλογές βραχίονα προγράμματος")
("program commands" "εντολές προγράμματος")
("program interface for buffer management" "διεπαφή προγράμματος για τη διαχείριση buffer")
("programming routines for editing documents" "ρουτίνες προγραμματισμού για την επεξεργασία εγγράφων")
("provoke C++ error" "προκαλεί σφάλμα C++")
("provoke menu error" "προκαλεί σφάλμα μενού")
("provoke scheme error" "σφάλμα πρόκλησης σφάλματος")
("public key encryption" "κρυπτογράφηση δημόσιου κλειδιού")
("public keys" "δημόσια κλειδιά")
("pulse" "παλμός")
("qt GUI only, sorry. Use \"Export selection\"" "qt GUI μόνο, συγγνώμη. Χρησιμοποιήστε την επιλογή \"Εξαγωγή επιλογής\"")
("qt-widgets" "qt-widgets")
("quantifier" "ποσοτικοποιητής")
("quasi" "οιονεί")
("questions only" "ερωτήσεις μόνο")
("questions with answers" "ερωτήσεις με απαντήσεις")
("quick evaluation of formulas" "γρήγορη αξιολόγηση των τύπων")
("raw" "ακατέργαστο")
("really delete user identity" "Διαγράψτε πραγματικά την ταυτότητα του χρήστη")
("rebuild translations file" "επαναδημιουργία αρχείων μεταφράσεων")
("recent documents" "πρόσφατα έγγραφα")
("recipients" "παραλήπτες")
("recognize" "αναγνωρίζουν")
("rectangular" "ορθογώνια")
("reduced margins" "μειωμένα περιθώρια")
("regenerate" "αναδημιουργία")
("register file" "αρχείο μητρώου")
("relate" "αναφέρονται")
("relation" "σχέση")
("release left button: finish editing" "αριστερό κουμπί απελευθέρωσης: τελειώστε την επεξεργασία")
("remote" "απομακρυσμένη")
("remote connections" "απομακρυσμένες συνδέσεις")
("remote controllers with keyboard simulation" "τηλεχειριστήρια με προσομοίωση πληκτρολογίου")
("remote directory" "απομακρυσμένος κατάλογος")
("remote servers" "απομακρυσμένοι διακομιστές")
("remote tool" "απομακρυσμένο εργαλείο")
("remove database entry" "Καταργήστε την καταχώρηση της βάσης δεδομένων")
("remove downwards" "αφαίρεση προς τα κάτω")
("remove entries" "Κατάργηση εγγραφών")
("remove entry" "Αφαίρεση καταχώρησης")
("remove field above" "καταργήστε το πεδίο παραπάνω")
("remove field below" "Αφαίρεση πεδίου κάτω")
("remove folded" "αφαιρέστε διπλωμένο")
("remove leftwards" "Αφαιρέστε αριστερά")
("remove link" "αφαιρέστε το σύνδεσμο")
("remove rightwards" "αφαίρεση δεξιά")
("remove selected database entries" "Αφαίρεση επιλεγμένων καταχωρίσεων βάσης δεδομένων")
("remove selected entries" "Αφαίρεση επιλεγμένων καταχωρήσεων")
("remove superfluous invisible operators" "αφαιρέστε τους περιττούς αόρατους χειριστές")
("remove tag" "αφαιρέστε ετικέτα")
("remove this branch" "αφαιρέστε αυτό το υποκατάστημα")
("remove unfolded" "αφαιρέστε ξεδιπλωμένο")
("remove upwards" "αφαιρέστε προς τα πάνω")
("removed entries from database" "καταργημένες καταχωρήσεις από τη βάση δεδομένων")
("removed entry from database" "κατάργηση καταχώρισης από βάση δεδομένων")
("rename" "μετονομάστε")
("rename section" "τμήμα μετονομασία")
("replace TeXmacs styles with no LaTeX equivalents" "αντικαθιστούν τα στυλ TeXmacs χωρίς ισοδύναμα LaTeX")
("replace toolbar" "αντικαταστήστε τη γραμμή εργαλείων")
("reset error counters" "μετρητές σφαλμάτων επαναφοράς")
("resize objects" "αλλαγή μεγέθους αντικειμένων")
("restart TeXmacs in order to let changes take effect" "επανεκκίνηση του TeXmacs για να επιτραπεί η πραγματοποίηση αλλαγών")
("restart in order to let the new look and feel take effect" "επανεκκίνηση για να αφήσει το νέο βλέμμα και αίσθηση να τεθεί σε ισχύ")
("retain" "διατηρήστε")
("retime" "retime")
("retina settings" "ρυθμίσεις αμφιβληστροειδούς")
("retrieve email" "Ανάκτηση email")
("retrieve remote live document" "ανάκτηση απομακρυσμένου ζωντανού εγγράφου")
("retrieved contents" "ανακτώμενα περιεχόμενα")
("reverse" "αντίστροφη")
("reverse ordering" "αντίστροφη σειρά")
("ridged paper" "συρραφθέν χαρτί")
("right baseline" "δεξιά γραμμή βάσης")
("right down" "προς τα κάτω")
("right on even pages" "δεξιά σε ζυγό σελίδες")
("right up" "δεξιά επάνω")
("rotate" "περιστροφή")
("rotate objects" "περιστροφή αντικειμένων")
("rough" "τραχύ")
("rough paper" "ακατέργαστο χαρτί")
("round" "γύρο")
("round overbrace" "στρογγυλό overbrace")
("round underbrace" "στρογγυλό κάτω μέρος")
("run current file" "τρέχον τρέχον αρχείο")
("same names" "ίδια ονόματα")
("same screen margins as on paper" "ίδια περιθώρια οθόνης όπως στο χαρτί")
("sample text" "δείγμα κειμένου")
("save auxiliary data" "αποθήκευση βοηθητικών δεδομένων")
("save entries" "αποθήκευση καταχωρήσεων")
("save entry" "αποθήκευση εγγραφής")
("save image as" "αποθήκευση εικόνας ως")
("save position" "αποθήκευση θέσης")
("save remote file" "Αποθήκευση απομακρυσμένου αρχείου")
("saved modifications in database" "αποθηκευμένες τροποποιήσεις στη βάση δεδομένων")
("scheme developers guide" "οδηγός προγραμματιστών")
("scheme extensions" "επεκτάσεις συστημάτων")
("scheme interface for the graphical mode" "Διεπαφή σχήματος για τη γραφική παράσταση")
("screen" "Οθόνη")
("screen rendering" "απεικόνιση οθόνης")
("screens" "Οθόνες")
("screenshot" "στιγμιότυπο οθόνης")
("scripting language" "γλώσσα δέσμης ενεργειών")
("scripts" "scripts")
("search and replace" "αναζήτηση και αντικατάσταση")
("search toolbar" "γραμμή εργαλείων αναζήτησης")
("second" "δεύτερη")
("secret keys" "μυστικά κλειδιά")
("sections" "τμήματα")
("see documentation" "βλέπε τεκμηρίωση")
("select pen" "επιλογή στυλό")
("select the action to be undertaken for each conflict" "επιλέξτε τη δράση που πρέπει να αναληφθεί για κάθε σύγκρουση")
("select view mode" "επιλογή λειτουργίας προβολής")
("semantic correctness" "σημασιολογική ορθότητα")
("semantic editing" "σημασιολογική επεξεργασία")
("semantic selections" "σημασιολογικές επιλογές")
("semantics" "σημασιολογία")
("senior" "ανώτεροι")
("serif" "serif")
("server" "εξυπηρετητής")
("session commands" "εντολές συνεδρίας")
("sessions" "συνεδρίες")
("set default" "προεπιλογή")
("set difference" "διαφορά τιμής")
("set intersection" "διασταυρώσεις")
("set number of columns" "καθορισμένος αριθμός στηλών")
("set number of rows" "καθορισμένος αριθμός γραμμών")
("set properties" "σύνολο ιδιοτήτων")
("set union" "σύνολο ένωση")
("set user information" "καθορισμός πληροφοριών χρήστη")
("seventh" "έβδομο")
("shadow" "σκιά")
("shadowed" "σκιασμένη")
("shadowed raise" "σκιασμένη αύξηση")
("show current focus" "δείχνουν την τρέχουσα εστίαση")
("show full context" "εμφάνιση πλήρους πλαισίου")
("show key presses" "εμφανίζει πλήκτρα")
("show main document" "εμφάνιση κύριου εγγράφου")
("show memory usage" "εμφάνιση χρήσης μνήμης")
("show panorama" "πανοραμική εικόνα")
("show preamble" "προοίμιο εμφάνισης")
("show subunits" "παρουσιάζουν υπομονάδες")
("show table cells" "στοιχεία πίνακα επιδείξεων")
("side tools" "πλευρικά εργαλεία")
("simple" "απλά")
("sixth" "έκτο")
("skew" "λοξή")
("skip all" "παραλείψτε όλα")
("slant" "κλίση")
("slashed fraction" "κομμένο τμήμα")
("slow" "αργή")
("slow decrease" "αργή μείωση")
("slow increase" "αργή αύξηση")
("small capitals" "μικρά κεφάλαια")
("small environment box" "μικρό πλαίσιο περιβάλλοντος")
("small focus" "μικρή εστίαση")
("small inline" "μικρά inline")
("small inline fraction" "μικρό κλάσμα inline")
("smooth" "ομαλή")
("smooth end" "ομαλό άκρο")
("smooth extremities" "ομαλά άκρα")
("smooth start" "ομαλή εκκίνηση")
("snap" "snap")
("snap distance" "απόσταση αποκοπής")
("snap to curves" "κουμπώνει στις καμπύλες")
("snap to grid" "πατήστε στο πλέγμα")
("snap to grid curve" "καμπύλη στο πλέγμα")
("snap to intersections of curves" "κουμπώνει στις διασταυρώσεις των καμπυλών")
("snap to text borders" "πρόσκρουση στα όρια κειμένου")
("snap to text corners" "προσκόλληση στις γωνίες κειμένου")
("solution to exercise" "λύση για την άσκηση")
("solution to problem" "λύση στο πρόβλημα")
("solutions" "διαλύματα")
("source macros tool" "Εργαλείο μακροεντολών προέλευσης")
("south" "νότια")
("south east" "νοτιοανατολικά")
("space bar in math mode" "space bar σε κατάσταση μαθηματικών")
("space bar in text mode" "διαστήματα στη λειτουργία κειμένου")
("space stretchability" "διαστασιοποίηση χώρου")
("span" "έκταση")
("span over all columns" "Μήκος πάνω από όλες τις στήλες")
("specific baseline" "ειδική γραμμή βάσης")
("specify color alternation" "καθορίστε εναλλαγή χρωμάτων")
("specify how to traverse the manual" "καθορίστε τον τρόπο μετάβασης από το εγχειρίδιο")
("specify semantics of a symbol or formula" "προσδιορίστε τη σημασιολογία ενός συμβόλου ή ενός τύπου")
("spell check" "Έλεγχος ορθογραφίας")
("spline" "spline")
("split program" "split program")
("square" "τετράγωνο")
("square overbrace" "τετράγωνο overbrace")
("square underbrace" "τετράγωνο κάτω μέρος")
("stack" "στοίβα")
("standard Output" "τυπική έξοδος")
("standard fraction" "πρότυπο κλάσμα")
("star" "αστέρι")
("start server" "αρχικός διακομιστής")
("statement" "δήλωση")
("status" "Κατάσταση")
("stop server" "server stop")
("storage" "αποθήκευση")
("store tracking information in LaTeX files" "πληροφορίες παρακολούθησης καταστημάτων σε αρχεία LaTeX")
("stretch factor" "συντελεστής τάνυσης")
("structured insert above" "Δομημένο ένθετο παραπάνω")
("structured insert at the left" "δομημένο ένθετο στα αριστερά")
("structured insert at the right" "δομημένο ένθετο στα δεξιά")
("structured insert below" "Δομημένο ένθετο κάτω από")
("structured remove downwards" "δομημένη κατάργηση προς τα κάτω")
("structured remove leftwards" "δομημένη αφαίρεση αριστερά")
("structured remove rightwards" "δομημένη αφαίρεση προς τα δεξιά")
("structured remove upwards" "δομημένη αφαίρεση προς τα πάνω")
("structured variant" "δομημένη παραλλαγή")
("subject" "θέμα")
("submenu" "υπομενού")
("subscript below" "δείκτης παρακάτω")
("subsubmenu" "δευτερεύον υποσύνολο")
("subsubsubmenu" "sububsubmenu")
("subsubsubsubmenu" "sububub sububmenu")
("subtraction" "αφαίρεση")
("superscript above" "παραπάνω δείγμα")
("supported plug-ins" "υποστηριζόμενες προσθήκες")
("switch to buffer" "αλλαγή στο buffer")
("symbol properties not found" "Δεν βρέθηκαν ιδιότητες συμβόλων")
("symbols" "σύμβολα")
("synchronize" "συγχρονισμός")
("synchronize bibliographic references" "συγχρονισμός βιβλιογραφικών αναφορών")
("synchronize with remote server" "συγχρονισμός με απομακρυσμένο διακομιστή")
("synopsis" "σύνοψη")
("tab-completion" "ολοκλήρωση καρτελών")
("table breaking" "σπάσιμο πίνακα")
("table properties" "ιδιότητες πίνακα")
("tags with special rendering" "ετικέτες με ειδική απόδοση")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Αναμενόμενο ρυθμιστικό διάλυμα  TeXmacs")
("teXmacs buffer on disk expected" "buffer TeXmacs στο δίσκο αναμένεται")
("teXmacs extensions to scheme and utilities" "επεκτάσεις TeXmacs στο σχέδιο και τις βοηθητικές εφαρμογές")
("teXmacs macro" "macro TeXmacs")
("teXmacs package" "πακέτο TeXmacs")
("teXmacs primitives" "αρχικά TeXmacs")
("teXmacs style" "στυλ TeXmacs")
("test routine" "ρουτίνα δοκιμής")
("testing tree-view" "έλεγχος δέντρου-προβολή")
("text borders" "σύνορα κειμένου")
("text box style" "στυλ πλαισίου κειμένου")
("text corners" "γωνίες κειμένου")
("textual" "κείμενο")
("textual operator" "χειριστής κειμένου")
("textual spreadsheet" "υπολογιστικό φύλλο με κείμενο")
("theme parameters" "παράμετροι θέματος")
("these collected public keys will be definitely lost" "αυτά τα συλλεγμένα δημόσια κλειδιά θα χαθούν σίγουρα")
("these public keys will be definitely lost" "αυτά τα δημόσια κλειδιά θα χαθούν σίγουρα")
("these secret keys will be definitely lost" "αυτά τα μυστικά κλειδιά θα χαθούν σίγουρα")
("thicken" "πάχος")
("third" "τρίτο")
("this" "αυτό")
("this page number" "αυτός ο αριθμός σελίδας")
("this style specifies page margins in the TeX way" "αυτό το στυλ καθορίζει τα περιθώρια της σελίδας με τον τρόπο TeX")
("three columns" "τρεις στήλες")
("three dots" "τρεις κουκκίδες")
("through popup windows" "μέσω αναδυόμενων παραθύρων")
("through the menus" "μέσω των μενού")
("time evolution" "εξέλιξη χρόνου")
("timings" "χρονισμοί")
("title presentation options" "επιλογές παρουσίασης τίτλου")
("title style" "στυλ τίτλου")
("title suffix" "κατάληξη τίτλου")
("titled block" "τίτλο μπλοκ")
("toggle cell wrapping mode" "εναλλαγή τρόπου περιτύλιξης κυττάρων")
("toggle here" "εναλλαγή εδώ")
("toggle off" "εναλλαγή")
("toggle on" "ενεργοποίηση")
("tolerant" "ανεκτικό")
("top baseline" "ανώτερη βασική γραμμή")
("top table padding" "επένδυση κορυφαίας τράπεζας")
("transform" "μετασχηματισμός")
("transform cell into subtable" "μετασχηματίζουμε το κύτταρο σε υποτάξιμο")
("translations" "μεταφράσεις")
("translations loaded" "φορτωμένες μεταφράσεις")
("traverse" "τραβέρσα")
("triangle" "τρίγωνο")
("turn off" "απενεργοποίηση")
("turn on" "ενεργοποίηση")
("two dots" "δύο κουκκίδες")
("type a latex command followed by return" "πληκτρολογήστε μια εντολή latex που ακολουθείται από επιστροφή")
("unevaluated argument" "ανεκμετάλλευτο επιχείρημα")
("unevaluated value" "μη αναπροσαρμοσμένη αξία")
("unfold" "ξεδιπλώστε")
("unfold all" "ξεδιπλώστε όλα")
("unit" "μονάδα")
("unit length" "Μήκος μονάδας")
("unknown secret key fingerprint" "άγνωστο απόσπασμα μυστικού κλειδιού")
("unregistered file" "μη καταχωρημένο αρχείο")
("unsecure script refused" "απρόσκοπτη δέσμη ενεργειών απορρίφθηκε")
("unsupported link mode" "μη υποστηριζόμενη λειτουργία σύνδεσης")
("until" "μέχρι")
("untitled block" "μπλοκ χωρίς τίτλο")
("up to date" "ενημερωμένα")
("update buffer" "buffer ενημέρωσης")
("update this buffer" "ενημερώστε αυτό το buffer")
("upight" "επάνω")
("upload" "μεταφόρτωση")
("use CSS for more advanced formatting" "χρήση CSS για πιο προηγμένη μορφοποίηση")
("use as master" "χρήση ως κύριος")
("use extensible brackets" "χρήση επεκτάσιμων στηριγμάτων")
("use line wrapping for lines which are longer than 80 characters" "χρήση περιτυλίγματος γραμμής για γραμμές μεγαλύτερες των 80 χαρακτήρων")
("use margin kerning (protrusion)" "πυκνότητα περιθωρίου χρήσης (προεξοχή)")
("use protrusion" "χρήση προεξοχής")
("use relative path" "χρήση σχετικής διαδρομής")
("user interface" "περιβάλλον χρήστη")
("user interface language" "γλώσσα διεπαφής χρήστη")
("utilities" "βοηθητικά προγράμματα")
("vanish" "εξαφανίζονται")
("verbose" "verbose")
("version" "έκδοση")
("versioning tool" "εργαλείο έκδοσης")
("vertical margins" "κατακόρυφα περιθώρια")
("vertical space stretchability" "κατακόρυφη διατομή διαστήματος")
("visible except here" "ορατά εκτός από εδώ")
("visible from here on" "ορατό από εδώ και πέρα")
("visible only here" "ορατό μόνο εδώ")
("visible until here" "ορατά μέχρι εδώ")
("visited loci" "επισκέφθηκαν τόπους")
("wallet" "πορτοφόλι")
("wave" "κύμα")
("weight" "βάρος")
("when line wrapping" "όταν τυλίγεται γραμμή")
("wide" "πλάτος")
("wide block" "ευρύ μπλοκ")
("wide colored" "ευρεία έγχρωμη")
("wide float" "Πλάτος")
("wide footnote" "Ευρεία υποσημείωση")
("wide tabular" "Πλάτος πλάτος")
("widescreen" "ευρεία οθόνη")
("writing TeXmacs bibliography styles" "γράφοντας τις μορφές βιβλιογραφίας του TeXmacs")
("writing documentation" "τεκμηρίωση γραφής")
("wrong empty passphrase" "λάθος κενή φράση πρόσβασης")
("wrong passphrase" "λανθασμένη φράση πρόσβασης")
("year" "έτος")
("you are attempting to open an encrypted file while" "προσπαθείτε να ανοίξετε ένα κρυπτογραφημένο αρχείο ενώ")
("you might consider enabling the experimental" "μπορείτε να εξετάσετε το ενδεχόμενο ενεργοποίησης του πειραματικού")
("you must add a bibliography file" "πρέπει να προσθέσετε ένα αρχείο βιβλιογραφίας")
("you should also make sure that GnuPG is installed" "θα πρέπει επίσης να βεβαιωθείτε ότι το GnuPG είναι εγκατεστημένο")
("your personal dictionary has been modified" "το προσωπικό λεξικό σας έχει τροποποιηθεί")
