("\"encryption\" features from the preference panel" "\"salaus\" ominaisuudet asetuspaneelista")
("(Re)Build autocompletion index" "(Re) Rakenna automaattisen täydentämisen hakemisto")
("a modifier" "modifioija")
("a series" "sarja")
("a.C.M. computing class" "automaattisen luokan luokka")
("a.M.S. subject class" "a.M.S. aihetta")
("abbreviated authors" "lyhennetyt kirjailijat")
("abreviated authors" "poistettua kirjailijaa")
("accent above" "aksentti yllä")
("accent below" "aksentti alle")
("accept during this pass" "hyväksy tämän passin aikana")
("acknowledgments" "tunnustusta")
("activate hidden" "aktivoi piilotettu")
("activate once" "aktivoi kerran")
("activation" "aktivointi")
("active link types" "aktiivista linkityyppiä")
("add" "lisää")
("add abstract information" "lisää abstraktit tiedot")
("add author information" "lisää kirjoittajan tiedot")
("add branch after" "lisää haara jälkeen")
("add branch before" "lisää haara ennen")
("add other package" "lisää toinen paketti")
("add package" "lisää paketti")
("add style package" "lisää tyylipaketti")
("add title information" "lisää otsikon tiedot")
("addition" "lisäys")
("adjust" "säädä")
("adjust limits" "säädä rajoituksia")
("advanced font customization" "edistynyt fonttien mukauttaminen")
("affiliation" "kuuluminen")
("albanian" "albanialaista")
("align cell to the decimal comma" "Kohdista solu desimaalin pilkkuun")
("align cell to the decimal dot" "Kohdista solu desimaalipisteeseen")
("align table at axis" "Kohdista taulukko akselilla")
("aligned" "kohdistettu")
("alignment of balloon" "ilmapallon kohdistus")
("all cells" "kaikki solut")
("all data attached to this identity will be lost" "kaikki tähän identiteettiin liitetyt tiedot menetetään")
("all saved passphrases will be lost forever" "kaikki tallennetut salasanat menetetään ikuisesti")
("allow for macro definitions in preamble" "sallia makromääritelmät johdannossa")
("allow multiple spaces" "salli useita välilyöntejä")
("allow spurious spaces" "salli väärät tilat")
("allowed page height extension" "sivun korkeuden sallittu laajennus")
("allowed page height reduction" "sallittu sivukorkeuden alennus")
("allowed positions" "sallittua paikkaa")
("allowed positions of floating object" "kelluvan esineen sallitut sijainnit")
("alpha transparency" "alfa läpinäkyvyys")
("also on paper" "myös paperilla")
("alter" "muutos")
("alternate" "varajäsen")
("alternate except here" "varajäsen paitsi täällä")
("alternate from here on" "varajäsen täältä")
("alternate only here" "vain varajäsen täällä")
("alternate until here" "varajäsen tähän asti")
("alternative colors" "vaihtoehtoista väriä")
("alternative specification" "vaihtoehtoinen eritelmä")
("always" "aina")
("american" "amerikkalainen")
("amplified" "vahvistettu")
("ancient" "muinaista")
("and perform casual settings from the \"Encryption\" tab" "ja suorita satunnaiset asetukset \"Salaus\"-välilehdeltä")
("angular" "kulmikas")
("animate" "animoi")
("animate folding" "animoitu taittaminen")
("animate object" "animoitu esine")
("animate objects" "animoivia esineitä")
("animate unfolding" "animoitu avautuminen")
("animated" "animoitu")
("animation" "animaatio")
("animation toolbar" "animaatiotyökalurivi")
("annotate" "huomautus")
("answer" "vastaus")
("answer field" "vastauskenttä")
("answer to question" "vastaus kysymykseen")
("answers only" "vain vastaukset")
("any" "mikä tahansa")
("appear" "ilmesty")
("apply macro" "käytä makroa")
("apply macro once" "käytä makro kerran")
("approximate" "likimääräinen")
("arc" "kaari")
("arc cosine" "valokaariin")
("arc sine" "kaari-sini")
("arc tangent" "kaari-tangentti")
("arch series" "kaari-sarja")
("are you sure you want to delete collected public keys" "oletko varma, että haluat poistaa kerätyt julkiset avaimet")
("are you sure you want to delete selected public keys" "oletko varma, että haluat poistaa valitut julkiset avaimet")
("are you sure you want to delete selected secret keys" "oletko varma, että haluat poistaa valitut salaiset avaimet")
("are you sure you want to destroy the wallet" "oletko varma, että haluat tuhota lompakon")
("art Pen" "taidekynä")
("art frame" "taidetta")
("arxiv category" "arxiv-luokka")
("as visual grid" "visuaalisena ruudukkona")
("aspect" "puoli")
("attach master" "liitä päällikkö")
("attached" "liitteenä")
("auto" "auto")
("auto-save file" "automaattinen tallennustiedosto")
("automatic brackets" "automaattiset hakasulkeet")
("automatic content generation" "automaattinen sisällöntuotanto")
("automatic program brackets" "automaattista ohjelmasulketta")
("automatic quotes" "automaattista tarjousta")
("automatically close brackets" "sulkevat automaattisesti suluissa")
("automatically import bibliographies when opening files" "Tuo bibliografiat automaattisesti tiedostojen avaamisen yhteydessä")
("automatically remember all passphrases in the wallet" "muistaa kaikki lompakon tunnuslauseet automaattisesti")
("automatically save" "tallentaa automaattisesti")
("autosave" "automaattinen tallennus")
("avoid spurious spaces" "välttää vääriä tiloja")
("axis" "akseli")
("b series" "b-sarja")
("back" "takaisin")
("background evaluations" "taustaarviointia")
("background picture selector" "taustakuvan valitsin")
("backtrace errors" "taaksepäinvirheet")
("base" "pohja")
("baseline" "perustaso")
("basic communication using pipes" "perusviestintä putkien avulla")
("beamer" "beamer")
("beamer formats" "beamer-muodot")
("beamer theme" "beamer-teema")
("bench" "penkki")
("bend bottom" "taivuta pohja")
("bend corner" "taivutuskulma")
("bend diagonal" "taivutustaso")
("bend in" "taipua sisään")
("bend out" "taivuta")
("bezier" "bezier")
("bibTeX command" "bibTeX-komento")
("bidirectional" "kaksisuuntainen")
("big environment box" "iso ympäristölaatikko")
("big focus" "suuri fokus")
("binary operator" "binaarioperaattori")
("bitmap resolution (dpi)" "bittikarttatarkkuus (dpi)")
("black floral I" "musta kukka I")
("black floral II" "musta kukka II")
("blackboard embold" "liitutaulun sisustus")
("blank column" "tyhjä sarake")
("blank row" "tyhjä rivi")
("block" "estää")
("block content" "estä sisältöä")
("block of code" "koodilohko")
("blur" "hämärtää")
("both versions" "molemmat versiot")
("bottom baseline" "alhaalta lähtötasoa")
("bottom cell border" "solun alareuna")
("bottom cell padding" "pohjakennon täyte")
("bottom table border" "pöydän alareuna")
("bottom table padding" "pohjapöydän pehmuste")
("bottom tools" "pohjatyökalua")
("box" "laatikko")
("broken white" "rikki valkoinen")
("browse back" "selaa takaisin")
("browse forward" "selaa eteenpäin")
("browse modules documentation" "selaa moduulien dokumentaatiota")
("buffer management" "puskurinhallinta")
("buffer must be on disk" "puskurin on oltava levyllä")
("buffer must have a name" "puskurilla on oltava nimi")
("build buffer" "rakenna puskuri")
("build buffer in" "rakenna puskuri sisään")
("build directory" "rakennushakemisto")
("build directory in" "rakenna hakemisto")
("build link pages" "rakenna linkkisivut")
("build-all" "rakenna kaikki")
("bulgarian" "bulgaria")
("bump" "kohokohta")
("busy" "varattu")
("cJK" "cJK")
("cJK spacing" "cJK-etäisyys")
("calculus" "calculus")
("cancelled" "peruutettu")
("cannot download directory to file" "ei voi ladata hakemistoa tiedostoon")
("cannot rename across different servers" "ei voi nimetä uudelleen eri palvelimilla")
("cannot upload directory to file" "ei voi ladata hakemistoa tiedostoon")
("cartesian" "kartesilainen")
("carved wood" "veistetty puu")
("case-insensitive search" "tapauskohtaisesti haku")
("categories" "luokkaa")
("category" "luokka")
("cell properties" "soluominaisuudet")
("cells" "solua")
("center baseline" "keskustaso")
("chalk" "liitu")
("change default unit" "muuta oletusyksikkö")
("change passphrase" "muuta tunnuslause")
("change permissions" "muuttaa käyttöoikeuksia")
("change step-size" "muuta askelkokoa")
("change tags" "vaihda tunnisteita")
("change the TeXmacs preferences" "muuttaa TeXmacs-asetuksia")
("change the border of the table" "muuta taulukon reunaa")
("change the style of mathematical formulas" "muuttaa matemaattisten kaavojen tyyliä")
("change wallet passphrase" "vaihda lompakon tunnuslause")
("character contraction" "merkin supistuminen")
("character encoding" "merkkikoodaus")
("character expansion" "merkin laajennus")
("check exported Pdf files for correctness" "tarkista vietyjen pdf-tiedostojen oikeellisuus")
("check for automatic updates" "tarkista automaattiset päivitykset")
("check for updates" "tarkista päivitykset")
("checkable field" "tarkistettava kenttä")
("choose background" "valitse tausta")
("choose color" "valitse väri")
("cipher algorithm for passphrase encryption" "salausalgoritmi salalausekoodien salaamiseen")
("circle" "ympyrä")
("classification" "luokittelu")
("clean slate" "puhdas liuskekivi")
("clear all fields" "tyhjennä kaikki kentät")
("clear local information" "selkeät paikalliset tiedot")
("clear menu" "tyhjennä valikko")
("clear undo history" "tyhjentä kumoa historia")
("click Ok button twice to discard this warning" "napsauta Ok-painiketta kahdesti hylätä tämä varoitus")
("clip" "leike")
("clipboard image format" "leikepöydän kuvamuoto")
("close animation tool" "sulje animaatiotyökalu")
("close document" "suljettu asiakirja")
("close program" "suljettu ohjelma")
("close replace tool" "sulje korvaava työkalu")
("close search tool" "sulje hakutyökalu")
("close spell tool" "sulje oikeinkirjoituksen työkalu")
("close translations to rebuild" "sulje käännökset uudelleenrakentamiseksi")
("closed bezier" "suljettu bezier")
("closed curve" "suljettu käyrä")
("closed smooth" "suljettu sileä")
("closed spline" "suljettu spline")
("closing style" "sulkemistyyli")
("cluster by affiliation" "klusteri kuulumisen mukaan")
("collect garbage" "kerätä roskat")
("collected keys" "kerättyä avainta")
("color of the axes" "akselien väri")
("color of the subunits" "alayksiköiden väri")
("color of the units" "yksiköiden väri")
("colors" "väriä")
("column to the left" "sarake vasemmalla")
("column to the right" "sarake oikealla")
("columns" "saraketta")
("column separation" "kolonnien erottelu")
("commit" "sitoudu")
("commit file" "lähettä tiedosto")
("common" "yhteinen")
("common formats" "yleiset muodot")
("commutative diagram" "kommutatiivinen kaavio")
("compact" "kompakti")
("compactification" "tiivistäminen")
("compactify" "tiivistä")
("compare" "vertaa")
("compare with" "vertaa")
("complete bibliographic reference" "täydellinen bibliografinen viite")
("completion" "valmistuminen")
("complex actions" "monimutkaiset toimet")
("compose" "säveltää")
("compound" "yhdiste")
("compress" "pakkaa")
("compress into toolbar" "pakkaa työkaluriville")
("compressed" "pakattu")
("conceal" "piilottaa")
("configure look and feel" "määritä ulkoasu")
("confirm collected public key deletion" "vahvista kerätyn julkisen avaimen poisto")
("confirm database entry" "vahvista tietokannan merkintä")
("confirm entry" "vahvista merkintä")
("confirm public key deletion" "vahvista julkisen avaimen poisto")
("confirm secret key deletion" "vahvista salainen avaimen poisto")
("confirm selected database entries" "vahvista valitut tietokantamerkinnät")
("confirm selected entries" "vahvista valitut merkinnät")
("confirm wallet destruction" "vahvista lompakon tuhoaminen")
("conservative conversion options" "konservatiiviset muuntovaihtoehdot")
("consoles" "konsolia")
("constellation" "tähdistö")
("contact" "yhteyshenkilö")
("content" "sisältö")
("context aids" "kontekstiapua")
("contextual hints" "asiayhteyteen liittyviä vihjeitä")
("continue" "jatka")
("continued fraction" "jatkuva fraktio")
("contour" "ääriviiva")
("contract logarithms" "sopimuslogaritmit")
("contribute" "osallistu")
("control flow" "ohjausvirta")
("control the evaluation of expressions" "hallitse lausekkeiden arviointia")
("convert" "muuntaa")
("converters" "muunnosta")
("convertible" "vaihdettava")
("copy new objects to all frames" "kopioi uudet objektit kaikkiin kehyksiin")
("copy new objects to previous frames" "kopioi uusia esineitä aiempiin kehyksiin")
("copy new objects to subsequent frames" "kopioi uusia kohteita seuraaviin kehyksiin")
("copy to all frames after" "kopioi kaikkiin kehyksiin jälkeen")
("copy to all frames before" "kopioi kaikkiin kehyksiin ennen")
("copy to all other frames" "kopioi kaikkiin muihin kehyksiin")
("copyright" "tekijänoikeudet")
("cork charset with TeX catcode definition in preamble" "korkkijärjestelmä, johdanto-osassa oleva TeX-kattokoodimäärittely")
("cork with catcodes" "korkki ja koodakoodit")
("correct" "oikea")
("correct all" "korjaa kaikki")
("correct formula" "oikea kaava")
("correct manually" "oikea manuaalisesti")
("correct mathematical formulas" "oikeat matemaattiset kaavat")
("correction" "korjaus")
("cosine" "kosinus")
("count characters" "laskea merkkiä")
("count lines" "laskuriviä")
("count words" "laskea sanoja")
("create a new document" "luo uusi asiakirja")
("create link" "luo linkki")
("create preamble" "luoda johdanto")
("create remote account" "luo etätili")
("create remote directory" "luo etähakemisto")
("create remote file" "luo etätiedosto")
("create subprogram" "luo aliohjelma")
("create subsession" "luo alajakso")
("create table macro" "luo taulukon makro")
("create web site" "luo verkkosivusto")
("creating new account" "uuden tilin luominen")
("creating technical pictures" "teknisten kuvien luominen")
("crop" "sato")
("crop marks" "rajamerkkiä")
("cross" "risti")
("crossed boxes" "ristikkäistä laatikkoa")
("crossed circles" "ristissä olevat ympyrät")
("current user version" "nykyinen käyttäjän versio")
("current version" "nykyinen versio")
("cursor" "kohdistin")
("curve" "käyrä")
("curve intersections" "käyrän leikkaukset")
("curve points" "käyräpistettä")
("customizations" "mukautukset")
("customizing and extending the user interface" "käyttöliittymän mukauttaminen ja laajentaminen")
("cyan" "syaani")
("danish" "tanskalainen")
("dark grey" "tummanharmaa")
("data" "data")
("database entry" "tietokannan merkintä")
("database tool" "tietokantatyökalu")
("database toolbar" "tietokantatyökalurivi")
("deactivate once" "deaktivoi kerran")
("dead" "kuollut")
("debug" "virheenkorjaus")
("debugging console" "virheenkorjauskonsolia")
("debugging tool" "virheenkorjaustyökalu")
("decimal comma" "desimaalin pilkku")
("decimal dot" "desimaalipiste")
("decomposed" "hajoaa")
("decorated" "sisustettu")
("decorated wood" "koristeltu puu")
("decorative" "koristeellista")
("decrease size" "pienennä kokoa")
("decrypt" "purkaa")
("decrypted" "purettu")
("decryption" "salauksen purku")
("default size" "oletuskoko")
("degrade" "hajoa")
("degraded" "heikentynyt")
("delete documentation cache" "poista dokumentaatiovälimuisti")
("delete entries" "poista merkinnät")
("delete link" "poista linkki")
("delete selected entries in wallet" "Poista valitut merkinnät lompakosta")
("delete user identity" "poista käyttäjän identiteetti")
("deleted" "poistettu")
("describe" "kuvaa")
("describe tag" "kuvaa tunnistetta")
("destroy" "tuhoamaan")
("detach master" "irrotettava päällikkö")
("detailed" "yksityiskohtainen")
("detailed menus" "yksityiskohtaiset valikot")
("details in menus" "yksityiskohdat valikoissa")
("determine margins from text width" "määritä marginaalit tekstin leveydestä")
("developer" "kehittäjä")
("developer tool" "kehittäjätyökalu")
("device" "laite")
("diamond" "timantti")
("differentiate" "erottele")
("digital" "digitaalista")
("dilate" "laajentunut")
("direction of progression" "etenemissuunta")
("direction of translation" "käännössuunta")
("disable" "pois käytöstä")
("disable coloring on paper" "poista paperilla värjäys käytöstä")
("disable encryption" "poista salaus käytöstä")
("disabled" "vammainen")
("disappear" "katoavat")
("disk" "levy")
("display style" "näyttötyyli")
("displayed formula" "näytetty kaava")
("dissociate joined cells" "dissosioitu liitetyt solut")
("distill encapsulated Pdf files" "tislattu kapseloidut pdf-tiedostot")
("distort" "vääristä")
("distorted" "vääristynyt")
("division" "jako")
("do not remap" "älä tee uudelleen")
("document colors" "asiakirjan värit")
("document font selector" "asiakirjan fontin valitsin")
("document language" "asiakirjan kieli")
("document metadata" "asiakirjan metatiedot")
("document page format" "asiakirjan sivumuoto")
("document paragraph format" "asiakirjan kappalemuoto")
("document source tree preferences" "asiakirjan lähdepuun asetukset")
("document updates run" "asiakirjan päivitykset suoritetaan")
("documents in separate windows" "asiakirjat erillisissä ikkunoissa")
("download" "lataa")
("download file or directory" "lataa tiedosto tai hakemisto")
("downwards" "alaspäin")
("dragging" "vetäminen")
("draw" "piirtää")
("draw graphics" "piirtä grafiikkaa")
("draw image" "piirtä kuva")
("draw over" "vetoa yli")
("draw over selection" "veto yli valinnan")
("drop" "pudota")
("due to" "johtuu")
("dynamic" "dynaaminen")
("eRROR" "eRROR")
("edit animation" "muokkaa animaatiota")
("edit groups of objects" "muokkaa objektiryhmiä")
("edit macro" "muokkaa makroa")
("edit macros" "muokkaa makroja")
("edit object properties" "muokkaa objektin ominaisuuksia")
("edit preamble" "muokkaa johdanto-osaa")
("edit source" "muokkaa lähde")
("edit source tree" "muokkaa lähdepuua")
("edit style" "muokkaustyyli")
("edit translations file" "muokata käännöstiedostoa")
("education" "koulutus")
("effect pen" "efektikynä")
("eigenvalues" "ominaisarvot")
("eighth" "kahdeksas")
("embold" "embold")
("emboss" "kohokuvio")
("enable page breaking" "salli sivun katkaisu")
("enabled" "käytössä")
("encoding" "koodaus")
("encrypt" "salattu")
("encrypted" "salattu")
("encrypted buffer" "salattu puskuri")
("encryption" "salaus")
("encryption error" "salausvirhe")
("encryption facilities are not currently available" "salausominaisuudet eivät ole tällä hetkellä saatavilla")
("encryption facilities have not been enabled for TeXmacs" "salausominaisuuksia ei ole otettu käyttöön TeXmacsille")
("enforce brackets to match" "suorita hakasulkeet vastaamaan")
("engrave" "kaiverrus")
("enter data" "kirjoita tiedot")
("enter graphics" "syötä grafiikka")
("enter graphics mode" "siirry grafiikkatilaan")
("enter new passphrase for encryption" "kirjoita uusi salasana salausta varten")
("enter passphrase for decryption" "kirjoita salasana salauksen purkamista varten")
("enter passphrase for identity" "kirjoita tunnuslause")
("enter title information" "kirjoita otsikkotiedot")
("entire table" "koko pöytä")
("entry up to date in database" "päivitys tietokantaan")
("enunciation" "ilmoittaminen")
("environment variable" "ympäristömuuttuja")
("environments" "ympäristöä")
("erode" "erode")
("error messages" "virheilmoitukset")
("error output" "virheilmoitus")
("error status report" "virhetilanneraportti")
("error: bracket does not match" "virhe: hakasulku ei vastaa")
("error: cyclic or missing chunks detected" "virhe: syklinen tai puuttuva kappale havaittu")
("error: file not found" "virhe: tiedostoa ei löydy")
("error: ghostview does not seem to be installed on your system" "virhe: ghostview ei näytä olevan asennettuna järjestelmään")
("error: one of the alternatives should be filled out" "virhe: yksi vaihtoehdoista tulisi täyttää")
("error: only one alternatives should be filled out" "virhe: vain yksi vaihtoehto olisi täytettävä")
("error: should fill out name for referencing" "virhe: pitäisi täyttää nimi viittauksille")
("error: should fill out required field" "virhe: pitäisi täyttää vaadittava kenttä")
("escape" "pakene")
("esperanto" "esperanto")
("evaluable field" "arvioitava kenttä")
("evaluate above" "arvioi yllä")
("evaluate all" "arvioi kaikki")
("evaluate below" "arvioi alla")
("evaluate fields" "arvioi kentät")
("evaluate fields in order" "arvioi kentät järjestyksessä")
("evaluate script" "arvioi käsikirjoitus")
("evaluation" "arviointi")
("evaluation switch" "arviointikytkin")
("evaluation tag" "arviointimerkki")
("even page" "parillinen sivu")
("even page left margin" "parillinen sivu vasemmalla marginaalilla")
("even page shift" "tasainen sivusiirto")
("even pages" "parillista sivua")
("events" "tapahtumaa")
("exact" "tarkka")
("execution of scripts" "komentosarjojen suorittaminen")
("exit graphics" "exit grafiikka")
("exit graphics mode" "poistu grafiikkatilasta")
("exit left" "poistuminen vasemmalle")
("exit right" "poistu oikealta")
("exit tag on the left" "poistumistunniste vasemmalla")
("exit tag on the right" "poistumistunniste oikealla")
("expand TeXmacs macros with no LaTeX equivalents" "laajenna TeXmacs-makroja ilman LaTeX-vastineita")
("expand beamer slides" "laajenna laakerin dioja")
("expand inclusions" "laajenna sulkeumat")
("expand logarithms" "laajenna logaritmit")
("expand trigonometric functions" "laajenna trigonometriset funktiot")
("expand unrecognized macros" "laajenna tuntematon makro")
("expand user-defined macros" "laajenna käyttäjän määrittämiä makroja")
("expanded" "laajennettu")
("experimental features (to be used with care)" "kokeelliset ominaisuudet (käytettävä varoen)")
("explain" "selitä")
("explanatory item" "selittävä kohta")
("explicit keystroke" "nimenomainen näppäinpainalluksen")
("explicit margins" "tarkka marginaali")
("exponential" "eksponentiaalinen")
("export bibliographies as links" "vie bibliografiat linkkeinä")
("export bibliography" "vientiluettelo")
("export entries in buffer" "vientimerkinnät puskuriin")
("export file" "vientitiedosto")
("export formulas as images" "vienti kaavat kuvina")
("export mathematical formulas as MathML" "vie matemaattiset kaavat MathML-muodossa")
("export mathematical formulas as images" "vie matemaattiset kaavat kuvina")
("export selected entries" "vie valitut merkinnät")
("export selection" "vientivalinta")
("export selection as image" "vientivalinta kuvana")
("export selections as" "vie valinnat nimellä")
("export sessions" "vientiistuntoa")
("exported bibliographic entries" "viedyt bibliografiset merkinnät")
("exported bibliographic references" "viedyt bibliografiset viitteet")
("extend" "laajenna")
("extend table to full paragraph width" "laajenna taulukko koko kappaleen leveyteen")
("extended" "laajennettu")
("extensible left arrow" "laajennettava vasen nuoli")
("extensible right arrow" "laajennettava oikea nuoli")
("extern" "ulko")
("external" "ulkoinen")
("extra branch" "ylimääräinen haara")
("extra interline space" "ylimääräinen interline-tila")
("extra name" "ylimääräinen nimi")
("extract" "ote")
("extract style file" "poimintityylitiedosto")
("extract style package" "ote tyylipaketti")
("factor" "kerroin")
("fade" "haalistu")
("fade in" "haalistu")
("fade out" "häivyttää")
("fast" "nopea")
("fast decrease" "nopea lasku")
("fast environments" "nopea ympäristö")
("fast increase" "nopea nousu")
("field reference" "kenttäviite")
("fifth" "viides")
("file saved" "tiedosto tallennettu")
("fill color" "täyttöväri")
("fill out" "täytä")
("filter" "suodatin")
("find file" "etsi tiedosto")
("finished collecting symbols documentation" "valmiina keräämään symbolien dokumentointi")
("finnish" "suomi")
("first" "ensimmäinen")
("first chunk" "ensimmäinen kimpale")
("first difference" "ensimmäinen ero")
("first error" "ensimmäinen virhe")
("first field" "ensimmäinen kenttä")
("first occurrence" "ensimmäinen esiintyminen")
("first similar" "ensimmäinen samanlainen")
("fit" "sopii")
("fit to height" "sopii korkeuteen")
("fit to screen" "sopii näytölle")
("fit to screen width" "sopii näytön leveyteen")
("fit to width" "sopii leveyteen")
("five columns" "viisi saraketta")
("fixed" "kiinteä")
("flag is off" "lippu ei ole käytössä")
("flag is on" "lippu on päällä")
("flatten" "litistä")
("floating algorithm" "kelluva algoritmi")
("floating phantom" "kelluva fantomi")
("focus" "tarkennus")
("focus dependent icons" "tarkennuksesta riippuvat kuvakkeet")
("fold all" "taita kaikki")
("fold all fields" "taita kaikki kentät")
("fold back" "taita takaisin")
("fold input field" "taittokenttä")
("follow external links" "seuraa ulkoisia linkkejä")
("follow inverse links" "seuraa käänteisiä linkkejä")
("font customization" "fontin mukauttaminen")
("font effects" "fonttiefektit")
("font selector" "fontin valitsin")
("font type" "kirjasintyyppi")
("for each" "jokaiselta")
("force reloading of translations" "käännösten pakollinen uudelleenlataus")
("formatted and structured output" "muotoiltu ja jäsennelty lähtö")
("formatting" "muotoilu")
("forward" "eteenpäin")
("four columns" "neljä saraketta")
("four dots" "neljä pistettä")
("fourth" "neljäs")
("fraktur" "fraktur")
("framed" "kehystetty")
("framed theorems" "kehystettyjä lauseita")
("from" "alkaen")
("from center" "keskustasta")
("front matter" "etumatka")
("full" "täynnä")
("full author list" "koko kirjoittajaluettelo")
("full screen mode" "koko näytön tila")
("functional" "toimiva")
("gap" "aukko")
("garbage collection" "roskien keruu")
("gaussian" "gaussia")
("gcd" "gcd")
("general" "yleinen")
("general note" "yleinen huomautus")
("generate GnuPG key" "luo GnuPG-avain")
("generated LaTeX document contains no errors" "luotu LaTeX-dokumentti ei sisällä virheitä")
("generated field" "luotu kenttä")
("geometry" "geometria")
("get arity" "hanki ariteetti")
("get label" "hanki tarra")
("get list with remote versions" "hae luettelo etäversioilla")
("global log" "globaali loki")
("global status" "globaali tila")
("glue multiple spaces" "liimaa useita välilyöntejä")
("glyphs" "kuviot")
("gnaw" "narttu")
("gnawed" "napattu")
("gnuPG command" "gnuPG-komento")
("gnuPG decryption error" "gnuPG-salauksen purkuvirhe")
("gnuPG error: buffer encryption failed" "gnuPG-virhe: puskurin salaus epäonnistui")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG-virhe: ei löydy sopivaa salaista avainta salauksen purkamiseen")
("gnuPG requires name and email to have at least 5 characters" "gnuPG vaatii nimen ja sähköpostin oltava vähintään 5 merkkiä")
("go to anchor" "mennä ankkuriin")
("go to anchor or float" "mennä ankkuriin tai kellua")
("go to anchor or footnote" "siirry ankkuriin tai alaviitteeseen")
("go to first similar tag" "siirry ensimmäiseen vastaavaan tunnisteeseen")
("go to float" "mennä kellua")
("go to footnote" "siirry alaviitteeseen")
("go to last similar tag" "Siirry viimeiseen vastaavaan tunnisteeseen")
("go to next similar tag" "siirry seuraavaan vastaavaan tunnisteeseen")
("go to previous similar tag" "siirry edelliseen vastaavaan tunnisteeseen")
("go to section" "siirry osioon")
("grain" "vilja")
("granite" "graniitti")
("graphical effects" "graafiset tehosteet")
("graphical interface font scale" "graafisen käyttöliittymän fonttiasteikko")
("graphical overlays" "graafista peittoa")
("graphical slides and overlays" "graafista dioa ja peittoa")
("graphics" "grafiikka")
("graphics geometry" "grafiikkageometria")
("graphics grids" "grafiikkaverkot")
("greyed" "harmaana")
("grid" "ruudukko")
("grid curves" "ristikkokäyrät")
("grid points" "ruudukkopistettä")
("grid-curve intersections" "ristikkokäyrän risteykset")
("group of objects" "esineiden ryhmä")
("group/ungroup" "ryhmä / ryhmä")
("group/ungroup objects" "ryhmä / ryhmittele objektit")
("grouped" "ryhmitetty")
("guarantee transparent source tracking" "takaa avoimen lähteen seurannan")
("h modifier" "h-muokkain")
("half wide" "puoli leveä")
("hand drawn" "käsin piirretty")
("handwritten" "käsin kirjoitettu")
("hangul" "hangul")
("headers" "otsikot")
("hidden" "piilotettu")
("high resolution settings" "korkearesoluutioiset asetukset")
("history" "historia")
("homepage" "kotisivu")
("homoglyph substitutions" "homoglyfisubstituutiot")
("horizontal alignment" "vaakasuuntainen kohdistus")
("horizontal collapse distance" "vaakasuora romahdusetäisyys")
("horizontal margins" "vaakasuorat marginaalit")
("hybrid command" "hybridi komento")
("hyphenate as" "tavuviiva")
("icon" "kuvake")
("if hyphenated" "jos tavutettu")
("ignore" "ohita")
("impact" "vaikutus")
("import bibliography" "Tuo bibliografia")
("import database entry" "Tuo tietokantatieto")
("import entries in buffer" "Tuo merkinnät puskuriin")
("import entry" "tuontitiedot")
("import file" "tuontitiedosto")
("import public keys from buffer" "Tuo julkiset avaimet puskurista")
("import selected database entries" "Tuo valitut tietokantamerkinnät")
("import selected entries" "Tuo valitut merkinnät")
("import selections as" "Tuo valinnat nimellä")
("import sessions" "tuontiistuntoa")
("import sophisticated objects as pictures" "tuo hienostuneita esineitä kuvina")
("imported bibliographic entries" "tuontia bibliografisia merkintöjä")
("in popup windows" "ponnahdusikkunoissa")
("inanimated" "elävä")
("inch" "tuumaa")
("incomplete entries found to be filled out" "puutteellisia merkintöjä todettiin täytetyiksi")
("increase size" "suurenna kokoa")
("indent paragraphs" "luetelmakohdat")
("indentation" "sisennys")
("indication" "merkintä")
("informative flags" "informatiivista lippua")
("initialize" "alusta")
("initialize wallet" "alusta lompakko")
("initials" "alkukirjaimet")
("ink here" "muste täällä")
("ink in" "mustetta")
("ink out" "muste lopussa")
("inline" "inline")
("inline args" "inline args")
("inline arguments" "inline argumentit")
("inline code" "sisäinen koodi")
("inline content" "sisäinen sisältö")
("inline formula" "sisäinen kaava")
("inner bottom" "sisäosa")
("inner left" "vasen sisäpuoli")
("inner right" "sisäinen oikea")
("inner top" "sisäosa")
("input command" "syöttökomento")
("input field" "syöttökenttä")
("input mode" "syöttötila")
("input options" "syöttövaihtoehdot")
("insert a computer program" "lisää tietokoneohjelma")
("insert a condition" "lisää ehto")
("insert a control flow instruction" "lisää ohjausvirtaohje")
("insert a gap" "lisää aukko")
("insert a list" "lisää luettelo")
("insert a multiple choice" "lisää monivalinta")
("insert a negation" "lisää kielitys")
("insert a new entry" "lisää uusi merkintä")
("insert a note or a floating object" "lisää muistiinpano tai kelluva esine")
("insert a numerical operation" "lisää numeerinen toiminto")
("insert a prominent piece of text" "lisää näkyvä teksti")
("insert a question" "lisää kysymys")
("insert a root" "lisää juuri")
("insert a script" "lisää skripti")
("insert a section block" "lisää osilohko")
("insert a textual operation" "lisää tekstimuotoinen toiminto")
("insert a textual operator" "lisää tekstinoperaattori")
("insert a wide symbol above" "lisää leveä symboli yllä")
("insert a wide symbol below" "lisää leveä symboli alle")
("insert above" "lisää yllä")
("insert abstract" "lisää abstrakti")
("insert an answer" "lisää vastaus")
("insert an enunciation" "lisää sanonta")
("insert an operation on tuples" "lisää operaatio tupleihin")
("insert annotation" "lisää merkintä")
("insert arcs" "lisää kaaria")
("insert argument after" "lisää argumentti jälkeen")
("insert argument before" "lisää argumentti ennen")
("insert author" "lisää kirjoittaja")
("insert below" "lisää alle")
("insert bibliography" "lisää bibliografia")
("insert circles" "lisää ympyröitä")
("insert closed splines" "lisää suljetut urat")
("insert copyright and license information" "lisää tekijänoikeus- ja lisenssitiedot")
("insert explanatory item" "lisää selittävä kohta")
("insert field above" "lisää kenttä yllä")
("insert field below" "lisää kenttä alapuolelle")
("insert fields" "lisää kentät")
("insert hand drawn curves" "aseta käsin piirretyt käyrät")
("insert input field above" "lisää syöttökenttä yllä")
("insert input field below" "lisää syöttökenttä alapuolelle")
("insert large delimiters" "lisää suuret rajoitimet")
("insert last name" "lisää sukunimi")
("insert left" "lisää vasen")
("insert lines" "lisää riviä")
("insert macro" "lisää makro")
("insert missing invisible operators" "lisää puuttuvat näkymättömät operaattorit")
("insert more names" "lisää lisää nimiä")
("insert multiple paragraphs" "lisää useita kappaleita")
("insert overlay after" "lisää peittokuva jälkeen")
("insert overlay before" "lisää peittokuva ennen")
("insert particle" "insert hiukkas")
("insert plain text" "lisää teksti")
("insert points" "lisää pisteitä")
("insert polygons" "insert polygons")
("insert right" "lisää oikea")
("insert similar above" "lisää samanlainen yllä")
("insert similar below" "lisää samanlainen alla")
("insert similar block above" "lisää samanlainen lohko yllä")
("insert similar block below" "lisää samanlainen lohko alapuolelle")
("insert slide after" "lisää dia jälkeen")
("insert slide before" "lisää dio ennen")
("insert splines" "insert splines")
("insert subscript" "lisää alaindeksi")
("insert subtable" "lisää altataulu")
("insert superscript" "lisää yläindeksi")
("insert symbol documentation" "lisää symbolitiedot")
("insert template" "lisää malli")
("insert text" "lisää teksti")
("insert text field" "lisää tekstikenttä")
("insert text field above" "lisää tekstikenttä yllä")
("insert text field below" "lisää tekstikenttä alapuolelle")
("insert title" "lisää otsikko")
("insert title after name" "lisää otsikko nimen jälkeen")
("insert user interface related markup" "lisää käyttöliittymään liittyvä merkintä")
("insert value" "lisää arvo")
("inserting control points" "ohjauspisteiden lisääminen")
("inside mathematics" "matematiikan sisällä")
("integrate" "integroida")
("interactive command" "interaktiivinen komento")
("interactive questions" "interaktiivista kysymystä")
("intercharacter compression" "merkkien välinen pakkaus")
("intercharacter stretching" "merkkien välinen venytys")
("interrupted" "keskeytetty")
("invalid multi-paragraph selection" "virheellinen monen kappaleen valinta")
("invalid renaming" "virheellinen uudelleennimeäminen")
("invert" "käänteinen")
("inverted breve" "käänteinen breve")
("invisible ending" "näkymätön pääte")
("invisible newline" "näkymätön uusi rivi")
("invisible opening" "näkymätön aukko")
("inwards" "sisäänpäin")
("join selected cells" "liity valittuihin soluihin")
("jump in" "hyppää sisään")
("junior" "nuorempi")
("justify" "perustella")
("keep evaluated expressions" "pitää arvioidut lausekkeet")
("keep local" "pitää paikallista")
("keep remote" "pysy kaukana")
("keep track of source code" "seuraa lähdekoodia")
("keep unfolded" "pysy taitettuna")
("key manager" "avaimenhoitaja")
("keyboard configuration" "näppäimistön kokoonpano")
("laTeX errors" "laTeX-virhettä")
("laptop presentations" "kannettavan tietokoneen esitykset")
("large brackets" "suurta kiinnikettä")
("large cells" "suuria soluja")
("large displayed" "iso näytössä")
("large displayed fraction" "suuri näytetty fraktio")
("large tables" "isot pöydät")
("last" "viimeinen")
("last check" "viimeinen tarkistus")
("last difference" "viimeinen ero")
("last error" "viimeinen virhe")
("last field" "viimeinen kenttä")
("last name" "sukunimi")
("last occurrence" "viimeinen esiintyminen")
("last similar" "viimeinen samanlainen")
("lcm" "lcm")
("left arrow" "vasen nuoli")
("left axis" "vasen akseli")
("left baseline" "vasen perustaso")
("left bottom" "vasen alaosa")
("left cell border" "vasen solun reuna")
("left cell padding" "vasemman solun tyyny")
("left center" "vasen keskusta")
("left click: add point; Right click: undo" "vasen napsautus: lisää kohta; oikea napsautus: kumoa")
("left click: finish; Right click: undo" "vasen napsautus: lopeta; oikea napsautus: kumoa")
("left click: new object" "vasen napsautus: uusi objekti")
("left click: operate" "vasen napsautus: käytä")
("left down" "vasen alas")
("left on even pages" "jäljellä parillisilla sivuilla")
("left table border" "vasen pöydän reuna")
("left table padding" "vasen pöytäpehmuste")
("left top" "vasen yläosa")
("left up" "jäljellä")
("left-right arrow" "vasen ja oikea nuoli")
("leftwards" "vasemmalle")
("let the environment float" "anna ympäristön kellua")
("light grey" "vaaleanharmaa")
("line arrows" "viivan nuolet")
("line breaking" "linjan katkaisu")
("line dashes" "viivaviivat")
("line portion" "riviosa")
("line style" "rivityyli")
("line width" "viivan leveys")
("line wrapping" "rivinkääre")
("line wrapping inside cell" "rivinkääre solun sisällä")
("linear 2D" "lineaarinen 2D")
("linear algebra" "lineaarinen algebra")
("lines around" "linjat ympärillä")
("link image and copies as" "linkkikuva ja kopioi nimellä")
("link image as" "linkkikuva nimellä")
("link mode" "linkkitila")
("link to URL" "linkki URL-osoitteeseen")
("linking tool" "linkitystyökalu")
("live" "live")
("live input-output" "suora tulo-lähtö")
("load help file" "lataa aputiedosto")
("load remote file" "lataa etätiedosto")
("loading" "lastaus")
("local entries" "paikalliset merkinnät")
("loci" "loci")
("locus" "lokus")
("locus rendering" "lokuksen renderointi")
("logarithm" "logaritmi")
("logarithmic" "logaritminen")
("logarithmic base" "logaritminen emäs")
("logarithms" "logaritmit")
("logging in" "sisäänkirjautuminen")
("logical and" "looginen ja")
("logical implication" "looginen merkitys")
("logical not" "looginen ei")
("logical or" "looginen tai")
("login" "kirjautuminen")
("logout" "uloskirjautuminen")
("long macro" "pitkä makro")
("long text" "pitkä teksti")
("look for more fonts" "etsi lisää fontteja")
("loops" "silmukkaa")
("m modifier" "m-muokkain")
("macro argument" "makroargumentti")
("macro definition" "makromääritelmä")
("macro editor" "makroeditori")
("macro name" "makronimi")
("macros" "makrot")
("macros editor" "makroeditori")
("magnify horizontally" "suurenna vaakatasossa")
("magnify vertically" "suurenna pystysuunnassa")
("main presentation style" "pääesitystyyli")
("make a letter environment" "tee kirjeympäristö")
("make a multi-slide presentation" "tee monien diojen esitys")
("make block wide" "tee lohko leveäksi")
("make float wide" "tee kellua leveäksi")
("make floating" "tee kelluvaksi")
("make footnote wide" "tee alaviite leveäksi")
("make link" "linkki")
("make non floating" "tee ei kelluvaksi")
("make wide" "tee leveä")
("manila paper" "manilapaperi")
("map arguments" "karttaargumentit")
("marginal note" "reunanumero")
("margins from width" "marginaalit leveydeltä")
("margins on paper" "marginaalit paperilla")
("margins on screen" "marginaalit näytöllä")
("marked" "merkitty")
("marker" "merkki")
("material" "materiaali")
("math Extra" "matemaattinen lisä")
("math Letters" "matemaattiset kirjeet")
("math Symbols" "matemaattiset symbolit")
("mathematical and customized input" "matemaattinen ja mukautettu syöttö")
("mathematical font" "matemaattinen kirjasinlaji")
("mathematical input" "matemaattinen syöttö")
("mathematical output" "matemaattinen tulos")
("matrices" "matriisia")
("maximal" "maksimi")
("maximal cell height" "solun maksimikorkeus")
("maximal clustering" "maksimaalinen klusterointi")
("maximal table height" "pöydän maksimikorkeus")
("maximal table width" "pöydän maksimileveys")
("maximum" "Enintään")
("meander" "mutkikkaat")
("medieval" "keskiaikainen")
("memory" "muisti")
("memory usage" "muistin käyttö")
("menu" "valikko")
("merge lines into paragraphs unless separated by blank lines" "yhdistä rivit kappaleiksi, elleivät ne ole eroteltu tyhjillä riveillä")
("messages" "viestiä")
("meta data" "metatiedot")
("metadata" "metatiedot")
("metal" "metalli")
("middle baseline" "keskimääräinen lähtöviiva")
("minimal" "minimaalinen")
("minimal cell height" "minimaalinen solun korkeus")
("minimal cell width" "minimaalinen solunleveys")
("minimal line separation" "minimaalinen linjaerotus")
("minimal table height" "minimipöydän korkeus")
("minimal table width" "minimipöydän leveys")
("minimum" "Vähintään")
("mirror" "peili")
("miscellaneous features" "sekalaiset ominaisuudet")
("miscellanous" "sekalainen")
("mixed" "sekoitettu")
("mode dependent icons" "tilasta riippuvat kuvakkeet")
("modify bibliography" "muokata bibliografiaa")
("modify remote live document" "muokata suoraa etäasiakirjaa")
("module" "moduuli")
("module browser" "moduuliselain")
("monospaced" "yksiosainen")
("more information about GNU TeXmacs can be found in the Help" "lisätietoja GNU TeXmacsista löytyy ohjeesta")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "lisätietoja GNU TeXmacsista löytyy Ohje-<gtr> Tietoja-valikosta")
("motion" "liike")
("mouse over object" "hiiri esineen yli")
("move" "liikku")
("move objects" "siirtä esineitä")
("move over object on which to operate" "liikuta esineen päällä, jolla sitä käytetään")
("multiline" "monilinja")
("multiline input" "monilinjainen sisääntulo")
("multiple choice" "monivalinta")
("multiple documents share window" "useiden asiakirjojen jakamisikkuna")
("multiple root" "useita juuria")
("multiplication" "kertolasku")
("mutator tags" "mutanttimerkit")
("my documents" "minun asiakirjat")
("named" "nimeltään")
("navigation options" "navigointivaihtoehdot")
("never" "ei koskaan")
("new account" "uusi tili")
("new bibliography dialogue" "uusi bibliografiavuoropuhelu")
("new document" "uusi asiakirja")
("new double page" "uusi kaksisivu")
("new double page before" "uusi kaksinkertainen sivu ennen")
("new entry" "uusi merkintä")
("new identity" "uusi identiteetti")
("new locus" "uusi lokus")
("new macro" "uusi makro")
("new passphrase" "uusi tunnuslause")
("new remote directory" "uusi etähakemisto")
("new remote file" "uusi etätiedosto")
("new style fonts" "uuden tyylin kirjasimet")
("new style page breaking" "uuden tyylisivunmuutos")
("new version" "uusi versio")
("new window" "uusi ikkuna")
("newer version" "uudempi versio")
("next" "seuraava")
("next chunk" "seuraava kimppu")
("next difference" "seuraava ero")
("next error" "seuraava virhe")
("next field" "seuraava kenttä")
("next occurrence" "seuraava tapahtuma")
("next screen" "seuraava näyttö")
("next similar" "seuraava samanlainen")
("no animation" "ei animaatiota")
("no clustering" "ei klusterointia")
("no completions" "ei täydennyksiä")
("no errors have been corrected" "virheitä ei ole korjattu")
("no grid" "ei ruutua")
("no matches found for" "hakutulosta ei löytynyt")
("no multiple spaces" "ei useita välilyöntejä")
("no new public key in document" "ei uutta julkista avainta asiakirjassa")
("no page break" "ei sivunvaihtoa")
("no page numbers" "ei sivunumeroita")
("no parent" "ei vanhempaa")
("no selection" "ei valintaa")
("no spelling errors" "ei kirjoitusvirheitä")
("no spurious spaces" "ei vääriä tiloja")
("normal loci" "normaali lokus")
("norwegian" "norja")
("not allowed to remove home directory" "ei saa poistaa kotihakemistoa")
("not connected to server" "ei ole yhteydessä palvelimeen")
("not yet implemented" "ei vielä toteutettu")
("notebook" "muistikirja")
("number equation" "lukuyhtälö")
("number of polar steps" "polaarivaiheiden lukumäärä")
("number of subunit steps" "alayksikön askelten lukumäärä")
("numbered" "numeroitu")
("numbering" "numerointi")
("numeric spreadsheet" "numeerinen laskentataulukko")
("oblique" "vino")
("odd page" "pariton sivu")
("odd page left margin" "pariton sivun vasen reuna")
("odd page right margin" "pariton sivun oikea marginaali")
("odd page shift" "pariton sivusiirto")
("odd pages" "paritonta sivua")
("of fingerprint" "sormenjäljet")
("old version" "vanha versio")
("older version" "vanhempi versio")
("on the footer" "alatunnisteessa")
("on your system and set it up from the \"Security\" tab" "järjestelmässäsi ja määritä se \"Suojaus\"-välilehdeltä")
("once" "kerran")
("one column" "yksi sarake")
("one error has been corrected" "yksi virhe on korjattu")
("one lower case letter, one non alpha-numeric symbol" "yksi pieni kirjain, yksi ei-aakkosnumeerinen symboli")
("one numeric character, one upper case letter" "yksi numeerinen merkki, yksi iso kirjain")
("only convert changes when re-importing" "muuntaa muutokset vain tuotaessa uudelleen")
("only convert changes with respect to imported version" "muuntaa muutokset vain tuodun version suhteen")
("only convert changes with respect to tracked version" "muuntaa vain seuratun version suhteen tehdyt muutokset")
("only implemented for complete subtrees" "toteutettu vain täydellisille alijäämille")
("only inline tags" "vain inline tags")
("only keep folded" "pidä vain taitettuna")
("only keep unfolded" "pidä vain taitettuna")
("only show paragraphs with hits" "Näytä vain kappaleita osumilla")
("only show semantic focus" "Näytä vain semanttinen fokus")
("opacity" "opasiteetti")
("open bibliography" "avoin bibliografia")
("open identities" "avoimet identiteetit")
("open in new window" "avoinna uudessa ikkunassa")
("open key manager" "avoimen avaimen hallinta")
("open licence agreement" "avoin lisenssisopimus")
("open mailbox" "avoin postilaatikko")
("open module browser" "avoin moduuliselain")
("open symbol browser" "avoin symboliselain")
("open tool in separate window" "avoin työkalu erillisessä ikkunassa")
("operation mode" "toimintatila")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "tai anna täydellinen polku \"gpg\" tai \"gpg2\"-komentoon")
("order" "tilaus")
("ordinary symbol" "tavallinen symboli")
("ornamented" "koristeltu")
("other login" "muu sisäänkirjautuminen")
("other package" "muu paketti")
("outer bottom" "ulkopinta")
("outer left" "vasen vasen")
("outer right" "oikea oikealla")
("outer top" "ulkopinta")
("outline" "ääriviivat")
("outlined" "hahmoteltu")
("outlined emboss" "hahmoteltu kohokuvio")
("outlined engrave" "kaiverrettu kaiverrus")
("output options" "lähtövaihtoehdot")
("outwards" "ulospäin")
("oval" "soikea")
("overbrace" "yliakseli")
("overlap" "päällekkäisyys")
("overlay" "peittokuva")
("overlay mode" "peittokuvatila")
("overlays" "peittokuvat")
("overline" "ylälinja")
("overlined" "yliviivattu")
("overview of the scheme extension language" "yleiskatsaus järjestelmän laajennuskielestä")
("padded" "pehmustettu")
("page background" "sivun tausta")
("page break after" "sivunvaihto jälkeen")
("page breaking algorithm" "sivunmuutosalgoritmi")
("page format" "sivumuoto")
("page number" "sivunumero")
("page number rendering" "sivunumeron renderointi")
("page number text" "sivunumeroteksti")
("page numbering" "sivunumerointi")
("page rendering" "sivun renderointi")
("page setup" "sivun asetukset")
("pagedown" "henkilöhaku")
("pageup" sivua)
("palette" "paletti")
("panorama" "panoraama")
("paragraph format" "kappalemuoto")
("paragraphs" "kappaleet")
("parametric curve" "parametrinen käyrä")
("parametric surface" "parametrinen pinta")
("parenthesis" "sulu")
("parenthesized" "suluissa")
("particle" "hiukkas")
("passphrase decryption" "salasanan salauksen purku")
("passphrase encryption" "tunnuslausekoodaus")
("passphrase wallet facilities are not currently available" "salasanalausekkeen palvelut eivät ole tällä hetkellä saatavilla")
("passphrases are expected to have at least: 8 characters" "tunnuslauseissa odotetaan olevan vähintään: 8 merkkiä")
("passphrases mismatch" "tunnuslauseiden epäsuhta")
("pastel" "pastelli")
("pattern" "kuvio")
("pattern selector" "kuvion valitsin")
("pause" "tauko")
("pdf version number" "pdf-versionumero")
("pen" "kynä")
("pen width" "kynän leveys")
("permanent footer" "pysyvä alatunniste")
("permanent header" "pysyvä otsikko")
("permanently add to dictionary" "lisää pysyvästi sanakirjaan")
("permanently insert into dictionary" "lisätään pysyvästi sanakirjaan")
("permissions" "käyttöoikeutta")
("phantom" "fantomi")
("phantoms" "phantoms")
("physics and astronomy class" "fysiikan ja tähtitieteen luokka")
("picture" "kuva")
("pine" "mänty")
("plain" "tavallinen")
("plain boxes" "tavallista laatikkoa")
("plain circles" "tavalliset ympyrät")
("play" "pelata")
("play all animations" "toista kaikki animaatiot")
("play animation" "toista animaatio")
("please install GnuPG software from https://www.gnupg.org" "asenna GnuPG-ohjelmisto osoitteesta https://www.gnupg.org")
("plot" "juoni")
("plug-ins" "laajennukset")
("plugin" "laajennus")
("plugins" "plugins")
("plural" "monikko")
("point" "piste")
("point border" "pisteraja")
("point size" "pistekoko")
("point style" "pistetyyli")
("polar" "napa")
("polygon" "monikulmio")
("pop server settings" "pop-palvelimen asetukset")
("portion" "annos")
("position of marginal note" "reunan reunan sijainti")
("poster formats" "julistemuodot")
("poster theme" "juliste teema")
("postfix" "postfix")
("preferences for editing mathematical formulas" "asetukset matemaattisten kaavojen muokkaamiseksi")
("preferences for tag" "tunnisteasetukset")
("prefix" "etuliite")
("presentation" "esitys")
("presentation tag" "esittelytagi")
("presentation tool" "esitystyökalu")
("preserve" "säilyttää")
("preserve tags" "säilytä tunnisteet")
("pretty" "kaunis")
("pretty tree output" "hieno puun tulostus")
("preview" "esikatselu")
("preview command" "esikatselukomento")
("previous" "edellinen")
("previous difference" "edellinen ero")
("previous error" "edellinen virhe")
("previous field" "edellinen kenttä")
("previous occurrence" "aiempi esiintyminen")
("previous screen" "edellinen näyttö")
("previous similar" "edellinen samanlainen")
("primitive or macro" "alkeellinen tai makro")
("print buffer" "tulostuspuskuri")
("print buffer to file" "tulostuspuskuri tiedostoon")
("print document" "tulosta asiakirja")
("print to file" "tulosta tiedostoon")
("printer setup" "tulostimen asetukset")
("produce Pdf using native export filter" "tuottaa PDF-tiedostoa alkuperäisellä vientisuodattimella")
("produce Postscript using native export filter" "tuottaa Postscriptiä alkuperäisellä vientisuodattimella")
("program bracket matching" "ohjelmalukon haku")
("program bracket selections" "ohjelmaluokan valinnat")
("program commands" "ohjelmakomennot")
("program font" "ohjelman kirjasin")
("program interface for buffer management" "ohjelmarajapinta puskurinhallintaan")
("programming routines for editing documents" "ohjelmointirutiinit asiakirjojen muokkaamiseen")
("prominent" "näkyvä")
("prompts and default input" "kehotteet ja oletussyöttö")
("provoke C++ error" "provosoi C++-virhe")
("provoke menu error" "provosoi valikkovirhe")
("provoke scheme error" "provosoi järjestelmän virhe")
("pseudo code" "pseudokoodi")
("public key encryption" "julkisen avaimen salaus")
("public keys" "julkiset avaimet")
("pulse" "pulssi")
("qt GUI only, sorry. Use \"Export selection\"" "Vain qt GUI, anteeksi. Käytä \"Vie valinta\"")
("qt-widgets" "qt-widgetit")
("quantifier" "kvantifioija")
("quasi" "kvasi")
("question" "kysymys")
("questions only" "vain kysymykset")
("questions with answers" "kysymykset ja vastaukset")
("quick evaluation of formulas" "kaavojen nopea arviointi")
("rank" "sijoitus")
("raw" "raaka")
("really close it" "sulje se todella")
("really delete user identity" "todella poistaa käyttäjän identiteetti")
("really tiny" "todella pieni")
("rebuild translations file" "käännä käännöstiedosto uudelleen")
("recent" "äskettäin")
("recent documents" "viimeisimmät asiakirjat")
("recipients" "vastaanottajaa")
("recognize" "tunnista")
("recolor" "väri")
("recover autosave file" "palauta automaattisen tallennuksen tiedosto")
("rectangular" "suorakulmainen")
("reduce" "pienennä")
("reduce trigonometric functions" "vähentää trigonometrisiä funktioita")
("reduced margins" "alennetut marginaalit")
("reference guide" "viiteopas")
("reference guide for the TeXmacs primitives" "Viiteopas TeXmacs-alkeille")
("reference guide for the standard TeXmacs styles" "ohjeopas vakio-TeXmacs-tyyleille")
("regenerate" "uudista")
("register" "rekisteröinti")
("register file" "rekisteritiedosto")
("relate" "liittyvät")
("relation" "suhde")
("release left button: finish editing" "vapauta vasen painike: lopeta muokkaaminen")
("remote" "kauko")
("remote connections" "etäyhteydet")
("remote control" "kaukosäädin")
("remote controllers with keyboard simulation" "kaukosäätimet näppäimistö simuloinnilla")
("remote directory" "etähakemisto")
("remote login" "etäkäyttö")
("remote servers" "etäpalvelimet")
("remote tool" "etätyökalu")
("remove" "poista")
("remove all output fields" "poista kaikki lähtökentät")
("remove animation" "poista animaatio")
("remove argument after" "poista argumentti jälkeen")
("remove argument before" "poista argumentti ennen")
("remove banner" "poista banneri")
("remove database entry" "poista tietokannan tieto")
("remove downwards" "poista alaspäin")
("remove entries" "poista merkinnät")
("remove entry" "poista merkintä")
("remove field above" "poista kenttä yllä")
("remove field below" "poista kenttä alla")
("remove fields" "poista kentät")
("remove folded" "poista taitettu")
("remove from previous frames" "poista aiemmista kehyksistä")
("remove from subsequent frames" "poista seuraavista kehyksistä")
("remove input field" "poista syöttökenttä")
("remove input field above" "poista syöttökenttä yllä")
("remove last field" "poista viimeinen kenttä")
("remove leftwards" "poista vasemmalle")
("remove link" "poista linkki")
("remove next field" "poista seuraava kenttä")
("remove number" "poista numero")
("remove overlay after" "poista peittokuva jälkeen")
("remove overlay before" "poista peitto ennen")
("remove package" "poista paketti")
("remove previous field" "poista edellinen kenttä")
("remove rightwards" "poista oikealta")
("remove selected database entries" "poista valitut tietokantamerkinnät")
("remove selected entries" "poista valitut merkinnät")
("remove slide after" "poista dia jälkeen")
("remove slide before" "poista dia ennen")
("remove superfluous invisible operators" "poista tarpeettomat näkymättömät operaattorit")
("remove tag" "poista tunniste")
("remove this branch" "poista tämä haara")
("remove this frame" "poista tämä kehys")
("remove unfolded" "poista taitettu")
("remove upwards" "poista ylöspäin")
("removed entries from database" "poistettu merkinnät tietokannasta")
("removed entry from database" "poistettu merkintä tietokannasta")
("rename" "nimeä uudelleen")
("rename section" "nimeä osio")
("rendering" "renderointi")
("rendering options for tag" "tagin vaihtoehdoista")
("renumber this page" "numeroi tämä sivu uudelleen")
("repeat" "toista")
("replace TeXmacs styles with no LaTeX equivalents" "korvata TeXmacs-tyylit ilman LaTeX-vastineita")
("replace all further occurrences" "korvata kaikki muut esiintymiset")
("replace one occurrence" "korvata yksi tapahtuma")
("replace toolbar" "korvata työkalurivi")
("replace unrecognized styles" "korvata tunnistamattomat tyylit")
("reset error counters" "nollaa virhelaskurit")
("resize" "koon muuttaminen")
("resize objects" "objektien koon muuttaminen")
("restart TeXmacs in order to let changes take effect" "Käynnistä TeXmacs uudelleen, jotta muutokset tulevat voimaan")
("restart in order to let the new look and feel take effect" "Käynnistä uudelleen, jotta uuden ilmeen ja vaikutelman voisi tulla voimaan")
("retain" "pidä")
("retime" "retime")
("retina settings" "verkkokalvon asetukset")
("retrieve email" "nouta sähköposti")
("retrieve remote live document" "noutaa suora etäasiakirja")
("retrieved contents" "haettu sisältö")
("retro" "retro")
("reverse" "käänteinen")
("reverse ordering" "käänteinen tilaaminen")
("ridged paper" "harjapaperi")
("right arrow" "oikea nuoli")
("right baseline" "oikea perusviiva")
("right cell border" "oikea solun reuna")
("right cell padding" "oikean solun tyyny")
("right down" "oikealla alas")
("right on even pages" "oikealla parillisilla sivuilla")
("right table border" "oikea pöydän reuna")
("right table padding" "oikea pöytäpehmuste")
("right up" "oikein ylös")
("rightwards" "oikealle")
("rigid box" "jäykkä laatikko")
("rotate" "kiertää")
("rotate objects" "kiertävät kohteita")
("rough" "karkea")
("rough paper" "karkea paperi")
("round" "pyöreä")
("round overbrace" "pyöreä ylikuormitus")
("round underbrace" "pyöreä alatuki")
("row above" "rivi yläpuolella")
("row below" "rivi alapuolella")
("rows" "riviä")
("run" "juokse")
("run current file" "suorita nykyinen tiedosto")
("same names" "samat nimet")
("same screen margins as on paper" "samat näytön reunat kuin paperilla")
("sample text" "näyteteksti")
("save auxiliary data" "tallenna aputiedot")
("save entries" "tallenna merkinnät")
("save entry" "tallenna merkintä")
("save image as" "tallenna kuva nimellä")
("save position" "tallenna sijainti")
("save remote file" "tallenna etätiedosto")
("saved modifications in database" "tallennetut muutokset tietokantaan")
("scheme command" "järjestelmän komento")
("scheme developers guide" "järjestelmän kehittäjien opas")
("scheme extensions" "järjestelmän laajennukset")
("scheme interface for the graphical mode" "graafinen tilan kaaviorajapinta")
("screen" "näyttö")
("screen rendering" "näytön renderöinti")
("screens" "näyttöä")
("screenshot" "kuvakaappaus")
("scripting language" "skriptikieli")
("scripts" "skriptit")
("search and replace" "etsi ja korvaa")
("search in database" "etsi tietokannasta")
("search results for" "hakutulokset haulle")
("search toolbar" "hakutyökalurivi")
("search words in my documents" "hakusanat asiakirjoissani")
("search words in the documentation" "hakusanat dokumentaatiossa")
("search words in the source code" "hakusanat lähdekoodissa")
("second" "toinen")
("secret keys" "salaiset avaimet")
("sections" "osastoa")
("see documentation" "katso ohjeet")
("select GnuPG recipients" "valitse GnuPG-vastaanottajat")
("select background picture" "valitse taustakuva")
("select document style" "valitse asiakirjatyyli")
("select pen" "valitse kynä")
("select the action to be undertaken for each conflict" "valitse kullekin konfliktille suoritettava toimenpide")
("select view mode" "valitse näyttötila")
("semantic correctness" "semanttinen oikeellisuus")
("semantic editing" "semanttinen muokkaus")
("semantic selections" "semanttiset valinnat")
("semantics" "semantiikka")
("sending commands to TeXmacs" "komentojen lähettäminen TeXmacsille")
("senior" "vanhempi")
("serb" "serbi")
("serif" "serif")
("server" "palvelin")
("server licence agreement" "palvelinlisenssisopimus")
("session commands" "istuntokomennot")
("set default" "oletusasetus")
("set difference" "asetettu ero")
("set intersection" "asetettu risteys")
("set number of columns" "asetettu määrä sarakkeita")
("set number of rows" "asetettu rivimäärä")
("set or get environment variables" "aseta tai hanki ympäristömuuttujat")
("set properties" "asetetut ominaisuudet")
("set union" "settiliitto")
("set user information" "aseta käyttäjätiedot")
("seventh" "seitsemäs")
("several equations" "useita yhtälöitä")
("shadow" "varjo")
("shadowed" "varjostettu")
("shadowed raise" "varjostettu korotus")
("shift" "vuoro")
("short" "lyhyt")
("show all parts" "näytä kaikki osat")
("show current focus" "näytä nykyinen tarkennus")
("show full context" "näytä koko konteksti")
("show hidden" "näytä piilotettu")
("show key presses" "Näytä näppäinpainallukset")
("show main document" "näytä pääasiakirja")
("show memory usage" "näytä muistin käyttö")
("show one part" "näytä yksi osa")
("show panorama" "näytä panoraama")
("show preamble" "näytä johdanto-osa")
("show several parts" "näytä useita osia")
("show subunits" "näytä alayksiköt")
("show table cells" "näytä taulukon solut")
("show timings" "näytä ajoitukset")
("side tools" "sivutyökalut")
("simple" "yksinkertainen")
("simple form" "yksinkertainen muoto")
("simple widget" "yksinkertainen widget")
("simplification" "yksinkertaistaminen")
("simplified evaluation of formulas" "kaavojen yksinkertaistettu arviointi")
("simplified menus" "yksinkertaistetut valikot")
("simplify" "yksinkertaista")
("sine" "sini")
("sixth" "kuudes")
("size tag" "kokotunniste")
("skew" "vino")
("skin" "iho")
("skip all" "ohita kaikki")
("slant" "vino")
("slashed fraction" "leikattu fraktio")
("slides" "dioja")
("slovene" "slovene")
("slow" "hidas")
("slow decrease" "hidas lasku")
("slow increase" "hidas nousu")
("small Capitals" "pienet pääkaupungit")
("small capitals" "pienet pääkaupungit")
("small environment box" "pieni ympäristölaatikko")
("small focus" "pieni tarkennus")
("small inline" "pieni inline")
("small inline fraction" "pieni rivin osa")
("smash" "murskaus")
("smooth" "sileä")
("smooth end" "sileä pää")
("smooth extremities" "sileät raajat")
("smooth start" "sileä alku")
("snap" "napsautus")
("snap distance" "napsautusetäisyys")
("snap to curves" "napsahtaa käyrään")
("snap to grid" "napsauta verkkoon")
("snap to grid curve" "napsauta ristikkokäyrään")
("snap to intersections of curves" "napsautus käyrien leikkauspisteille")
("snap to text borders" "napsauta tekstin reunoihin")
("snap to text corners" "napsauta tekstinurkkaan")
("solution" "ratkaisu")
("solution to exercise" "liikuntaratkaisu")
("solution to problem" "ratkaisu ongelmaan")
("solutions" "ratkaisua")
("sound" "ääni")
("source" "lähde")
("source macros tool" "lähdemakro-työkalu")
("source tags" "lähdetagia")
("south" "etelään")
("south east" "kaakkoon")
("space bar in math mode" "välilyönti matematiikkatilassa")
("space bar in text mode" "välilyönti tekstitilassa")
("space stretchability" "tilan venyvyys")
("span" "span")
("span over all columns" "span kaikkien sarakkeiden välillä")
("special functions" "erikoistoiminnot")
("special properties" "erikoisominaisuudet")
("specific baseline" "erityinen perustaso")
("specified" "määritelty")
("specify color alternation" "määritä värivaihtoehto")
("specify how to traverse the manual" "määrittele, kuinka käsikirjaa siirretään")
("specify semantics of a symbol or formula" "määritä symbolin tai kaavan semantiikka")
("specify the size of the table" "määritä taulukon koko")
("specify user identity" "määritä käyttäjän tunnus")
("spell check" "oikeinkirjoituksen tarkistus")
("spline" "spline")
("split program" "jaettu ohjelma")
("split session" "jaettu istunto")
("square" "neliö")
("square overbrace" "neliön yliakseli")
("square underbrace" "neliötuki")
("stack" "pino")
("standard" "vakio")
("standard Output" "standardilähtö")
("standard TeXmacs styles" "tavalliset TeXmacs-tyylit")
("standard environment variables" "standardi ympäristömuuttuja")
("standard formats" "vakiomuodot")
("standard fraction" "vakiofraktio")
("star" "tähti")
("start server" "aloituspalvelin")
("statement" "lausunto")
("statistics" "tilastot")
("status" "tila")
("stop server" "lopetuspalvelin")
("storage" "varastointi")
("store tracking information in LaTeX files" "tallentaa seurantatiedot LaTeX-tiedostoihin")
("stretch" "venytys")
("stretch factor" "venytyskerroin")
("stretched" "venytetty")
("strict Ascii" "tiukka Ascii")
("strike through" "läpi läpi")
("structured insert above" "jäsennelty insertti yllä")
("structured insert at the left" "jäsennelty insertti vasemmalla")
("structured insert at the right" "jäsennelty insertti oikealla")
("structured insert below" "jäsennelty insertti alla")
("structured remove downwards" "jäsennelty poisto alaspäin")
("structured remove leftwards" "jäsennelty poisto vasemmalle")
("structured remove rightwards" "jäsennelty poisto oikealle")
("structured remove upwards" "jäsennelty poisto ylöspäin")
("structured variant" "jäsennelty variantti")
("style options" "tyylivaihtoehtoa")
("style parameters" "tyyliparametrit")
("stylesheet language" "tyylitaulukkokieli")
("subject" "aihe")
("submenu" "alivalikko")
("subscript below" "alaindeksi alla")
("subsubmenu" "alavalikko")
("subsubsubmenu" "subsububmenu")
("subsubsubsubmenu" "subsubsubmenmenu")
("subtable" "subtable")
("subtitle" "tekstitys")
("subtraction" "vähennys")
("summarized" "yhteenveto")
("summary of the principal TeXmacs tags" "yhteenveto tärkeimmistä TeXmacs-tunnisteista")
("superscript above" "yläindeksi yllä")
("supported plug-ins" "tuetut laajennukset")
("surface" "pinta")
("inflate" "turvota")
("swiss" "sveitsin")
("switch to buffer" "vaihtaa puskuriin")
("symbol browser" "symboliselain")
("symbol properties not found" "symbolin ominaisuuksia ei löydy")
("symbols" "symbolia")
("synchronization status" "synkronoinnin tila")
("synchronize" "synkronoi")
("synchronize bibliographic references" "synkronoi bibliografiset viitteet")
("synchronize file or directory" "synkronoi tiedosto tai hakemisto")
("synchronize with remote server" "synkronoi etäpalvelimen kanssa")
("synopsis" "tiivistelmä")
("system command" "järjestelmän komento")
("tab-completion" "välilehden valmistuminen")
("tabbed" "välilehti")
("table breaking" "pöydänrikko")
("table height" "pöydän korkeus")
("table properties" "taulukon ominaisuudet")
("table width" "pöydän leveys")
("tags with special rendering" "erityisen renderoinnin tunnisteet")
("tangent" "tangentti")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacs-puskurin odotetaan")
("teXmacs buffer on disk expected" "teXmacs-puskuri levyllä odotetaan")
("teXmacs database preferences" "teXmacs-tietokanta-asetukset")
("teXmacs extensions to scheme and utilities" "teXmacs-laajennukset järjestelmään ja apuohjelmiin")
("teXmacs macro" "teXmacs-makro")
("teXmacs package" "teXmacs-paketti")
("teXmacs plugins" "teXmacs-laajennukset")
("teXmacs primitives" "teXmacs-primitiivit")
("teXmacs style" "teXmacs-tyyli")
("teXmacs style files" "teXmacs-tyyliset tiedostot")
("test routine" "testirutiini")
("testing tree-view" "puunäkymän testaaminen")
("text borders" "tekstin reunat")
("text box style" "tekstikenttityyli")
("text corners" "tekstinkulmat")
("text padding" "tekstin täyte")
("textual" "tekstinen")
("textual operator" "tekstinkäsittelyoperaattori")
("textual spreadsheet" "tekstimuotoinen laskentataulukko")
("the TeXmacs format" "TeXmacs-muoto")
("the TeXmacs plug-in system" "TeXmacs-laajennusjärjestelmä")
("the document has not been saved" "asiakirjaa ei ole tallennettu")
("theme parameters" "teemaparametrit")
("these collected public keys will be definitely lost" "nämä kerätyt julkiset avaimet menetetään ehdottomasti")
("these public keys will be definitely lost" "nämä julkiset avaimet menetetään ehdottomasti")
("these secret keys will be definitely lost" "nämä salaiset avaimet katoavat ehdottomasti")
("thicken" "sakenee")
("thin" "ohut")
("third" "kolmas")
("this" "tämä")
("this column" "tämä sarake")
("this document has not been saved" "tätä asiakirjaa ei ole tallennettu")
("this page footer" "tämän sivun alatunniste")
("this page header" "tämän sivun otsikko")
("this page number" "tämän sivun numero")
("this row" "tämä rivi")
("this style specifies page margins in the TeX way" "tämä tyyli määrittelee sivun marginaalit TeX-tavalla")
("three columns" "kolme saraketta")
("three dots" "kolme pistettä")
("three times" "kolme kertaa")
("through popup windows" "ponnahdusikkunoiden kautta")
("through the menus" "valikoiden läpi")
("thumbnails" "pikkukuvat")
("time evolution" "ajan kehitys")
("timings" "ajoitusta")
("title presentation options" "otsikon esitysvaihtoehdot")
("title style" "otsikkotyyli")
("title suffix" "otsikon jälkiliite")
("titled block" "nimeltään lohko")
("toggle cell wrapping mode" "vaihtosolun käärintätila")
("toggle here" "vaihtaa tähän")
("toggle name" "vaihtonimi")
("toggle numbering" "vaihtaa numerointi")
("toggle off" "pois päältä")
("toggle on" "kytkeä päälle")
("toggle specification" "kytkentämääritys")
("toggle titled" "vaihtaa otsikkoa")
("tolerant" "suvaitsevainen")
("top baseline" "ylätason perustaso")
("top cell border" "solun yläreuna")
("top cell padding" "solun top-tyyny")
("top table border" "pöydän yläreuna")
("top table padding" "yläpöydän pehmustus")
("transform" "muunnos")
("transform cell into subtable" "muunna solu alataulukoksi")
("translations" "käännökset")
("translations loaded" "käännökset ladattu")
("transpose" "saatettava osaksi kansallista lainsäädäntöä")
("traversal" "läpikulku")
("traverse" "kulku")
("triangle" "kolmio")
("triangularize" "kolmionmuotoinen")
("trigonometric" "trigonometrinen")
("trigonometry" "trigonometria")
("turn off" "sammuta")
("turn on" "päälle")
("turn on wallet" "käännä lompakko päälle")
("twice" "kahdesti")
("two columns" "kaksi saraketta")
("two dots" "kaksi pistettä")
("type a latex command followed by return" "kirjoita lateksikomento, jota seuraa paluu")
("unchanged" "muuttumattomana")
("underbrace" "alatuki")
("underline" "alleviivattu")
("underlined" "alleviivattu")
("unevaluated argument" "arvioimaton argumentti")
("unevaluated value" "arvoton arvo")
("unextended" "odottamaton")
("unfold" "aukeaa")
("unfold all" "avaa kaikki")
("unfold all fields" "avaa kaikki kentät")
("unfolded" "taitettu")
("unit" "yksikkö")
("unit length" "yksikön pituus")
("unknown secret key fingerprint" "tuntematon salainen avaimen sormenjälki")
("unregistered file" "rekisteröimätön tiedosto")
("unroll" "rullaa")
("unsecure script refused" "suojaamaton käsikirjoitus kielletty")
("unsupported link mode" "ei tueta linkkitilaa")
("until" "asti")
("untitled block" "otsikoimaton lohko")
("up to date" "ajan tasalla")
("update buffer" "päivityspuskuri")
("update this buffer" "päivitä tämä puskuri")
("update web site" "päivitä verkkosivusto")
("upight" "ylöspäin")
("upload" "lähetä")
("upload file or directory" "lataa tiedosto tai hakemisto")
("upright" "pystyssä")
("upwards" "ylöspäin")
("url" "URL")
("use CSS for more advanced formatting" "käytä CSS: ää edistyneempään muotoiluun")
("use MathML" "käytä MathML")
("use as master" "käytä isäntänä")
("use extensible brackets" "käytä laajennettavia kiinnikkeitä")
("use high resolution fonts" "käytä korkearesoluutioisia fontteja")
("use high resolution icons" "käytä korkearesoluutioisia kuvakkeita")
("use line wrapping for lines which are longer than 80 characters" "käytä rivinkäärettä yli 80 merkkiä pitkille riveille")
("use margin kerning (protrusion)" "käytä marginaaliviiltoa (ulkonema)")
("use print dialogue" "käytä tulostusdialogia")
("use protrusion" "käytä ulkonemaa")
("use relative path" "käytä suhteellista polkua")
("use retina fonts" "käytä verkkokalvon kirjasimia")
("use retina icons" "käytä verkkokalvon kuvakkeita")
("use unified toolbars" "käytä yhtenäisiä työkalurivejä")
("user interface" "käyttöliittymä")
("user interface language" "käyttöliittymän kieli")
("user preferences" "käyttäjän asetukset")
("users of Cyrillic languages" "kyrillisten kielten käyttäjää")
("users of oriental languages" "itämaisten kielten käyttäjiä")
("utf-8 with inputenc" "utf-8 sisääntulolla")
("utf-8 with inputenc LaTeX package" "utf-8 inputenc LaTeX-paketilla")
("utilities" "apuohjelmat")
("vanish" "katoaa")
("verbose" "verbose")
("version" "versio")
("versioning tool" "versiointityökalu")
("vertical alignment" "pystysuuntainen kohdistus")
("vertical margins" "pystysuuntaiset marginaalit")
("vertical space after" "pystysuuntainen tila jälkeen")
("vertical space before" "pystysuuntainen tila ennen")
("vertical space stretchability" "pystysuora tilan venyvyys")
("visible except here" "näkyvissä paitsi täällä")
("visible from here on" "näkyvissä tästä eteenpäin")
("visible only here" "näkyvissä vain täällä")
("visible until here" "näkyvissä tähän asti")
("visited loci" "vieraili lokit")
("wallet" "lompakko")
("wave" "aalto")
("web" "verkko")
("weight" "paino")
("when line wrapping" "kun rivitys tapahtuu")
("when wrapping" "käärettäessä")
("whitespace" "välilyönti")
("wide" "leveä")
("wide bar" "leveä palkki")
("wide block" "leveä lohko")
("wide colored" "leveä värillinen")
("wide float" "leveä kellua")
("wide footnote" "leveä alaviite")
("wide tabular" "leveä taulukko")
("widescreen" "laajakuva")
("with newer version" "uudemmalla versiolla")
("with older version" "vanhemmalla versiolla")
("wrap lines" "rivityslinjaa")
("write a macro" "kirjoita makro")
("writing TeXmacs bibliography styles" "TeXmacs-bibliografiatyylien kirjoittaminen")
("writing documentation" "dokumentoinnin kirjoittaminen")
("written with TeXmacs" "kirjoitettu TeXmacsilla")
("wrong empty passphrase" "väärä tyhjä tunnuslause")
("wrong passphrase" "väärä salasana")
("year" "vuosi")
("year, Name" "vuosi, nimi")
("you are attempting to open an encrypted file while" "yrität avata salattua tiedostoa, kun")
("you might consider enabling the experimental" "saatat harkita kokeellisen käytön mahdollistamista")
("you must add a bibliography file" "sinun on lisättävä bibliografiatiedosto")
("you should also make sure that GnuPG is installed" "sinun on myös varmistettava, että GnuPG on asennettu")
("your language" "omalla kielelläsi")
("your personal dictionary has been modified" "henkilökohtaista sanastoasi on muokattu")
("zebra" "seepra")
("zoom" "zoom")
("zoom in" "lähentä")
("zoom out" "pienennä")
("zoom/unzoom objects" "zoomata / pienentää objekteja")
