;; Conversions between Unicode and LaTeX ascii code

;; (C) 2015 Francois Poulain, Joris van der Hoeven
;;
;; This software falls under the GNU general public license version 3 or later.
;; It comes WITHOUT ANY WARRANTY WHATSOEVER. For details, see the file LICENSE
;; in the root directory or <http://www.gnu.org/licenses/gpl-3.0.html>.
;;
;; Inspired from utf8enc.dfu

("#EC" "{\\`{\\i}}")
("#ED" "{\\'{\\i}}")
("#EE" "{\\^{\\i}}")
("#EF" "{\\\"{\\i}}")
("#EC" "\\`{\\i}")
("#ED" "\\'{\\i}")
("#EE" "\\^{\\i}")
("#EF" "\\\"{\\i}")
