("GNU" "GNU")
("LaTeX" "LaTeX")
("TeX" "TeX")
("a modifier" "modyfikator a")
("abbreviation" "skrót")
("about" "o mnie")
("about menu" "o menu")
("above" "ponad")
("abstract" "streszczenie")
("accent" "akcent")
("accept" "zaakceptuj")
("accept all scripts" "akceptuj skrypty")
("accept no scripts" "»adnych skryptów")
("accept script" "akceptuj skrypt")
("acknowledgment" "podzi¦kowanie")
("acronym" "akronim")
("action" "operacja")
("activate" "aktywacja")
("acute" "acute")
("add switch after" "wstaw przeŖ”cznik po")
("add switch before" "wstaw przeŖ”cznik przed")
("address" "adres")
("address block" "blok adresu")
("advanced" "trudniejsze")
("advanced layout features" "zaawansowany ukŖad")
("after" "po")
("albanian" "alba«ski")
("algorithm" "algorytm")
("align cell to the bottom" "wyrównaj komórk¦ do doŖu")
("align cell to the left" "wyrównaj komórk¦ do lewej")
("align cell to the right" "wyrównaj komórk¦ do prawej")
("align cell to the top" "wyrównaj komórk¦ do góry")
("align table at base of left column" "wyrównaj tablic¦ do bazy lewej kolumny")
("align table at base of middle column" "wyrównaj tablic¦ do bazy ±rodkowej kolumny")
("align table at base of origin column" "wyrównaj tablic¦ do bazy kolumny")
("align table at base of right column" "wyrównaj tablic¦ do bazy prawej kolumny")
("align table at fraction bar height" "wyrównaj tablic¦ do cz¦±ci wysoko±ci")
("align table at the base of bottom row" "wyrównaj tablic¦ do bazy dolnego rz¦du")
("align table at the base of middle row" "wyrównaj tablic¦ to bazy ±rodkowego rz¦du")
("align table at the base of origin row" "wyrównaj tablic¦ do bazy rz¦du")
("align table at the base of top row" "wyrównaj tablic¦ do bazy górnego rz¦du")
("align table at the bottom" "wyrównaj tablic¦ do doŖu")
("align table at the center" "wyrównaj tablic¦ do ±rodka")
("align table at the horizontal center" "wyrównaj tablic¦ do ±rodka poziomo")
("align table at the left" "wyrównaj tablic¦ do lewej")
("align table at the top" "wyrównaj tablic¦ do góry")
("align table to the right" "wyrównaj tablic¦ do prawej")
("align text to the left" "dosu« tekst w lewo")
("align text to the right" "dosu« tekst w prawo")
("aligned" "dostawiony")
("alignment" "wyrównanie")
("all" "wszystko")
("allow" "dopu±¢")
("allowed extension" "dopuszczalne rozszerzenie")
("allowed reduction" "dopuszczalna redukcja")
("alpha release" "wydanie alpha")
("alt key" "klawisz alt")
("and" "i")
("appendix" "dodatek")
("apply" "zastosuj")
("april" "kwiecie«")
("arab" "arabski")
("archaic" "archaiczny")
("architecture" "architektura")
("argument" "argument")
("arithmetic" "arytmetyczny")
("armenian" "arme«ski")
("arrow" "strzaŖka")
("arrows" "strzaŖki")
("article" "artykuŖ")
("as on paper" "jak na papierze")
("assign" "przypisz")
("at fraction bar height" "do wysoko±ci linii frakcji")
("at the baseline" "do lini bazowej")
("at the bottom" "do doŖu")
("at the left" "do lewej")
("at the middle" "do ±rodka")
("at the right" "do prawej")
("at the top" "do góry")
("attach" "doŖ”cz")
("attach buffer to which project" "doŖ”cz bufor do projektu")
("august" "sierpie«")
("author" "autor")
("authorize" "autoryzuj")
("automatic" "automatyczny")
("automatic quotes" "automatyczne cudzysŖowy")
("automatically close brackets" "automatyczne zamykanie nawiasów")
("automatically generated content" "spis generowany automatycznie")
("axiom" "aksjomat")
("background" "tŖo")
("background color" "kolor tŖa")
("backward replace" "zamieniaj w tyŖ")
("backward search" "szukaj w tyŖ")
("bad data format" "zŖy format danych")
("bar" "kreska")
("bard" "bard")
("base level" "poziom bazy")
("bashkirian" "bashkirian")
("basic" "podstawowy")
("basic communication using pipes" "podstawowa komunikacja za pomoc” potoków")
("basic data types" "podstawowe typy danych")
("basic types" "gŖówne typy")
("be useful" "u»ytki")
("become a TeXmacs developer" "zosta« deweloperem TeXmacs'a")
("before" "przed")
("begin" "pocz”tek")
("below" "poni»ej")
("beta release" "wydanie beta")
("bibliography" "bibliografia")
("bibliography file" "plik z bibliografi”")
("bibliography style" "styl bibliografii")
("big" "wielki")
("big figure" "du»y obrazek")
("big operator" "du»y operator")
("big skip" "du»y odst¦p")
("big table" "du»a tablica")
("binary operation" "operacja binarna")
("binary relation" "relacja binarna")
("black" "czarny")
("blackboard bold" "blackboard bold")
("blackboard math" "blackboard math")
("blackletter" "blackletter")
("blue" "niebieski")
("body" "zawarto±¢")
("bold" "tŖusty")
("book" "ksi”»ka")
("border" "obramowanie")
("both" "oba")
("bottom" "na koniec")
("bottom border" "dolna ramka")
("bottom margin" "dolny margines")
("bottom padding" "dolne wypeŖnienie")
("branch" "zakres")
("break" "zako«cz")
("breaking" "przerwanie")
("breve" "breve")
("british" "brytyjski")
("broken white" "zestarzaŖy biaŖy")
("brown" "br”zowy")
("browse" "przegl”daj")
("browse web" "przegl”daj web")
("browser" "przegl”d")
("buffer" "bufor")
("bulgarian" "buŖgarski")
("bullet" "kropka")
("bullets" "kropki")
("by" "autor")
("by typing" "przez wpisanie")
("bytes free" "bajtów wolnych")
("bytes used" "bajtów zaj¦tych")
("calligraphic" "kaligraficzny")
("cancel" "anuluj")
("caps-lock key" "klawisz caps-lock")
("case" "wybór")
("cc" "cc")
("cell" "komórka")
("cell background color" "kolor tŖa komórki")
("cell border" "ramka komórki")
("cell height" "wysoko±¢ komórki")
("cell operation mode" "forma operacji komórkowych")
("cell width" "wysoko±¢ komórki")
("center" "na ±rodek")
("center text" "centruj tekst")
("centered" "wy±rodkowany")
("centered block" "blok wy±rodkowany")
("centered tabular" "centrowane tabulowanie")
("change border of cell" "zmie« obramowanie komórki")
("change cell operation mode" "zmie« sposób operacji komórkowych")
("change log" "opis zmian")
("changes" "zmiany")
("chapter" "rozdziaŖ")
("check" "haczyk")
("check text for spelling errors" "sprawd¹ pisowni¦ tekstu")
("chinese" "chi«ski")
("choice" "wybór")
("citation" "cytat")
("cite" "cytat")
("class" "klasa")
("clear" "wyczy±¢")
("clear selection" "odznaczenie")
("clipped" "uchwycony")
("clipped and magnified" "uchwycony i powi¦kszony")
("clipped and resized" "uchwycony i przeskalowany")
("clone" "klonuj")
("clone window" "klonuj okno")
("close" "zamknij")
("close TeXmacs" "zamknij TeXmacs")
("close buffer" "zamknij bufor")
("close session" "zamknij sesj¦")
("close window" "zamknij okno")
("closing" "zamko«czenie")
("code" "kod")
("color" "kolor")
("column" "kolumna")
("column contains glued items" "kolumna zawiera elementy sklejone")
("compact" "kompaktowy")
("compatibility with other formats" "zgodno±¢ z innymi formatami")
("compile article" "kompiluj artykuŖ")
("compile book" "kompiluj ksi”»k¦")
("compile buffer" "kompiluj bufor")
("compile project" "kompiluj projekt")
("completion" "uzupeŖnianie")
("complex" "zŖo»one")
("concrete" "concrete")
("condensed" "zwarty")
("condition" "warunek")
("configuration" "konfiguracja")
("content" "zawarto±¢")
("content tag" "znacznik zawarto±ci")
("context dependent icons" "ikony kontekstowe")
("continuation of" "kontynuacja")
("convention" "konwencja")
("converters to other data formats" "konwertery do innych formatów danych")
("copy" "kopiuj")
("copy text" "kopiuj tekst")
("copy to" "kopiuj do")
("copying" "kopiowanie")
("corollary" "wniosek")
("correct text" "poprawny tekst")
("cursors" "kursor")
("custom tab" "wŖasny tab")
("customizing TeXmacs" "dostosuj TeXmacs'a")
("customizing the TeXmacs styles" "dostosuj style TeXmacs'a")
("custum tab" "wŖasny tab")
("cut" "wytnij")
("cut text" "wytnij tekst")
("cut to" "wytnij to")
("cypriot" "cypriot")
("cyrillic" "cyrylica")
("cyrillic input method" "metoda wpisu cyrylicy")
("cyrillic italic right" "cyrylica-kursywa")
("czech" "czeski")
("dancers" "dancers")
("danish" "du«ski")
("dark grey" "ciemno-szary")
("dash" "kreska")
("dashes" "kreski")
("data conversion" "konwersja danych")
("data format" "format danych")
("date" "data")
("deactivate" "wyŖ”cz")
("deactivate table" "wyŖ”cz tablic¦")
("december" "grudzie«")
("decorate atoms" "dekorowane atomy")
("default" "domy±lne")
("default padding" "podstawowe wypeŖnienie")
("definition" "definicja")
("delete" "skasuj")
("delete column" "kasuj kolumn¦")
("delete row" "kasuj rz”d")
("denominator" "mianownik")
("description" "opis")
("destination" "przeznaczenie")
("detach" "odŖ”cz")
("determinant" "wyznacznik")
("devangari" "devangari")
("developers guide" "przwodnik deweroperów")
("directory" "katalog")
("disable first indentation" "zako«cz pierwsze wci¦cie")
("disable first indentation after" "zako«cz pierwsze wci¦cie po")
("disable first indentation before" "zako«cz pierwsze wci¦cie przed")
("disable indentation" "zako«cz wcinanie")
("disable indentation after" "zako«cz wcinanie po")
("disable indentation before" "zako«cz wcinanie przed")
("disallow" "zabro«")
("distribute unused space" "rozmie±¢ nieu»yteczne spacje")
("div" "dziel")
("do not remap" "nie zmieniaj mapowania")
("document" "dokument")
("document format" "format dokumentu")
("document style" "styl dokumentu")
("document styles" "styl dokumentu")
("documentation" "dokumentacji")
("documents are trees" "dokumenty s” drzewami")
("dot" "kropka")
("dots" "wykropkowanie")
("double stroke" "double stroke")
("down" "w dóŖ")
("dpi" "dpi")
("duplicate" "duplikat")
("dutch" "holenderski")
("dynamic libraries" "biblioteki dynamiczne")
("edit" "edytuj")
("editing tools" "narz¦dzia edycji")
("email" "email")
("emphasize" "wytŖu±¢")
("emphasize text" "wytŖu±¢ tekst")
("empty box" "pusta ramka")
("enable first indentation" "wŖ”cz pierwsze wci¦cie")
("enable first indentation after" "wŖ”cz pierwsze wci¦cie po")
("enable first indentation before" "wŖ”cz pierwsze wci¦cie przed")
("enable indentation" "wŖ”cz wcinanie")
("enable indentation after" "wŖ”cz wcinanie po")
("enable indentation before" "wŖ”cz wcinanie przed")
("encl" "encl")
("end" "koniec")
("english" "angielski")
("enter a title" "podaj tytuŖ")
("enumerate" "wyliczenie")
("enumerate|Alpha" "wyliczenie|Alfa")
("enumerate|Roman" "wyliczenie|Rzymskie")
("enumerate|alpha" "wyliczenie|alfa")
("enumerate|roman" "wyliczenie|rzymskie")
("env" "±rod")
("environment" "±rodowisko")
("epilogue" "epilog")
("equal" "równy")
("equation" "równanie")
("equations" "równania")
("equivalent for" "równowa»ny")
("error" "bŖ”d")
("esperanto" "esperanto")
("etruscan" "etruski")
("evaluate" "ewaluacjia")
("evaluate scheme expression" "interpertuj wyra»enie scheme")
("even page footer" "parzysta stopka")
("even page header" "parzysty nagŖówek")
("even page margin" "parzyst marginesy strony")
("even page text" "parzysty tekst strony")
("exact horizontal" "dokŖadnie w poziomie")
("exact mode" "tryb dok³adny")
("exam" "exam")
("example" "przykŖad")
("exclusive" "exclusive")
("exclusive or" "exclusive or")
("executable" "executable")
("execute" "wykonaj")
("execute a TeXmacs command" "wykonaj komend¦ TeXmacsa")
("execute system command" "wykonaj komend¦ systemow”")
("executive" "executive")
("exercise" "¢wiczenie")
("expand" "rozszerz")
("explained" "wytŖumacz")
("export" "eksportuj")
("export as" "eksportuj jako")
("extend or normal" "rozszerz lub normalizuj")
("extern " "zewn¦trzne")
("extra" "dodatki")
("extract format" "otrzymany format")
("family" "rodzina")
("february" "luty")
("figure" "rysunek")
("file" "plik")
("file name" "nazwa pliku")
("file not found" "pliku nie znaleziono")
("find next match" "znajd¹ nast¦pne dopasowanie")
("find text" "znajd¹ tekst")
("finnish" "fi«ski")
("first contact" "pierwszy kontakt")
("first indentation" "pierwsze wci¦cie")
("first item" "pierwsze wyszczególnienie")
("first page" "pierwsza strona")
("first start" "pierwszy start")
("flat" "pŖaski")
("flexibility" "elastyczno±¢")
("flexibility factor for vertical spacing" "elastyczny czynnik odst¦pów w pionie")
("floating figure" "pŖynny obrazek")
("floating object" "pŖynny obiekt")
("floating table" "pŖynna tablica")
("fold" "zszycie")
("folded" "zszyty")
("font" "czcionka")
("font base size" "rozmiar czcionki podstawowej")
("font dpi" "dpi czcionki")
("font family" "czcionka z rodziny")
("font name" "nazwa czcionki")
("font series" "czcionka seria")
("font shape" "czcionka ksztaŖt")
("font size" "rozmiar czcionki")
("font type" "rodzaj czcionk")
("font variant" "wariant czcionki")
("fonts" "czcionki")
("footer" "stopka")
("footnote" "przypis")
("for" "dla")
("foreground" "przód")
("foreign" "obcy")
("format" "format")
("formatted date" "sformatowana data")
("formula" "wzór")
("formula style" "styl równania")
("forward replace" "zamieniaj w przód")
("forward search" "szukaj w przód")
("fraction" "uŖamek")
("french" "francuski")
("full manuals" "peŖny podr¦cznik")
("function" "funkcja")
("further customization" "dalsze dostosowanie")
("future changes" "planowane zmiany")
("gNU TeXmacs comes without any form of legal warranty" "gNU TeXmacs nie poci”ga za sob” »adnej gwarancji prawnej")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs jest chroniony przez GNU general public license")
("general architecture of TeXmacs" "ogólna architektura TeXmacs'a")
("general negation" "ogólna negacja")
("generating font file" "generowanie pliku czcionek")
("generic" "ogólny")
("georgian" "georgian")
("german" "niemiecki")
("getting started" "uruchamianie")
("glossary" "sŖownik")
("glossary entry" "hasŖo sŖownika")
("glue" "sklej")
("glue decorations" "przyklej dekoracje")
("go" "id¹")
("gothic" "gotycki")
("graphical interface" "interfejs graficzny")
("grave" "grave")
("greater" "wi¦kszy")
("greater or equal" "wi¦kszy lub równy")
("greek" "grecki")
("greek letter" "litera grecka")
("green" "zielony")
("grey" "szary")
("group" "grupa")
("h modifier" "modyfikator h")
("happy typing" "wpisywanie")
("has been aborted" "zostaŖo odrzucone")
("has completed its task" "zako«czyŖ zadanie")
("hat" "daszek")
("header" "nagŖówek")
("header and footer" "nagŖówek i stopka")
("hebrew" "hebrajski")
("height" "wysoko±¢")
("height is exactly the specified height" "wysoko±¢ jest podana dokŖadnie")
("height is maximum of specified height and box height" "wysoko±¢ jest maksimum z podanej i wysoko±ci pudeŖka")
("height is minimum of specified height and box height" "wysoko±¢ jest minimum z podanej i wysoko±ci pudeŖka")
("height magnification" "zwi¦kszenie w pionie")
("help" "pomoc")
("help me" "pomó» mi")
("help us" "pomó» nam")
("here" "tutaj")
("home" "home")
("horizontal" "poziomo")
("horizontal cell alignment" "wyrównanie poziome komórki")
("horizontal ink separation" "poziomy odst¦p")
("horizontal part" "cz¦±¢ pozioma")
("horizontal position" "poŖo»enie pionowe")
("horizontal space" "odst¦p poziomy")
("horizontal table alignment" "wyrównanie poziome tablicy")
("horizontally align cell to the base" "wyrównaj poziomo komórk¦ do bazy")
("horizontally center the cell" "wycentruj poziomo komórk¦")
("how much longer may pages become" "o ile strona mo»e by¢ dŖu»sza")
("how much shorter may pages become" "o ile strona mo»e by¢ krótsza")
("huge" "ogromny")
("hungarian" "w¦gierski")
("hyperlink" "hiperlink")
("hyphenation" "podziaŖ wyrazów")
("icelandic" "icelandic")
("if" "je±li")
("image" "obrazek")
("image links" "linki do obrazków")
("implementation" "implementacja")
("import" "importuj")
("improving the current implementation" "popraw bie»”c” implementacj¦")
("inactive" "interakcyjny")
("include" "wstaw")
("include a document" "wstaw dokument")
("include file" "wstaw plik")
("inclusion into TeXmacs" "wstawnianie do TeXmacs'a")
("inclusions" "wstawki")
("indent" "wci¦cie")
("indentation flag" "znacznik wci¦cia")
("index" "indeks")
("index entry" "hasŖo indeksu")
("index level" "poziom indeksu")
("input mode" "tryb wprowadzania")
("insert" "wstaw")
("insert Pr" "wstaw Pr")
("insert a TeXmacs symbol" "wstaw symbol TeXmacsa")
("insert a big operator" "wstaw du»y operator")
("insert a binary operation" "wstaw operator dwuarg.")
("insert a binary relation" "wstaw relacj¦ dwuarg.")
("insert a blackboard bold character" "wstaw wytŖszczony znak pisany")
("insert a bold calligraphic character" "wstaw wytŖuszczony znak kaligrafowany")
("insert a bold character" "wstaw wytŖuszczony znak")
("insert a calligraphic character" "wstaw znak kaligrafowany")
("insert a fraction" "wstaw uŖamek")
("insert a fraktur character" "wstaw znak frakturowy")
("insert a greek character" "wstaw znak grecki")
("insert a large left delimiter" "wstaw du»y lewy ogranicznik")
("insert a large right delimiter" "wstaw du»y prawy ogranicznik")
("insert a large separator" "wstaw du»y separator")
("insert a left subscript" "wstaw lewy indeks dolny")
("insert a link" "wstaw link")
("insert a miscellaneous symbol" "wstaw inny symbol")
("insert a new branch" "wstaw nowy zakres")
("insert a new item" "wstaw nowy element")
("insert a picture" "wstaw obrazek")
("insert a square root" "wstaw pierwiastek kwadratowy")
("insert a table" "wstaw tablic¦")
("insert a table or a matrix" "wstaw tablic¦ lub macierz")
("insert a wide symbol above" "wstaw szeroki symbol powy»ej")
("insert a wide symbol below" "wstaw szeroki symbol poni»ej")
("insert an" "wstaw")
("insert an accent" "wstaw akcent")
("insert an arrow" "wstaw starzaŖk¦")
("insert an environment" "wstaw nowe ±rodowisko")
("insert an n" "wstaw n")
("insert appendix" "wstaw dodatek")
("insert arccos" "wstaw arccos")
("insert arcsin" "wstaw arcsin")
("insert arctan" "wstaw arctan")
("insert arg" "wstaw arg")
("insert argument" "wstaw argument")
("insert automatically generated content" "wstaw wygenerowany automatycznie spis")
("insert big contour integral" "wstaw du»” caŖk¦ po konturze")
("insert big coproduct" "wstaw du»y koprodukt")
("insert big direct sum" "wstaw du»e sumowanie")
("insert big dotted point" "wstaw du»y punkt")
("insert big integral" "wstaw du»” caŖk¦")
("insert big intersection" "wstaw du»” intersekcj¦")
("insert big logical and" "wstaw du»e logiczne i")
("insert big logical or" "wstaw du»e logiczne lub")
("insert big product" "wstaw du»y iloczyn")
("insert big square union" "wstaw du»” uni¦ kwadratow”")
("insert big summation" "wstaw du»” sum¦")
("insert big tensor product" "wstaw du»y iloczyn tensorowy")
("insert big union" "wstaw du»” uni¦")
("insert big union sum" "wstaw du»” sum¦ zbiorów")
("insert big vertical space" "wstaw du»y odst¦p pionowy")
("insert chapter" "wstaw rozdziaŖ")
("insert column" "wstaw kolumn¦")
("insert column to the left" "wstaw kolumn¦ po lewej")
("insert column to the right" "wstaw kolumn¦ po prawej")
("insert cos" "wstaw cos")
("insert cosh" "wstaw cosh")
("insert cot" "wstaw cot")
("insert coth" "wstaw coth")
("insert csc" "wstaw csc")
("insert deg" "wstaw deg")
("insert det" "wstaw det")
("insert dim" "wstaw dim")
("insert dollar" "wstaw dolar")
("insert equation" "wstaw równanie")
("insert executable markup" "wstaw wykonalny znacznik")
("insert exp" "wstaw exp")
("insert footnote" "wstaw przypis")
("insert formula" "wstaw wzór")
("insert gcd" "wstaw gcd")
("insert hom" "wstaw hom")
("insert horizontal interword space" "wstaw poziomy odst¦p mi¦dzywyrazowy")
("insert image" "wstaw obrazek")
("insert inactive markup" "wstaw nieaktywny znacznik")
("insert inf" "wstaw inf")
("insert ker" "wstaw ker")
("insert lg" "wstaw lg")
("insert lim" "wstaw lim")
("insert liminf" "wstaw liminf")
("insert limsup" "wstaw limsup")
("insert ln" "wstaw ln")
("insert log" "wstaw log")
("insert mathematics" "wstaw matematyk¦")
("insert max" "wstaw max")
("insert medium horizontal space" "wstaw ±redni odst¦p poziomy")
("insert medium vertical space" "wstaw ±redni odst¦p pionowy")
("insert min" "wstaw min")
("insert negative horizontal space" "wstaw wsteczny odst¦p poziomy")
("insert new item or number" "wstaw nowy element lub liczb¦")
("insert new rows or columns" "wstaw nowe rz¦dy lub kolumny")
("insert or delete rows or columns" "wstaw lub kasuj rz¦dy lub kolumny")
("insert row" "wstaw rz”d")
("insert row above" "wstaw rz”d powy»ej")
("insert row below" "wstaw rz”d poni»ej")
("insert sec" "wstaw sec")
("insert section" "wstaw akapit")
("insert sharp" "wstaw sharp")
("insert sin" "wstaw sin")
("insert sinh" "wstaw sinh")
("insert small horizontal space" "wstaw maŖy odst¦p poziomy")
("insert small vertical space" "wstaw maŖy odst¦p pionowy")
("insert structural markup" "wstaw strukturalny znacznik")
("insert subsection" "wstaw punkt")
("insert subsubsection" "wstaw podpunkt")
("insert sup" "wstaw sup")
("insert tan" "wstaw tan")
("insert tanh" "wstaw tanh")
("insert text field" "wstaw pole tekstowe")
("insert thick horizontal space" "wstaw szeroki odst¦p poziomy")
("interfacing" "interfacing")
("interfacing TeXmacs with other systems" "interfejs TeXmacs'a z innymi systemami")
("interjection" "w miejsce")
("interline separation" "odlegŖo±¢ interlinii")
("interline space" "odst¦py mi¦dzy liniami")
("internationalization" "umi¦dzynarodowienie")
("interparagraph space" "odst¦p mi¦dzy akapitami")
("interrupt execution" "przerwij wykonanie")
("introduction" "wprowadzenie")
("invisible" "niewidoczny")
("invisible citation" "niewidoczny cytat")
("irish" "irlandzki")
("is running" "praca w toku")
("is tuple" "is tuple")
("ispell does not respond" "ispell nie odpowiada")
("ispell is already busy" "ispell jest zaj¦ty")
("italian" "wŖoski")
("italic" "kursywa")
("italic right" "kursywa w prawo")
("itemize" "wyszczególnienie")
("january" "stycze«")
("japanese" "japo«ski")
("july" "lipiec")
("june" "czerwiec")
("justified" "wyrównany")
("justify text" "wyrównuj tekst")
("key" "klawisz")
("keyboard" "klawiatura")
("keyboard equivalent" "skrót klawiszowy")
("keyboard modifiers" "modyfikatory klawiatury")
("keyboard shortcut" "skrót klawiszowy")
("keymaps" "mapa klawiszy")
("keyword" "sŖowo kluczowe")
("keywords" "sŖowa kluczowe")
("kill" "zniszcz")
("known bugs" "znane problemy")
("label" "etykieta")
("landscape" "poprzecznie")
("language" "j¦zyk")
("large" "wielki")
("large closing bracket" "du»y zamykaj”cy nawias")
("large delimiter" "du»y ogranicznik")
("large opening bracket" "du»y otwieraj”cy nawias")
("large separator" "du»y separator")
("last page" "ostatnia strona")
("latex command" "komenda latex")
("latin" "Ŗaci«ski")
("layout" "ukŖad")
("left" "w lewo")
("left arrow" "strzaŖka w lewo")
("left border" "lewy brzeg")
("left margin" "lewy margines")
("left padding" "lewe wypeŖnienie")
("left prime" "lewy prime")
("left aligned" "wyrównanie do lewej")
("left slanted" "pochylony w lewo")
("left subscript" "lewy indeks dolny")
("left superscript" "lewy indeks górny")
("left surrounding" "lewe otoczenie")
("legal" "legal")
("lemma" "lemat")
("length" "dŖugo±¢")
("less" "mniejszy")
("less or equal" "mniejszy lub równu")
("letter" "list")
("license" "licencja")
("light" "jasny")
("light grey" "jasno-szary")
("limitations" "ograniczenia")
("limits" "granice")
("line" "linia")
("line break" "koniec linii")
("line stretch" "rozpi¦cie linii")
("link" "link")
("link image" "link do obrazka")
("list" "lista")
("list of figures" "spis ryskunków")
("list of tables" "spis tablic")
("load" "Ŗaduj")
("load LaTeX file" "Ŗaduj plik formatu LaTeX")
("load TeX file" "Ŗaduj plik formatu TeX")
("load TeXmacs file" "Ŗaduj plik TeXmacs")
("load TeXmacs style file" "Ŗaduj plik style")
("load a file" "Ŗaduj plik")
("load buffer" "Ŗaduj bufor")
("load file" "Ŗaduj plik")
("load html file" "Ŗaduj plik html")
("load image" "Ŗaduj obrazek")
("load in new window" "Ŗaduj do nowego okna")
("load latex file" "Ŗ”duj plik latex")
("load more recent autosave file" "Ŗaduj najnowsze pliki autosave")
("load tex file" "Ŗaduj plik tex")
("load verbatim file" "Ŗaduj plik verbatim")
("loaded" "zaŖadowany")
("long" "dŖugi")
("look and feel" "wygl”d")
("look up" "zajrzyj")
("lower border" "dolny brzeg")
("m modifier" "m modyfikator")
("macro" "makro")
("magenta" "fioletowy")
("magic" "magic")
("magnification" "powi¦kszenie")
("magnified" "powi¦kszony")
("main" "gŖówne")
("main icon bar" "gŖówny pasek ikon")
("major changes" "gŖówne zmiany")
("make a page insertion" "zrób wstawnienie strony")
("make a subscript" "utwórz indeks dolny")
("make a superscript" "utwórz indeks górny")
("make acute" "utwórz acute")
("make bar" "utwórz kresk¦")
("make check" "utwórz haczyk")
("make fraction" "utwórz uŖamek")
("make grave" "utwórz grave")
("make hat" "utwórz daszek")
("make label" "utwórz etykiet¦")
("make negation" "utwórz negacj¦")
("make page reference" "zrób odno±nik do strony")
("make reference" "utwórz odsyŖacz")
("make square root" "utwórz pierwiastek kwadratowy")
("make tilde" "utwórz tyld¦")
("make title" "zrób tytuŖ")
("make vector" "utwórz wektor")
("making donations" "robienie donations")
("manual" "podr¦cznik")
("map to" "zmie« na")
("march" "marzec")
("margins" "marginesy")
("margins as on paper" "marginesy jak na papierze")
("master" "gŖówny")
("master file" "gŖówny plik")
("math" "matma")
("math font" "czcionka matematyczna")
("math font family" "czcionka mat. rodzina")
("math font series" "czcionka mat. seria")
("math font shape" "czcionka mat. ksztaŖt")
("mathematical" "matematyczny")
("mathematical formulas" "formuŖy matematyczne")
("mathematical typesetting" "typesetting matematyczny")
("mathematics" "matematyka")
("matrix" "macierz")
("maximal number of columns" "maksymalna liczba kolumn")
("maximal number of rows" "maksymalna liczba rz¦dów")
("maximum mode" "tryb maksimum")
("may" "maj")
("medium" "±redni")
("medium skip" "±redni odst¦p")
("meminfo" "pami¦¢")
("merge" "rozszerzenie")
("messy" "messy")
("meta key" "klawisz meta")
("middle" "na ±rodek")
("minimal number of columns" "minimalna liczba kolumn")
("minimal number of rows" "minimalna liczba rz¦dów")
("minimum mode" "tryb minimum")
("minus" "minus")
("miscellaneous" "ró»ne")
("miscellaneous features" "ró»ne funkcje")
("mod" "modulo")
("mode" "tryb")
("modifier" "modyfikator")
("modify cell alignment" "zmie« wyrównanie komórki")
("modify cell border" "zmie« ramk¦ komórki")
("modify cell padding" "zmie« wypeŖnienie komórki")
("modify cell size" "zmie« rozmiar komórki")
("modify table border" "zmie« ramk¦ tablicy")
("modify table padding" "zmie« wypeŖnienie tablicy")
("mongolian" "mongolski")
("more information about GNU TeXmacs can be found in the help" "wi¦cej informacji na temat GNU TEXmacs'a mo»na znale¹¢ w Pomocy")
("mosaic" "mosaic")
("move down" "przesu« w dóŖ")
("move object" "przesu« obiekt")
("move to the right when finished" "przesu« na prawo po sko«czeniu")
("move up" "przesu« w gór¦")
("my documents" "moje dokumenty")
("n-th" "-ty/a")
("n-th root" "pierwiastek n-ty")
("name" "nazwa")
("negation" "negacja")
("new" "nowy")
("new buffer" "nowy bufor")
("new column" "nowa kolumna")
("new item" "nowy element")
("new line" "nowa linia")
("new number" "nowa warto±¢")
("new page" "nowa strona")
("new page before" "nowa strona przed")
("new paragraph" "nowy akapit")
("new roman" "new roman")
("new row" "nowy rz”d")
("new table" "nowa tablica")
("next line" "nast¦pna linia")
("no changes need to be saved" "nie trzeba zapisywa¢")
("no dictionary for" "brak sŖownika dla")
("no first indentation" "bez pierwszego wci¦cia")
("no indentation" "bez wci¦¢")
("no line break" "bez Ŗamania linii")
("no matches found" "nie znaleziono dopasowa«")
("no matches found for" "nie znaleziono dopasowa« dla")
("no more matches for" "brak dopasowa« dla")
("no more redo information available" "brak informacji redo")
("no more undo information available" "brak informacji undo")
("no name" "bez nazwy")
("no page break after" "bez Ŗamania strony po")
("no page break before" "bez Ŗamania strony przed")
("no spelling errors found in text" "brak bŖ¦dów pisowni")
("no style" "brak styli")
("none" "»aden")
("normal" "normalny")
("norwegian" "norweski")
("not" "nie")
("not equal" "nie równy")
("not found" "nie znaleziono")
("notation" "notacja")
("note" "notka")
("november" "listopad")
("number" "liczba")
("number equation" "numerowane równanie")
("number of columns" "liczba kolumn")
("numbered equation" "numerowane równanie")
("numbered equations" "numerowane równania")
("numerator" "licznik")
("numeric" "numeryczny")
("objectives" "objectives")
("occurrences" "wyst”pie«/nia")
("october" "pa¹dziernik")
("odd page footer" "nieparzysty")
("odd page header" "nieparzysty nagŖówek strony")
("odd page margin" "nieparzyste marginesy strony")
("odd page text" "tekst na stronach nieparzystych")
("off" "wyŖ”cz")
("ok" "ok")
("old english" "staro-angielski")
("old slavonic" "starp-sŖowia«ski")
("old style" "dawny styl")
("on" "wŖ”cz")
("on cells" "na komórkach")
("on columns" "na kolumnach")
("on entire table" "na caŖej tablicy")
("on rows" "na rz¦dach")
("one spelling error has been corrected" "poprawiono jeden bŖ”d pisowni")
("online documentation" "dokumentacja on line")
("online help" "pomoc on line")
("open" "otwórz")
("open a new buffer" "otwórz nowy bufor")
("open new window" "otwórz nowe okno")
("opening" "otwarcie")
("operation on named selection" "operacja na nazwanych selekcjach")
("operation on primary selection" "oparacja na pierwszej selekcji")
("operation on secondary selection" "operacja na drugiej selekcji")
("operation on ternary selection" "opreacja na trzeciej selekcji")
("optical" "optical")
("option" "opcja")
("options" "opcje")
("or" "lub")
("orange" "pomara«czowy")
("orientation" "uŖo»enie")
("origin" "pochodzenie")
("original welcome message" "oryginalna wiadomo±¢ powitania")
("other" "inne")
("other pages" "inne strony")
("other projects" "inne projekty")
("other style" "inny styl")
("outlined roman" "outlined roman")
("over" "przez")
("overbrace" "klamra górna")
("overline" "kreska górna")
("padding" "wypeŖnienie")
("page" "strona")
("page bottom margin" "dolny margines strony")
("page break" "zako«cz stron¦")
("page break before" "koniec strony przed")
("page height" "wysoko±¢ strony")
("page insertion" "wstawianie na stronie")
("page layout" "ukŖad strony")
("page number text" "tekst numeracji strony")
("page numbering" "numeracja stron")
("page reference" "odsyŖacz do strony")
("page right margin" "prawy margines strony")
("page setup" "ustawienia strony")
("page top margin" "górny margines strony")
("page type" "typ strony")
("page width" "szeroko±¢ strony")
("paper" "papier")
("paper type" "rodzaj papieru")
("papyrus" "papirus")
("paragraph" "akapit")
("paragraph mode" "tryb akapitu")
("paragraph width" "szeroko±¢ akapitu")
("part" "cz¦±¢")
("past changes" "ostatnie zmiany")
("paste" "wklej")
("paste from" "wklej z")
("paste text" "wklej tekst")
("path" "±cie»ka")
("perform operations on cells" "wykonaj operacje na komórkach")
("perform operations on columns" "wykonaj operacje na kolumnach")
("perform operations on entire table" "wykonaj operacje na caŖej tablicy")
("perform operations on rows" "wykonaj operaje na rz¦dach")
("permanent" "staŖy")
("person" "osoba")
("personal dictionary has been modified" "zmieniony sŖownik osobisyty")
("phantasy" "phantasy")
("philosophy" "filozofia")
("phoenician" "phoenician")
("phonetic" "phonetic")
("pink" "ró»owy")
("plain block" "zwykŖy blok")
("plain tabular" "zwykŖe tabulowanie")
("planned changes" "planowane zmiany")
("plans for the future" "plany na przyszŖo±¢")
("please" "prosz¦")
("please wait" "prosz¦ czeka¢")
("plugin" "wtyczka")
("plugins" "wtyczki")
("plus" "plus")
("polish" "polski")
("porting TeXmacs to other platforms" "przeniesienie TeXmacs'a na inne platformy")
("portrait" "pionowo")
("portuguese" "portugalski")
("position" "pozycja")
("position float" "pozycja pŖynna")
("position floating object" "pozycja pŖynnego obiektu")
("position the table" "pozycja tablicy")
("postscript" "postscript")
("postscript image" "obrazek postscriptowy")
("pre-alpha release" "wydanie pre-alpha")
("preamble" "kody jawne")
("preamble mode" "tryb preambuŖy")
("preferences" "ustawienia")
("presentation" "prezentacja")
("presentation mode" "tryb prezentacji")
("presentation tag" "znacznik prezentacji")
("preview before printing" "podgl”d przed wydrukiem")
("preview command" "polecenie podgl”du")
("preview with ghostview" "podgl”d przez ghostview")
("primary" "pierwszego")
("prime" "prime")
("print" "drukuj")
("print all" "drukuj wszystko")
("print all to file" "drukuj wszystko do pliku")
("print page selection" "drukuj wybrane strony")
("print page selection to file" "drukuj wybrane strony do pliku")
("print to postscript file" "drukuj do pliku postscriptowego")
("printer" "drukarka")
("printer dpi" "dpi drukarki")
("printing command" "parametr wydruku")
("problem" "problem")
("professional" "profesjonalny")
("prog" "program")
("prog font" "czcionka programowa")
("prog font family" "czcionka prog. rodzina")
("prog font series" "czcionka prog. seria")
("prog font shape" "czcionka prog. ksztaŖt")
("program" "program")
("program mode" "tryb programu")
("programming" "programowanie")
("progressive" "progresywny")
("project" "projekt")
("projects" "projekty")
("prologue" "kody jawne")
("prompt on scripts" "potwierd¹ skrypt")
("proof" "dowód")
("proportional" "proporcjonalny")
("proportional typewriter" "proporcjonalny maszynowy")
("proposition" "stwierdzenie")
("query replace" "zamieniaj")
("quit" "zako«cz")
("quotation" "cytowane")
("quote" "cytat")
("range" "zakres")
("really close it" "na pewno chcesz zamkn”¢")
("really huge" "przeogromny")
("really quit" "rzeczywi±cie zako«czy¢")
("red" "czerwony")
("redo" "przywoŖaj ponownie operacj¦")
("redo undone changes" "przywoŖaj ostatnio wycofan” zmian¦")
("reduce bottom margin by" "zredukuj dolny margines o")
("reduce left margin by" "zredukuj lewy margines o")
("reduce margins" "zredukuj marginesy")
("reduce right margin by" "zredukuj prawy margines o")
("reduce top margin by" "zredukuj górny margines o")
("reduction even page margin" "redukcja nieparzystego marginesu strony")
("reduction odd page margin" "redukcja parzystego margiesu strony")
("reduction page bottom margin" "redukcja dolnego marginesu strony")
("reduction page right margin" "redukcja prawego marginesu strony")
("reduction page top margin" "redukcja górnego marginesu strony")
("reference" "odsyŖacz")
("references" "odsyŖacze")
("regular" "zwykŖe")
("release" "wydanie")
("reload" "przeŖaduj")
("remark" "uwaga")
("remove number" "usu« numer")
("remove this switch" "usu« ten przeŖ”cznik")
("renumber this page" "zmie« numeracj¦ tej strony")
("repeat object" "powtórz obiekt")
("replace" "zamie«")
("replace by" "zamie« na")
("replaced" "zamieniono")
("replaced one occurrence" "zamieniono pojedyncze wyst”pienie")
("reset" "skasuj")
("resize object" "przeskaluj obiekt")
("resized" "przeskalowany")
("search results for" "wyniki wyszukiwania dla")
("return" "powrót")
("revert" "przywró¢")
("revert buffer" "przywró¢ bufor")
("right" "w prawo")
("right arrow" "strzaŖka w prawo")
("right border" "prawy brzeg")
("right margin" "prawy margines")
("right padding" "prawe wypeŖnienie")
("right aligned" "wyrównanie do prawej")
("right subscript" "prawy indeks dolny")
("right superscript" "prawy indeks górny")
("right surrounding" "prawe otoczenie")
("rigid" "twardy")
("rigid horizontal" "twardy poziom")
("rigid space" "twardy odst¦p")
("romanian" "rumu«ski")
("root" "pierwiastek")
("rotate backward" "odwró¢ w tyŖ")
("rotate forward" "odwró¢ w przód")
("row" "rz”d")
("row contains glued items" "rz”d zawiera elementy sklejone")
("runic" "runic")
("running author" "przewodni autor")
("running title" "przewodni tytluŖ")
("russian" "rosyjski")
("sample" "próba")
("sans serif" "sans serif")
("save" "zapisz")
("save TeXmacs file" "zapisz plik TeXmacs")
("save TeXmacs style file" "zapisz plik styli TeXmacs")
("save as" "zapisz jako")
("save as LaTeX" "zapisz w formacie LaTeX")
("save as TeX" "zapisz w formacie TeX")
("save buffer" "zapisz bufor")
("save buffer as" "zapisz bufor jako")
("save file" "zapisz plik")
("save html file" "zapisz plik html")
("save image" "zapisz obrazek")
("save latex file" "zapisz plik latex")
("save tex file" "zapisz plik tex")
("save this buffer" "zapisz ten bufor")
("save verbatim file" "zapisz plik verbatim")
("saved" "zapisano")
("screen layout" "ustawienie ekranu")
("screen margins" "marginesy ekranu")
("script" "skrypt")
("script above" "pisane powy»ej")
("script below" "pisane poni»ej")
("script script size" "rozmiar script script")
("script size" "rozmiar script")
("scripts not accepted" "skryptu nie zaakceptowano")
("search" "szukaj")
("search words in my documents" "wyszukiwanie sŖów we wŖasnych dokumentach")
("search words in the documentation" "wyszukiwanie sŖów w dokumentacji")
("search words in the source code" "wyszukiwanie sŖów w kodzie ¹ródŖowym")
("searching" "poszukiwanie")
("secondary" "drugiego")
("section" "akapit")
("security" "bezpiecze«stwo")
("see" "zobacz")
("select a document style" "wybierz styl dokumentu")
("select a foreground color" "wybierz kolor pisma")
("select a language" "wybierz j¦zyk")
("selected region" "obszar zaznaczony")
("selection" "selekcja")
("selections" "wybory")
("seminar" "seminarium")
("sending commands to TeXmacs" "wysyŖanie komend do TeXmacs'a")
("separation between lines" "separacja mi¦dzy liniami")
("separation between paragraphs" "separacja mi¦dzy akapitami")
("separator" "separator")
("september" "wrzesie«")
("serb" "serbski")
("series" "seria")
("series|right" "seria|prawy")
("session" "sesja")
("session name" "nazwa sesji")
("session type" "typ sesji")
("sessions" "sesje")
("set" "ustaw")
("set background color of cell" "ustaw kolor tŖa komórki")
("set cell mode" "ustaw tryb komórki")
("set extension center" "ustaw ±rodek poszerzenia")
("set height" "ustaw wysoko±¢")
("set height of cell" "ustaw wysoko±¢ komórki")
("set margins" "ustawienie marginesów")
("set n" "ustaw n")
("set paragraph margins" "ustaw marginesy akapitu")
("set paragraph mode" "ustaw form¦ akapitu")
("set printer dpi" "ustaw dpi drukarki")
("set printing command" "ustaw parametry wydruku")
("set span" "ustaw rozpi¦to±¢")
("set special cell properties" "ustaw specjalne wŖa±ciwo±ci komórki")
("set special table properties" "ustaw specjalne wŖa±ciwo±ci tablicy")
("set text width" "ustaw szeroko±¢ tekstu")
("set width" "ustaw szeroko±¢")
("set width of cell" "ustaw szeroko±¢ komórki")
("settings" "ustawienia")
("setup printer" "ustaw drukark¦")
("shape" "ksztaŖt")
("shift-down" "przesu« w dóŖ")
("shift-right" "przesu« w prawo")
("show" "poka»")
("show header and footer" "poka» nagŖówek i stopk¦")
("show on screen" "poka» na ekranie")
("shrinking factor" "czynnik zw¦»enia")
("signature" "podpis")
("size" "rozmiar")
("size limits" "granice rozmiaru")
("slanted" "pochylony")
("sloppy" "byle jaki")
("small" "maŖy")
("small caps" "maŖy")
("small figure" "maŖy obrazek")
("small skip" "maŖy odst¦p")
("small table" "maŖa tablica")
("source code" "kod ¹ródŖowy")
("space" "odst¦p")
("space between lines" "odst¦p mi¦dzy liniami")
("space between paragraphs" "odst¦p mi¦dzy paragrafami")
("spacing" "odst¦py")
("spanish" "hiszpa«ski")
("special" "specjalne")
("special cell properties" "specjalne wŖa±ciwo±ci komórki")
("special table properties" "specjalne wŖa±ciwo±ci tablicy")
("specific" "specyficzny")
("spell" "pisownia")
("spell checking complete" "koniec sprawdzania pisowni")
("spelling error" "bŖ”d pisowni")
("spelling errors have been corrected" "bŖ¦dy pisowni zostaŖy poprawione")
("split" "podziel")
("split session" "podziel sesj¦")
("square root" "pierwiastek kwadratowy")
("start" "start")
("start a new chapter" "rozpocznij nowy rozdziaŖ")
("start a new section" "rozpocznij nowy akapit")
("start an interactive session" "rozpocznij sesj¦ interaktywnie")
("status bar" "pasek stanu")
("stretchable" "rozpi¦cie")
("stretchable horizontal" "rozpi¦cie w poziomie")
("stretchable vertical" "rozpi¦cie w pionie")
("stroke" "przekre±l")
("strokes" "przekre±lenia")
("strong" "mocny")
("structural" "strukturalny")
("style" "styl")
("styles" "style")
("sub" "podrz¦dne")
("subparagraph" "pod-paragraf")
("subscript" "indeks dolny")
("subsection" "punkt")
("subsub" "pod-podrz¦dne")
("subsubsection" "podpunkt")
("summary" "streszczenie")
("summary of the principal TeXmacs tags" "informacje o podstawowych znacznikach TeXmacs'a")
("superpose" "superpoza")
("superposed" "superpozowany")
("superscript" "indeks górny")
("swedish" "szwedzki")
("switch" "przeŖ”cznik")
("switch to first" "przeŖ”cz na pierwszy")
("switch to formula style" "przeŖ”cz na styl równa«")
("switch to last" "przeŖ”cz na ostatni")
("switch to next" "przeŖ”cz na nast¦pny")
("switch to previous" "przeŖ”cz na poprzedni")
("switching and folding" "przeŖ”czanie i foldowanie")
("symbol" "symbol")
("system environment variables" "zmienne otoczenia systemu")
("tab" "tab")
("table" "tablica")
("table command" "rozkaz tablicy")
("table of contents" "spis tre±ci")
("tables" "tablice")
("tabular" "tabulowanie")
("tabular material" "materiaŖ tabulowany")
("teXmacs as an interface" "teXmacs jako interfejs")
("teXmacs fonts" "czcionki TeXmacs'a")
("teXmacs notice" "noty TeXmacs'a")
("teXmacs plugins" "wtyczki TeXmacs'a")
("teXmacs style files" "pliki stylów teXmacs")
("ternary" "trzeciego")
("test" "test")
("tex" "tex")
("text" "tekst")
("text font" "czcionka tekstowa")
("text height correction" "poprawa wysoko±ci tekstu")
("text width" "szeroko±¢ tekstu")
("texts" "teksty")
("th century bc" "th century bc")
("th root" "-ty pierwiastek")
("thai" "thai")
("the TeXmacs authors" "autorzy TeXmacs'a")
("the application did not send its usual startup banner" "aplikacja nie przesŖaŖa swego startowego bannera")
("the application does not reply" "aplikacja nie odpowiada")
("the application is already running" "aplikacja ju» uruchomiona")
("the boxes produced by the typesetter" "pudeŖko wykonane przez zecera")
("the graphical user interface" "interfejs graficzny u»ytkownika")
("the leaves of TeXmacs trees" "li±cie drzew TeXmacs'a")
("the mycas example" "przykŖad mycas")
("the primitive TeXmacs constructs" "podstawowe konstrukty TeXmacs'a")
("the standard TeXmacs styles" "standardowe style TeXmacs'a")
("theorem" "twierdzenie")
("there are unsaved documents" "s” niezapisane pliki")
("this document has not been saved" "ten bufor nie byŖ zapisywany")
("this document has been produced using" "ten dokument byŖ wykonany przy u»yciu")
("this line" "ta linia")
("this page" "ta strona")
("tilda" "tylda")
("tilde" "tylde")
("times" "razy")
("tiny" "male«ki")
("title" "tytuŖ")
("to the left" "do lewej")
("to the right" "do prawej")
("today" "dzisiaj")
("tools" "narz¦dzia")
("top" "na pocz”tek")
("top border" "górna ramka")
("top level" "poziom górny")
("top margin" "górny margines")
("top padding" "górne wypeŖnienie")
("translate" "transliteracja")
("tree" "drzewo")
("tuple" "tuple")
("turkish" "turecki")
("tutorial" "podr¦cznik")
("type" "typ")
("type a latex command followed by" "wpisz komend¦ latex a nast¦pnie")
("type body" "wpisz zawarto±¢")
("type denominator" "wpisz mianownik")
("type numerator" "licznik typu")
("type script" "wpisz skrypt")
("typesetted boxes" "pudeŖka zecera")
("typewriter" "maszynowy")
("typewriter small caps" "maŖy maszynowy")
("typing a simple text" "pisanie prostego tekstu")
("typing simple texts" "pisanie prostych tekstów")
("ugaritic" "ugaritic")
("ukrainian" "ukrai«ski")
("underbrace" "klamra dolna")
("underline" "podkre±lenie")
("undo" "cofnij operacj¦")
("undo last changes" "wycofaj ostatni” zmian¦")
("up" "do góry")
("update" "aktualizuj")
("update from web" "update z web")
("update image links" "update linki obrazków")
("upper border" "górny brzeg")
("use TeXmacs" "u»yj TeXmacs'a")
("use a black color" "u»yj koloru czarnego")
("use a blue color" "u»yj koloru niebieskiego")
("use a bold font" "u»yj tŖustej czcionki")
("use a brown color" "u»yj koloru br”zowego")
("use a calligraphic font" "u»yj czcionki kaligraficznej")
("use a green color" "u»yj koloru zielonego")
("use a grey color" "u»yj koloru szarego")
("use a magenta color" "u»yj koloru fioletowego")
("use a orange color" "u»yj koloru pomara«czowego")
("use a pink color" "u»yj koloru ró»owego")
("use a red color" "u»yj koloru czerwonego")
("use a sans serif font" "u»yj czcionki sans serif")
("use a typewriter font" "u»yj czcionki maszynowej")
("use a white color" "u»yj koloru biaŖego")
("use a yellow color" "u»yj koloru »óŖtego")
("use blackboard bold font" "u»yj czcionek blackboard")
("use bold font series" "u»uj czcionek tŖustych")
("use calligraphical font" "u»yj czcionek kaligraficznych")
("use footnote font size" "u»yj czcionek rozmiaru przypisów")
("use fraktur font" "u»yj czcionek fraktury")
("use huge font size" "u»yj czcionek rozmiaru ogromnego")
("use italic font shape" "u»yj czcionek italic shape")
("use large font size" "u»yj czcionek rozmiaru du»ego")
("use left hand column as border" "u»yj lewej kolumny jako ramki")
("use medium font series" "u»yj czcionek medium")
("use normal font size" "u»yj czcionek rozmiaru normalnego")
("use package" "u»yj pakietu")
("use paragraph width" "u»yj szeroko±ci paragrafu")
("use really huge font size" "u»yj czcionek rozmiaru przeogromnego")
("use right font shape" "u»yj czcionek right shape")
("use right hand column as border" "u»yj prawej kolumny jako ramki")
("use roman font family" "u»yj czcionek rzymskich")
("use row above as border" "u»yj rz¦du powy»ej jako ramki")
("use row below as border" "u»yj rz¦du poni»ej jako ramki")
("use sans serif font family" "u»yj czcionek sans serif")
("use script font size" "u»yj czcionek script")
("use slanted font shape" "u»yj czcionek slanded shape")
("use small capitals" "u»yj czcionki small capitals")
("use small font size" "u»yj czcionek rozmiaru maŖego")
("use small-caps font shape" "u»yj czcionek small-caps shape")
("use the blackboard bold font" "u»yj cicionki blackboard")
("use the fraktur font" "u»yj czcionki fraktur")
("use tiny font font size" "u»yj czcionek male«kich")
("use typewriter font family" "u»yj czcionek maszynowych")
("use very large font size" "u»yj czcionek rozmiaru bardzo du»ego")
("user manual" "podr¦cznik u»ytkownika")
("user provided icons" "ikony u»ytkownika")
("users of Cyrillic languages" "u»ytkownicy Cyrlicy ")
("value" "warto±¢")
("variable" "zmienna")
("variant" "wariant")
("vector" "wektor")
("verbatim" "dosŖownie")
("verse" "werset")
("vertical" "pionowo")
("vertical after" "w pionie po")
("vertical before" "w pionie przed")
("vertical cell alignment" "wyrównanie pionowe komórki")
("vertical part" "pionowa cz¦±¢")
("vertical position" "poŖo»enie poziome")
("vertical space" "odst¦p pionowy")
("vertical table alignment" "wyrównanie pionowe tablicy")
("vertically align cell to the base" "wyrównaj pionowo komórk¦ do bazy")
("vertically center the cell" "wycentruj pionowo komórk¦")
("very large" "bardzo wielki")
("very small" "bardzo maŖy")
("vietnamese" "wietnamski")
("view" "widok")
("visible" "widoczny")
("warning" "ostrze»enie")
("welcome" "powitanie")
("welcome to GNU TeXmacs" "Witaj w GNU TeXmacs")
("what is new" "co nowego")
("when finished" "kiedy sko«czone")
("while" "dopóki")
("white" "biaŖy")
("wide accent" "szeroki akcent")
("wide bar" "szeroka kreska")
("width" "szeroko±¢")
("width is exactly the specified width" "szeroko±¢ jest dokŖadnie podana")
("width is maximum of specified width and box width" "szeroko±¢ jest maximum z podanej i szeroko±ci pudeŖka")
("width is minimum of specified width and box width" "szeroko±¢ jest minimum z podanej i szeroko±ci pudeŖka")
("width magnification" "zwi¦kszenie w poziomie")
("window" "okno")
("window height" "wysoko±¢ okna")
("window width" "szeroko±¢ okna")
("windows key" "klawisz okna")
("with" "z")
("write a name" "wpisz nazwisko")
("write bold mathematics" "pisz na tŖusto matematyk¦")
("write bold text" "pisz tekst na tŖusto")
("write italic text" "pisz tekst kursyw”")
("write sample text" "wpisz prosty tekst")
("write strong text" "wpisz tŖusty tekst")
("write typewriter text" "wpisz maszynowy tekst")
("write verbatim text" "wpisz vervatim tekst")
("writing data converters" "zapis konwerterów danych")
("writing your own style files" "zapis wŖasnych plików styli")
("yellow" "»óŖty")
("you can also obtain" "mo»na otrzyma¢ tak»e")
("your document is back in its original state" "dokument jest na nowo w stanie pierwotnym")
("your first interface" "twój pierwszy interface")
("your language" "twój j¦zyk")
