<TeXmacs|1.99.6>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package-dtd|a2-poster|1.0|poster-size|1.0>

    <\src-purpose>
      Style parameters for A2 posters.
    </src-purpose>

    <src-copyright|2018|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <assign|page-type|a2>

  <assign|magnification|1.6>

  \;

  <assign|page-odd|1.6cm>

  <assign|page-even|1.6cm>

  <assign|page-right|1.6cm>

  <assign|page-top|1.6cm>

  <assign|page-bot|1.6cm>
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>