("\"encryption\" features from the preference panel" "\"szyfrowanie\" funkcje z panelu preferencji")
("(Re)Build autocompletion index" "(Ponowny) budowanie indeksu autouzupeŖniania")
("a series" "seria")
("a.C.M. computing class" "a.C.M. klasa obliczeniowa")
("a.M.S. subject class" "klasa przedmiotów a.M.S.")
("abbreviated authors" "autorów skróconych")
("abreviated authors" "wycofanych autorów")
("accent above" "akcent powy»ej")
("accent below" "akcent poni»ej")
("accept during this pass" "akceptuj podczas tego przej±cia")
("acknowledgments" "podzi¦kowa«")
("activate hidden" "aktywuj ukryte")
("activate once" "aktywuj raz")
("activation" "aktywacja")
("active link types" "aktywnych typów linków")
("add" "dodaj")
("add abstract information" "dodaj streszczenie")
("add author information" "dodaj informacje o autorze")
("add branch after" "dodaj gaŖ”¹ po")
("add branch before" "dodaj gaŖ”¹ przed")
("add other package" "dodaj inny pakiet")
("add package" "dodaj pakiet")
("add style package" "dodaj pakiet stylów")
("add title information" "dodaj informacje o tytule")
("addition" "dodanie")
("adjust" "dostosuj")
("adjust limits" "dostosowanie limitów")
("advanced font customization" "zaawansowane dostosowywanie czcionek")
("affiliation" "afiliacja")
("align cell to the decimal comma" "wyrównaj komórk¦ do przecinka dziesi¦tnego")
("align cell to the decimal dot" "wyrównaj komórk¦ do kropki dziesi¦tnej")
("align table at axis" "wyrównaj tabel¦ na osi")
("alignment of balloon" "wyrównanie balonu")
("all cells" "wszystkie komórki")
("all data attached to this identity will be lost" "wszystkie dane zwi”zane z t” to»samo±ci” zostan” utracone")
("all saved passphrases will be lost forever" "wszystkie zapisane hasŖa zostan” utracone na zawsze")
("allow for macro definitions in preamble" "zezwól na definicje makr w preambule")
("allowed page height extension" "dozwolone rozszerzenie wysoko±ci strony")
("allowed page height reduction" "dozwolona redukcja wysoko±ci strony")
("allowed positions" "dozwolone pozycje")
("allowed positions of floating object" "dozwolone pozycje obiektu pŖywaj”cego")
("alpha transparency" "przezroczysto±¢ alfa")
("also on paper" "tak»e na papierze")
("alter" "alter")
("alternate" "alternatywny")
("alternate except here" "na przemian z wyj”tkiem tutaj")
("alternate from here on" "naprzemiennie st”d")
("alternate only here" "tylko tutaj alternatywnie")
("alternate until here" "na przemian do tutaj")
("alternative specification" "alternatywna specyfikacja")
("always" "zawsze")
("american" "ameryka«ski")
("amplified" "wzmocniony")
("and perform casual settings from the \"Encryption\" tab" "i wprowad¹ swobodne ustawienia z karty Szyfrowanie")
("angular" "k”towy")
("animate" "animacja")
("animate folding" "animowane skŖadanie")
("animate unfolding" "animacja rozwijania")
("animated" "animowane")
("animation" "animacji")
("animation toolbar" "pasek narz¦dzi animacji")
("annotate" "adnotacja")
("answer" "odpowied¹")
("answer field" "pole odpowiedzi")
("answer to question" "odpowied¹ na pytanie")
("answers only" "tylko odpowiedzi")
("any" "dowolne")
("appear" "pojawia si¦")
("apply macro" "zastosuj makro")
("apply macro once" "Zastosuj makro raz")
("approximate" "przybli»one")
("arc" "Ŗuk")
("arc cosine" "arc cosinus")
("arc sine" "Ŗuk sinusoidalny")
("arc tangent" "styczna Ŗukowa")
("arch series" "arch arch")
("are you sure you want to delete collected public keys" "czy na pewno chcesz usun”¢ zebrane klucze publiczne")
("are you sure you want to delete selected public keys" "czy na pewno chcesz usun”¢ wybrane klucze publiczne")
("are you sure you want to delete selected secret keys" "Czy na pewno chcesz usun”¢ wybrane tajne klucze")
("are you sure you want to destroy the wallet" "czy na pewno chcesz zniszczy¢ portfel")
("art frame" "ramka artystyczna")
("arxiv category" "kategoria arxiv")
("as visual grid" "jako siatka wizualna")
("aspect" "aspekt")
("attach master" "attach master")
("auto" "auto")
("auto-save file" "plik automatycznego zapisywania")
("automatic brackets" "wsporników automatycznych")
("automatic content generation" "automatyczne generowanie tre±ci")
("automatic program brackets" "automatyczne nawiasy programowe")
("automatically import bibliographies when opening files" "automatycznie importuj bibliografie podczas otwierania plików")
("automatically remember all passphrases in the wallet" "automatycznie zapami¦tuje wszystkie hasŖa w portfelu")
("automatically save" "automatycznie zapisz")
("autosave" "autozapis")
("axis" "o±")
("b series" "seria b")
("back" "z powrotem")
("background evaluations" "ocen w tle")
("backtrace errors" "bŖ¦dów ±ledzenia")
("base" "baza")
("baseline" "poziom podstawowy")
("beamer" "beamer")
("beamer formats" "formaty rzutników")
("beamer theme" "motyw beamer")
("bench" "Ŗawa")
("bend bottom" "zagnij do doŖu")
("bend corner" "zagi¦cie rogu")
("bend diagonal" "zgi¦cie po przek”tnej")
("bend in" "zagi¦cie")
("bend out" "wygnij")
("bezier" "bezier")
("bibTeX command" "polecenie bibTeX")
("bidirectional" "dwukierunkowy")
("big environment box" "du»e okno ±rodowiska")
("big focus" "du»y nacisk")
("binary operator" "operator binarny")
("bitmap resolution (dpi)" "rozdzielczo±¢ bitmapy (dpi)")
("black floral I" "czarny kwiatowy I")
("black floral II" "czarny kwiatowy II")
("blackboard embold" "tablica pogrubiona")
("blank column" "pusta kolumna")
("blank row" "pusty wiersz")
("block" "blok")
("block content" "tre±¢ bloku")
("block of code" "blok kodu")
("blur" "rozmycie")
("both versions" "obie wersje")
("bottom baseline" "dolna linia bazowa")
("bottom cell border" "dolna ramka komórki")
("bottom cell padding" "dolne wypeŖnienie komórki")
("bottom table border" "dolna kraw¦d¹ tabeli")
("bottom table padding" "wy±cióŖka dolnego stoŖu")
("bottom tools" "dolne narz¦dzia")
("box" "pudeŖko")
("browse back" "przegl”daj wstecz")
("browse forward" "przegl”daj do przodu")
("browse modules documentation" "przegl”daj dokumentacj¦ moduŖów")
("buffer management" "zarz”dzanie buforami")
("buffer must be on disk" "bufor musi by¢ na dysku")
("buffer must have a name" "bufor musi mie¢ nazw¦")
("build buffer" "bufor budowania")
("build buffer in" "wbudowany bufor")
("build directory" "katalog budowania")
("build directory in" "katalog budowania w")
("build link pages" "budowanie stron linków")
("build-all" "build-all")
("bump" "guz")
("busy" "zaj¦ty")
("cJK" "cJK")
("cJK spacing" "odst¦pów cJK")
("calculus" "rachunek ró»niczkowy")
("cancelled" "anulowane")
("cannot download directory to file" "Nie mo»na pobra¢ katalogu do pliku")
("cannot rename across different servers" "Nie mo»na zmieni¢ nazwy na ró»nych serwerach")
("cannot upload directory to file" "Nie mo»na przesŖa¢ katalogu do pliku")
("cartesian" "kartezja«ski")
("carved wood" "rze¹bione drewno")
("case-insensitive search" "wyszukiwanie bez rozró»niania wielko±ci liter")
("categories" "kategorii")
("category" "kategoria")
("cell properties" "wŖa±ciwo±ci komórki")
("cells" "komórki")
("change default unit" "zmie« jednostk¦ domy±ln”")
("change passphrase" "zmie« hasŖo")
("change step-size" "zmie« rozmiar kroku")
("change tags" "zmie« tagi")
("change the TeXmacs preferences" "zmie« preferencje TeXmacs")
("change the border of the table" "zmie« granic¦ tabeli")
("change the style of mathematical formulas" "zmie« styl formuŖ matematycznych")
("character contraction" "skurcz znaków")
("character encoding" "kodowanie znaków")
("character expansion" "rozwini¦cie postaci")
("check for updates" "sprawd¹ dost¦pno±¢ aktualizacji")
("checkable field" "pole do sprawdzenia")
("cipher algorithm for passphrase encryption" "algorytm szyfrowania dla szyfrowania hasŖa")
("circle" "kóŖko")
("classification" "klasyfikacja")
("clean slate" "czyste konto")
("clear all fields" "wyczy±¢ wszystkie pola")
("clear local information" "wyczy±¢ informacje lokalne")
("clear menu" "jasne menu")
("clear undo history" "wyczy±¢ histori¦ cofania")
("click Ok button twice to discard this warning" "Kliknij przycisk OK dwa razy, aby odrzuci¢ to ostrze»enie")
("clip" "klip")
("clipboard image format" "format obrazu schowka")
("close animation tool" "zamknij narz¦dzie do animacji")
("close document" "zamknij dokument")
("close program" "zamknij program")
("close replace tool" "zamknij narz¦dzie wymiany")
("close search tool" "zamknij narz¦dzie wyszukiwania")
("close spell tool" "zamknij narz¦dzie pisowni")
("close translations to rebuild" "zamknij tŖumaczenia, aby odbudowa¢")
("closed bezier" "zamkni¦ty bezier")
("closed curve" "krzywa zamkni¦ta")
("closed smooth" "zamkni¦ty gŖadki")
("closed spline" "zamkni¦ty splajn")
("closing style" "styl zamykania")
("cluster by affiliation" "klaster wedŖug przynale»no±ci")
("collect garbage" "zbieranie ±mieci")
("collected keys" "zebranych kluczy")
("color of the axes" "kolor osi")
("color of the subunits" "kolor podjednostek")
("color of the units" "kolor jednostek")
("colors" "kolory")
("column to the left" "kolumna po lewej")
("column to the right" "kolumna po prawej")
("columns" "kolumn")
("column separation" "separacja kolumn")
("commit file" "plik zatwierdzenia")
("common" "wspólne")
("common formats" "popularnych formatów")
("commutative diagram" "schemat zast¦pczy")
("compactification" "kompaktowanie")
("compactify" "compactify")
("complete bibliographic reference" "peŖne odniesienie bibliograficzne")
("complex actions" "zŖo»onych dziaŖa«")
("compose" "komponuj")
("compound" "zwi”zek")
("compress" "kompres")
("compress into toolbar" "kompresuj w pasek narz¦dzi")
("compressed" "skompresowany")
("conceal" "ukry¢")
("configure look and feel" "konfiguracja wygl”du")
("confirm database entry" "Potwierd¹ wpis w bazie danych")
("confirm entry" "potwierd¹ wpis")
("confirm selected database entries" "Potwierd¹ wybrane wpisy bazy danych")
("confirm selected entries" "Potwierd¹ wybrane wpisy")
("conservative conversion options" "konserwatywne opcje konwersji")
("consoles" "konsol")
("constellation" "konstelacja")
("contact" "kontakt")
("context aids" "pomoce kontekstowe")
("contextual hints" "wskazówki kontekstowe")
("continue" "kontynuuj")
("continued fraction" "ci”g dalszy uŖamek")
("contour" "kontur")
("contract logarithms" "logarytmy umowne")
("contribute" "przyczynia si¦")
("control flow" "przepŖyw kontrolny")
("control the evaluation of expressions" "kontroluj ocen¦ wyra»e«")
("convert" "konwersja")
("converters" "konwertery")
("convertible" "cabrio")
("copyright" "prawa autorskie")
("cork charset with TeX catcode definition in preamble" "zestaw korka z definicj” kodu kat TeX w preambule")
("correct" "poprawne")
("correct all" "popraw wszystko")
("correct formula" "poprawna formuŖa")
("correct manually" "popraw r¦cznie")
("correct mathematical formulas" "poprawnych wzorów matematycznych")
("correction" "korekta")
("cosine" "cosinus")
("count characters" "policz znaki")
("count lines" "liczba linii")
("count words" "policz sŖowa")
("create a new document" "utwórz nowy dokument")
("create link" "Utwórz link")
("create preamble" "utwórz preambuŖ¦")
("create remote directory" "Utwórz katalog zdalny")
("create remote file" "utwórz plik zdalny")
("create subprogram" "utwórz podprogram")
("create subsession" "Utwórz podsesj¦")
("create table macro" "Utwórz makro tabeli")
("create web site" "utwórz stron¦ internetow”")
("creating new account" "tworzenie nowego konta")
("creating technical pictures" "tworzenie zdj¦¢ technicznych")
("crop" "upraw")
("crop marks" "znaków upraw")
("cross" "krzy»")
("crossed boxes" "skrzy»owanych pól")
("crossed circles" "skrzy»owanych kóŖ")
("current user version" "aktualna wersja u»ytkownika")
("current version" "aktualna wersja")
("cursor" "kursor")
("curve" "krzywa")
("curve intersections" "skrzy»owania krzywych")
("curve points" "punktów krzywej")
("customizations" "dostosowa«")
("customizing and extending the user interface" "Dostosowywanie i rozszerzanie interfejsu u»ytkownika")
("data" "danych")
("database entry" "wpis do bazy danych")
("database tool" "narz¦dzie bazy danych")
("database toolbar" "pasek narz¦dzi bazy danych")
("deactivate once" "dezaktywuj raz")
("dead" "martwych")
("debug" "debugowanie")
("debugging console" "konsola debugowania")
("debugging tool" "narz¦dzie do debugowania")
("decimal comma" "przecinek dziesi¦tny")
("decimal dot" "kropka dziesi¦tna")
("decomposed" "rozŖo»ony")
("decorated" "zdobione")
("decorated wood" "drewno zdobione")
("decrease size" "zmniejsz rozmiar")
("decrypt" "odszyfrowa¢")
("default size" "domy±lny rozmiar")
("degrade" "degradacja")
("degraded" "zdegradowanych")
("delete documentation cache" "Usu« pami¦¢ podr¦czn” dokumentacji")
("delete entries" "usu« wpisy")
("delete link" "usu« link")
("deleted" "usuni¦to")
("describe" "opisz")
("describe tag" "opisz tag")
("destroy" "zniszczy¢")
("detach master" "OdŖ”cz master")
("detailed" "szczegóŖowych")
("detailed menus" "szczegóŖowych menu")
("details in menus" "szczegóŖów w menu")
("determine margins from text width" "okre±l marginesy na podstawie szeroko±ci tekstu")
("developer" "programista")
("developer tool" "narz¦dzie programistyczne")
("device" "urz”dzenie")
("diamond" "diament")
("differentiate" "ró»nicowanie")
("dilate" "rozszerzy¢")
("direction of progression" "kierunek post¦pu")
("direction of translation" "kierunek tŖumaczenia")
("disable" "wyŖ”cz")
("disable coloring on paper" "wyŖ”cz kolorowanie na papierze")
("disable encryption" "wyŖ”cz szyfrowanie")
("disappear" "znikaj”")
("disk" "dysk")
("display style" "styl wy±wietlania")
("displayed formula" "wy±wietlana formuŖa")
("dissociate joined cells" "odŖ”czy¢ poŖ”czone komórki")
("distort" "znieksztaŖca")
("distorted" "znieksztaŖcony")
("division" "dziaŖ")
("document font selector" "Wybór czcionki dokumentu")
("document language" "j¦zyk dokumentu")
("document page format" "format strony dokumentu")
("document paragraph format" "format akapitu dokumentu")
("document updates run" "Uruchomiono aktualizacje dokumentów")
("download" "pobieranie")
("downwards" "w dóŖ")
("dragging" "przeci”ganie")
("draw image" "narysuj obraz")
("draw over" "remis")
("draw over selection" "losowanie nad wyborem")
("drop" "drop")
("due to" "z powodu")
("dynamic" "dynamiczny")
("eRROR" "eRROR")
("edit animation" "edycja animacji")
("edit groups of objects" "edytuj grupy obiektów")
("edit macro" "edytuj makro")
("edit macros" "edytuj makra")
("edit preamble" "Edytuj preambuŖ¦")
("edit source" "edytuj kod ¹ródŖowy")
("edit source tree" "edytuj drzewo ¹ródŖowe")
("edit style" "styl edycji")
("edit translations file" "edytuj plik tŖumacze«")
("education" "edukacja")
("effect pen" "dŖugopis efektowy")
("eigenvalues" "warto±ci wŖasne")
("eighth" "ósmy")
("embold" "pogrubienie")
("emboss" "pŖaskorze¹ba")
("enable page breaking" "wŖ”cz podziaŖ strony")
("encoding" "kodowanie")
("encrypt" "szyfruj")
("encryption" "szyfrowanie")
("encryption facilities are not currently available" "funkcje szyfrowania nie s” obecnie dost¦pne")
("encryption facilities have not been enabled for TeXmacs" "szyfrowanie nie zostaŖo wŖ”czone dla TeXmacs")
("enforce brackets to match" "egzekwuj nawiasy, aby dopasowa¢")
("engrave" "wygrawerowa¢")
("enter data" "wprowad¹ dane")
("enter graphics" "wprowad¹ grafik¦")
("enter graphics mode" "wejd¹ w tryb graficzny")
("enter new passphrase for encryption" "wprowad¹ nowe hasŖo do szyfrowania")
("enter passphrase for decryption" "wprowad¹ hasŖo do deszyfrowania")
("enter passphrase for identity" "wprowad¹ hasŖo dla to»samo±ci")
("enter title information" "wprowad¹ informacje o tytule")
("entire table" "caŖy stóŖ")
("entry up to date in database" "wpis do bazy danych")
("enunciation" "o±wiadczenie")
("environment variable" "zmienna ±rodowiskowa")
("environments" "±rodowisk")
("erode" "erodowa¢")
("error messages" "komunikatów o bŖ¦dach")
("error output" "wyj±cie bŖ¦du")
("error status report" "raport o bŖ¦dzie")
("error: bracket does not match" "bŖ”d: brak pasuj”cego nawiasu")
("error: cyclic or missing chunks detected" "BŖ”d: wykryto cykliczne lub brakuj”ce porcje")
("error: file not found" "bŖ”d: nie znaleziono pliku")
("error: ghostview does not seem to be installed on your system" "bŖ”d: duch nie wydaje si¦ by¢ zainstalowany w twoim systemie")
("error: one of the alternatives should be filled out" "bŖ”d: nale»y wypeŖni¢ jedn” z alternatyw")
("error: only one alternatives should be filled out" "bŖ”d: nale»y wypeŖni¢ tylko jedn” alternatyw¦")
("error: should fill out name for referencing" "bŖ”d: nale»y wpisa¢ nazw¦ odniesienia")
("error: should fill out required field" "bŖ”d: nale»y wypeŖni¢ wymagane pole")
("evaluable field" "pole podlegaj”ce ocenie")
("evaluate above" "oce« powy»ej")
("evaluate all" "oce« wszystko")
("evaluate below" "oce« poni»ej")
("evaluate fields" "oce« pola")
("evaluate fields in order" "oceniaj pola w kolejno±ci")
("evaluate script" "oce« skrypt")
("evaluation" "ocena")
("evaluation switch" "przeŖ”cznik oceny")
("evaluation tag" "tag oceny")
("even page" "parzysta strona")
("even page left margin" "parzysty lewy margines")
("even page shift" "parzyste przesuni¦cie strony")
("even pages" "parzystych stron")
("events" "wydarze«")
("exact" "dokŖadne")
("execution of scripts" "wykonywanie skryptów")
("exit graphics" "grafika wyj±cia")
("exit graphics mode" "wyjd¹ z trybu graficznego")
("exit left" "wyj±cie z lewej")
("exit right" "wyj±cie z prawej")
("exit tag on the left" "tag wyj±cia po lewej stronie")
("exit tag on the right" "tag wyj±cia po prawej stronie")
("expand TeXmacs macros with no LaTeX equivalents" "rozwi« makra TeXmacs bez odpowiedników LaTeX")
("expand beamer slides" "rozwi« slajdy rzutnika")
("expand inclusions" "rozwi« inkluzje")
("expand logarithms" "rozwi« logarytmy")
("expand trigonometric functions" "rozwi« funkcje trygonometryczne")
("expand unrecognized macros" "rozwi« nierozpoznane makra")
("expand user-defined macros" "rozwi« makra zdefiniowane przez u»ytkownika")
("expanded" "rozwini¦ty")
("experimental features (to be used with care)" "funkcje eksperymentalne (do ostro»nego u»ycia)")
("explain" "wyja±ni¢")
("explanatory item" "obja±nienie")
("explicit keystroke" "wyra¹ne naci±ni¦cie klawisza")
("explicit margins" "wyra¹nych marginesów")
("exponential" "wykŖadniczy")
("export bibliographies as links" "eksportuj bibliografie jako linki")
("export bibliography" "bibliografia eksportowa")
("export entries in buffer" "wpisy eksportu w buforze")
("export file" "plik eksportu")
("export formulas as images" "Eksportuj formuŖy jako obrazy")
("export mathematical formulas as MathML" "eksportuj formuŖy matematyczne jako MathML")
("export mathematical formulas as images" "eksportuj wzory matematyczne jako obrazy")
("export selected entries" "eksportuj wybrane wpisy")
("export selection" "wybór eksportu")
("export selection as image" "Eksportuj zaznaczenie jako obraz")
("export selections as" "wybór eksportu jako")
("export sessions" "sesji eksportowych")
("exported bibliographic entries" "wyeksportowane pozycje bibliograficzne")
("exported bibliographic references" "wyeksportowane odniesienia bibliograficzne")
("extend" "przedŖu»y¢")
("extended" "rozszerzony")
("extensible left arrow" "rozszerzalna strzaŖka w lewo")
("extensible right arrow" "rozszerzalna strzaŖka w prawo")
("extern" "zewn¦trzny")
("external" "zewn¦trzny")
("extra branch" "dodatkowy oddziaŖ")
("extra interline space" "dodatkowa przestrze« mi¦dzy wierszami")
("extra name" "dodatkowa nazwa")
("extract" "ekstrakt")
("extract style file" "wyodr¦bnij plik stylu")
("extract style package" "ekstrakt z pakietu stylów")
("factor" "wspóŖczynnik")
("fade" "zanikanie")
("fade in" "zanikanie")
("fade out" "zanikanie")
("fast" "szybko")
("fast decrease" "szybki spadek")
("fast environments" "szybkich ±rodowisk")
("fast increase" "szybki wzrost")
("field reference" "odniesienie do pola")
("fifth" "pi”ty")
("file saved" "plik zapisany")
("fill color" "kolor wypeŖnienia")
("fill out" "wypeŖnij")
("filter" "filtr")
("find file" "znajd¹ plik")
("finished collecting symbols documentation" "zako«czono gromadzenie dokumentacji symboli")
("first" "pierwszy")
("first chunk" "pierwsza porcja")
("first difference" "pierwsza ró»nica")
("first error" "pierwszy bŖ”d")
("first field" "pierwsze pole")
("first occurrence" "pierwsze wyst”pienie")
("first similar" "pierwszy podobny")
("fit to screen" "dopasuj do ekranu")
("fit to screen width" "pasuje do szeroko±ci ekranu")
("five columns" "pi¦¢ kolumn")
("fixed" "naprawiono")
("flag is off" "Flaga jest wyŖ”czona")
("flag is on" "Flaga jest wŖ”czona")
("flatten" "spŖaszczy¢")
("floating algorithm" "algorytm pŖywaj”cy")
("floating phantom" "pŖywaj”cy fantom")
("focus" "focus")
("focus dependent icons" "ikon zale»nych od ostro±ci")
("fold all" "fold all")
("fold all fields" "zŖó» wszystkie pola")
("fold back" "zŖó»")
("fold input field" "zŖó» pole wprowadzania")
("follow external links" "pod”»aj za linkami zewn¦trznymi")
("follow inverse links" "±led¹ odwrotne linki")
("font effects" "efektów czcionek")
("font selector" "selektor czcionek")
("for each" "na ka»dy")
("force reloading of translations" "wymuszenie przeŖadowania tŖumacze«")
("formatted and structured output" "sformatowane i uporz”dkowane dane wyj±ciowe")
("formatting" "formatowanie")
("forward" "do przodu")
("four columns" "cztery kolumny")
("four dots" "cztery kropki")
("fourth" "czwarty")
("fraktur" "fraktur")
("framed" "w ramce")
("from" "od")
("from center" "od centrum")
("front matter" "przód")
("full" "peŖny")
("full author list" "peŖna lista autorów")
("full screen mode" "tryb peŖnoekranowy")
("functional" "funkcjonalne")
("gap" "przerwa")
("garbage collection" "wywóz ±mieci")
("gaussian" "gaussian")
("gcd" "gcd")
("general" "ogólne")
("general note" "uwaga ogólna")
("generated LaTeX document contains no errors" "wygenerowany dokument LaTeX nie zawiera bŖ¦dów")
("generated field" "wygenerowane pole")
("geometry" "geometria")
("get arity" "get arity")
("get label" "pobierz etykiet¦")
("get list with remote versions" "pobierz list¦ ze zdalnymi wersjami")
("glyphs" "glifów")
("gnaw" "gry¹¢")
("gnawed" "pogryziony")
("gnuPG command" "polecenie gnuPG")
("gnuPG error: buffer encryption failed" "BŖ”d gnuPG: bŖ”d szyfrowania bufora")
("gnuPG error: cannot find suitable secret key to decrypt" "BŖ”d gnuPG: nie mo»na znale¹¢ odpowiedniego tajnego klucza do odszyfrowania")
("gnuPG requires name and email to have at least 5 characters" "gnuPG wymaga, aby imi¦ i adres e-mail zawieraŖy co najmniej 5 znaków")
("go to anchor" "przejd¹ do kotwicy")
("go to anchor or float" "przejd¹ do zakotwiczenia lub pŖywaka")
("go to anchor or footnote" "przejd¹ do zakotwiczenia lub przypisu")
("go to first similar tag" "Id¹ do pierwszego podobnego tagu")
("go to float" "go float")
("go to footnote" "przejd¹ do przypisu")
("go to last similar tag" "Id¹ do ostatniego podobnego tagu")
("go to next similar tag" "przejd¹ do nast¦pnego podobnego tagu")
("go to previous similar tag" "przejd¹ do poprzedniego podobnego tagu")
("go to section" "przejd¹ do sekcji")
("grain" "ziarno")
("granite" "granit")
("graphical effects" "efektów graficznych")
("graphical interface font scale" "skala czcionek interfejsu graficznego")
("graphics" "grafiki")
("graphics geometry" "geometria grafiki")
("graphics grids" "siatek graficznych")
("greyed" "szary")
("grid" "kratka")
("grid curves" "krzywe siatki")
("grid points" "punktów siatki")
("grid-curve intersections" "Przeci¦cia krzywej siatki")
("group of objects" "grupa obiektów")
("group/ungroup" "grupa / rozgrupowanie")
("grouped" "zgrupowane")
("guarantee transparent source tracking" "gwarantuje przejrzyste ±ledzenie ¹ródŖa")
("half wide" "póŖ szeroko±ci")
("hand drawn" "wyci”gn”¢ r¦k¦")
("headers" "nagŖówków")
("hidden" "ukryty")
("history" "historia")
("homepage" "strona gŖówna")
("homoglyph substitutions" "substytucje homoglifów")
("horizontal alignment" "wyrównanie w poziomie")
("horizontal collapse distance" "odlegŖo±¢ zawini¦cia w poziomie")
("horizontal margins" "marginesy poziome")
("hybrid command" "polecenie hybrydowe")
("hyphenate as" "dzielenie jako")
("icon" "ikona")
("if hyphenated" "je±li dzielony")
("ignore" "ignoruj")
("impact" "wpŖyw")
("import bibliography" "import bibliografii")
("import database entry" "import pozycji bazy danych")
("import entries in buffer" "importuj wpisy do bufora")
("import entry" "pozycja importowa")
("import file" "plik importu")
("import selected database entries" "importuj wybrane wpisy bazy danych")
("import selected entries" "importuj wybrane wpisy")
("import selections as" "importuj wybrane jako")
("import sessions" "sesje importowania")
("import sophisticated objects as pictures" "importuj wyrafinowane obiekty jako obrazy")
("imported bibliographic entries" "zaimportowane wpisy bibliograficzne")
("in popup windows" "w wyskakuj”cych oknach")
("inanimated" "inanimated")
("inch" "cali")
("incomplete entries found to be filled out" "Znaleziono niekompletne wpisy")
("increase size" "zwi¦ksz rozmiar")
("indent paragraphs" "akapity tiret")
("indentation" "wci¦cie")
("indication" "wskazanie")
("informative flags" "flagi informacyjne")
("initialize" "inicjowanie")
("ink here" "tu atrament")
("ink in" "ink in")
("ink out" "brak atramentu")
("inline" "w linii")
("inline arguments" "argumentów wbudowanych")
("inline code" "kod wewn¦trzny")
("inline content" "tre±¢ wbudowana")
("inline formula" "wzór wbudowany")
("inner bottom" "dno wewn¦trzne")
("inner left" "wewn¦trzna lewa")
("inner right" "wewn¦trzna prawa")
("inner top" "wewn¦trzna góra")
("input command" "polecenie wprowadzania")
("input field" "pole wprowadzania")
("input options" "opcji wprowadzania")
("insert a computer program" "wstaw program komputerowy")
("insert a condition" "wstaw warunek")
("insert a control flow instruction" "wstaw instrukcj¦ sterowania przepŖywem")
("insert a gap" "wstaw przerw¦")
("insert a list" "wstaw list¦")
("insert a multiple choice" "wstaw wielokrotny wybór")
("insert a negation" "wstaw negacj¦")
("insert a new entry" "wstaw nowy wpis")
("insert a note or a floating object" "wstaw notatk¦ lub obiekt pŖywaj”cy")
("insert a numerical operation" "wstaw operacj¦ numeryczn”")
("insert a prominent piece of text" "wstaw widoczny fragment tekstu")
("insert a question" "wstaw pytanie")
("insert a root" "wstaw root")
("insert a script" "wstaw skrypt")
("insert a section block" "wstaw blok sekcji")
("insert a textual operation" "wstaw operacj¦ tekstow”")
("insert a textual operator" "wstaw operator tekstowy")
("insert above" "wstawi¢ powy»ej")
("insert abstract" "wstaw streszczenie")
("insert an answer" "wstaw odpowied¹")
("insert an enunciation" "wstaw zdanie")
("insert an operation on tuples" "wstaw operacj¦ na krotkach")
("insert annotation" "wstaw adnotacj¦")
("insert author" "wstaw autora")
("insert below" "wstaw poni»ej")
("insert copyright and license information" "wstaw informacje o prawach autorskich i licencji")
("insert explanatory item" "wstawi¢ wyja±nienie")
("insert field above" "wstaw pole powy»ej")
("insert field below" "wstaw pole poni»ej")
("insert fields" "wstaw pola")
("insert input field above" "wstaw pole wprowadzania powy»ej")
("insert input field below" "wstaw pole wprowadzania poni»ej")
("insert large delimiters" "wstaw du»e separatory")
("insert last name" "wstaw nazwisko")
("insert left" "wstaw lewy")
("insert macro" "wstaw makro")
("insert missing invisible operators" "wstaw brakuj”ce niewidoczne operatory")
("insert more names" "wstaw wi¦cej nazw")
("insert particle" "wstaw cz”stk¦")
("insert plain text" "wstaw zwykŖy tekst")
("insert right" "wstaw z prawej")
("insert similar above" "wstaw podobnie jak powy»ej")
("insert similar below" "wstaw podobne poni»ej")
("insert similar block above" "wstaw podobny blok powy»ej")
("insert similar block below" "wstaw podobny blok poni»ej")
("insert subtable" "wstaw podtabuŖ¦")
("insert symbol documentation" "wstaw dokumentacj¦ symboli")
("insert template" "wstaw szablon")
("insert text field above" "wstaw pole tekstowe powy»ej")
("insert text field below" "wstaw pole tekstowe poni»ej")
("insert title" "wstaw tytuŖ")
("insert title after name" "wstaw tytuŖ po nazwie")
("insert user interface related markup" "wstaw znaczniki zwi”zane z interfejsem u»ytkownika")
("insert value" "wstaw warto±¢")
("inserting control points" "wstawianie punktów kontrolnych")
("integrate" "zintegruj")
("interactive command" "polecenie interaktywne")
("interactive questions" "interaktywnych pyta«")
("intercharacter compression" "kompresja mi¦dzy znakami")
("intercharacter stretching" "rozci”ganie mi¦dzy znakami")
("interrupted" "przerwane")
("invalid multi-paragraph selection" "nieprawidŖowy wybór wielu akapitów")
("invalid renaming" "nieprawidŖowa zmiana nazwy")
("invert" "invert")
("inverted breve" "odwrócony breve")
("invisible ending" "niewidoczne zako«czenie")
("invisible newline" "niewidzialna nowa linia")
("invisible opening" "niewidoczne otwarcie")
("join selected cells" "doŖ”cz wybrane komórki")
("jump in" "wskoczy¢")
("junior" "junior")
("keep evaluated expressions" "zachowaj ocenione wyra»enia")
("keep local" "zachowaj lokalny")
("keep remote" "zachowaj zdalne")
("keep track of source code" "±led¹ kod ¹ródŖowy")
("keep unfolded" "zachowaj rozkŖad")
("keyboard configuration" "konfiguracja klawiatury")
("laptop presentations" "prezentacje na laptopie")
("large cells" "du»e komórki")
("large displayed" "du»y wy±wietlany")
("large displayed fraction" "du»a wy±wietlana frakcja")
("large tables" "du»e stoŖy")
("last" "ostatni")
("last difference" "ostatnia ró»nica")
("last error" "ostatni bŖ”d")
("last field" "ostatnie pole")
("last name" "nazwisko")
("last occurrence" "ostatnie wyst”pienie")
("last similar" "ostatni podobny")
("lcm" "lcm")
("left axis" "lewa o±")
("left baseline" "lewa linia bazowa")
("left bottom" "lewy dolny")
("left cell border" "lewa ramka komórki")
("left cell padding" "dopeŖnienie lewej komórki")
("left center" "lewy ±rodkowy")
("left click: add point; Right click: undo" "lewy przycisk myszy: dodaj punkt; prawy przycisk myszy: cofnij")
("left click: finish; Right click: undo" "lewy przycisk myszy: zako«czenie; prawy przycisk myszy: cofnij")
("left click: new object" "lewy przycisk myszy: nowy obiekt")
("left click: operate" "lewy przycisk myszy: operacja")
("left down" "w lewo")
("left on even pages" "pozostawiono na stronach parzystych")
("left table border" "lewa ramka tabeli")
("left table padding" "lewa wy±cióŖka stoŖu")
("left top" "lewy górny")
("left up" "w lewo")
("left-right arrow" "strzaŖka w lewo-prawo")
("leftwards" "lewostronny")
("let the environment float" "Niech ±rodowisko si¦ unosi")
("line breaking" "Ŗamanie linii")
("line wrapping" "zawijanie linii")
("linear 2D" "liniowy 2D")
("linear algebra" "algebra liniowa")
("lines around" "linii wokóŖ")
("link image and copies as" "link do obrazu i kopie jako")
("link image as" "link image as")
("link mode" "tryb linków")
("link to URL" "link do URL")
("linking tool" "narz¦dzie do Ŗ”czenia")
("live" "na »ywo")
("live input-output" "wej±cie-wyj±cie na »ywo")
("load help file" "ZaŖaduj plik pomocy")
("load remote file" "Ŗaduj plik zdalny")
("loading" "Ŗadowanie")
("local entries" "wpisy lokalne")
("loci" "loci")
("locus" "locus")
("locus rendering" "renderowanie locus")
("logarithm" "logarytm")
("logarithmic" "logarytmiczny")
("logarithmic base" "podstawa logarytmiczna")
("logarithms" "logarytmy")
("logging in" "logowanie")
("logical and" "logiczne i")
("logical implication" "logiczna implikacja")
("logical not" "logiczne nie")
("logical or" "logiczne lub")
("login" "login")
("logout" "wylogowanie")
("long macro" "dŖugie makro")
("long text" "dŖugi tekst")
("look for more fonts" "szukaj wi¦cej czcionek")
("loops" "p¦tle")
("macro argument" "argument makr")
("macro definition" "definicja makr")
("macro name" "nazwa makra")
("macros" "makr")
("magnify horizontally" "powi¦ksz w poziomie")
("magnify vertically" "powi¦ksz w pionie")
("main presentation style" "gŖówny styl prezentacji")
("make a letter environment" "±rodowisko listowe")
("make a multi-slide presentation" "wykonaj prezentacj¦ z wieloma slajdami")
("make floating" "Make Floating")
("make link" "Utwórz link")
("make non floating" "make un floating")
("manila paper" "papier manila")
("map arguments" "argumentów mapy")
("marginal note" "nota marginalna")
("margins from width" "marginesów od szeroko±ci")
("margins on paper" "marginesów na papierze")
("margins on screen" "marginesów na ekranie")
("marked" "oznaczone")
("material" "materiaŖ")
("mathematical and customized input" "dane matematyczne i niestandardowe")
("mathematical font" "czcionka matematyczna")
("mathematical input" "dane matematyczne")
("mathematical output" "wyj±cie matematyczne")
("matrices" "matryc")
("maximal" "maksymalna")
("maximal cell height" "maksymalna wysoko±¢ komórki")
("maximal clustering" "maksymalne grupowanie")
("maximal table height" "maksymalna wysoko±¢ stoŖu")
("maximal table width" "maksymalna szeroko±¢ stoŖu")
("maximum" "maksimum")
("meander" "meander")
("memory" "pami¦¢")
("memory usage" "zu»ycie pami¦ci")
("menu" "menu")
("merge lines into paragraphs unless separated by blank lines" "scal linie w akapity, chyba »e zostan” rozdzielone pustymi liniami")
("messages" "wiadomo±ci")
("meta data" "metadane")
("metadata" "metadane")
("metal" "metal")
("middle baseline" "±rodkowa linia bazowa")
("minimal" "minimalny")
("minimal cell height" "minimalna wysoko±¢ komórki")
("minimal cell width" "minimalna szeroko±¢ komórki")
("minimal line separation" "minimalna separacja linii")
("minimal table height" "minimalna wysoko±¢ stoŖu")
("minimal table width" "minimalna szeroko±¢ stoŖu")
("minimum" "minimum")
("mirror" "mirror")
("miscellanous" "ró»ne")
("mode dependent icons" "ikony zale»ne od trybu")
("modify remote live document" "zmodyfikuj zdalny dokument na »ywo")
("module" "moduŖ")
("monospaced" "monospaced")
("more information about GNU TeXmacs can be found in the Help" "wi¦cej informacji o GNU TeXmacs mo»na znale¹¢ w Pomocy")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "")
("more information about GNU TeXmacs can be found in the Help-<less>gtr<gtr>About menu" "wi¦cej informacji o GNU TeXmacs mo»na znale¹¢ w menu Pomoc-<gtr>Informacje")
("motion" "ruch")
("mouse over object" "kursor myszy nad obiektem")
("move" "ruch")
("move objects" "przenie± obiekty")
("move over object on which to operate" "ruch nad obiektem, na którym ma dziaŖa¢")
("multiline" "multiline")
("multiline input" "wej±cie wielowierszowe")
("multiple choice" "wielokrotnego wyboru")
("multiple root" "wielokrotny root")
("multiplication" "mno»enie")
("mutator tags" "tagów mutatora")
("navigation options" "opcji nawigacji")
("never" "nigdy")
("new account" "nowe konto")
("new bibliography dialogue" "nowy dialog bibliograficzny")
("new document" "nowy dokument")
("new double page" "nowa podwójna strona")
("new double page before" "nowa podwójna strona przed")
("new entry" "nowy wpis")
("new identity" "nowa to»samo±¢")
("new locus" "nowe miejsce")
("new macro" "nowe makro")
("new passphrase" "nowe hasŖo")
("new remote directory" "nowy katalog zdalny")
("new remote file" "nowy plik zdalny")
("new style fonts" "czcionek w nowym stylu")
("new style page breaking" "Ŗamanie stron w nowym stylu")
("new version" "nowa wersja")
("new window" "nowe okno")
("newer version" "nowsza wersja")
("next" "nast¦pny")
("next chunk" "nast¦pny fragment")
("next difference" "nast¦pna ró»nica")
("next error" "nast¦pny bŖ”d")
("next field" "nast¦pne pole")
("next occurrence" "nast¦pne wyst”pienie")
("next screen" "nast¦pny ekran")
("next similar" "nast¦pny podobny")
("no clustering" "bez grupowania")
("no completions" "brak uzupeŖnie«")
("no errors have been corrected" "nie naprawiono »adnych bŖ¦dów")
("no grid" "brak siatki")
("no new public key in document" "brak nowego klucza publicznego w dokumencie")
("no page break" "brak podziaŖu strony")
("no page numbers" "brak numerów stron")
("no parent" "bez rodzica")
("no selection" "brak wyboru")
("no spelling errors" "bez bŖ¦dów pisowni")
("normal loci" "normalne loci")
("not allowed to remove home directory" "nie wolno usuwa¢ katalogu domowego")
("not connected to server" "brak poŖ”czenia z serwerem")
("not yet implemented" "jeszcze nie zaimplementowano")
("notebook" "notatnik")
("number of polar steps" "liczba kroków polarnych")
("number of subunit steps" "liczba kroków podjednostek")
("numbering" "numeracja")
("numeric spreadsheet" "numeryczny arkusz kalkulacyjny")
("odd page" "strona nieparzysta")
("odd page left margin" "lewy margines strony nieparzystej")
("odd page right margin" "prawy margines strony nieparzystej")
("odd page shift" "przesuni¦cie strony nieparzystej")
("odd pages" "nieparzystych stron")
("of fingerprint" "odcisku palca")
("old version" "stara wersja")
("older version" "starsza wersja")
("on the footer" "w stopce")
("on your system and set it up from the \"Security\" tab" "w systemie i skonfiguruj go z karty \"Bezpiecze«stwo\"")
("one column" "jedna kolumna")
("one error has been corrected" "jeden bŖ”d zostaŖ poprawiony")
("one lower case letter, one non alpha-numeric symbol" "jedna maŖa litera, jeden nie alfanumeryczny symbol")
("one numeric character, one upper case letter" "jeden znak numeryczny, jedna wielka litera")
("only convert changes when re-importing" "konwertuj zmiany tylko podczas ponownego importowania")
("only convert changes with respect to imported version" "konwertuj tylko zmiany w odniesieniu do wersji importowanej")
("only convert changes with respect to tracked version" "konwertuj tylko zmiany w odniesieniu do wersji ±ledzonej")
("only implemented for complete subtrees" "zaimplementowano tylko dla peŖnych poddrzewa")
("only inline tags" "tylko tagi wbudowane")
("only keep folded" "tylko skŖadaj")
("only keep unfolded" "rozwijaj tylko")
("only show semantic focus" "poka» tylko fokus semantyczny")
("opacity" "krycie")
("open bibliography" "otwarta bibliografia")
("open identities" "otwarte to»samo±ci")
("open in new window" "otwórz w nowym oknie")
("open key manager" "mened»er kluczy")
("open licence agreement" "otwarta umowa licencyjna")
("open mailbox" "otwarta skrzynka pocztowa")
("open module browser" "przegl”darka moduŖów otwartych")
("open symbol browser" "przegl”darka symboli otwartych")
("open tool in separate window" "otwórz narz¦dzie w osobnym oknie")
("operation mode" "tryb pracy")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "lub podaj peŖn” ±cie»k¦ do polecenia \"gpg\" lub \"gpg2\"")
("order" "zamówienie")
("ordinary symbol" "zwykŖy symbol")
("ornamented" "zdobione")
("other login" "inny login")
("other package" "inny pakiet")
("outer bottom" "zewn¦trzne dno")
("outer left" "zewn¦trzny lewy")
("outer right" "zewn¦trzna prawa")
("outer top" "wierzch górny")
("outline" "zarys")
("outlined" "przedstawione")
("outlined emboss" "konturowany wytŖoczenie")
("outlined engrave" "zarysowany grawer")
("output options" "opcje wyj±ciowe")
("oval" "owalny")
("overlap" "nakŖadanie si¦")
("overlay" "nakŖadka")
("overlays" "nakŖadek")
("overlined" "podkre±lono")
("overview of the scheme extension language" "przegl”d j¦zyka rozszerzenia systemu")
("padded" "wy±cieŖane")
("page background" "tŖo strony")
("page break after" "podziaŖ strony po")
("page breaking algorithm" "algorytm podziaŖu strony")
("page number" "numer strony")
("page number rendering" "Renderowanie numerów stron")
("page rendering" "renderowanie strony")
("palette" "paleta")
("panorama" "panorama")
("paragraphs" "akapitów")
("parametric curve" "krzywa parametryczna")
("parametric surface" "powierzchnia parametryczna")
("parenthesis" "nawias")
("parenthesized" "w nawiasach")
("particle" "cz”stka")
("passphrase encryption" "szyfrowanie hasŖa")
("passphrase wallet facilities are not currently available" "Funkcje portfela z hasŖami nie s” obecnie dost¦pne")
("passphrases are expected to have at least: 8 characters" "Oczekuje si¦, »e haseŖ ma co najmniej: 8 znaków")
("passphrases mismatch" "niedopasowanie haseŖ")
("pastel" "pastel")
("pattern" "wzór")
("pause" "pauza")
("pen width" "szeroko±¢ pióra")
("permanent footer" "staŖa stopka")
("permanent header" "staŖy nagŖówek")
("permanently add to dictionary" "na staŖe dodaj do sŖownika")
("permanently insert into dictionary" "na staŖe wstaw do sŖownika")
("permissions" "uprawnie«")
("phantom" "fantom")
("phantoms" "fantomów")
("physics and astronomy class" "klasa fizyki i astronomii")
("picture" "obraz")
("pine" "sosna")
("plain" "zwykŖy")
("plain boxes" "zwykŖych pudeŖ")
("plain circles" "zwykŖych kóŖ")
("play" "gra")
("play animation" "Odtwórz animacj¦")
("please install GnuPG software from https://www.gnupg.org" "zainstaluj oprogramowanie GnuPG z https://www.gnupg.org")
("plot" "fabuŖa")
("plug-ins" "wtyczki")
("plural" "liczba mnoga")
("point" "punkt")
("polar" "polarny")
("polygon" "wielok”t")
("pop server settings" "ustawienia serwera pop")
("position of marginal note" "pozycja marginesu")
("poster formats" "formaty plakatów")
("poster theme" "motyw plakatu")
("postfix" "postfix")
("preferences for editing mathematical formulas" "preferencje dotycz”ce edytowania formuŖ matematycznych")
("preferences for tag" "preferencje dla tagu")
("prefix" "prefiks")
("presentation tool" "narz¦dzie prezentacji")
("preserve" "zachowaj")
("preserve tags" "zachowaj tagi")
("pretty tree output" "Ŗadna produkcja drzewa")
("preview" "podgl”d")
("previous" "poprzedni")
("previous difference" "poprzednia ró»nica")
("previous error" "poprzedni bŖ”d")
("previous field" "poprzednie pole")
("previous occurrence" "poprzednie wyst”pienie")
("previous screen" "poprzedni ekran")
("previous similar" "poprzednie podobne")
("primitive or macro" "prymitywne lub makro")
("print buffer" "bufor wydruku")
("print buffer to file" "bufor wydruku do pliku")
("print to file" "wydruk do pliku")
("printer setup" "konfiguracja drukarki")
("program bracket matching" "Dopasowywanie nawiasów programowych")
("program bracket selections" "Wybór nawiasów programowych")
("program commands" "komendy programu")
("program font" "czcionka programu")
("program interface for buffer management" "Interfejs programu do zarz”dzania buforami")
("programming routines for editing documents" "procedury programowania do edycji dokumentów")
("prominent" "wybitnych")
("prompts and default input" "monity i domy±lne dane wej±ciowe")
("provoke C++ error" "wywoŖa¢ bŖ”d C ++")
("provoke menu error" "wywoŖa¢ bŖ”d menu")
("provoke scheme error" "wywoŖa¢ bŖ”d schematu")
("pseudo code" "pseudo kod")
("public key encryption" "szyfrowanie klucza publicznego")
("public keys" "klucze publiczne")
("pulse" "impulsów")
("qt GUI only, sorry. Use \"Export selection\"" "Niestety, tylko GUI qt. U»yj \"Eksportuj wybór\"")
("qt-widgets" "wid»etów qt")
("quantifier" "kwantyfikator")
("quasi" "quasi")
("question" "pytanie")
("questions only" "tylko pytania")
("questions with answers" "pyta« z odpowiedziami")
("quick evaluation of formulas" "szybka ocena formuŖ")
("rank" "ranga")
("raw" "surowe")
("really delete user identity" "Naprawd¦ usu« to»samo±¢ u»ytkownika")
("really tiny" "naprawd¦ malutki")
("rebuild translations file" "odbuduj plik tŖumacze«")
("recent" "najnowsze")
("recent documents" "najnowsze dokumenty")
("recipients" "odbiorców")
("recognize" "rozpoznaj")
("recover autosave file" "odzyskaj plik autozapisu")
("rectangular" "prostok”tny")
("reduce" "zmniejsz")
("reduce trigonometric functions" "zmniejsz funkcje trygonometryczne")
("reduced margins" "obni»onych mar»")
("reference guide" "przewodnik referencyjny")
("reference guide for the TeXmacs primitives" "przewodnik referencyjny dla prymitywów TeXmacsa")
("reference guide for the standard TeXmacs styles" "przewodnik odniesienia dla standardowych stylów TeXmacs")
("regenerate" "regeneruj")
("register file" "plik rejestru")
("relate" "relate")
("relation" "relacja")
("release left button: finish editing" "zwolnij lewy przycisk: zako«cz edycj¦")
("remote" "zdalny")
("remote connections" "zdalne poŖ”czenia")
("remote control" "pilot")
("remote controllers with keyboard simulation" "pilotów z symulacj” klawiatury")
("remote directory" "katalog zdalny")
("remote servers" "zdalne serwery")
("remote tool" "narz¦dzie zdalne")
("remove" "usu«")
("remove all output fields" "usu« wszystkie pola wyj±ciowe")
("remove banner" "usu« baner")
("remove database entry" "usu« wpis z bazy danych")
("remove downwards" "usu« w dóŖ")
("remove entries" "usu« wpisy")
("remove entry" "usu« wpis")
("remove field above" "usu« pole powy»ej")
("remove field below" "usu« pole poni»ej")
("remove fields" "usu« pola")
("remove folded" "usu« zŖo»ony")
("remove input field" "usu« pole wprowadzania")
("remove input field above" "usu« pole wprowadzania powy»ej")
("remove last field" "usu« ostatnie pole")
("remove leftwards" "usu« w lewo")
("remove link" "usu« link")
("remove next field" "usu« nast¦pne pole")
("remove package" "usu« paczk¦")
("remove previous field" "usu« poprzednie pole")
("remove rightwards" "usu« w prawo")
("remove selected database entries" "Usu« wybrane wpisy bazy danych")
("remove selected entries" "usu« wybrane wpisy")
("remove superfluous invisible operators" "usu« zb¦dnych niewidocznych operatorów")
("remove tag" "usu« tag")
("remove this branch" "usu« t¦ gaŖ”¹")
("remove unfolded" "usu« rozwini¦ty")
("remove upwards" "usu« w gór¦")
("removed entries from database" "usuni¦to wpisy z bazy danych")
("removed entry from database" "usuni¦to wpis z bazy danych")
("rename" "Zmie« nazw¦")
("rename section" "sekcja zmiany nazwy")
("repeat" "powtórzenie")
("replace TeXmacs styles with no LaTeX equivalents" "zast”p style TeXmacs bez odpowiedników LaTeX")
("replace all further occurrences" "zast”p wszystkie dalsze wyst”pienia")
("replace one occurrence" "zamie« jedno wyst”pienie")
("replace toolbar" "zamie« pasek narz¦dzi")
("replace unrecognized styles" "zast”p nierozpoznane style")
("reset error counters" "zresetuj liczniki bŖ¦dów")
("resize" "zmiana rozmiaru")
("resize objects" "zmiana rozmiaru obiektów")
("restart TeXmacs in order to let changes take effect" "zrestartuj TeXmacs, aby zmiany zacz¦Ŗy obowi”zywa¢")
("restart in order to let the new look and feel take effect" "uruchom ponownie, aby nowy wygl”d zadziaŖaŖ")
("retain" "zachowaj")
("retime" "retime")
("retina settings" "Ustawienia siatkówki")
("retrieve email" "odzyska¢ e-mail")
("retrieve remote live document" "pobierz zdalny dokument na »ywo")
("retrieved contents" "odzyskana tre±¢")
("reverse" "rewers")
("reverse ordering" "odwrotne zamówienie")
("ridged paper" "papier pr”»kowany")
("right baseline" "prawa linia bazowa")
("right cell border" "prawa kraw¦d¹ komórki")
("right cell padding" "dopeŖnienie prawej komórki")
("right down" "w prawo")
("right on even pages" "bezpo±rednio na stronach parzystych")
("right table border" "prawa kraw¦d¹ tabeli")
("right table padding" "wy±cióŖka prawego stoŖu")
("right up" "w prawo")
("rightwards" "w prawo")
("rigid box" "sztywne pudeŖko")
("rotate" "obró¢")
("rotate objects" "obracaj obiekty")
("rough" "szorstki")
("rough paper" "szorstki papier")
("round" "okr”gŖy")
("round overbrace" "okr”gŖy overbrace")
("round underbrace" "okr”gŖy underbrace")
("row above" "wiersz powy»ej")
("row below" "wiersz poni»ej")
("rows" "wierszy")
("run" "bieg")
("run current file" "uruchom bie»”cy plik")
("same names" "te same nazwy")
("same screen margins as on paper" "takich samych marginesów ekranu jak na papierze")
("sample text" "przykŖadowy tekst")
("save auxiliary data" "zapisz dane pomocnicze")
("save entries" "zapisz wpisy")
("save entry" "zapisz wpis")
("save image as" "zapisz obraz jako")
("save position" "zapisz pozycj¦")
("save remote file" "zapisz plik zdalny")
("saved modifications in database" "zapisane modyfikacje w bazie danych")
("scheme command" "polecenie schematu")
("scheme developers guide" "przewodnik dla programistów")
("scheme extensions" "rozszerze« systemu")
("scheme interface for the graphical mode" "interfejs schematu dla trybu graficznego")
("screen" "ekran")
("screen rendering" "renderowanie ekranu")
("screens" "ekrany")
("screenshot" "zrzut ekranu")
("scripting language" "j¦zyk skryptowy")
("scripts" "skryptów")
("search and replace" "wyszukaj i zamie«")
("search toolbar" "pasek narz¦dzi wyszukiwania")
("second" "sekunda")
("secret keys" "tajnych kluczy")
("sections" "sekcji")
("see documentation" "patrz dokumentacja")
("select pen" "wybierz pióro")
("select the action to be undertaken for each conflict" "wybierz dziaŖanie, które nale»y podj”¢ dla ka»dego konfliktu")
("select view mode" "wybierz tryb widoku")
("semantic correctness" "poprawno±¢ semantyczna")
("semantic editing" "edycja semantyczna")
("semantic selections" "selekcje semantyczne")
("semantics" "semantyka")
("senior" "starszy")
("serif" "serif")
("server" "serwer")
("session commands" "komendy sesji")
("set default" "Ustaw jako domy±lny")
("set difference" "ustaw ró»nic¦")
("set intersection" "ustaw przeci¦cie")
("set number of columns" "ustaw liczb¦ kolumn")
("set number of rows" "ustaw liczb¦ wierszy")
("set or get environment variables" "ustaw lub pobierz zmienne ±rodowiskowe")
("set properties" "ustaw wŖa±ciwo±ci")
("set union" "set union")
("set user information" "ustaw informacje o u»ytkowniku")
("seventh" "siódmy")
("several equations" "kilka równa«")
("shadow" "cie«")
("shadowed" "shadowed")
("shadowed raise" "shadowed raise")
("shift" "shift")
("short" "krótki")
("show all parts" "poka» wszystkie cz¦±ci")
("show current focus" "poka» aktualny fokus")
("show full context" "poka» peŖny kontekst")
("show hidden" "poka» ukryty")
("show key presses" "Poka» naci±ni¦cia klawiszy")
("show main document" "poka» gŖówny dokument")
("show memory usage" "poka» u»ycie pami¦ci")
("show one part" "poka» jedn” cz¦±¢")
("show panorama" "poka» panoram¦")
("show preamble" "poka» preambuŖ¦")
("show several parts" "poka» kilka cz¦±ci")
("show subunits" "poka» podjednostki")
("show table cells" "poka» komórki tabeli")
("show timings" "poka» czasy")
("side tools" "narz¦dzia boczne")
("simple" "prosty")
("simplification" "uproszczenie")
("simplified evaluation of formulas" "uproszczona ocena formuŖ")
("simplified menus" "menu uproszczone")
("simplify" "upro±ci¢")
("sine" "sinus")
("sixth" "szósty")
("size tag" "znacznik rozmiaru")
("skew" "pochylenie")
("skip all" "pomi« wszystko")
("slant" "uko±ny")
("slashed fraction" "frakcja ci¦ta")
("slides" "slajdów")
("slovene" "sŖowenia")
("slow" "wolny")
("slow decrease" "powolny spadek")
("slow increase" "powolny wzrost")
("small capitals" "maŖe litery")
("small environment box" "maŖe pudeŖko ±rodowiska")
("small focus" "maŖa ostro±¢")
("small inline" "maŖy wiersz")
("small inline fraction" "maŖa frakcja wbudowana")
("smash" "smash")
("smooth" "gŖadki")
("smooth end" "gŖadki koniec")
("smooth extremities" "gŖadkie ko«czyny")
("smooth start" "pŖynny start")
("snap" "snap")
("snap distance" "odlegŖo±¢ przyci”gania")
("snap to curves" "przyci”ganie do krzywych")
("snap to grid" "przyci”ganie do siatki")
("snap to grid curve" "przyci”ganie do krzywej siatki")
("snap to intersections of curves" "przyci”ganie do przeci¦¢ krzywych")
("snap to text borders" "przyci”ganie do granic tekstu")
("snap to text corners" "przyci”gaj do rogów tekstu")
("solution" "rozwi”zanie")
("solution to exercise" "rozwi”zanie do ¢wicze«")
("solution to problem" "rozwi”zanie problemu")
("solutions" "rozwi”za«")
("sound" "d¹wi¦k")
("source" "¹ródŖo")
("source macros tool" "narz¦dzie do makr ¹ródŖowych")
("source tags" "tagi ¹ródŖowe")
("south" "poŖudnie")
("south east" "poŖudniowy wschód")
("space bar in math mode" "spacja w trybie matematycznym")
("space bar in text mode" "spacja w trybie tekstowym")
("space stretchability" "rozci”gliwo±¢ przestrzeni")
("span" "rozpi¦to±¢")
("span over all columns" "rozpi¦to±¢ na wszystkie kolumny")
("special functions" "funkcje specjalne")
("special properties" "wŖa±ciwo±ci specjalne")
("specific baseline" "konkretny poziom odniesienia")
("specify color alternation" "okre±l zmian¦ koloru")
("specify how to traverse the manual" "okre±l sposób przechodzenia przez instrukcj¦")
("specify semantics of a symbol or formula" "nale»y poda¢ semantyk¦ symbolu lub wzoru")
("specify the size of the table" "okre±l rozmiar tabeli")
("spell check" "sprawdzanie pisowni")
("spline" "splajn")
("split program" "program podzielony")
("square" "kwadrat")
("square overbrace" "kwadratowy overbrace")
("square underbrace" "kwadratowy underbrace")
("stack" "stos")
("standard" "standard")
("standard Output" "standardowe wyj±cie")
("standard TeXmacs styles" "standardowych stylów TeXmacs")
("standard environment variables" "standardowe zmienne ±rodowiskowe")
("standard formats" "standardowe formaty")
("standard fraction" "frakcja standardowa")
("star" "gwiazda")
("start server" "start server")
("statement" "o±wiadczenie")
("statistics" "statystyki")
("status" "status")
("stop server" "zatrzymaj serwer")
("storage" "pami¦ci")
("store tracking information in LaTeX files" "przechowuj informacje o ±ledzeniu w plikach LaTeX")
("stretch" "odcinek")
("stretch factor" "wspóŖczynnik rozci”gni¦cia")
("stretched" "rozci”gni¦ty")
("strict Ascii" "surowe Ascii")
("strike through" "przekre±lenie")
("structured insert above" "wkŖadka strukturalna powy»ej")
("structured insert at the left" "wkŖadka strukturalna po lewej stronie")
("structured insert at the right" "wkŖadka strukturalna po prawej stronie")
("structured insert below" "wkŖadka strukturalna poni»ej")
("structured remove downwards" "usuni¦cie strukturalne w dóŖ")
("structured remove leftwards" "uporz”dkowane usu« w lewo")
("structured remove rightwards" "uporz”dkowane usu« w prawo")
("structured remove upwards" "usuni¦cie strukturalne w gór¦")
("structured variant" "wariant strukturalny")
("style options" "opcji stylu")
("style parameters" "parametrów stylu")
("stylesheet language" "j¦zyk arkusza stylów")
("subject" "temat")
("submenu" "podmenu")
("subscript below" "indeks dolny poni»ej")
("subsubmenu" "podmenu")
("subsubsubmenu" "podmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "podtabela")
("subtitle" "podtytuŖ")
("subtraction" "odejmowanie")
("summarized" "podsumowane")
("superscript above" "indeks górny powy»ej")
("supported plug-ins" "obsŖugiwane wtyczki")
("surface" "powierzchnia")
("inflate" "puchni¦cie")
("swiss" "szwajcarski")
("switch to buffer" "PrzeŖ”cz na bufor")
("symbol properties not found" "Nie znaleziono wŖa±ciwo±ci symbolu")
("symbols" "symboli")
("synchronize" "synchronizacja")
("synchronize bibliographic references" "synchronizuj odniesienia bibliograficzne")
("synchronize with remote server" "synchronizacja ze zdalnym serwerem")
("synopsis" "streszczenie")
("system command" "polecenie systemowe")
("tab-completion" "UzupeŖnianie tabulatorów")
("tabbed" "z zakŖadkami")
("table breaking" "Ŗamanie tabel")
("table height" "wysoko±¢ stoŖu")
("table properties" "wŖa±ciwo±ci tabeli")
("table width" "szeroko±¢ stoŖu")
("tags with special rendering" "tagi ze specjalnym renderowaniem")
("tangent" "styczna")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Oczekiwany bufor TeXmacs")
("teXmacs buffer on disk expected" "Oczekiwany bufor TeXmacs na dysku")
("teXmacs extensions to scheme and utilities" "Rozszerzenia TeXmacs do schematu i narz¦dzi")
("teXmacs macro" "makro TeXmacs")
("teXmacs package" "pakiet TeXmacs")
("teXmacs primitives" "prymitywy TeXmacs")
("teXmacs style" "styl TeXmacs")
("test routine" "procedura testowa")
("testing tree-view" "testowanie widoku drzewa")
("text borders" "obramowa« tekstu")
("text box style" "styl pola tekstowego")
("text corners" "rogi tekstu")
("textual" "tekstowy")
("textual operator" "operator tekstowy")
("textual spreadsheet" "tekstowy arkusz kalkulacyjny")
("the TeXmacs format" "format TeXmacs")
("the TeXmacs plug-in system" "system wtyczek TeXmacs")
("the document has not been saved" "dokument nie zostaŖ zapisany")
("theme parameters" "parametry motywu")
("these collected public keys will be definitely lost" "te zebrane klucze publiczne na pewno zostan” utracone")
("these public keys will be definitely lost" "te klucze publiczne zostan” na pewno utracone")
("these secret keys will be definitely lost" "te tajne klucze na pewno zostan” utracone")
("thicken" "zag¦±ci¢")
("third" "trzeci")
("this" "to")
("this column" "ta kolumna")
("this page footer" "ta stopka strony")
("this page header" "ten nagŖówek strony")
("this page number" "ten numer strony")
("this row" "ten wiersz")
("this style specifies page margins in the TeX way" "ten styl okre±la marginesy strony w stylu TeX")
("three columns" "trzy kolumny")
("three dots" "trzy kropki")
("through popup windows" "przez wyskakuj”ce okna")
("through the menus" "poprzez menu")
("thumbnails" "miniatur")
("time evolution" "ewolucja czasu")
("timings" "czasy")
("title presentation options" "opcje prezentacji tytuŖu")
("title style" "styl tytuŖowy")
("title suffix" "sufiks tytuŖu")
("titled block" "tytuŖowany blok")
("toggle cell wrapping mode" "PrzeŖ”cz tryb zawijania komórek")
("toggle here" "przeŖ”cz tutaj")
("toggle off" "wyŖ”cz")
("toggle on" "WŖ”cz")
("tolerant" "tolerancyjny")
("top baseline" "górna linia bazowa")
("top cell border" "górna kraw¦d¹ komórki")
("top cell padding" "górne wypeŖnienie komórki")
("top table border" "obramowanie górnego stoŖu")
("top table padding" "wy±cieŖanie górnego stoŖu")
("transform" "transformacja")
("transform cell into subtable" "transformuj komórk¦ w podtabuŖ¦")
("translations" "tŖumaczenia")
("translations loaded" "zaŖadowano tŖumaczenia")
("transpose" "transponuj")
("traversal" "przej±cie")
("traverse" "trawers")
("triangle" "trójk”t")
("triangularize" "trójk”tny")
("trigonometric" "trygonometryczny")
("trigonometry" "trygonometria")
("turn off" "wyŖ”cz")
("turn on" "wŖ”cz")
("two columns" "dwie kolumny")
("two dots" "dwie kropki")
("type a latex command followed by return" "wpisz polecenie lateksu, a nast¦pnie return")
("underlined" "podkre±lono")
("unevaluated argument" "nieoceniony argument")
("unevaluated value" "nieoceniona warto±¢")
("unfold" "rozŖó»")
("unfold all" "rozŖó» wszystko")
("unfold all fields" "rozŖó» wszystkie pola")
("unit" "jednostka")
("unit length" "dŖugo±¢ jednostki")
("unknown secret key fingerprint" "nieznany tajny odcisk palca")
("unregistered file" "niezarejestrowany plik")
("unroll" "rozwijaj")
("unsecure script refused" "odmówiono niezabezpieczonego skryptu")
("unsupported link mode" "nieobsŖugiwany tryb Ŗ”cza")
("until" "do")
("untitled block" "blok bez tytuŖu")
("up to date" "na bie»”co")
("update buffer" "bufor aktualizacji")
("update this buffer" "zaktualizuj ten bufor")
("update web site" "aktualizacja strony internetowej")
("upight" "pionowy")
("upload" "przesyŖanie")
("upright" "pionowo")
("upwards" "w gór¦")
("use CSS for more advanced formatting" "U»yj CSS do bardziej zaawansowanego formatowania")
("use MathML" "u»yj MathML")
("use as master" "u»yj jako wzorca")
("use extensible brackets" "u»yj wysuwanych wsporników")
("use line wrapping for lines which are longer than 80 characters" "u»yj zawijania linii dla linii dŖu»szych ni» 80 znaków")
("use margin kerning (protrusion)" "u»yj kerningu marginesów (wyst¦p)")
("use protrusion" "u»yj wyst¦pu")
("use relative path" "u»yj ±cie»ki wzgl¦dnej")
("user interface" "interfejs u»ytkownika")
("user interface language" "j¦zyk interfejsu u»ytkownika")
("user preferences" "preferencje u»ytkownika")
("users of oriental languages" "u»ytkownicy j¦zyków orientalnych")
("utf-8 with inputenc LaTeX package" "utf-8 z pakietem inputenc LaTeX")
("utilities" "narz¦dzia")
("vanish" "znikn”¢")
("verbose" "verbose")
("version" "wersja")
("versioning tool" "narz¦dzie do wersjonowania")
("vertical alignment" "wyrównanie pionowe")
("vertical margins" "pionowe marginesy")
("vertical space after" "odst¦p pionowy za")
("vertical space before" "przestrze« pionowa przed")
("vertical space stretchability" "rozci”gliwo±¢ przestrzeni pionowej")
("visible except here" "widoczny oprócz tutaj")
("visible from here on" "widoczny odt”d")
("visible only here" "widoczny tylko tutaj")
("visible until here" "widoczny do tutaj")
("visited loci" "odwiedzone loci")
("wallet" "portfel")
("wave" "fala")
("web" "sie¢")
("weight" "waga")
("when line wrapping" "podczas zawijania linii")
("whitespace" "biaŖe znaki")
("wide" "szeroki")
("wide block" "szeroki blok")
("wide colored" "szeroki kolor")
("wide float" "wide float")
("wide footnote" "szeroki przypis")
("wide tabular" "szeroki tabelaryczny")
("widescreen" "panoramiczny")
("wrap lines" "zawijanie linii")
("write a macro" "Napisz makro")
("writing TeXmacs bibliography styles" "pisanie stylów bibliografii TeXmacsa")
("writing documentation" "pisanie dokumentacji")
("written with TeXmacs" "napisane z TeXmacs")
("wrong empty passphrase" "zŖe puste hasŖo")
("wrong passphrase" "zŖe hasŖo")
("year" "rok")
("you are attempting to open an encrypted file while" "próbujesz otworzy¢ zaszyfrowany plik, gdy")
("you might consider enabling the experimental" "mo»esz rozwa»y¢ wŖ”czenie eksperymentu")
("you must add a bibliography file" "musisz doda¢ plik bibliografii")
("you should also make sure that GnuPG is installed" "powiniene± tak»e upewni¢ si¦, »e GnuPG jest zainstalowany")
("your personal dictionary has been modified" "Twój sŖownik osobisty zostaŖ zmodyfikowany")
("zoom" "zoom")
("zoom in" "powi¦ksz")
("zoom out" "oddalenie")
