("A modifier" "Modifikátor A")
("GNU" "GNU")
("H modifier" "Modifikátor H")
("LaTeX" "LaTeX")
("M modifier" "Modifikátor M")
("TeX" "TeX")
("abbreviation" "zkratka")
("about" "o programu")
("about menu" "o programu")
("above" "nad")
("abstract" "abstrakt")
("accent" "akcent")
("accept" "akceptovat")
("accept all scripts" "povolit v˛echny skripty")
("accept no scripts" "nepovolit şádné skripty")
("accept script" "povolit skript")
("acknowledgment" "podĽkování")
("acronym" "akronym")
("action" "akce")
("activate" "aktivovat")
("acute" "Łárka")
("add switch after" "vloşit p°epínaŁ za")
("add switch before" "vloşit p°epínaŁ p°ed")
("address" "adresa")
("address block" "blok adresy")
("advanced" "pokroŁilé")
("advanced layout features" "pokroŁilé vlastnosti rozloşení")
("after" "po")
("albanian" "albánský")
("algorithm" "algoritmus")
("align cell to the bottom" "zarovnat buŹku dolˇ")
("align cell to the left" "zarovnat buŹku doleva")
("align cell to the right" "zarovnat buŹku doprava")
("align cell to the top" "zarovnat buŹku nahoru")
("align table at base of left column" "zarovnat tabulku podle sloupku vlevo")
("align table at base of middle column" "zarovnat tabulku podle sloupku uprost°ed")
("align table at base of origin column" "zarovnat tabulku podle pˇvodního sloupku")
("align table at base of right column" "zarovnat tabulku podle pˇvodního sloupku vpravo")
("align table at fraction bar height" "zarovnat tabulku")
("align table at the base of bottom row" "zarovnat tabulku podle °ádku dole")
("align table at the base of middle row" "zarovnat tabulku podle °ádku uprost°ed")
("align table at the base of origin row" "zarovnat tabulku podle pˇvodního °ádku")
("align table at the base of top row" "zarovnat tabulku podle °ádku naho°e")
("align table at the bottom" "zarovnat tabulku dolˇ")
("align table at the center" "zarovnat tabulku na st°ed")
("align table at the horizontal center" "zarovnat tabulku doprost°ed")
("align table at the left" "zarovnat tabulku nalevo")
("align table at the top" "zarovnat tabulku nahoru")
("align table to the right" "zarovnat tabulku doprava")
("align text to the left" "zarovnat text doleva")
("align text to the right" "zarovnat text doprava")
("alignment" "zarovnání")
("all" "v˛e")
("allow" "povolit")
("allowed extension" "povolit roz˛í°ení")
("allowed reduction" "povolit redukci")
("alpha release" "alpha release")
("alt key" "klávesa alt")
("and" "a")
("appendix" "dodatek")
("apply" "pouşij")
("april" "duben")
("arab" "arab˛tina")
("archaic" "archaický")
("architecture" "architektura")
("argument" "argument")
("arithmetic" "aritmetický")
("armenian" "arménský")
("arrow" "˛ipka")
("arrows" "˛ipky")
("article" "Łlánek")
("as on paper" "jako na papí°e")
("assign" "p°i°adit")
("at fraction bar height" "na zlomkovou Łáru")
("at the baseline" "na úŁa°í")
("at the bottom" "dolˇ")
("at the left" "doleva")
("at the middle" "doprost°ed")
("at the right" "doprava")
("at the top" "nahoru")
("attach" "p°ipojit")
("attach buffer to which project" "p°ipojit snímek k projektu")
("august" "srpen")
("author" "autor")
("authorize" "autorizovat")
("automatic" "automatický")
("automatically generated content" "automaticky generovaný obsah")
("axiom" "axióm")
("background" "pozadí")
("background color" "barva pozadí")
("backward replace" "nahrazovat dozadu")
("backward search" "hledat dozadu")
("bad data format" "˛patný formát dat")
("bar" "pruh")
("bard" "bard")
("base level" "základní úroveŹ")
("bashkirian" "bashkrian")
("basic" "základní")
("basic data types" "základní datové typy")
("basic types" "základní typy")
("be useful" "bu¤te uşiteŁný")
("become a TeXmacs developer" "staŹte se vývojá°em TeXmacsu")
("before" "p°ed")
("begin" "zaŁátek")
("below" "pod")
("beta release" "beta release")
("bibliography" "literatura")
("bibliography file" "soubor s literaturou")
("bibliography style" "styl pro literaturu")
("big" "velký")
("big figure" "velký obrázek")
("big operator" "velký operátor")
("big skip" "velký odstup")
("big table" "velká tabulka")
("binary operation" "binární operace")
("binary relation" "binární relace")
("black" "Łerná")
("blackboard bold" "blackboard tuŁný")
("blackboard math" "blackboard matematický")
("blackletter" "blackletter")
("blue" "modrá")
("body" "tĽlo")
("bold" "tuŁnĽ")
("book" "kniha")
("border" "okraj")
("both" "oba")
("bottom" "spodek")
("bottom border" "spodní okraj")
("bottom margin" "dolní okraj")
("bottom padding" "spodní odskok")
("branch" "vĽtev")
("break" "zalomení")
("breaking" "zalamování")
("breve" "kulatý háŁek")
("british" "britský")
("brown" "hnĽdá")
("browse" "procházet")
("browse web" "procházet web")
("browser" "prohlíşeŁ")
("buffer" "snímek")
("bulgarian" "bulharský")
("bullet" "odráşka")
("bullets" "odráşky")
("by" "vytvo°il")
("by typing" "psaním")
("bytes free" "volných bytˇ")
("bytes used" "obsazených bytˇ")
("calligraphic" "kaligrafický")
("cancel" "zru˛it")
("caps-lock key" "klávesa caps-lock")
("case" "case")
("cc" "slepá kopie")
("cell" "buŹka")
("cell background color" "barva pozadí buŹky")
("cell border" "okraj buŹky")
("cell height" "vý˛ka buŹky")
("cell operation mode" "operaŁní reşim buŹky")
("cell width" "˛í°ka buŹky")
("center" "doprost°ed")
("center text" "vyst°edit text")
("centered" "doprost°ed")
("centered block" "vyst°edĽný blok")
("centered tabular" "vyst°edĽná tabulka")
("change border of cell" "zmĽnit okraj buŹky")
("change cell operation mode" "zmĽnit operaŁní reşim buŹky")
("change log" "záznam zmĽn")
("changes" "zmĽny")
("chapter" "kapitola")
("check" "háŁek")
("check text for spelling errors" "otestovat pravopis textu")
("chinese" "Łín˛tina")
("choice" "výbĽr")
("citation" "citace")
("cite" "citát")
("class" "t°ída")
("clear" "smazat")
("clear selection" "smazat schránku")
("clipped" "o°ezáno")
("clipped and magnified" "o°ezáno a zvĽt˛eno")
("clipped and resized" "o°ezáno a zmĽnĽny rozmĽry")
("clone" "duplikovat")
("clone window" "duplikovat okno")
("close" "zav°ít")
("close TeXmacs" "zav°ít TeXmacs")
("close buffer" "zav°ít snímek")
("close session" "uzav°ít sezení")
("close window" "zav°ít okno")
("closing" "uzav°ení")
("code" "zdrojový kód")
("color" "barva")
("column" "sloupeŁek")
("column contains glued items" "sloupec obsahuje p°ilepené poloşky")
("compatibility with other formats" "kompatibilita s jinými formáty")
("compile article" "p°eloşit Łlánek")
("compile book" "p°eloşit knihu")
("compile buffer" "p°eloşit snímek")
("compile project" "p°eloşit projekt")
("complex" "komplexní")
("concrete" "concrete")
("condensed" "zúşené")
("condition" "podmínka")
("configuration" "nastavení")
("content tag" "znaŁka obsahu")
("context dependent icons" "kontextovĽ závislé ikony")
("continuation of" "obnovení Łinnosti")
("convention" "konvence")
("converters to other data formats" "p°evadĽŁe do jiných datových formátˇ")
("copy" "kopírovat")
("copy text" "kopírovat text")
("copy to" "kopírovat do schránky")
("copying" "kopírování")
("corollary" "korolár")
("correct text" "opravit text")
("cursors" "kurzor")
("custom tab" "vlastní tabulátor")
("customizing TeXmacs" "p°izpˇsobení TeXmacsu")
("customizing the TeXmacs styles" "p°izpˇsobení stylˇ TeXmacsu")
("custum tab" "vlastní tabulátor")
("cut" "vyjmout")
("cut text" "vyjmout text")
("cut to" "vyjmout do")
("cypriot" "cypriot")
("cyrillic" "azbuka")
("cyrillic input method" "metoda vstupu cyrilice")
("cyrillic italic right" "kurzívní azbuka")
("czech" "Łe˛tina")
("dancers" "dancers")
("danish" "dánský")
("dash" "pomlŁka")
("dashes" "pomlŁky")
("data conversion" "p°evod dat")
("data format" "formát dat")
("date" "datum")
("deactivate" "deaktivovat")
("deactivate table" "deaktivovat tabulku")
("december" "prosinec")
("decorate atoms" "ozdobné atomy")
("default" "standardní")
("default padding" "standardní odskakování")
("definition" "definice")
("delete" "smazat")
("delete column" "smazat sloupec")
("delete row" "smazat °ádek")
("denominator" "jmenovatel")
("description" "popis")
("destination" "cíl")
("detach" "odpojit")
("determinant" "determinant")
("devangari" "devangari")
("developers guide" "prˇvodce vývojá°e")
("directory" "adresá°")
("disable first indentation" "zakázat odsazení prvního")
("disable first indentation after" "zakázat odsazení prvního p°ed")
("disable first indentation before" "zakázat odsazení prvního p°ed")
("disable indentation" "zakázat odsazení")
("disable indentation after" "zakázat odsazení za")
("disable indentation before" "zakázat odsazení p°ed")
("disable last indentation" "zakázat odsazení posledního")
("disable last indentation after" "zakázat odsazení posledního")
("disable last indentation before" "zakázat odsazení posledního")
("disallow" "nepovolit")
("distribute unused space" "rozloşit nepouşité mezery")
("div" "podíl")
("document" "dokument")
("document format" "formát dokumentu")
("document style" "styl dokumentu")
("document styles" "styly dokumentˇ")
("documentation" "dokumentace")
("documents are trees" "dokumenty jsou stromovĽ")
("dot" "teŁka")
("dots" "teŁky")
("double stroke" "dvakrát p°e˛krtnutý")
("down" "dolˇ")
("dpi" "dpi")
("duplicate" "duplikovat")
("dutch" "holand˛tina")
("dynamic libraries" "dynamické knihovny")
("edit" "úpravy")
("editing tools" "editaŁní nástroje")
("email" "email")
("emphasize" "zvýraznĽní")
("emphasize text" "zdˇraznit text")
("empty box" "prázný box")
("enable first indentation" "povolit odsazení prvního")
("enable first indentation after" "povolit odsazení prvního")
("enable first indentation before" "povolit odsazení prvního")
("enable indentation" "povolit odsazení")
("enable indentation after" "povolit odsazení za")
("enable indentation before" "povolit odsazení p°ed")
("enable last indentation" "povolit odsazení posledního")
("enable last indentation after" "povolit odsazení posledního p°ed")
("enable last indentation before" "povolit odsazení posledního p°ed")
("encl" "p°ílohy")
("end" "konec")
("english" "angliŁtina")
("enter a title" "vloşit titulek")
("enumerate" "Łíslovaný seznam")
("enumerate|Alpha" "Łíslování|Abecední")
("enumerate|Roman" "Łíslování|ímské")
("enumerate|alpha" "Łíslování|abecední")
("enumerate|roman" "Łíslování|°ímské")
("env" "prost°edí")
("environment" "prost°edí")
("epilogue" "epilog")
("equal" "rovno")
("equation" "rovnice")
("equations" "soustava rovnic")
("equivalent for" "ekvivalent pro")
("error" "chyba")
("esperanto" "esperanto")
("etruscan" "etruský")
("evaluate" "vyhodnotit")
("evaluate scheme expression" "vyhodnotit výraz scheme")
("even page footer" "zápatí sudé stránky")
("even page header" "záhlaví sudé stránky")
("even page margin" "okraj sudé stránky")
("even page text" "text sudé stránky")
("exact horizontal" "p°esná vodorovná")
("exact mode" "p°esný reşim")
("exam" "zkou˛ka")
("example" "p°íklad")
("exclusive" "vyjma")
("exclusive or" "nonekvivalence")
("executable" "spustitelný")
("execute" "spustit")
("execute a TeXmacs command" "vykonat p°íkaz TeXmacsu")
("execute system command" "vykonat systémový p°íkaz")
("executive" "executive")
("exercise" "cviŁení")
("expand" "expandovat")
("explained" "vysvĽtlený")
("export" "export")
("export as" "exportovat do")
("extend or normal" "roz˛í°ené nebo normální")
("extern " "externí")
("extra" "extra")
("extract format" "získej formát")
("family" "rodina")
("february" "únor")
("figure" "obrázek")
("file" "soubor")
("file name" "jméno souboru")
("file not found" "soubor nenalezen")
("find next match" "hledat dal˛í")
("find text" "hledat text")
("finnish" "dokonŁit")
("first contact" "první seznámení")
("first indentation" "první odsazení")
("first item" "první poloşka")
("first page" "první strana")
("first start" "zaŁít od")
("flat" "zplo˛tĽné")
("flexibility" "flexiblita")
("flexibility factor for vertical spacing" "Łinitel flexibility pro svislé mezery")
("floating figure" "plovoucí obrázek")
("floating object" "plovoucí objekt")
("floating table" "plovoucí tabulka")
("fold" "balení")
("folded" "sbaleno")
("font" "písmo")
("font base size" "základní velikost písma")
("font dpi" "dpi písma")
("font family" "rodina písma")
("font name" "jméno písma")
("font series" "série písma")
("font shape" "tvar písma")
("font size" "velikost písma")
("font variant" "varianta písma")
("fonts" "písma")
("footer" "zápatí")
("footnote" "poznámka pod Łarou")
("for" "for")
("foreground" "pop°edí")
("foreign" "cizí")
("format" "formát")
("formatted date" "formátované datum")
("formula" "vzorec")
("formula style" "reşim vzorce")
("forward replace" "nahrazovat dop°edu")
("forward search" "hledat dop°edu")
("fraction" "zlomek")
("french" "francouz˛tina")
("full manuals" "p°íruŁky v plném znĽní")
("function" "funkce")
("further customization" "dal˛í p°izpˇsobení")
("future changes" "budoucí zmĽny")
("gNU TeXmacs comes without any form of legal warranty" "na gNU TeXmacs se nevztahují şádné právní nároky")
("gNU TeXmacs falls under the GNU general public license" "gNU TeXmacs spadá pod licenci GNU")
("general architecture of TeXmacs" "celková architektura TeXmacsu")
("general negation" "obecná negace")
("generating font file" "generuji font")
("generic" "obecný")
("georgian" "georgian")
("german" "nĽmŁina")
("getting started" "zaŁínáme")
("glossary" "glosá°")
("glossary entry" "poloşka glosá°e")
("glue" "slepit")
("glue decorations" "slepit dekorace")
("go" "Jdi na")
("gothic" "gotický")
("graphical interface" "grafické rozhraní")
("grave" "obrácená Łárka")
("greater" "vĽt˛í")
("greater or equal" "vĽt˛í nebo rovno")
("greek" "°ecký")
("greek letter" "°ecké písmeno")
("green" "zelená")
("grey" "˛edá")
("group" "skupina")
("happy typing" "p°íjemné psaní")
("has been aborted" "byl p°eru˛en")
("has completed its task" "ukonŁil Łinnost")
("hat" "st°í˛ka")
("header" "hlaviŁka")
("header and footer" "záhlaví a zápatí")
("hebrew" "hebrejský")
("height" "vý˛ka")
("height is exactly the specified height" "vý˛ka je p°esnĽ dle zadání")
("height is maximum of specified height and box height" "vý˛ka je maximum ze zadání a vý˛ky boxu")
("height is minimum of specified height and box height" "vý˛ka je minimum ze zadání a vý˛ky boxu")
("height magnification" "prodlouşení")
("help" "nápovĽda")
("help me" "pomozte mi")
("help us" "pomozte nám")
("here" "zde")
("home" "domovský adresá°")
("horizontal" "vodorovná")
("horizontal cell alignment" "vodorovné zarovnání buŹky")
("horizontal ink separation" "vodorovné oddĽlení barvy")
("horizontal part" "vodorovná Łást")
("horizontal position" "vodorovná pozice")
("horizontal space" "vodorvná mezera")
("horizontal table alignment" "vodorovné zarovnání tabulky")
("horizontally align cell to the base" "zarovnat buŹku vodorovnĽ k základnĽ")
("horizontally center the cell" "vycentrovat buŹku")
("how much longer may pages become" "o kolik mohou být stránky del˛í")
("how much shorter may pages become" "o kolik mohou být stránky krat˛í")
("huge" "obrovský")
("hungarian" "ma¤arský")
("hyperlink" "hyperodkaz")
("hyphenation" "dĽlení slov")
("icelandic" "islandský")
("if" "if")
("image" "obrázek")
("image links" "odkazy obrázku")
("implementation" "implementace")
("import" "import")
("improving the current implementation" "zlep˛ování souŁasné implementace")
("inactive" "neaktivní")
("include" "vloşit")
("include a document" "vloşit dokument")
("include file" "vloşit soubor")
("inclusion into TeXmacs" "zahrnutí do TeXmacsu")
("inclusions" "vloşení")
("indent" "odsazení")
("indentation flag" "nastavení odsazení")
("index" "rejst°ík")
("index entry" "poloşka rejst°íku")
("index level" "úroveŹ indexu")
("insert" "vloşit")
("insert Pr" "vloşit Pr")
("insert a TeXmacs symbol" "vloşit symbol TeXmacsu")
("insert a big operator" "vloşit velký operátor")
("insert a binary operation" "vloşit binární operaci")
("insert a binary relation" "vloşit binární relaci")
("insert a blackboard bold character" "vloşit velmi tuŁný znak")
("insert a bold calligraphic character" "vloşit tuŁný kaligrafický znak")
("insert a bold character" "vloşit tuŁný znak")
("insert a calligraphic character" "vloşit kaligrafický znak")
("insert a fraction" "vloşit zlomek")
("insert a fraktur character" "vloşit znak fraktur")
("insert a greek character" "vloşit °ecké písmeno")
("insert a large left delimiter" "vloşit velký levý omezovaŁ")
("insert a large right delimiter" "vloşit velký pravý omezovaŁ")
("insert a large separator" "vloşit velký oddĽlovaŁ")
("insert a left subscript" "vloşit levý dolní index")
("insert a link" "vloşte odkaz")
("insert a miscellaneous symbol" "vloşit jiný symbol")
("insert a new branch" "vloşte novou vĽtev")
("insert a new item" "vloşit novou poloşku")
("insert a picture" "vloşit obrázek")
("insert a square root" "vloşit odmocninu")
("insert a table" "vloşit tabulku")
("insert a table or a matrix" "vloşit tabulku nebo matici")
("insert an" "vloşit")
("insert an accent" "vloşit Łárku")
("insert an arrow" "vloşit ˛ipku")
("insert an environment" "vloşit prost°edí")
("insert an n" "vloşit n")
("insert appendix" "vloşit dodatek")
("insert arccos" "vloşit arccos")
("insert arcsin" "vloşit arcsin")
("insert arctan" "vloşit arctan")
("insert arg" "vloşit arg")
("insert argument" "vloşte argument")
("insert automatically generated content" "vloşit automaticky generovaný obsah")
("insert big contour integral" "vloşit integrál po k°ivce")
("insert big coproduct" "vloşit velký coproduct")
("insert big direct sum" "vloşit velké plus v koleŁku")
("insert big dotted point" "vloşit velkou teŁku v koleŁku")
("insert big integral" "vloşit velký integrál")
("insert big intersection" "vloşit velký prˇnik")
("insert big logical and" "vloşit velkou konjunkci")
("insert big logical or" "vloşit velkou disjunkci")
("insert big product" "vloşit velký souŁin")
("insert big square union" "vloşit velké hranaté sjednocení")
("insert big summation" "vloşit velkou sumu")
("insert big tensor product" "vloşit velký souŁin tenzorˇ")
("insert big union" "vloşit velké sjednocení")
("insert big union sum" "vloşit velký sjednocující souŁet")
("insert big vertical space" "vloşit velkou svislou mezeru")
("insert chapter" "vloşit kapitolu")
("insert column" "vloşit sloupec")
("insert column to the left" "vloşit sloupec nalevo")
("insert column to the right" "vloşit sloupec napravo")
("insert cos" "vloşit cos")
("insert cosh" "vloşit cosh")
("insert cot" "vloşit cot")
("insert coth" "vloşit coth")
("insert csc" "vloşit csc")
("insert deg" "vloşit deg")
("insert det" "vloşit det")
("insert dim" "vloşit dim")
("insert dollar" "vloşit dolar")
("insert equation" "vloşit rovnici")
("insert executable markup" "vloşit spustitelnou znaŁku")
("insert exp" "vloşit exp")
("insert footnote" "vloşit poznámku pod Łarou")
("insert formula" "vloşit vzorec")
("insert gcd" "vloşit gcd")
("insert hom" "vloşit hom")
("insert horizontal interword space" "vloşit vodorovnou mezislovní mezeru")
("insert image" "vloşit obrázek")
("insert inactive markup" "vloşit neaktivní znaŁku")
("insert inf" "vloşit inf")
("insert ker" "vloşit ker")
("insert lg" "vloşit lg")
("insert lim" "vloşit lim")
("insert liminf" "vloşit liminf")
("insert limsup" "vloşit limsup")
("insert ln" "vloşit ln")
("insert log" "vloşit log")
("insert mathematics" "vloşit matematiku")
("insert max" "vloşit max")
("insert medium horizontal space" "vloşit st°ední vodorovnou mezeru")
("insert medium vertical space" "vloşit st°ední svislou mezeru")
("insert min" "vloşit min")
("insert negative horizontal space" "vloşit zápornou vodorovnou mezeru")
("insert new item or number" "vloşit novou poloşku")
("insert new rows or columns" "voşit nové °ádky nebo sloupce")
("insert or delete rows or columns" "vloşit nebo smazat °ádky nebo sloupce")
("insert row" "vloşit °ádek")
("insert row above" "vloşit °ádek nad")
("insert row below" "vloşit °ádek pod")
("insert sec" "vloşit sec")
("insert section" "vloşit sekci")
("insert sharp" "vloşit k°íşek")
("insert sin" "vloşit sin")
("insert sinh" "vloşit sinh")
("insert small horizontal space" "vloşit malou vodorovnou mezeru")
("insert small vertical space" "vloşit malou svislou mezeru")
("insert structural markup" "vloşit strukturovanou znaŁku")
("insert subsection" "vloşit podsekci")
("insert subsubsection" "vloşit podpodsekci")
("insert sup" "vloşit sup")
("insert tan" "vloşit tan")
("insert tanh" "vloşit tanh")
("insert thick horizontal space" "vloşit velkou vodorovnou mezeru")
("interfacing" "rozhraní")
("interfacing TeXmacs with other systems" "rozhraní TeXmacsu s jinými systémy")
("interjection" "citoslovce")
("interline separation" "oddĽlené °ádkˇ")
("interline space" "mezera mezi °ádky")
("internationalization" "lokalizace")
("interparagraph space" "mezera mezi odstavci")
("interrupt execution" "p°eru˛it spu˛tĽní")
("introduction" "úvod")
("invisible" "neviditelný")
("invisible citation" "neviditelná citace")
("irish" "irský")
("is running" "je spu˛tĽn")
("is tuple" "je n-tice")
("ispell does not respond" "ispell neodpovídá")
("ispell is already busy" "ispell jiş pracuje")
("italian" "ital˛tina")
("italic" "kurzíva")
("italic right" "kurzíva vpravo")
("itemize" "neŁíslovaný seznam")
("january" "leden")
("japanese" "japon˛tina")
("july" "Łervenec")
("june" "Łerven")
("justified" "zarovnání")
("justify text" "p°eformátovat text")
("key" "klávesa")
("keyboard" "klávesnice")
("keyboard equivalent" "klávesová zkratka")
("keyboard modifiers" "klávesové modifikátory")
("keyboard shortcut" "klávesová zkratka")
("keymaps" "mapování kláves")
("keyword" "klíŁové slovo")
("keywords" "klíŁová slova")
("kill" "zabít")
("known bugs" "známé chyby")
("label" "popisek")
("landscape" "na ˛í°ku")
("language" "jazyk")
("large" "vĽt˛í")
("large closing bracket" "velká uzavírací závorka")
("large delimiter" "velký omezovaŁ znakˇ")
("large opening bracket" "velké otevírací závorka")
("large separator" "velký oddĽlovaŁ")
("last indentation" "poslední odsazení")
("last page" "poslední strana")
("latex command" "p°íkaz pro latex")
("latin" "latinka")
("layout" "vzhled")
("left" "levý")
("left border" "levý okraj")
("left margin" "levý okraj")
("left padding" "levé odskoŁení")
("left prime" "levá Łárka")
("left aligned" "zarovnání doleva")
("left slanted" "sklonĽné doleva")
("left subscript" "dolní index vlevo")
("left superscript" "horní index vlevo")
("left surrounding" "levé okolí")
("legal" "legal")
("lemma" "lemma")
("length" "délka")
("less" "men˛í")
("less or equal" "men˛í nebo rovno")
("letter" "dopis")
("license" "licence")
("light" "jemné")
("limitations" "omezení")
("limits" "limity")
("line" "°ádek")
("line break" "zalomení °ádku")
("line stretch" "roztáhnutí °ádky")
("link" "odkaz")
("link image" "propojit obrázek")
("list" "seznam")
("list of figures" "seznam obrázkˇ")
("list of tables" "seznam tabulek")
("load" "otev°ít")
("load LaTeX file" "otev°ít soubor LaTeX")
("load TeX file" "otev°ít soubor TeX")
("load TeXmacs file" "otev°ít soubor TeXmacs")
("load TeXmacs style file" "otev°ít soubor stylu TeXmacs")
("load a file" "otev°ít soubor")
("load buffer" "otev°ít snímek")
("load file" "otev°ít soubor")
("load html file" "otev°ít soubor html")
("load image" "otev°ít obrázek")
("load in new window" "nahrát do nového okna")
("load latex file" "otev°ít soubor LaTeX")
("load more recent autosave file" "otev°ít novĽj˛í soubor automatické zálohy")
("load tex file" "otev°ít soubor TeX")
("load verbatim file" "otev°ít soubor verbatim")
("loaded" "otev°eno")
("long" "protaşené")
("look and feel" "vzhled a chování")
("look up" "vyhledat")
("lower border" "dolní okraj")
("macro" "makro")
("magenta" "fialová")
("magic" "kouzelný")
("magnification" "zvĽt˛ení")
("magnified" "zvĽt˛eno")
("main" "hlavní")
("main icon bar" "hlavní panel nástrojˇ")
("major changes" "hlavní zmĽny")
("make a page insertion" "vloşení stránky")
("make a subscript" "dolní index")
("make a superscript" "horní index")
("make acute" "vloşit Łárku")
("make bar" "vloşit pruh")
("make check" "vloşit háŁek")
("make fraction" "vloşit zlomek")
("make grave" "vloşit obrácenou Łárku")
("make hat" "vloşit st°í˛ka")
("make label" "vytvo°it návĽ˛tí")
("make negation" "vloşit negaci")
("make page reference" "vytvo°it odkaz na stranu")
("make reference" "vytvo°it odkaz")
("make square root" "vloşit odmocninu")
("make tilde" "vloşit vlnka")
("make title" "vytvo°it titul")
("make vector" "vloşit vektor")
("making donations" "finanŁní podpora")
("manual" "p°íruŁka")
("map to" "p°i°azení k")
("march" "b°ezen")
("margins" "okraje")
("margins as on paper" "okraje jako na papí°e")
("master" "hlavní")
("master file" "hlavní soubor")
("math" "matika")
("math font" "písmo pro matematiku")
("math font family" "rodina písma pro matematiku")
("math font series" "série písma pro matematiku")
("math font shape" "tvar písma pro matematiku")
("mathematical" "matematický")
("mathematical formulas" "matematické vzorce")
("mathematical typesetting" "matematická sazba")
("mathematics" "matematika")
("matrix" "matice")
("maximal number of columns" "nejvy˛˛í poŁet sloupcˇ")
("maximal number of rows" "nejvy˛˛í poŁet °ádkˇ")
("maximum mode" "nejvy˛˛í reşim")
("may" "kvĽten")
("medium" "st°ední")
("medium skip" "st°ední odstup")
("meminfo" "informace o pamĽti")
("merge" "spojit")
("messy" "messy")
("meta key" "meta klávesa")
("middle" "prost°edek")
("minimal number of columns" "nejmen˛í poŁet sloupcˇ")
("minimal number of rows" "nejmen˛í poŁet °ádkˇ")
("minimum mode" "nejmen˛í reşim")
("minus" "mínus")
("miscellaneous" "rˇzné")
("mod" "modulo")
("mode" "reşim")
("modifier" "modifikátor")
("modify cell alignment" "zmĽnit zarovnání buŹky")
("modify cell border" "zmĽnit okraj buŹky")
("modify cell padding" "zmĽnit odskok buŹky")
("modify cell size" "zmĽnit velikost buŹky")
("modify table border" "zmĽnit okraj tabulky")
("modify table padding" "zmĽnit rozestup bunĽk")
("mongolian" "mongolský")
("more information about GNU TeXmacs can be found in the help" "Více informací o GNU TeXmacs mˇşete najít v nápovĽdĽ")
("mosaic" "mozaika")
("move down" "p°esunout dolˇ")
("move object" "p°esun objektu")
("move to the right when finished" "p°esunout vpravo po ukonŁení")
("move up" "p°esunout nahoru")
("n-th" "n-tá")
("n-th root" "n-tá odmocnina")
("name" "jméno")
("negation" "negace")
("new" "nový")
("new buffer" "nový snímek")
("new column" "nový sloupec")
("new item" "nová poloşka")
("new line" "nový °ádek")
("new number" "nové Łíslo")
("new page" "nová stránka")
("new page before" "nová strana p°ed")
("new paragraph" "nový odstavec")
("new roman" "new roman")
("new row" "nový °ádek")
("new table" "nová tabulka")
("next line" "dal˛í °ádek")
("no" "ne")
("no changes need to be saved" "şádné zmĽny pro uloşení")
("no dictionary for" "chybí slovník")
("no first indentation" "neodsazovat první")
("no indentation" "bez odsazení")
("no last indentation" "neodsazovat poslední")
("no line break" "nezalamovat °ádek")
("no matches found" "nic nenalezeno")
("no more matches for" "nelze nalézt dal˛í")
("no more redo information available" "není moşné provést akci 'znovu'")
("no more undo information available" "není moşné provést akci 'zpĽt'")
("no name" "bezejména")
("no page break after" "nezalamovat stránku za")
("no page break before" "nezalamovat stránku p°ed")
("no spelling errors found in text" "nebyly nalezeny pravopisné chyby")
("no style" "şádný styl")
("none" "şádné")
("normal" "normální")
("norwegian" "norský")
("not" "non")
("not equal" "nerovno")
("not found" "nenalezen")
("notation" "notace")
("note" "poznámka")
("november" "listopad")
("number" "Łíslo")
("number equation" "Łíslovat rovnice")
("number of columns" "poŁet sloupcˇ")
("numbered equation" "Łíslovaná rovnice")
("numbered equations" "Łíslovaná soustava rovnic")
("numerator" "Łitatel")
("numeric" "Łíselné")
("objectives" "cíle")
("occurrences" "výskytˇ")
("october" "°íjen")
("odd page footer" "zápatí liché stránky")
("odd page header" "záhlaví liché stránky")
("odd page margin" "okraj liché stránky")
("odd page text" "text liché stránky")
("off" "vypnuto")
("ok" "ok")
("old english" "staroanglický")
("old slavonic" "staroslovĽnský")
("old style" "starý styl")
("on" "zapnuto")
("on cells" "na buŹky")
("on columns" "na sloupce")
("on entire table" "na celou tabulku")
("on rows" "na °ádky")
("one spelling error has been corrected" "jedna pravopisná chyba opravena")
("online documentation" "online dokumentace")
("online help" "online nápovĽda")
("open" "otev°ít")
("open a new buffer" "otev°ít nový snímek")
("open new window" "otev°ít nové okno")
("opening" "otevírání")
("operation on named selection" "operace s pojmenovaným výbĽrem")
("operation on primary selection" "operace s primárním výbĽrem")
("operation on secondary selection" "operace se sekundárním výbĽrem")
("operation on ternary selection" "operace s terciárním výbĽrem")
("optical" "optical")
("option" "nastavení")
("options" "nastavení")
("or" "nebo")
("orange" "oranşová")
("orientation" "orientace")
("origin" "pˇvod")
("original welcome message" "pˇvodní p°ivítací hlá˛ka")
("other" "jiný")
("other pages" "jiné stránky")
("other projects" "jiné projekty")
("other style" "jiný styl")
("outlined roman" "roman obrysový")
("over" "nad")
("padding" "odskakování")
("page" "strana")
("page bottom margin" "dolní okraj stránky")
("page break" "zalomení stránky")
("page break before" "zlom strany p°ed")
("page height" "vý˛ka stránky")
("page insertion" "vloşení stránky")
("page layout" "vzhled stránky")
("page number text" "text pro Łíslování stran")
("page numbering" "Łíslování stránek")
("page reference" "odkaz na stránku")
("page right margin" "pravý okraj stránky")
("page top margin" "horní okraj stránky")
("page type" "typ stránky")
("page width" "˛í°ka stránky")
("paper" "papír")
("paper type" "velikost papíru")
("papyrus" "papyrus")
("paragraph" "odstavec")
("paragraph mode" "reşim odstavce")
("paragraph width" "˛í°ka odstavce")
("part" "Łást")
("past changes" "minulé zmĽny")
("paste" "vloşit")
("paste from" "vloşit ze schránky")
("paste text" "vloşit text")
("path" "cesta")
("perform operations on cells" "provést operace na buŹkách")
("perform operations on columns" "provést operace na sloupcích")
("perform operations on entire table" "provést operace na celé tabulce")
("perform operations on rows" "provést operace na °ádcích")
("permanent" "permanentní")
("person" "osoba")
("personal dictionary has been modified" "osobní slovník byl zmĽnĽn")
("phantasy" "fantazie")
("philosophy" "filosofie")
("phoenician" "fénický")
("phonetic" "fonetický")
("pink" "rˇşová")
("plain block" "prostý blok")
("plain tabular" "prostá tabulka")
("planned changes" "plánované zmĽny")
("plans for the future" "plány do budoucna")
("please" "prosím")
("please wait" "Łekejte, prosím")
("plus" "plus")
("polish" "pol˛tina")
("porting TeXmacs to other platforms" "portace TeXmacsu na dal˛í platformy")
("portrait" "portrét")
("portuguese" "portugal˛tina")
("position" "pozice")
("position float" "umístit plovoucí")
("position floating object" "umístit plovoucí objekt")
("position the table" "umístit tabulku")
("postscript" "postscript")
("postscript image" "postscriptový obrázek")
("pre-alpha release" "pre-alpha release")
("preamble" "preambule")
("preamble mode" "reşim preambule")
("preferences" "nastavení")
("presentation mode" "reşim prezentace")
("preview before printing" "náhled p°ed tiskem")
("preview with ghostview" "náhled p°es ghostview")
("primary" "první")
("prime" "Łárka")
("print" "tisknout")
("print all" "tisknout v˛e")
("print all to file" "tisknout do souboru")
("print page selection" "tisknout výbĽr stran")
("print page selection to file" "tisknout výbĽr stran do souboru")
("print to postscript file" "tisknout do postscriptového souboru")
("printer" "tiskárna")
("printer dpi" "dpi tiskárny")
("printing command" "p°íkaz pro tisk")
("problem" "p°íklad")
("professional" "profesionální")
("prog" "prog")
("prog font" "písmo pro programy")
("prog font family" "rodina písma pro programy")
("prog font series" "série písma pro programy")
("prog font shape" "tvar písma pro programy")
("program" "program")
("program mode" "reşim programu")
("programming" "programování")
("progressive" "progresívní")
("project" "projekt")
("projects" "projekty")
("prologue" "prolog")
("prompt on scripts" "dotázat se p°i skriptu")
("proof" "dˇkaz")
("proportional" "proporcionální")
("proportional typewriter" "proporcionální psací stroj")
("proposition" "tvrzení")
("query replace" "dotázat se p°ed náhradou")
("quit" "konec")
("quotation" "citát")
("quote" "uvozovky")
("range" "rozsah")
("really close it" "opravdu uzav°ít")
("really huge" "vskutku velký")
("really quit" "opravdu ukonŁit")
("red" "Łervená")
("redo" "znovu")
("redo undone changes" "znovu poslední úpravy")
("reduce bottom margin by" "zmen˛it dolní okraj o")
("reduce left margin by" "zmen˛it levý okraj o")
("reduce margins" "zmen˛it okraje")
("reduce right margin by" "zmen˛it pravý okraj o")
("reduce top margin by" "zmen˛it horní okraj o")
("reduction even page margin" "zmen˛ení okraje sudé stránky")
("reduction odd page margin" "zmen˛ení okraje liché stránky")
("reduction page bottom margin" "zmen˛ení dolního okraje stránky")
("reduction page right margin" "zmen˛ení pravého okraje stránky")
("reduction page top margin" "zmen˛ení horního okraje stránky")
("reference" "reference")
("references" "odkazy")
("regular" "regulární")
("release" "release")
("reload" "znova nahrát")
("remark" "anotace")
("remove number" "odebrat Łíslo")
("remove this switch" "odebrat p°epínaŁ")
("renumber this page" "znovu oŁíslovat tuto stranu")
("repeat object" "zopakovat objekt")
("replace" "nahradit")
("replace by" "nahradit")
("replaced" "nahrazeno")
("replaced one occurrence" "nahrazen jeden výskyt")
("reset" "reset")
("resize object" "zmĽna rozmĽrˇ objektu")
("resized" "zmĽnĽny rozmĽry")
("return" "return")
("revert" "zpĽt")
("revert buffer" "obnovit snímek")
("right" "pravý")
("right border" "pravý okraj")
("right margin" "pravý okraj")
("right padding" "odskakování vpravo")
("right aligned" "zarovnání doprava")
("right subscript" "dolní index vpravo")
("right superscript" "horní index vpravo")
("right surrounding" "pravé okolí")
("rigid" "pevná")
("rigid horizontal" "pevný ")
("rigid space" "pevná mezera")
("romanian" "rumun˛tina")
("root" "ko°en")
("rotate backward" "p°etoŁit nazpĽt")
("rotate forward" "p°etoŁit dop°edu")
("row" "°ádek")
("row contains glued items" "°ádek obsahuje p°ilepené poloşky")
("runic" "runy")
("running author" "autor")
("running title" "titul (název)")
("russian" "ru˛tina")
("russian and Ukrainian users" "uşivatelé z Ruska a Ukrajiny")
("sample" "p°íklad")
("sans serif" "bez patek")
("save" "uloşit")
("save TeXmacs file" "uloşit soubor TeXmacs")
("save TeXmacs style file" "uloşit soubor stylu TeXmacs")
("save as" "uloşit jako")
("save as LaTeX" "uloşit jako LaTeX")
("save as TeX" "uloşit jako TeX")
("save buffer" "uloşit snímek")
("save buffer as" "uloşit snímek jako")
("save file" "uloşit soubor")
("save html file" "uloşit soubor html")
("save image" "uloşit obrázek")
("save latex file" "uloşit soubor LaTeX")
("save tex file" "uloşit soubor TeX")
("save this buffer" "uloşit tento snímek")
("save verbatim file" "uloşit soubor verbatim")
("saved" "uloşeno")
("screen layout" "rozvrşení obrazovky")
("screen margins" "okraje na obrazovce")
("script" "indexy")
("script above" "index nad")
("script below" "index pod")
("script script size" "velikost indexu indexu")
("script size" "velikost indexu")
("scripts not accepted" "skripty nejsou povoleny")
("search" "hledat")
("searching" "hledám")
("secondary" "druhá")
("section" "sekce")
("security" "zabezpeŁení")
("see" "viz")
("select a document style" "vyberte styl dokumentu")
("select a foreground color" "vybrat barvu pop°edí")
("select a language" "vyberte jazyk")
("selected region" "vybraná oblast")
("selection" "výbĽr")
("selections" "výbĽry")
("seminar" "seminá°")
("separation between lines" "oddĽlení °ádkˇ")
("separation between paragraphs" "oddĽlení odstavcˇ")
("separator" "oddĽlovaŁ")
("september" "zá°í")
("serb" "srbský")
("series" "série")
("series|right" "série|right")
("session" "sezení")
("session name" "jméno sezení")
("session type" "typ sezení")
("sessions" "sezení")
("set" "nastavit")
("set background color of cell" "nastavit barvu pozadí buŹky")
("set cell mode" "nastavit reşim buŹky")
("set extension center" "nastavit st°ed roz˛í°ení")
("set height" "nastavit vý˛ku")
("set height of cell" "nastavit vý˛ku buŹky")
("set margins" "nastavit okraje")
("set n" "nastavte n")
("set paragraph margins" "nastavit okraje odstavce")
("set paragraph mode" "nastavit reşim odstavce")
("set printer dpi" "nastavení dpi tiskárny")
("set printing command" "nastavení tiskového p°íkazu")
("set span" "nastavit rozpĽtí")
("set special cell properties" "nastavit spec. vlastnosti buŹky")
("set special table properties" "nastavit spec. vlastnosti tabulky")
("set text width" "nastavit ˛í°ku textu")
("set width" "nastavit ˛í°ku")
("set width of cell" "nastavit ˛í°ku buŹky")
("settings" "nastavení")
("setup printer" "nastavení tiskárny")
("shape" "tvar")
("shift-down" "shift-dolˇ")
("shift-right" "shift-doprava")
("show" "ukázat")
("show header and footer" "ukazovat záhlaví a zápatí")
("show on screen" "na obrazovku")
("shrinking factor" "zmen˛ení")
("signature" "podpis")
("size" "velikost")
("size limits" "omezení velikosti")
("slanted" "sklonĽné")
("sloppy" "nedbalý")
("small" "men˛í")
("small caps" "kapitálky")
("small figure" "malý obrázek")
("small skip" "malý odstup")
("small table" "malá tabulka")
("source code" "zdrojový kód")
("space" "mezera")
("space between lines" "mezery mezi °ádky")
("space between paragraphs" "mezery mezi odstavci")
("spacing" "prokládání")
("spanish" "˛panĽl˛tina")
("special" "speciální")
("special cell properties" "spec. vlastnosti buŹky")
("special table properties" "spec. vlastnosti tabulky")
("specific" "specifický")
("spell" "pravopis")
("spell checking complete" "kontrolo pravopisu dokonŁena")
("spelling error" "pravopisná chyba")
("spelling errors have been corrected" "pravopisné chyby byly opraveny")
("split" "oddĽlit")
("square root" "odmocnina")
("start" "zaŁátek")
("start a new chapter" "zaŁít novou kapitolu")
("start a new section" "zaŁít novou sekci")
("start an interactive session" "spustit interaktivní sezení")
("status bar" "stavový °ádek")
("stretchable" "zvĽt˛itelná")
("stretchable horizontal" "vodorovnĽ roz˛i°itelná")
("stretchable vertical" "svisle prodlouşitelná")
("stroke" "p°e˛krtnutí")
("strokes" "p°e˛krtnutí")
("strong" "silnĽ")
("structural" "strukturovanĽ")
("style" "styl")
("styles" "styly")
("sub" "pod-")
("subparagraph" "pododstavec")
("subscript" "dolní index")
("subsection" "podsekce")
("subsub" "podpod-")
("subsubsection" "podposekce")
("summary" "souhrn")
("summary of the principal TeXmacs tags" "souhrn hlavních tegˇ TeXmacsu")
("superpose" "superpozice")
("superposed" "superponován")
("superscript" "horní index")
("swedish" "˛véd˛tina")
("switch" "p°epínaŁ")
("switch to first" "první p°epínaŁ")
("switch to formula style" "p°epnout do stylu vzorcˇ")
("switch to last" "poslední p°epínaŁ")
("switch to next" "dal˛í p°epínaŁ")
("switch to previous" "p°edchozí p°epínaŁ")
("switching and folding" "p°epínání a balení")
("symbol" "symbol")
("system environment variables" "systémové promĽnné")
("tab" "tab")
("table" "tabulka")
("table command" "p°íkaz tabulky")
("table of contents" "obsah")
("tables" "tabulky")
("tabular" "tabulovat")
("tabular material" "tabelární materiál")
("teXmacs as an interface" "TeXmacs jako rozhraní")
("teXmacs fonts" "fonty TeXmacsu")
("teXmacs notice" "poznámka TeXmacsu")
("teXmacs style files" "soubory se styly TeXmacsu")
("ternary" "t°etí")
("test" "test")
("tex" "TeX")
("text" "text")
("text font" "písmo pro text")
("text height correction" "oprava vý˛ky textu")
("text width" "˛í°ka textu")
("texts" "texty")
("th century bc" "th century bc")
("th root" "-tá odmocnina")
("thai" "thai")
("the TeXmacs authors" "auto°i TeXmacsu")
("the application did not send its usual startup banner" "aplikace nezaslala obvyklou startovací zprávu")
("the application does not reply" "aplikace neodpovídá")
("the application is already running" "aplikace je jiş spu˛tĽna")
("the boxes produced by the typesetter" "boxy produkované sazeŁem")
("the graphical user interface" "grafické uşivatelské rozhraní")
("the leaves of TeXmacs trees" "listy stromu TeXmacsu")
("the mycas example" "p°íklad mycas")
("the primitive TeXmacs constructs" "primitivní konstrukty TeXmacsu")
("the standard TeXmacs styles" "standardní styly TeXmacsu")
("theorem" "teorém")
("there are unsaved documents" "nĽkteré soubory nejsou uloşeny")
("this document has not been saved" "tento snímek nebyl uloşen")
("this document has been produced using" "tento dokumenty byl vytvo°en pouşitím")
("this line" "tento °ádek")
("this page" "tato stránka")
("tilda" "tilda")
("tilde" "vlnka")
("times" "times")
("tiny" "mrŹavý")
("title" "titul")
("to the left" "nalevo")
("to the right" "napravo")
("today" "dnes")
("tools" "nástroje")
("top" "vrch")
("top border" "horní okraj")
("top level" "nejvy˛˛í úroveŹ")
("top margin" "horní okraj")
("top padding" "horní odskok")
("translate" "p°eloşit")
("tree" "strom")
("tuple" "n-tice")
("turkish" "turecký")
("tutorial" "prˇvodce zaŁáteŁníka")
("type" "typ")
("type a latex command followed by" "napi˛tĽ p°íkaz pro latex následovaný")
("type body" "napi˛te tĽlo")
("type denominator" "napi˛tĽ jmenovatel")
("type numerator" "napi˛tĽ Łitatel")
("type script" "napi˛te skript")
("typesetted boxes" "sázení boxˇ")
("typewriter" "psací stroj")
("typewriter small caps" "psací stroj kapitálky")
("typing a simple text" "psaní jednoduchého textu")
("typing simple texts" "psaní jednoduchých textˇ")
("ugaritic" "ugaritic")
("ukrainian" "ukrajin˛tina")
("undo" "zpĽt")
("undo last changes" "zpĽt poslední úpravy")
("up" "nahoru")
("update" "obnovit")
("update from web" "aktualizace z webu")
("update image links" "aktualizovat odkazy obrázkˇ")
("upper border" "horní okraj")
("use TeXmacs" "pouşívejte TeXmacs")
("use a black color" "pouşít Łernou barvu")
("use a blue color" "pouşít modrou barvu")
("use a bold font" "pouşít tuŁné písmo")
("use a brown color" "pouşít hnĽdou barvu")
("use a calligraphic font" "pouşít kaligrafické písmo")
("use a green color" "pouşít zelenou barvu")
("use a grey color" "pouşít ˛edou barvu")
("use a magenta color" "pouşít fialovou barvu")
("use a orange color" "pouşít oranşovou barvu")
("use a pink color" "pouşít rˇşovou barvu")
("use a red color" "pouşít Łervenou barvu")
("use a sans serif font" "pouşít bezpatkové písmo")
("use a typewriter font" "pouşít písmo psacího stroje")
("use a white color" "pouşít bílou barvu")
("use a yellow color" "pouşít şlutou barvu")
("use blackboard bold font" "pouşít písmo blackboard")
("use bold font series" "pouşít tuŁné písmo")
("use calligraphical font" "pouşít kaligrafické písmo")
("use footnote font size" "pouşít velikost písma poznámky pod Łarou")
("use fraktur font" "pouşít písmo fraktur")
("use huge font size" "pouşít obrovské písmo")
("use italic font shape" "pouşít kurzívní písmo")
("use large font size" "pouşít vĽt˛í písmo")
("use left hand column as border" "pouşít levý sloupec jako okraj")
("use medium font series" "pouşít polotuŁné písmo")
("use normal font size" "pouşít st°ední písmo")
("use package" "pouşití balíŁku")
("use paragraph width" "pouşít ˛í°ku odstavce")
("use really huge font size" "pouşít vskutku obrovské písmo")
("use right font shape" "pouşít písmo kurzívní vpravo")
("use right hand column as border" "pouşít pravý sloupec jako okraj")
("use roman font family" "pouşít písmo roman")
("use row above as border" "pouşít horní °ádek jako okraj")
("use row below as border" "pouşít spodní °ádek jako okraj")
("use sans serif font family" "pouşít bezpatkové písmo")
("use script font size" "pouşít velikost písma indexu")
("use slanted font shape" "pouşít sklonĽné písmo")
("use small capitals" "pouşít kapitálky")
("use small font size" "pouşít malé písmo")
("use small-caps font shape" "pouşít kapitálky")
("use the blackboard bold font" "pouşít tuŁné písmo blackboard")
("use the fraktur font" "pouşít písmo fraktur")
("use tiny font font size" "pouşít mrŹavé písmo")
("use typewriter font family" "pouşít písmo psacího stroje")
("use very large font size" "pouşít velké písmo")
("user manual" "uşivatelská p°íruŁka")
("user provided icons" "uşivatelské ikony")
("value" "hodnota")
("variable" "promĽnná")
("variant" "variant")
("vector" "vektor")
("verbatim" "verbatim")
("verse" "ver˛")
("vertical" "svislá")
("vertical after" "svislá za")
("vertical before" "svislá p°ed")
("vertical cell alignment" "svislé zarovnání buŹky")
("vertical part" "svislá Łást")
("vertical position" "svislá pozice")
("vertical space" "svislá mezera")
("vertical table alignment" "svislé zarovnání tabulky")
("vertically align cell to the base" "zarovnat buŹku svisle na základnu")
("vertically center the cell" "vyst°edit buŹku svisle")
("very large" "velký")
("very small" "malý")
("vietnamese" "vietnamský")
("view" "pohled")
("visible" "viditelný")
("warning" "varování")
("welcome" "vítejte")
("welcome to GNU TeXmacs" "Vítejte v GNU TeXmacs")
("what is new" "co je nového")
("when finished" "po ukonŁení")
("while" "while")
("white" "bílá")
("wide accent" "˛iroký akcent")
("width" "˛í°ka")
("width is exactly the specified width" "˛í°ka je p°esnĽ podle zadání")
("width is maximum of specified width and box width" "˛í°ka je maximum zadané ˛í°ky a ˛í°ky boxu")
("width is minimum of specified width and box width" "˛í°ka je minimum zadané ˛í°ky a ˛í°ky boxu")
("width magnification" "roz˛í°ení")
("window" "okno")
("window height" "vý˛ka okna")
("window width" "˛í°ka okna")
("windows key" "klávesa windows")
("with" "s")
("write a name" "pouşít kapitálky")
("write bold mathematics" "pouşít tuŁné matematické písmo")
("write bold text" "pouşít tuŁné písmo")
("write italic text" "pouşít kurzívní písmo")
("write sample text" "pouşít bezpatkové písmo")
("write strong text" "pouşít silné písmo")
("write typewriter text" "pouşít písmo psacího stroje")
("write verbatim text" "pouşít reşim verbatim")
("writing data converters" "tvorba konvertorˇ dat")
("writing your own style files" "tvorba va˛ich vlastních souborˇ stylˇ")
("yellow" "şlutá")
("yes" "ano")
("you can also obtain" "mˇşe také získat")
("your document is back in its original state" "vá˛ dokument je opĽt v pˇvodní stavu")
("your first interface" "va˛e první rozhraní")
