("\"encryption\" features from the preference panel" "\"titkosítási\" szolgáltatás a preferencia panelen")
("(Re)Build autocompletion index" "(Újraépítés automatikus kiegészítés indexe)")
("a.C.M. computing class" "min. Számítási osztály")
("a.M.S. subject class" "középiskolai tantárgy")
("abbreviated authors" "rövidített szerz®")
("abreviated authors" "elhagyott szerz®")
("accent above" "ékezetes fent")
("accent below" "ékezetes lent")
("accept during this pass" "elfogadja ezen átadás során")
("acknowledgments" "elismerés")
("add" "hozzáadás")
("add abstract information" "absztrakt információ hozzáadása")
("add author information" "a szerz® adatainak hozzáadása")
("add branch after" "ág hozzáadása után")
("add branch before" "ág hozzáadása el®tt")
("add other package" "további csomag hozzáadása")
("add style package" "stíluscsomag hozzáadása")
("add title information" "címbejegyzés hozzáadása")
("addition" "kiegészítés")
("adjust" "beállítani")
("adjust limits" "határérték beállítása")
("advanced font customization" "speciális bet¶készlet-testreszabás")
("affiliation" "kapcsolat")
("align cell to the decimal comma" "igazítsa a cellát a tizedes vessz®höz")
("align cell to the decimal dot" "igazítsa a cellát a tizedes ponthoz")
("align table at axis" "táblázat összehangolása a tengelyen")
("alignment of balloon" "a ballon beállítása")
("all cells" "minden cella")
("all data attached to this identity will be lost" "az azonosítóhoz csatolt összes adat el fog veszni")
("all saved passphrases will be lost forever" "az összes mentett jelszó örökre elveszik")
("allowed page height extension" "megengedett oldalmagasság-kiterjesztés")
("allowed page height reduction" "megengedett oldalmagasság-csökkentés")
("allowed positions" "megengedett pozíció")
("allowed positions of floating object" "úszó tárgy megengedett pozíciói")
("alpha transparency" "alfa-átlátszóság")
("alter" "alter")
("alternate" "póttag")
("alternate except here" "alternatív, kivéve itt")
("alternate from here on" "innen váltakozva")
("alternate only here" "csak itt váltakozva")
("alternate until here" "váltakozó ideje")
("amplified" "er®sített")
("and perform casual settings from the \"Encryption\" tab" "és végezzen véletlenszer¶ beállításokat a \"Titkosítás\" lapon")
("animate" "animálni")
("animate folding" "animációs hajtogatás")
("animate unfolding" "animációs kibontakozás")
("animated" "animált")
("animation toolbar" "animációs eszköztár")
("annotate" "megjegyzés")
("answer" "válasz")
("answer field" "válasz mez®")
("answer to question" "válasz a kérdésre")
("answers only" "csak válaszok")
("any" "bármilyen")
("appear" "megjelenik")
("approximate" "hozzávet®leges")
("are you sure you want to delete collected public keys" "biztosan törli a gy¶jtött nyilvános kulcsokat")
("are you sure you want to delete selected public keys" "biztosan törli a kiválasztott nyilvános kulcsokat")
("are you sure you want to delete selected secret keys" "biztosan törli a kiválasztott titkos kulcsokat")
("are you sure you want to destroy the wallet" "biztos benne, hogy el akarja pusztítani a pénztárcáját")
("art frame" "képkeret")
("arxiv category" "arxiv kategória")
("as visual grid" "vizuális rácsként")
("aspect" "aspektus")
("attach master" "csatolja a mestert")
("auto" "auto")
("auto-save file" "automatikus mentés fájl")
("automatic brackets" "automatikus zárójel")
("automatic content generation" "automatikus tartalom generálás")
("automatic program brackets" "automatikus programtartó")
("automatically import bibliographies when opening files" "automatikusan bibliográfiákat importál a fájlok megnyitásakor")
("automatically remember all passphrases in the wallet" "automatikusan megjegyzi a pénztárca összes jelszavát")
("automatically save" "automatikus mentés")
("base" "alap")
("beamer" "beamer")
("beamer formats" "beamer formátum")
("beamer theme" "beamer theme")
("bench" "pad")
("bend bottom" "alsó hajlítás")
("bend corner" "kanyar")
("bend diagonal" "hajlítási átló")
("bend in" "hajlítás")
("bend out" "kihajlik")
("bezier" "bezier")
("bibTeX command" "bibTeX parancs")
("big environment box" "nagy környezet doboz")
("big focus" "nagy fókusz")
("binary operator" "bináris operátor")
("bitmap resolution (dpi)" "bitmap felbontás (dpi)")
("black floral I" "fekete virágos I")
("black floral II" "fekete virág II")
("blackboard embold" "tábla beágyazás")
("block" "blokk")
("block of code" "kódblokk")
("blur" "elmosódás")
("both versions" "mindkét változat")
("bottom baseline" "alsó kiindulási alap")
("bottom tools" "alsó szerszám")
("box" "doboz")
("browse back" "visszakeresés")
("browse forward" "böngészés el®re")
("browse modules documentation" "böngészés a modulok dokumentációjában")
("buffer management" "pufferkezelés")
("buffer must be on disk" "puffernek lemezen kell lennie")
("buffer must have a name" "a puffernek nevének kell lennie")
("build buffer" "épít®puffer")
("build buffer in" "puffer beépítése")
("build directory" "épít könyvtár")
("build directory in" "könyvtár készítése")
("build link pages" "linkoldalt épít")
("build-all" "összeszerelés")
("bump" "ütés")
("busy" "elfoglalt")
("cJK" "cJK")
("cJK spacing" "cJK távolság")
("cancelled" "törölve")
("cannot download directory to file" "nem lehet letölteni a könyvtárat a fájlba")
("cannot rename across different servers" "nem tud átnevezni különböz® szerverek között")
("cannot upload directory to file" "nem tudja feltölteni a könyvtárat a fájlba")
("carved wood" "faragott fa")
("case-insensitive search" "a kis- és nagybet¶kre érzékeny keresés")
("categories" "kategória")
("category" "kategória")
("cell properties" "cella tulajdonság")
("change default unit" "alapértelmezett egység módosítása")
("change passphrase" "jelszó módosítása")
("change step-size" "lépésméret megváltoztatása")
("change tags" "címkék megváltoztatása")
("change the TeXmacs preferences" "módosítsa a TeXmacs beállításait")
("change the style of mathematical formulas" "megváltoztatja a matematikai képletek stílusát")
("character contraction" "karakter összehúzódás")
("character encoding" "karakterkódolás")
("character expansion" "karakter kiterjesztés")
("check for updates" "frissítések keresése")
("checkable field" "ellen®rizhet® mez®")
("cipher algorithm for passphrase encryption" "titkosítási algoritmus a jelmondat titkosításához")
("classification" "besorolás")
("clean slate" "tiszta pala")
("clear all fields" "törölje az összes mez®t")
("clear local information" "tiszta helyi információ")
("clear menu" "világos menü")
("clear undo history" "történelem törlése")
("click Ok button twice to discard this warning" "kattintson kétszer az OK gombra a figyelmeztetés elvetéséhez")
("clip" "klip")
("clipboard image format" "vágólap képformátum")
("close animation tool" "bezárási animációs eszköz")
("close program" "bezárási program")
("close replace tool" "csereszerszám bezárása")
("close search tool" "keresési eszköz bezárása")
("close spell tool" "helyesírás-eszköz")
("close translations to rebuild" "közeli fordítások az újjáépítéshez")
("closed bezier" "zárt keret")
("closed curve" "zárt görbe")
("closed smooth" "zárt sima")
("cluster by affiliation" "klaszter tagság szerint")
("collect garbage" "szemetet gy¶jteni")
("collected keys" "összegy¶jtött kulcs")
("color of the axes" "tengelyek színe")
("color of the subunits" "az alegységek színe")
("color of the units" "az egységek színe")
("colors" "szín")
("column separation" "oszlopok elválasztása")
("commit file" "átadási fájl")
("common" "közös")
("commutative diagram" "kommutációs diagram")
("complete bibliographic reference" "teljes bibliográfiai referencia")
("complex actions" "összetett intézkedés")
("compose" "komponálni")
("compound" "vegyület")
("compress" "tömörítés")
("compress into toolbar" "tömörítés az eszköztárba")
("compressed" "tömörített")
("conceal" "elrejteni")
("configure look and feel" "a megjelenés és a hangulat beállítása")
("confirm database entry" "az adatbázis bejegyzésének meger®sítése")
("confirm entry" "meger®sítse a bejegyzést")
("confirm selected database entries" "A kiválasztott adatbázis bejegyzéseinek meger®sítése")
("confirm selected entries" "A kiválasztott bejegyzések meger®sítése")
("conservative conversion options" "konzervatív konverziós lehet®ség")
("consoles" "konzol")
("constellation" "csillagkép")
("context aids" "kontextussegéd")
("contextual hints" "kontextuális tipp")
("continue" "folytatás")
("continued fraction" "folyamatos frakció")
("contour" "kontúr")
("control flow" "vezérl®áram")
("convert" "konvertálni")
("convertible" "kabrió")
("copyright" "szerz®i jog")
("cork charset with TeX catcode definition in preamble" "parafa karakterkészlet a preambulumban szerepl® TeX katódkód-meghatározással")
("correct" "helyes")
("correct all" "minden javítása")
("correct formula" "helyes képlet")
("correct manually" "manuálisan helyes")
("correct mathematical formulas" "helyes matematikai képlet")
("correction" "javítás")
("count characters" "számjegy karakter")
("count lines" "gróf sor")
("count words" "gróf szó")
("create remote directory" "távoli könyvtár létrehozása")
("create remote file" "távoli fájl létrehozása")
("create subprogram" "alprogram létrehozása")
("create subsession" "alszekció létrehozása")
("create table macro" "tábla makró létrehozása")
("creating new account" "új fiók létrehozása")
("creating technical pictures" "m¶szaki képek készítése")
("crop" "termés")
("crop marks" "termésjel")
("cross" "kereszt")
("crossed boxes" "keresztezett doboz")
("crossed circles" "keresztezett kör")
("current user version" "jelenlegi felhasználói verzió")
("current version" "jelenlegi verzió")
("cursor" "kurzor")
("curve intersections" "görbe metszéspont")
("curve points" "görbe pont")
("customizations" "testreszabás")
("customizing and extending the user interface" "a felhasználói felület testreszabása és b®vítése")
("data" "adat")
("database entry" "adatbázis-bejegyzés")
("database tool" "adatbázis eszköz")
("database toolbar" "adatbázis eszköztár")
("dead" "halott")
("debug" "hibakeresés")
("debugging console" "hibakeresési konzol")
("debugging tool" "hibakeres® eszköz")
("decomposed" "bomlik")
("decorated" "díszített")
("decorated wood" "díszített fa")
("decrease size" "méret csökkentése")
("decrypt" "dekódolás")
("default size" "alapértelmezett méret")
("degrade" "lebomlik")
("degraded" "leromlott")
("delete documentation cache" "dokumentációs gyorsítótár törlése")
("delete entries" "bejegyzések törlése")
("deleted" "törölve")
("describe" "leírni")
("describe tag" "leíró címke")
("destroy" "elpusztítani")
("detach master" "leválasztó mester")
("determine margins from text width" "a margók meghatározása a szöveg szélessége alapján")
("developer" "fejleszt®")
("developer tool" "fejleszt®i eszköz")
("device" "eszköz")
("diamond" "gyémánt")
("dilate" "dilate")
("direction of progression" "a haladás iránya")
("direction of translation" "fordítási irány")
("disable coloring on paper" "letiltja a papíron történ® színezést")
("disable encryption" "letiltja a titkosítást")
("disappear" "elt¶nik")
("display style" "megjelenítési stílus")
("displayed formula" "megjelenített képlet")
("dissociate joined cells" "disszociált összekapcsolt sejtek")
("distort" "torz")
("distorted" "torz")
("division" "osztály")
("document font selector" "dokumentum bet¶készlet-választó")
("document language" "dokumentumnyelv")
("document page format" "dokumentumoldal formátuma")
("document paragraph format" "dokumentum bekezdés formátum")
("document updates run" "dokumentumfrissítés fut")
("downwards" "lefelé")
("dragging" "húzás")
("draw over" "áthúzás")
("drop" "csepp")
("due to" "miatt")
("dynamic" "dinamikus")
("eRROR" "eRROR")
("edit animation" "animáció szerkesztése")
("edit groups of objects" "objektumcsoportok szerkesztése")
("edit macro" "makró szerkesztése")
("edit macros" "makrók szerkesztése")
("edit preamble" "preambulum szerkesztése")
("edit source" "forrás szerkesztése")
("edit style" "szerkesztési stílus")
("edit translations file" "fordítási fájl szerkesztése")
("education" "oktatás")
("effect pen" "toll")
("eighth" "nyolcadik")
("embold" "embold")
("emboss" "dombornyomás")
("enable page breaking" "engedélyezze az oldal törését")
("encrypt" "titkosítás")
("encryption" "titkosítás")
("encryption facilities are not currently available" "titkosítási lehet®ségek jelenleg nem állnak rendelkezésre")
("encryption facilities have not been enabled for TeXmacs" "titkosítási lehet®ségek nem engedélyezettek a TeXmacs számára")
("enforce brackets to match" "szögletes zárójelek érvényesítése")
("engrave" "metszet")
("enter data" "adatbevitel")
("enter graphics" "enter grafika")
("enter graphics mode" "belépés a grafikus módba")
("enter new passphrase for encryption" "új jelszó beírása a titkosításhoz")
("enter passphrase for decryption" "írja be a jelszót a dekódoláshoz")
("enter passphrase for identity" "írja be az azonosító jelmondatát")
("enter title information" "írja be a cím információit")
("entry up to date in database" "naprakész bejegyzés az adatbázisban")
("enunciation" "felszólalás")
("environment variable" "környezeti változó")
("environments" "környezet")
("erode" "erode")
("error messages" "hibaüzenet")
("error output" "hiba output")
("error status report" "hibaállapot-jelentés")
("error: bracket does not match" "hiba: a zárójel nem egyezik")
("error: cyclic or missing chunks detected" "hiba: ciklikus vagy hiányzó darabokat észleltek")
("error: file not found" "hiba: a fájl nem található")
("error: ghostview does not seem to be installed on your system" "hiba: Úgy t¶nik, hogy a ghostview nincs telepítve a rendszerére")
("error: one of the alternatives should be filled out" "hiba: az alternatívák egyikét ki kell tölteni")
("error: only one alternatives should be filled out" "hiba: csak egy alternatívát kell kitölteni")
("error: should fill out name for referencing" "hiba: kitöltenie kell a hivatkozás nevét")
("error: should fill out required field" "hiba: kitöltenie kell a kötelez® mez®t")
("evaluable field" "értékelhet® mez®")
("evaluate above" "értékelje fent")
("evaluate all" "mindet értékel")
("evaluate below" "az alábbiak értékelése")
("evaluate fields" "mez®k értékelése")
("evaluate fields in order" "mez®k értékelése sorrendben")
("evaluate script" "szkript értékelése")
("evaluation" "értékelés")
("even page" "páros oldal")
("even pages" "páros oldal")
("events" "esemény")
("execution of scripts" "szkriptek végrehajtása")
("exit graphics" "exit grafika")
("exit graphics mode" "kilépési grafikus mód")
("exit left" "kilépés balra")
("exit right" "kijárat jobbra")
("exit tag on the left" "kilépési címke a bal oldalon")
("exit tag on the right" "kilépési címke a jobb oldalon")
("expand TeXmacs macros with no LaTeX equivalents" "kib®vítse a TeXmacs makrókat LaTeX-ekvivalensek nélkül")
("expand beamer slides" "beamer diák kib®vítése")
("expand inclusions" "kib®vítések")
("expanded" "kib®vített")
("experimental features (to be used with care)" "kísérleti szolgáltatások (gondosan kell használni)")
("explain" "magyarázza")
("explanatory item" "magyarázó pont")
("explicit keystroke" "explicit billenty¶leütés")
("explicit margins" "kifejezett árrés")
("export bibliography" "export bibliográfia")
("export entries in buffer" "pufferbejegyzés exportálása")
("export file" "export fájl")
("export mathematical formulas as MathML" "matematikai képletek exportálása MathML formátumban")
("export mathematical formulas as images" "matematikai képletek exportálása képként")
("export selected entries" "Kiválasztott bejegyzések exportálása")
("export selection" "export kiválasztás")
("export selection as image" "Kiválasztás exportálása képként")
("export selections as" "export kiválasztás mint")
("export sessions" "export ülés")
("exported bibliographic entries" "exportált bibliográfiai adatok")
("exported bibliographic references" "exportált bibliográfiai hivatkozások")
("extend" "kiterjesztés")
("extended" "kib®vített")
("extensible left arrow" "kinyitható bal nyíl")
("extensible right arrow" "kinyitható jobb nyíl")
("extern" "küls®")
("extra branch" "extra ág")
("extra interline space" "extra interline space")
("extra name" "extra név")
("extract" "kivonat")
("extract style file" "kivonat stílus fájl")
("extract style package" "kivonatstílus-csomag")
("fade" "fade")
("fade in" "fade in")
("fade out" "fade out")
("fast" "gyors")
("fast decrease" "gyors csökkenés")
("fast environments" "gyors környezet")
("fast increase" "gyors növekedés")
("field reference" "terepi hivatkozás")
("fifth" "ötödik")
("file saved" "fájl mentve")
("fill out" "kitölteni")
("filter" "sz¶r®")
("find file" "fájl keresése")
("finished collecting symbols documentation" "kész a szimbólumok gy¶jtésének dokumentációja")
("first" "els®")
("first chunk" "els® darab")
("first difference" "els® különbség")
("first error" "els® hiba")
("first field" "els® mez®")
("first occurrence" "els® el®fordulás")
("first similar" "els® hasonló")
("fit to screen" "képerny®höz illeszked®")
("fit to screen width" "illeszkedik a képerny® szélességéhez")
("five columns" "öt oszlop")
("flag is off" "zászló ki van kapcsolva")
("flag is on" "jelz® világít")
("flatten" "lapos")
("floating algorithm" "lebeg® algoritmus")
("floating phantom" "úszó fantom")
("focus" "fókusz")
("focus dependent icons" "fókusztól függ® ikonok")
("fold all" "mindet összehajt")
("fold all fields" "összes mez® hajtása")
("fold back" "hajtás vissza")
("font effects" "bet¶típus-effektusok")
("font selector" "bet¶készlet-választó")
("for each" "mindegyiknél")
("force reloading of translations" "A fordítások újratelepítése")
("four columns" "négy oszlop")
("four dots" "négy pont")
("fourth" "negyedik")
("fraktur" "fraktur")
("framed" "keretes")
("from" "-tól")
("from center" "a központtól")
("full" "tele")
("full author list" "teljes szerz®k listája")
("gap" "rés")
("garbage collection" "szemetes gy¶jtés")
("gaussian" "gaussian")
("general" "általános")
("generated LaTeX document contains no errors" "a létrehozott LaTeX dokumentum nem tartalmaz hibát")
("generated field" "létrehozott mez®")
("get arity" "kap aritást")
("get label" "szerezz címkét")
("get list with remote versions" "letöltési lista távoli verziókkal")
("glyphs" "karakterjelek")
("gnaw" "rágás")
("gnawed" "harapott")
("gnuPG command" "gnuPG parancs")
("gnuPG error: buffer encryption failed" "gnuPG hiba: a puffer-titkosítás sikertelen")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG hiba: nem található megfelel® titkos kulcs a dekódoláshoz")
("gnuPG requires name and email to have at least 5 characters" "gnuPG név és e-mail legalább 5 karakterb®l áll")
("go to anchor" "horgonyzásra")
("go to anchor or float" "horgonyzáshoz vagy úszóhoz")
("go to anchor or footnote" "rögzítéshez vagy lábjegyzethez")
("go to first similar tag" "ugrás az els® hasonló címkére")
("go to float" "úszni")
("go to footnote" "megy a lábjegyzethez")
("go to last similar tag" "Ugrás az utolsó hasonló címkére")
("go to next similar tag" "ugrás a következ® hasonló címkére")
("go to previous similar tag" "ugrás az el®z® hasonló címkére")
("go to section" "megy a szakaszba")
("grain" "gabona")
("granite" "gránit")
("graphical effects" "grafikus effektusok")
("graphical interface font scale" "grafikus interfész bet¶méret")
("graphics geometry" "grafikai geometria")
("graphics grids" "grafikus rács")
("greyed" "szürke")
("grid" "rács")
("grid curves" "rácsgörbék")
("grid points" "rácspont")
("grid-curve intersections" "rács-görbe metszéspontok")
("group of objects" "tárgycsoport")
("group/ungroup" "csoport / csoport")
("grouped" "csoportosítva")
("guarantee transparent source tracking" "átlátszó forráskövetés garantálása")
("half wide" "fél széles")
("hand drawn" "kézzel rajzolt")
("headers" "fejlécek")
("history" "történelem")
("homoglyph substitutions" "homoglifszubsztitúciók")
("horizontal collapse distance" "vízszintes összeesési távolság")
("horizontal margins" "vízszintes margó")
("hyphenate as" "köt®jel mint")
("icon" "ikon")
("ignore" "figyelmen kívül hagyás")
("impact" "ütés")
("import bibliography" "import bibliográfia")
("import database entry" "adatbázis-bejegyzés importálása")
("import entries in buffer" "Bejegyzés importálása pufferben")
("import entry" "behozatali bejegyzés")
("import file" "import fájl")
("import selected database entries" "Kiválasztott adatbázis bejegyzések importálása")
("import selected entries" "Kiválasztott bejegyzések importálása")
("import selections as" "Kiválasztások importálása mint")
("import sessions" "import munkamenet")
("import sophisticated objects as pictures" "Kifinomult objektumok importálása képként")
("imported bibliographic entries" "importált bibliográfiai adatok")
("inanimated" "élettelen")
("inch" "hüvelyk")
("incomplete entries found to be filled out" "hiányos kitöltést találtak")
("increase size" "méret növelése")
("indent paragraphs" "francia bekezdés")
("indentation" "behúzás")
("indication" "jelzés")
("initialize" "inicializálás")
("ink here" "tinta itt")
("ink in" "tinta be")
("ink out" "tinta ki")
("inline" "inline")
("inline code" "beépített kód")
("inline content" "inline content")
("inline formula" "inline formula")
("inner bottom" "bels® alsó")
("inner left" "bels® bal")
("inner right" "bels® jobb")
("inner top" "bels® fels®")
("input command" "input parancs")
("input field" "beviteli mez®")
("input options" "beviteli opció")
("insert a computer program" "beilleszt egy számítógépes programot")
("insert a gap" "beszúrjon egy rést")
("insert a list" "lista beszúrása")
("insert a multiple choice" "feleletválasztós beillesztés")
("insert a negation" "tagadás beillesztése")
("insert a new entry" "új bejegyzés beszúrása")
("insert a note or a floating object" "jegyzet vagy úszó tárgy beszúrása")
("insert a prominent piece of text" "helyezze el a kiemelked® szöveget")
("insert a question" "kérdés beillesztése")
("insert a root" "gyökér beszúrása")
("insert a script" "szkript beszúrása")
("insert a section block" "szekcióblokk beszúrása")
("insert a textual operator" "szöveges operátor beszúrása")
("insert above" "beillesztés a fenti")
("insert abstract" "betét beszúrása")
("insert an answer" "írjon be egy választ")
("insert an enunciation" "beilleszteni egy kiejtést")
("insert annotation" "kommentár beszúrása")
("insert below" "beillesztés lent")
("insert copyright and license information" "a szerz®i és licenc információk beillesztése")
("insert explanatory item" "magyarázat beillesztése")
("insert field above" "mez® beillesztése a fenti")
("insert field below" "alatti mez® beillesztése")
("insert large delimiters" "nagy határoló beillesztése")
("insert last name" "vezetéknév beszúrása")
("insert left" "bal beillesztés")
("insert missing invisible operators" "hiányzó láthatatlan operátorok beszúrása")
("insert more names" "további nevek beszúrása")
("insert particle" "beszúrható részecske")
("insert plain text" "egyszer¶ szöveg beszúrása")
("insert right" "jobb beillesztés")
("insert similar above" "a fenti beillesztés hasonló")
("insert similar below" "hasonló beillesztés lentebb")
("insert similar block above" "hasonló blokk beszúrása a fenti")
("insert similar block below" "a hasonló blokk beszúrása lent")
("insert subtable" "betáblázat beszúrása")
("insert symbol documentation" "szimbólumdokumentáció beszúrása")
("insert template" "sablon beszúrása")
("insert text field above" "a szövegmez® beillesztése a fenti")
("insert text field below" "a szövegmez® beszúrása lent")
("insert title after name" "a cím beillesztése a név után")
("insert user interface related markup" "felhasználói felülettel kapcsolatos jelölés beszúrása")
("inserting control points" "vezérl®pontok beillesztése")
("intercharacter compression" "karakterközi tömörítés")
("intercharacter stretching" "karakterközi nyújtás")
("interrupted" "megszakítva")
("invalid multi-paragraph selection" "érvénytelen több bekezdés kiválasztása")
("invalid renaming" "érvénytelen átnevezés")
("inverted breve" "fordított breve")
("invisible ending" "láthatatlan vége")
("invisible newline" "láthatatlan új vonal")
("invisible opening" "láthatatlan nyílás")
("join selected cells" "csatlakozzon a kiválasztott cellákhoz")
("jump in" "beugrás")
("junior" "junior")
("keep local" "tartsa a helyi")
("keep remote" "tartsa távol")
("keep track of source code" "nyomon kell követni a forráskódot")
("keep unfolded" "tartsa széthajtva")
("keyboard configuration" "billenty¶zet konfiguráció")
("laptop presentations" "laptop bemutató")
("large cells" "nagy sejtek")
("large displayed" "nagy kijelz®")
("large displayed fraction" "nagy megjelenített frakció")
("large tables" "nagy asztal")
("last" "utolsó")
("last difference" "utolsó különbség")
("last error" "utolsó hiba")
("last field" "utolsó mez®")
("last name" "vezetéknév")
("last occurrence" "utolsó el®fordulás")
("last similar" "utolsó hasonló")
("left axis" "bal tengely")
("left baseline" "bal alapvonal")
("left bottom" "bal alsó")
("left center" "bal középpont")
("left click: add point; Right click: undo" "bal kattintás: pont hozzáadása; jobb kattintás: visszavonás")
("left click: finish; Right click: undo" "bal kattintás: befejezés; jobb kattintás: visszavonás")
("left click: new object" "bal kattintás: új objektum")
("left click: operate" "bal kattintás: m¶ködés")
("left down" "balra")
("left on even pages" "bal oldalon marad páros")
("left top" "bal fels®")
("left up" "balra")
("left-right arrow" "bal-jobb nyíl")
("leftwards" "balra")
("let the environment float" "hagyja, hogy a környezet lebegjen")
("line breaking" "vonalszakadás")
("line wrapping" "vonalcsomagolás")
("linear 2D" "lineáris 2D")
("lines around" "vonal körül")
("link image and copies as" "linkkép és másolás másként")
("link image as" "linkkép mint")
("link to URL" "link az URL-hez")
("live" "él®")
("live input-output" "él® bemenet-kimenet")
("load help file" "súgófájl betöltése")
("load remote file" "távoli fájl betöltése")
("loading" "betöltése")
("local entries" "helyi bejegyzés")
("loci" "loci")
("locus rendering" "locus renderelés")
("logarithmic base" "logaritmikus bázis")
("logging in" "bejelentkezés")
("logical and" "logikus és")
("logical implication" "logikai implikáció")
("logical not" "logikusan nem")
("logical or" "logikus vagy")
("long macro" "hosszú makró")
("long text" "hosszú szöveg")
("look for more fonts" "további bet¶készlet keresése")
("loops" "hurok")
("macro argument" "makró argumentum")
("macro definition" "makrómeghatározás")
("macro name" "makró név")
("macros" "makró")
("magnify horizontally" "vízszintesen nagyítani")
("magnify vertically" "függ®leges nagyítás")
("main presentation style" "f® prezentációs stílus")
("make a letter environment" "levélkörnyezet készítése")
("make a multi-slide presentation" "multi-slide prezentáció készítése")
("make floating" "lebeg®sséget tenni")
("make link" "link létrehozása")
("make non floating" "nem úszó")
("manila paper" "manila papír")
("map arguments" "térkép érvek")
("marginal note" "margin note")
("margins from width" "szélek szélessége")
("margins on paper" "margó papíron")
("margins on screen" "margó a képerny®n")
("marked" "megjelölve")
("material" "anyag")
("mathematical output" "matematikai output")
("maximal clustering" "maximális csoportosulás")
("maximum" "Legfeljebb")
("meander" "kanyargó")
("memory" "memória")
("memory usage" "memóriahasználat")
("menu" "menü")
("merge lines into paragraphs unless separated by blank lines" "sorok egyesítése bekezdésekbe, kivéve, ha azokat üres sorok választják el")
("messages" "üzenet")
("meta data" "meta adatok")
("metadata" "metaadatok")
("metal" "fém")
("middle baseline" "középs® kiindulópont")
("minimal line separation" "minimális vezetékválasztás")
("minimum" "Legalább")
("mirror" "tükör")
("miscellanous" "vegyes")
("mode dependent icons" "üzemmódfügg® ikon")
("modify remote live document" "távoli él® dokumentum módosítása")
("module" "modul")
("monospaced" "egyszeres")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "")
("more information about GNU TeXmacs can be found in the Help-<less>gtr<gtr>About menu" "további információ a GNU TeXmacs-r®l a Súgó- <less>gtr<gtr> Névjegy menüben található")
("more information about GNU TeXmacs can be found in the help" "További információ a GNU TeXmacs-r®l a súgóban található")
("motion" "mozgás")
("mouse over object" "egér az objektum felett")
("move objects" "objektumok mozgatása")
("move over object on which to operate" "mozog egy tárgy felett, amelyen m¶ködik")
("multiline" "többvonalas")
("multiple choice" "feleletválasztós")
("multiple root" "több gyökér")
("multiplication" "szorzás")
("new bibliography dialogue" "új bibliográfiai párbeszéd")
("new entry" "új bejegyzés")
("new identity" "új identitás")
("new macro" "új makró")
("new passphrase" "új jelszó")
("new remote directory" "új távoli könyvtár")
("new remote file" "új távoli fájl")
("new style fonts" "új stílusú bet¶típusok")
("new style page breaking" "új stílusú oldal törés")
("new version" "új verzió")
("new window" "új ablak")
("newer version" "újabb verzió")
("next chunk" "következ® darab")
("next difference" "következ® különbség")
("next error" "következ® hiba")
("next field" "következ® mez®")
("next occurrence" "következ® esemény")
("next screen" "következ® képerny®")
("next similar" "következ® hasonló")
("no clustering" "nincs csoportosulás")
("no completions" "nincs teljes")
("no errors have been corrected" "nincs javítva hiba")
("no new public key in document" "nincs új nyilvános kulcs a dokumentumban")
("no page break" "nincs oldalszünet")
("no page numbers" "nincs oldalszám")
("no parent" "nincs szül®")
("no selection" "nincs kiválasztás")
("no spelling errors" "nincs helyesírási hiba")
("normal loci" "normál lókuszok")
("not allowed to remove home directory" "nem engedélyezett az otthoni könyvtár eltávolítása")
("not connected to server" "nincs csatlakoztatva a szerverhez")
("not yet implemented" "még nem valósult meg")
("notebook" "notebook")
("number of polar steps" "poláris lépések száma")
("number of subunit steps" "alegységlépések száma")
("numbering" "számozás")
("numeric spreadsheet" "numerikus táblázat")
("odd page" "páratlan oldal")
("odd pages" "páratlan oldal")
("of fingerprint" "ujjlenyomat")
("old version" "régi változat")
("older version" "régebbi verzió")
("on your system and set it up from the \"Security\" tab" "a rendszeren, és állítsa be a \"Biztonság\" lapon")
("one column" "egy oszlop")
("one error has been corrected" "egy hibát kijavítottak")
("one lower case letter, one non alpha-numeric symbol" "egy kisbet¶, egy nem alfanumerikus szimbólum")
("one numeric character, one upper case letter" "egy numerikus karakter, egy nagybet¶")
("only convert changes when re-importing" "csak a módosítások átalakítása újraimportáláskor")
("only convert changes with respect to imported version" "csak a változások konvertálása az importált verzióhoz képest")
("only convert changes with respect to tracked version" "csak a változások konvertálása a követett verzióhoz viszonyítva")
("only implemented for complete subtrees" "csak teljes alsó fákra valósítva meg")
("only keep folded" "csak hajtogatva")
("only keep unfolded" "csak bontsa ki")
("only show semantic focus" "csak szemantikai fókuszt mutat")
("opacity" "átlátszóság")
("open bibliography" "nyílt bibliográfia")
("open identities" "nyitott identitások")
("open in new window" "új ablakban nyitva")
("open key manager" "nyitott kulcskezel®")
("open licence agreement" "nyílt licencszerz®dés")
("open mailbox" "nyitott postafiók")
("open module browser" "nyitott modul böngész®")
("open symbol browser" "nyitott szimbólum böngész®")
("open tool in separate window" "szerszám nyitása külön ablakban")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "vagy adja meg a \"gpg\" vagy \"gpg2\" parancs teljes elérési útját")
("order" "megrendelés")
("ordinary symbol" "rendes szimbólum")
("ornamented" "díszes")
("other login" "egyéb bejelentkezés")
("other package" "egyéb csomag")
("outer bottom" "küls® alsó")
("outer left" "bal bal")
("outer right" "jobb fels®")
("outer top" "küls® fels®")
("outline" "vázlat")
("outlined" "vázolt")
("outlined emboss" "vázolt dombornyomás")
("outlined engrave" "vázolt metszet")
("output options" "output output")
("oval" "ovális")
("overlap" "átfedés")
("overlay" "overlay")
("overlays" "átfedések")
("overlined" "aláhúzott")
("padded" "párnázott")
("page background" "oldal háttér")
("page break after" "oldal szünet után")
("page breaking algorithm" "oldalbontó algoritmus")
("page number" "oldalszám")
("page number rendering" "oldalszám renderelés")
("page rendering" "oldalmegjelenítés")
("palette" "paletta")
("panorama" "panoráma")
("paragraphs" "bekezdések")
("parenthesis" "zárójel")
("parenthesized" "zárójelben")
("particle" "részecske")
("passphrase encryption" "jelmondat titkosítás")
("passphrase wallet facilities are not currently available" "jelmondat-pénztárca szolgáltatás jelenleg nem érhet® el")
("passphrases are expected to have at least: 8 characters" "jelmondatok várhatóan legalább: 8 karakter")
("passphrases mismatch" "jelmondat-eltérés")
("pastel" "pasztell")
("pattern" "minta")
("pause" "szünet")
("pen width" "tollszélesség")
("permanent footer" "állandó lábléc")
("permanent header" "állandó fejléc")
("permanently add to dictionary" "véglegesen hozzáadja a szótárhoz")
("permanently insert into dictionary" "véglegesen beilleszthet® a szótárba")
("phantom" "fantom")
("phantoms" "fantom")
("physics and astronomy class" "fizika és csillagászat osztály")
("picture" "kép")
("pine" "feny®")
("plain" "egyszer¶")
("plain boxes" "egyszer¶ doboz")
("plain circles" "egyszer¶ kör")
("play" "játék")
("play animation" "animációs játék")
("please install GnuPG software from https://www.gnupg.org" "kérjük, telepítse a GnuPG szoftvert a https://www.gnupg.org webhelyr®l")
("plug-ins" "plug-inek")
("plural" "többes szám")
("pop server settings" "pop kiszolgáló beállításai")
("position of marginal note" "a jegyzet pozíciója")
("poster formats" "poszter formátumok")
("poster theme" "poszter téma")
("postfix" "postfix")
("preferences for editing mathematical formulas" "Preferenciák a matematikai képletek szerkesztéséhez")
("preferences for tag" "címkepreferencia")
("prefix" "el®tag")
("presentation tool" "bemutató eszköz")
("preserve" "meg®rzés")
("preserve tags" "címkék meg®rzése")
("pretty tree output" "szép fa output")
("preview" "el®nézet")
("previous difference" "el®z® különbség")
("previous error" "el®z® hiba")
("previous field" "el®z® mez®")
("previous occurrence" "el®z® esemény")
("previous screen" "el®z® képerny®")
("previous similar" "el®z® hasonló")
("primitive or macro" "primitív vagy makro")
("print buffer" "nyomtatási puffer")
("print buffer to file" "puffer nyomtatás fájlba")
("print to file" "fájlba nyomtatás")
("printer setup" "nyomtatóbeállítás")
("program bracket matching" "programkonzol-illesztés")
("program bracket selections" "programkonzol választás")
("program commands" "programparancsok")
("program interface for buffer management" "program interfész pufferkezeléshez")
("programming routines for editing documents" "programozási rutinok a dokumentumok szerkesztéséhez")
("prominent" "kiemelked®")
("provoke C++ error" "C ++ hibát provokál")
("provoke menu error" "provokáló menühiba")
("provoke scheme error" "sémahiba provokálása")
("pseudo code" "álnév")
("public key encryption" "nyilvános kulcs titkosítás")
("public keys" "nyilvános kulcs")
("pulse" "impulzus")
("qt GUI only, sorry. Use \"Export selection\"" "Csak qt grafikus felhasználói felület, sajnálom. Használja a \"Kiválasztás exportálása\" lehet®séget")
("qt-widgets" "qt-kütyü")
("quantifier" "számszer¶sít®")
("quasi" "kvázi")
("question" "kérdés")
("questions only" "csak kérdések")
("questions with answers" "kérdés és válasz")
("quick evaluation of formulas" "a képletek gyors értékelése")
("raw" "nyers")
("really delete user identity" "valóban törölje a felhasználói azonosítót")
("rebuild translations file" "fordítási fájl újraépítése")
("recent" "nemrégiben")
("recent documents" "legutóbbi dokumentum")
("recipients" "címzett")
("recognize" "felismer")
("rectangular" "téglalap alakú")
("reduce" "csökkent")
("reduced margins" "csökkentett haszonkulcs")
("regenerate" "regenerálni")
("register file" "regisztrációs fájl")
("relate" "vonatkozik")
("relation" "kapcsolat")
("release left button: finish editing" "engedje el a bal gombot: fejezze be a szerkesztést")
("remote control" "távirányító")
("remote controllers with keyboard simulation" "távirányító billenty¶zet-szimulációval")
("remote directory" "távoli könyvtár")
("remote servers" "távoli szerver")
("remote tool" "távoli eszköz")
("remove banner" "transzparens eltávolítása")
("remove database entry" "adatbázis-bejegyzés eltávolítása")
("remove downwards" "lefelé távolítsa el")
("remove entries" "tételek eltávolítása")
("remove entry" "bejegyzés eltávolítása")
("remove field above" "törölje a fenti mez®t")
("remove field below" "távolítsa el a mez®t")
("remove folded" "eltávolítva hajtogatott")
("remove last field" "az utolsó mez® eltávolítása")
("remove leftwards" "balra eltávolítás")
("remove link" "link eltávolítása")
("remove next field" "a következ® mez® eltávolítása")
("remove previous field" "az el®z® mez® eltávolítása")
("remove rightwards" "jobbra eltávolítás")
("remove selected database entries" "a kiválasztott adatbázis bejegyzések eltávolítása")
("remove selected entries" "a kijelölt bejegyzések eltávolítása")
("remove superfluous invisible operators" "felesleges láthatatlan operátorok eltávolítása")
("remove tag" "eltávolítsd a címkét")
("remove this branch" "az ág eltávolítása")
("remove unfolded" "eltávolítás behajtogatva")
("remove upwards" "eltávolítsa felfelé")
("removed entries from database" "eltávolított bejegyzések az adatbázisból")
("removed entry from database" "eltávolítva bejegyzés az adatbázisból")
("rename" "átnevezés")
("rename section" "átnevezési szakasz")
("replace TeXmacs styles with no LaTeX equivalents" "a TeXmacs stílusok helyettesítése LaTeX ekvivalensek nélkül")
("replace all further occurrences" "minden további esemény helyettesítése")
("replace one occurrence" "egy esemény helyettesítése")
("replace toolbar" "eszköztár cseréje")
("reset error counters" "hiba számlálók visszaállítása")
("resize" "átméretezés")
("resize objects" "objektumok átméretezése")
("restart TeXmacs in order to let changes take effect" "indítsa újra a TeXmacs-ot, hogy a változások hatályba lépjenek")
("restart in order to let the new look and feel take effect" "újraindítás az új küls® megjelenésének és érzésének érvényre juttatása érdekében")
("retain" "megtartani")
("retime" "retime")
("retina settings" "retina beállítások")
("retrieve email" "e-mail lekérése")
("retrieve remote live document" "távoli él® dokumentum letöltése")
("retrieved contents" "letöltött tartalom")
("reverse" "fordított")
("reverse ordering" "fordított rendelés")
("ridged paper" "szegélyes papír")
("right baseline" "jobb alapvonal")
("right down" "jobbra")
("right on even pages" "jobbra páros oldalak")
("right up" "jobbra fel")
("rightwards" "jobbra")
("rigid box" "merev doboz")
("rotate" "forgatás")
("rotate objects" "objektumok elforgatása")
("rough" "durva")
("rough paper" "durva papír")
("round overbrace" "kerek ütés")
("round underbrace" "kerek alváz")
("run" "fut")
("run current file" "futtassa az aktuális fájlt")
("same names" "azonos nevek")
("same screen margins as on paper" "ugyanazok a margók, mint a papíron")
("sample text" "mintaszöveg")
("save auxiliary data" "kiegészít® adatok mentése")
("save entries" "bejegyzések mentése")
("save entry" "bejegyzés mentése")
("save image as" "kép mentése másként")
("save position" "pozíció mentése")
("save remote file" "távoli fájl mentése")
("saved modifications in database" "mentett módosítások az adatbázisban")
("scheme developers guide" "sémafejleszt®i útmutató")
("scheme interface for the graphical mode" "séma felület a grafikus üzemmódhoz")
("screen" "képerny®")
("screen rendering" "képerny®megjelenítés")
("screens" "képerny®k")
("screenshot" "screenshot")
("scripting language" "szkriptnyelv")
("search and replace" "keresés és csere")
("search toolbar" "keres® eszköztár")
("second" "második")
("secret keys" "titkos kulcsok")
("sections" "szakasz")
("see documentation" "lásd a dokumentációt")
("select pen" "válogatott toll")
("select the action to be undertaken for each conflict" "válassza ki az egyes konfliktusokhoz végrehajtandó tevékenységet")
("select view mode" "nézet mód kiválasztása")
("semantic correctness" "szemantikai helyesség")
("semantic editing" "szemantikai szerkesztés")
("semantic selections" "szemantikai választások")
("semantics" "szemantika")
("senior" "id®sebb")
("serif" "serif")
("server" "szerver")
("session commands" "munkamenet parancsok")
("set default" "alapértelmezett beállítás")
("set difference" "beállított különbség")
("set intersection" "beállított keresztez®dés")
("set number of columns" "meghatározott oszlopok száma")
("set number of rows" "meghatározott sorok száma")
("set properties" "beállított tulajdonságok")
("set union" "set union")
("set user information" "felhasználói adatok megadása")
("seventh" "hetedik")
("several equations" "több egyenlet")
("shadow" "árnyék")
("shadowed" "árnyékolt")
("shadowed raise" "árnyékos emelés")
("shift" "m¶szak")
("show current focus" "jelenlegi fókusz megjelenítése")
("show full context" "teljes környezet megjelenítése")
("show key presses" "gombnyomások mutatása")
("show main document" "a f® dokumentum megjelenítése")
("show memory usage" "memóriahasználat mutatása")
("show panorama" "panoráma megjelenítése")
("show preamble" "bevezet® megjelenítése")
("show subunits" "alegységek megjelenítése")
("show table cells" "táblázatcellák megjelenítése")
("show timings" "id®zítés mutatása")
("side tools" "oldalsó szerszám")
("sixth" "hatodik")
("skew" "ferde")
("skip all" "összes kihagyása")
("slant" "ferde")
("slashed fraction" "csökkentett frakció")
("slides" "diák")
("slow" "lassú")
("slow decrease" "lassú csökkenés")
("slow increase" "lassú növekedés")
("small capitals" "kis f®város")
("small environment box" "kis környezet doboz")
("small focus" "kis fókusz")
("small inline" "kis inline")
("small inline fraction" "kis inline frakció")
("smash" "összetör")
("smooth" "sima")
("smooth end" "sima vég")
("smooth extremities" "sima végtagok")
("smooth start" "zökken®mentes indulás")
("snap" "pillanat")
("snap distance" "bepattanási távolság")
("snap to curves" "görbékhez igazítás")
("snap to grid" "rácsra kattintva")
("snap to grid curve" "beillesztés a grid görbe")
("snap to intersections of curves" "bepattanás a görbék metszéspontjaira")
("snap to text borders" "beillesztés a szöveg szélére")
("snap to text corners" "beillesztés a szövegsorba")
("solution" "megoldás")
("solution to exercise" "gyakorlati megoldás")
("solution to problem" "problémamegoldás")
("solutions" "megoldás")
("source macros tool" "forrásmakró eszköz")
("south" "dél")
("south east" "délkelet")
("space bar in math mode" "szóköz matematikai módban")
("space bar in text mode" "szóköz szöveges módban")
("space stretchability" "tér nyújthatóság")
("span" "span")
("span over all columns" "átmér® az összes oszlop felett")
("specific baseline" "meghatározott kiindulási alap")
("specify color alternation" "adja meg a színváltást")
("specify how to traverse the manual" "meghatározza, hogyan kell áthaladni a kézikönyvbe")
("specify semantics of a symbol or formula" "adja meg a szimbólum vagy képlet szemantikáját")
("spell check" "helyesírás-ellen®rzés")
("spline" "spline")
("split program" "split program")
("square overbrace" "négyzet alakú túlfutó")
("square underbrace" "négyszögletes alátét")
("stack" "verem")
("standard" "standard")
("standard Output" "normál kimenet")
("standard fraction" "standard frakció")
("star" "csillag")
("start server" "indítószerver")
("statement" "nyilatkozat")
("statistics" "statisztika")
("status" "állapot")
("stop server" "stop szerver")
("storage" "tároló")
("store tracking information in LaTeX files" "A nyomkövetési információkat tárolja a LaTeX fájlokban")
("stretch factor" "nyújtási tényez®")
("strict Ascii" "szigorú Ascii")
("strike through" "áttörés")
("structured insert above" "strukturált betét fent")
("structured insert at the left" "strukturált betét balra")
("structured insert at the right" "strukturált betét a jobb oldalon")
("structured insert below" "strukturált betét lent")
("structured remove downwards" "strukturált eltávolítás lefelé")
("structured remove leftwards" "strukturált eltávolítás balra")
("structured remove rightwards" "strukturált eltávolítás jobbra")
("structured remove upwards" "strukturált eltávolítás felfelé")
("structured variant" "strukturált változat")
("style options" "stílusbeállítások")
("style parameters" "stílusparaméterek")
("subject" "tárgy")
("submenu" "almenü")
("subscript below" "alsó index")
("subsubmenu" "almenü")
("subsubsubmenu" "subsububmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtraction" "kivonás")
("summarized" "összefoglalva")
("superscript above" "felülíró fenti")
("supported plug-ins" "támogatott beépül® modul")
("inflate" "duzzanat")
("switch to buffer" "átváltás pufferre")
("symbol properties not found" "szimbólum tulajdonságok nem találhatók")
("symbols" "szimbólumok")
("synchronize" "szinkronizálás")
("synchronize bibliographic references" "a bibliográfiai hivatkozások szinkronizálása")
("synchronize with remote server" "szinkronizálás távoli szerverrel")
("synopsis" "összefoglaló")
("tab-completion" "fül-kitöltés")
("tabbed" "füles")
("table breaking" "asztali törés")
("table properties" "tábla tulajdonságai")
("tags with special rendering" "speciális megjelenítéssel ellátott címkék")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "teXmacs puffer várható")
("teXmacs buffer on disk expected" "teXmacs-puffer a lemezen várható")
("teXmacs extensions to scheme and utilities" "séma és segédprogramok TeXmacs kiterjesztése")
("teXmacs macro" "teXmacs makró")
("teXmacs package" "teXmacs csomag")
("teXmacs style" "teXmacs stílus")
("test routine" "tesztprogram")
("testing tree-view" "fa nézet tesztelése")
("text borders" "szövegkeretek")
("text box style" "szövegdoboz stílus")
("text corners" "szöveges sarok")
("textual" "szöveges")
("textual operator" "szöveges operátor")
("textual spreadsheet" "szöveges táblázat")
("the TeXmacs plug-in system" "a TeXmacs beépül® rendszer")
("theme parameters" "témaparaméterek")
("these collected public keys will be definitely lost" "ezek az összegy¶jtött nyilvános kulcsok teljesen elvesznek")
("these public keys will be definitely lost" "ezek a nyilvános kulcsok teljesen elvesznek")
("these secret keys will be definitely lost" "ezek a titkos kulcsok teljesen elvesznek")
("thicken" "s¶r¶södik")
("third" "harmadik")
("this" "ez")
("this page number" "ennek az oldalnak a száma")
("this style specifies page margins in the TeX way" "ez a stílus meghatározza az oldalmargókat a TeX módon")
("three columns" "három oszlop")
("three dots" "három pont")
("through popup windows" "felugró ablakon keresztül")
("through the menus" "a menükön keresztül")
("time evolution" "id®beli fejl®dés")
("title presentation options" "címbemutató lehet®ségek")
("title style" "címstílus")
("title suffix" "cím utótag")
("titled block" "címblokk")
("toggle cell wrapping mode" "váltócellás csomagolási mód")
("toggle here" "váltás itt")
("toggle off" "váltás")
("toggle on" "bekapcsol")
("tolerant" "toleráns")
("top baseline" "fels® kiindulópont")
("transform" "átalakítás")
("transform cell into subtable" "a cella átalakítható táblává")
("translations" "fordítás")
("translations loaded" "fordítás betöltve")
("traversal" "áthaladás")
("traverse" "átmenet")
("triangle" "háromszög")
("turn off" "kikapcsol")
("turn on" "bekapcsol")
("two columns" "két oszlop")
("two dots" "két pont")
("type a latex command followed by return" "írjon be egy latex parancsot, majd adjon vissza")
("underlined" "aláhúzott")
("unevaluated argument" "nem becsült érv")
("unevaluated value" "nem becsült érték")
("unfold" "kibontakozik")
("unfold all" "mindet kibont")
("unfold all fields" "kibontja az összes mez®t")
("unit length" "egységhossz")
("unknown secret key fingerprint" "ismeretlen titkos kulcs ujjlenyomata")
("unregistered file" "nem regisztrált fájl")
("unroll" "tekercs")
("unsecure script refused" "nem biztonságos szkript visszautasítva")
("unsupported link mode" "nem támogatott kapcsolatmód")
("until" "-ig")
("untitled block" "cím nélküli blokk")
("up to date" "naprakész")
("update buffer" "frissítési puffer")
("update this buffer" "frissítse ezt a puffert")
("update web site" "weboldal frissítése")
("upight" "felfelé")
("upload" "feltöltés")
("upwards" "felfelé")
("use CSS for more advanced formatting" "CSS használata a fejlettebb formázáshoz")
("use as master" "masterként történ® felhasználás")
("use extensible brackets" "b®víthet® zárójel használata")
("use line wrapping for lines which are longer than 80 characters" "vonalcsomagolást használjon 80 karakternél hosszabb sorokhoz")
("use margin kerning (protrusion)" "Használjon szélvéd®t (kiemelkedést)")
("use protrusion" "használjon kiemelkedést")
("use relative path" "használja a relatív utat")
("user interface" "felhasználói felület")
("user interface language" "felhasználói felület nyelve")
("user preferences" "felhasználói beállítások")
("utf-8 with inputenc LaTeX package" "utf-8 inputenc LaTeX csomaggal")
("vanish" "elt¶nik")
("verbose" "verbose")
("version" "verzió")
("versioning tool" "verziókészít® eszköz")
("vertical margins" "függ®leges margó")
("vertical space after" "függ®leges tér utána")
("vertical space before" "függ®leges hely el®tte")
("vertical space stretchability" "függ®leges tér nyújthatóság")
("visible except here" "itt látható, kivéve")
("visible from here on" "innen látható")
("visible only here" "csak itt látható")
("visible until here" "itt látható")
("visited loci" "meglátogatott helyek")
("wallet" "pénztárca")
("wave" "hullám")
("weight" "súly")
("when line wrapping" "vonalcsomagoláskor")
("whitespace" "szóköz")
("wide" "széles")
("wide block" "széles blokk")
("wide colored" "széles szín¶")
("wide float" "széles úszó")
("wide footnote" "széles lábjegyzet")
("wide tabular" "széles táblázatos")
("widescreen" "szélesvásznú")
("writing TeXmacs bibliography styles" "TeXmacs bibliográfiai stílusok írása")
("writing documentation" "dokumentáció írása")
("wrong empty passphrase" "rossz üres jelmondat")
("wrong passphrase" "rossz jelszó")
("year" "év")
("you are attempting to open an encrypted file while" "titkosított fájlt próbál megnyitni, míg")
("you might consider enabling the experimental" "fontolóra veheti a kísérleti engedélyezését")
("you must add a bibliography file" "hozzá kell adnia egy bibliográfiai fájlt")
("you should also make sure that GnuPG is installed" "gy®z®djön meg arról, hogy a GnuPG telepítve van")
("your personal dictionary has been modified" "a személyes szótárod módosult")
("zoom in" "nagyítás")
("zoom out" "kicsinyítés")
