("\"encryption\" features from the preference panel" "\"criptografia\" recursos do painel de preferências")
("(Re)Build autocompletion index" "(Re) Criar índice de preenchimento automático")
("a modifier" "um modificador")
("a series" "uma série")
("a.C.M. computing class" "classe de computação a.C.")
("a.M.S. subject class" "turma da disciplina de mestrado")
("abbreviated authors" "autores abreviados")
("abreviated authors" "autores abreviados")
("accent above" "acento acima")
("accent below" "acento abaixo")
("accept during this pass" "aceitar durante este passe")
("acknowledgment" "reconhecimento")
("acknowledgments" "agradecimentos")
("activate hidden" "ativar oculto")
("activate once" "ativar uma vez")
("activation" "ativação")
("active link types" "tipos de links ativos")
("add" "adicionar")
("add abstract information" "adicionar informação abstrata")
("add author information" "adicionar informações do autor")
("add branch after" "adicionar ramo depois")
("add branch before" "adicionar ramo antes")
("add other package" "adicione outro pacote")
("add package" "adicionar pacote")
("add style package" "adicionar pacote de estilo")
("add switch after" "adicionar switch depois")
("add switch before" "adicionar chave antes")
("add title information" "adicionar informações do título")
("addition" "adição")
("adjust" "ajustar")
("adjust limits" "ajustar limites")
("advanced font customization" "personalização avançada de fonte")
("affiliation" "afiliação")
("align cell to the decimal comma" "alinhar célula à vírgula decimal")
("align cell to the decimal dot" "alinhar célula ao ponto decimal")
("align table at axis" "alinhar tabela no eixo")
("aligned" "alinhado")
("alignment of balloon" "alinhamento do balão")
("all cells" "todas as células")
("all data attached to this identity will be lost" "todos os dados anexados a essa identidade serão perdidos")
("all saved passphrases will be lost forever" "todas as senhas salvas serão perdidas para sempre")
("allow for macro definitions in preamble" "permite definições de macro no preâmbulo")
("allow multiple spaces" "permite vários espaços")
("allow spurious spaces" "permitir espaços espúrios")
("allowed page height extension" "extensão de altura permitida da página")
("allowed page height reduction" "redução permitida na altura da página")
("allowed positions" "posições permitidas")
("allowed positions of floating object" "posições permitidas de objeto flutuante")
("alpha transparency" "transparência alfa")
("also on paper" "também no papel")
("alter" "alterar")
("alternate" "alternativo")
("alternate except here" "alternativo, exceto aqui")
("alternate from here on" "alternativo daqui em diante")
("alternate only here" "alternativo apenas aqui")
("alternate until here" "alternam até aqui")
("alternative colors" "cores alternativas")
("alternative specification" "especificação alternativa")
("always" "sempre")
("american" "americano")
("amplified" "amplificado")
("ancient" "antigo")
("and perform casual settings from the \"Encryption\" tab" "e execute configurações casuais na guia \"Criptografia\"")
("angular" "angular")
("animate" "animado")
("animate folding" "dobra animada")
("animate object" "objeto animado")
("animate objects" "objetos animados")
("animate unfolding" "desdobramento animado")
("animated" "animado")
("animation" "animação")
("animation toolbar" "barra de ferramentas de animação")
("annotate" "anotar")
("answer" "resposta")
("answer field" "campo de resposta")
("answer to question" "resposta à pergunta")
("answers only" "apenas respostas")
("any" "qualquer")
("appear" "aparece")
("apply macro" "aplicar macro")
("apply macro once" "aplicar macro uma vez")
("approximate" "aproximado")
("arc" "arco")
("arc cosine" "arco cosseno")
("arc sine" "arco senoidal")
("arc tangent" "arco tangente")
("arch series" "arch series")
("are you sure you want to delete collected public keys" "tem certeza de que deseja excluir as chaves públicas coletadas")
("are you sure you want to delete selected public keys" "tem certeza de que deseja excluir as chaves públicas selecionadas")
("are you sure you want to delete selected secret keys" "tem certeza de que deseja excluir as chaves secretas selecionadas")
("are you sure you want to destroy the wallet" "tem certeza de que deseja destruir a carteira")
("art Pen" "caneta artística")
("art frame" "quadro de arte")
("arxiv category" "categoria arxiv")
("as visual grid" "como grade visual")
("aspect" "aspecto")
("attach master" "anexar mestre")
("attached" "anexado")
("auto" "automático")
("auto-save file" "arquivo de salvamento automático")
("automatic brackets" "colchetes automáticos")
("automatic content generation" "geração automática de conteúdo")
("automatic program brackets" "colchetes de programa automáticos")
("automatic quotes" "aspas automáticas")
("automatically close brackets" "fecha automaticamente colchetes")
("automatically import bibliographies when opening files" "importa automaticamente bibliografias ao abrir arquivos")
("automatically remember all passphrases in the wallet" "lembra automaticamente de todas as senhas da carteira")
("automatically save" "salvar automaticamente")
("autosave" "salvamento automático")
("avoid spurious spaces" "evite espaços espúrios")
("axis" "eixo")
("b series" "série b")
("back" "de volta")
("background evaluations" "avaliações de base")
("background picture selector" "seletor de imagem de fundo")
("backtrace errors" "erros de rastreamento")
("base" "base")
("baseline" "linha de base")
("basic communication using pipes" "comunicação básica usando tubos")
("beamer" "beamer")
("beamer formats" "formatos beamer")
("beamer theme" "tema beamer")
("bench" "banco")
("bend bottom" "fundo dobrado")
("bend corner" "canto dobrado")
("bend diagonal" "dobra na diagonal")
("bend in" "dobrar-se")
("bend out" "dobrar")
("bezier" "bezier")
("bibTeX command" "comando bibTeX")
("bidirectional" "bidirecional")
("big environment box" "caixa grande ambiente")
("big focus" "grande foco")
("binary operator" "operador binário")
("bitmap resolution (dpi)" "resolução de bitmap (dpi)")
("black floral I" "preto floral I")
("black floral II" "floral preto II")
("blackboard embold" "quadro negro")
("blank column" "coluna em branco")
("blank row" "linha em branco")
("block" "bloco")
("block content" "conteúdo do bloco")
("block of code" "bloco de código")
("blur" "desfoque")
("both versions" "ambas as versões")
("bottom baseline" "linha de base inferior")
("bottom cell border" "borda inferior da célula")
("bottom cell padding" "preenchimento da célula inferior")
("bottom table border" "borda inferior da tabela")
("bottom table padding" "preenchimento de mesa inferior")
("bottom tools" "ferramentas inferiores")
("box" "caixa")
("broken white" "branco quebrado")
("browse back" "navegar para trás")
("browse forward" "avançar")
("browse modules documentation" "procure a documentação dos módulos")
("buffer management" "gerenciamento de buffer")
("buffer must be on disk" "o buffer deve estar no disco")
("buffer must have a name" "o buffer deve ter um nome")
("build buffer" "buffer de construção")
("build buffer in" "compilar buffer")
("build directory" "diretório de compilação")
("build directory in" "compilar diretório em")
("build link pages" "criar páginas de links")
("build-all" "compilação tudo")
("bump" "solavanco")
("busy" "ocupado")
("cJK" "cJK")
("cJK spacing" "espaçamento cJK")
("calculus" "cálculo")
("cancelled" "cancelado")
("cannot download directory to file" "não é possível baixar o diretório para o arquivo")
("cannot rename across different servers" "não é possível renomear em servidores diferentes")
("cannot upload directory to file" "não é possível fazer upload do diretório para o arquivo")
("cartesian" "cartesiano")
("carved wood" "madeira esculpida")
("case-insensitive search" "pesquisa que não diferencia maiúsculas de minúsculas")
("categories" "categorias")
("category" "categoria")
("cell properties" "propriedades da célula")
("cells" "células")
("center baseline" "linha de base central")
("chalk" "giz")
("change default unit" "alterar unidade padrão")
("change passphrase" "alterar senha")
("change permissions" "alterar permissões")
("change step-size" "alterar tamanho da etapa")
("change tags" "alterar tags")
("change the TeXmacs preferences" "altere as preferências do TeXmacs")
("change the border of the table" "alterar a borda da tabela")
("change the style of mathematical formulas" "mude o estilo das fórmulas matemáticas")
("change wallet passphrase" "alterar senha da carteira")
("character contraction" "contração de caracteres")
("character encoding" "codificação de caracteres")
("character expansion" "expansão de caracteres")
("check exported Pdf files for correctness" "verificar a exatidão dos arquivos PDF exportados")
("check for automatic updates" "verificar atualizações automáticas")
("check for updates" "verificar atualizações")
("checkable field" "campo verificável")
("choose background" "escolha o plano de fundo")
("choose color" "escolha a cor")
("cipher algorithm for passphrase encryption" "algoritmo de cifra para criptografia de senha")
("circle" "círculo")
("classification" "classificação")
("clean slate" "ardósia limpa")
("clear all fields" "limpe todos os campos")
("clear local information" "informações locais claras")
("clear menu" "menu claro")
("clear undo history" "limpar desfazer histórico")
("click Ok button twice to discard this warning" "clique no botão OK duas vezes para descartar este aviso")
("clip" "clipe")
("clipboard image format" "formato de imagem da área de transferência")
("close animation tool" "ferramenta de animação fechada")
("close document" "documento fechado")
("close program" "fechar programa")
("close replace tool" "fechar substituir ferramenta")
("close search tool" "ferramenta de pesquisa fechada")
("close spell tool" "ferramenta para fechar feitiços")
("close translations to rebuild" "fechar traduções para reconstruir")
("closed bezier" "bezier fechado")
("closed curve" "curva fechada")
("closed smooth" "fechado suave")
("closed spline" "spline fechado")
("closing style" "estilo de fechamento")
("cluster by affiliation" "agrupar por afiliação")
("collect garbage" "colete lixo")
("collected keys" "chaves coletadas")
("color of the axes" "cor dos eixos")
("color of the subunits" "cor das subunidades")
("color of the units" "cor das unidades")
("colors" "cores")
("column to the left" "coluna à esquerda")
("column to the right" "coluna à direita")
("columns" "colunas")
("column separation" "separação de colunas")
("commit" "confirmar")
("commit file" "arquivo de confirmação")
("common" "comum")
("common formats" "formatos comuns")
("commutative diagram" "diagrama comutativo")
("compact" "compacto")
("compactification" "compactação")
("compactify" "compactar")
("compare" "comparar")
("compare with" "compare com")
("complete bibliographic reference" "referência bibliográfica completa")
("completion" "conclusão")
("complex actions" "ações complexas")
("compose" "compor")
("compound" "composto")
("compress" "comprimir")
("compress into toolbar" "comprimir na barra de ferramentas")
("compressed" "compactado")
("conceal" "ocultar")
("configure look and feel" "configurar aparência")
("confirm collected public key deletion" "confirmar exclusão de chave pública coletada")
("confirm database entry" "confirmar entrada do banco de dados")
("confirm entry" "confirmar entrada")
("confirm public key deletion" "confirmar exclusão de chave pública")
("confirm secret key deletion" "confirmar exclusão de chave secreta")
("confirm selected database entries" "confirmar entradas selecionadas do banco de dados")
("confirm selected entries" "confirmar entradas selecionadas")
("confirm wallet destruction" "confirmar a destruição da carteira")
("conservative conversion options" "opções de conversão conservadoras")
("consoles" "consoles")
("constellation" "constelação")
("contact" "contato")
("content" "conteúdo")
("context aids" "auxílios ao contexto")
("contextual hints" "dicas contextuais")
("continue" "continuar")
("continued fraction" "fração continuada")
("contour" "contorno")
("contract logarithms" "logaritmos do contrato")
("contribute" "contribuição")
("control flow" "fluxo de controle")
("control the evaluation of expressions" "controlam a avaliação de expressões")
("convert" "conversão")
("converters" "conversores")
("convertible" "conversível")
("copy new objects to all frames" "copiar novos objetos para todos os quadros")
("copy new objects to previous frames" "copiar novos objetos para quadros anteriores")
("copy new objects to subsequent frames" "copiar novos objetos para quadros subseqüentes")
("copy to all frames after" "copiar para todos os quadros depois")
("copy to all frames before" "copiar para todos os quadros antes")
("copy to all other frames" "copiar para todos os outros quadros")
("copyright" "direitos autorais")
("cork charset with TeX catcode definition in preamble" "conjunto de cortiça com definição de código de código TeX no preâmbulo")
("cork with catcodes" "cortiça com códigos")
("correct" "correto")
("correct all" "corrigir tudo")
("correct formula" "fórmula correta")
("correct manually" "corrigir manualmente")
("correct mathematical formulas" "fórmulas matemáticas corretas")
("correction" "correção")
("cosine" "cosseno")
("count characters" "caracteres de contagem")
("count lines" "linhas de contagem")
("count words" "contar palavras")
("create a new document" "criar um novo documento")
("create link" "criar link")
("create preamble" "criar preâmbulo")
("create remote account" "criar conta remota")
("create remote directory" "criar diretório remoto")
("create remote file" "criar arquivo remoto")
("create subprogram" "criar subprograma")
("create subsession" "criar subsessão")
("create table macro" "criar macro da tabela")
("create web site" "criar site")
("creating new account" "criando nova conta")
("creating technical pictures" "criando imagens técnicas")
("crop" "colheita")
("crop marks" "marcas de corte")
("cross" "cruz")
("crossed boxes" "caixas cruzadas")
("crossed circles" "círculos cruzados")
("current user version" "versão atual do usuário")
("current version" "versão atual")
("cursor" "cursor")
("curve" "curva")
("curve intersections" "interseções de curvas")
("curve points" "pontos da curva")
("customizations" "personalizações")
("customizing and extending the user interface" "customizando e estendendo a interface do usuário")
("custum tab" "guia custum")
("cyan" "ciano")
("dark grey" "cinza escuro")
("data" "dados")
("database entry" "entrada do banco de dados")
("database tool" "ferramenta de banco de dados")
("database toolbar" "barra de ferramentas do banco de dados")
("deactivate once" "desativar uma vez")
("dead" "morto")
("debug" "depuração")
("debugging console" "console de depuração")
("debugging tool" "ferramenta de depuração")
("decimal comma" "vírgula decimal")
("decimal dot" "ponto decimal")
("decomposed" "decomposto")
("decorated" "decorado")
("decorated wood" "madeira decorada")
("decorative" "decorativo")
("decrease size" "diminuir tamanho")
("decrypt" "descriptografar")
("decrypted" "descriptografado")
("decryption" "descriptografia")
("default size" "tamanho padrão")
("degrade" "degradação")
("degraded" "degradado")
("delete documentation cache" "excluir cache da documentação")
("delete entries" "excluir entradas")
("delete link" "excluir link")
("delete selected entries in wallet" "excluir entradas selecionadas na carteira")
("delete user identity" "excluir identidade do usuário")
("deleted" "excluído")
("describe" "descrever")
("describe tag" "descrever etiqueta")
("destroy" "destruir")
("detach master" "desanexar mestre")
("detailed" "detalhado")
("detailed menus" "menus detalhados")
("details in menus" "detalhes nos menus")
("determine margins from text width" "determinar margens a partir da largura do texto")
("developer" "desenvolvedor")
("developer tool" "ferramenta de desenvolvedor")
("device" "dispositivo")
("diamond" "diamante")
("differentiate" "diferenciar")
("digital" "digital")
("dilate" "dilatado")
("direction of progression" "direção da progressão")
("direction of translation" "direção da tradução")
("disable" "desativar")
("disable coloring on paper" "desativar coloração no papel")
("disable encryption" "desativar criptografia")
("disabled" "desativado")
("disappear" "desaparecer")
("disk" "disco")
("display style" "estilo de exibição")
("displayed formula" "fórmula exibida")
("dissociate joined cells" "dissociar células unidas")
("distill encapsulated Pdf files" "destila arquivos PDF encapsulados")
("distort" "distorcer")
("distorted" "distorcida")
("division" "divisão")
("do not remap" "não remapear")
("document colors" "cores do documento")
("document font selector" "seletor de fonte de documento")
("document language" "idioma do documento")
("document metadata" "metadados do documento")
("document page format" "formato de página do documento")
("document paragraph format" "formato de parágrafo do documento")
("document source tree preferences" "preferências da árvore de origem do documento")
("document updates run" "atualizações de documentos executadas")
("documents in separate windows" "documentos em janelas separadas")
("download" "download")
("download file or directory" "baixar arquivo ou diretório")
("downwards" "para baixo")
("dragging" "arrastando")
("draw" "empate")
("draw graphics" "desenhar gráficos")
("draw image" "desenhar imagem")
("draw over" "empate")
("draw over selection" "empate sobre a seleção")
("drop" "queda")
("due to" "devido a")
("dynamic" "dinâmico")
("eRROR" "eRROR")
("edit animation" "editar animação")
("edit groups of objects" "editar grupos de objetos")
("edit macro" "editar macro")
("edit macros" "editar macros")
("edit object properties" "editar propriedades do objeto")
("edit preamble" "editar preâmbulo")
("edit source" "editar fonte")
("edit source tree" "editar árvore de origem")
("edit style" "estilo de edição")
("edit translations file" "editar arquivo de traduções")
("education" "educação")
("effect pen" "caneta de efeito")
("eigenvalues" "autovalores")
("eighth" "oitavo")
("embold" "incold")
("emboss" "em relevo")
("enable page breaking" "ativar quebra de página")
("enabled" "ativado")
("encoding" "codificação")
("encrypt" "criptografar")
("encrypted" "criptografado")
("encrypted buffer" "buffer criptografado")
("encryption" "criptografia")
("encryption error" "erro de criptografia")
("encryption facilities are not currently available" "os recursos de criptografia não estão disponíveis no momento")
("encryption facilities have not been enabled for TeXmacs" "recursos de criptografia não foram ativados para o TeXmacs")
("enforce brackets to match" "aplicar colchetes para corresponder")
("engrave" "gravar")
("enter data" "inserir dados")
("enter graphics" "inserir gráficos")
("enter graphics mode" "entre no modo gráfico")
("enter new passphrase for encryption" "digite uma nova senha para criptografia")
("enter passphrase for decryption" "digite a senha para descriptografia")
("enter passphrase for identity" "digite a senha da identidade")
("enter title information" "inserir informações do título")
("entire table" "tabela inteira")
("entry up to date in database" "entrada atualizada no banco de dados")
("enunciation" "enunciação")
("environment variable" "variável de ambiente")
("environments" "ambientes")
("erode" "corroer")
("error messages" "mensagens de erro")
("error output" "saída de erro")
("error status report" "relatório de status do erro")
("error: bracket does not match" "erro: o suporte não corresponde")
("error: cyclic or missing chunks detected" "erro: pedaços cíclicos ou ausentes detectados")
("error: file not found" "erro: arquivo não encontrado")
("error: ghostview does not seem to be installed on your system" "erro: o ghostview não parece estar instalado no seu sistema")
("error: one of the alternatives should be filled out" "erro: uma das alternativas deve ser preenchida")
("error: only one alternatives should be filled out" "erro: apenas uma alternativa deve ser preenchida")
("error: should fill out name for referencing" "erro: deve preencher o nome para referência")
("error: should fill out required field" "erro: deve preencher o campo obrigatório")
("escape" "escape")
("evaluable field" "campo avaliável")
("evaluate above" "avaliar acima")
("evaluate all" "avaliar tudo")
("evaluate below" "avaliar abaixo")
("evaluate fields" "avaliar campos")
("evaluate fields in order" "avaliar campos em ordem")
("evaluate script" "script de avaliação")
("evaluation" "avaliação")
("evaluation switch" "interruptor de avaliação")
("evaluation tag" "etiqueta de avaliação")
("even page" "página par")
("even page left margin" "margem esquerda da página par")
("even page shift" "mudança de página uniforme")
("even pages" "páginas pares")
("events" "eventos")
("exact" "exato")
("execution of scripts" "execução de scripts")
("exit graphics" "gráficos de saída")
("exit graphics mode" "sair do modo gráfico")
("exit left" "saída esquerda")
("exit right" "saída à direita")
("exit tag on the left" "etiqueta de saída à esquerda")
("exit tag on the right" "etiqueta de saída à direita")
("expand TeXmacs macros with no LaTeX equivalents" "expanda as macros do TeXmacs sem equivalentes ao LaTeX")
("expand beamer slides" "expandir slides beamer")
("expand inclusions" "expandir inclusões")
("expand logarithms" "expandir logaritmos")
("expand trigonometric functions" "expandir funções trigonométricas")
("expand unrecognized macros" "expandir macros não reconhecidas")
("expand user-defined macros" "expandir macros definidas pelo usuário")
("expanded" "expandido")
("experimental features (to be used with care)" "recursos experimentais (a serem usados â\x80\x8bâ\x80\x8bcom cuidado)")
("explain" "explicar")
("explanatory item" "item explicativo")
("explicit keystroke" "pressionamento de tecla explícito")
("explicit margins" "margens explícitas")
("exponential" "exponencial")
("export bibliographies as links" "exportar bibliografias como links")
("export bibliography" "bibliografia de exportação")
("export entries in buffer" "exportar entradas no buffer")
("export file" "arquivo de exportação")
("export formulas as images" "exportar fórmulas como imagens")
("export mathematical formulas as MathML" "exportar fórmulas matemáticas como MathML")
("export mathematical formulas as images" "exportar fórmulas matemáticas como imagens")
("export selected entries" "exportar entradas selecionadas")
("export selection" "seleção de exportação")
("export selection as image" "seleção de exportação como imagem")
("export selections as" "seleções de exportação como")
("export sessions" "sessões de exportação")
("exported bibliographic entries" "entradas bibliográficas exportadas")
("exported bibliographic references" "referências bibliográficas exportadas")
("extend" "estender")
("extend table to full paragraph width" "estender a tabela para a largura total do parágrafo")
("extended" "estendido")
("extensible left arrow" "seta esquerda extensível")
("extensible right arrow" "seta direita extensível")
("extern" "externo")
("external" "externo")
("extra branch" "ramo extra")
("extra interline space" "espaço interline extra")
("extra name" "nome extra")
("extract" "extrato")
("extract style file" "extrair arquivo de estilo")
("extract style package" "extrair pacote de estilo")
("factor" "fator")
("fade" "desaparecer")
("fade in" "desaparecer")
("fade out" "desaparecer")
("fast" "rápido")
("fast decrease" "diminuição rápida")
("fast environments" "ambientes rápidos")
("fast increase" "aumento rápido")
("field reference" "referência de campo")
("fifth" "quinto")
("file saved" "arquivo salvo")
("fill color" "cor de preenchimento")
("fill out" "preencher")
("filter" "filtro")
("find file" "localizar arquivo")
("finished collecting symbols documentation" "terminou de coletar a documentação dos símbolos")
("first" "primeiro")
("first chunk" "primeiro pedaço")
("first difference" "primeira diferença")
("first error" "primeiro erro")
("first field" "primeiro campo")
("first occurrence" "primeira ocorrência")
("first similar" "primeiro similar")
("fit" "apto")
("fit to height" "ajuste à altura")
("fit to screen" "adequado para a tela")
("fit to screen width" "ajustado à largura da tela")
("fit to width" "ajuste à largura")
("five columns" "cinco colunas")
("fixed" "fixo")
("flag is off" "sinalizador está desativado")
("flag is on" "sinalizador está ativado")
("flatten" "nivelar")
("floating algorithm" "algoritmo flutuante")
("floating phantom" "fantasma flutuante")
("focus" "foco")
("focus dependent icons" "ícones dependentes do foco")
("fold all" "dobre tudo")
("fold all fields" "dobre todos os campos")
("fold back" "dobra para trás")
("fold input field" "campo de entrada dobrável")
("follow external links" "seguir links externos")
("follow inverse links" "siga links inversos")
("font customization" "personalização de fonte")
("font effects" "efeitos de fonte")
("font selector" "seletor de fonte")
("font type" "tipo de fonte")
("for each" "para cada")
("force reloading of translations" "forçar o recarregamento de traduções")
("formatted and structured output" "saída formatada e estruturada")
("formatting" "formatação")
("forward" "encaminhado")
("four columns" "quatro colunas")
("four dots" "quatro pontos")
("fourth" "quarto")
("fraktur" "fraktur")
("framed" "emoldurado")
("framed theorems" "teoremas enquadrados")
("from" "de")
("from center" "do centro")
("front matter" "assunto dianteiro")
("full" "cheio")
("full author list" "lista completa de autores")
("full screen mode" "modo de tela cheia")
("functional" "funcional")
("gap" "intervalo")
("garbage collection" "coleta de lixo")
("gaussian" "gaussiano")
("gcd" "gcd")
("general" "geral")
("general note" "nota geral")
("generate GnuPG key" "gerar chave GnuPG")
("generated LaTeX document contains no errors" "o documento LaTeX gerado não contém erros")
("generated field" "campo gerado")
("geometry" "geometria")
("get arity" "obter aridade")
("get label" "obter rótulo")
("get list with remote versions" "obter lista com versões remotas")
("global log" "log global")
("global status" "status global")
("glue multiple spaces" "cole vários espaços")
("glyphs" "glifos")
("gnaw" "roer")
("gnawed" "roído")
("gnuPG command" "comando gnuPG")
("gnuPG decryption error" "erro de descriptografia do gnuPG")
("gnuPG error: buffer encryption failed" "Erro no gnuPG: falha na criptografia do buffer")
("gnuPG error: cannot find suitable secret key to decrypt" "erro gnuPG: não é possível encontrar a chave secreta adequada para descriptografar")
("gnuPG requires name and email to have at least 5 characters" "o gnuPG requer que o nome e o email tenham pelo menos 5 caracteres")
("go to anchor" "ancorar")
("go to anchor or float" "ancorar ou flutuar")
("go to anchor or footnote" "ir para a âncora ou nota de rodapé")
("go to first similar tag" "vá para a primeira tag semelhante")
("go to float" "flutuar")
("go to footnote" "vá para nota de rodapé")
("go to last similar tag" "ir para a última tag semelhante")
("go to next similar tag" "vá para a próxima tag semelhante")
("go to previous similar tag" "vá para a tag semelhante anterior")
("go to section" "vá para a seção")
("grain" "grão")
("granite" "granito")
("graphical effects" "efeitos gráficos")
("graphical interface font scale" "escala de fonte da interface gráfica")
("graphical overlays" "sobreposições gráficas")
("graphical slides and overlays" "slides e sobreposições gráficas")
("graphics" "gráficos")
("graphics geometry" "geometria gráfica")
("graphics grids" "grades gráficas")
("greyed" "acinzentado")
("grid" "grade")
("grid curves" "curvas de grade")
("grid points" "pontos da grade")
("grid-curve intersections" "interseções curva-grade")
("group of objects" "grupo de objetos")
("group/ungroup" "agrupar / desagrupar")
("group/ungroup objects" "agrupar / desagrupar objetos")
("grouped" "agrupado")
("guarantee transparent source tracking" "garantir rastreamento transparente da fonte")
("h modifier" "modificador h")
("half wide" "meia largura")
("hand drawn" "desenhado à mão")
("handwritten" "manuscrita")
("hangul" "hangul")
("headers" "cabeçalhos")
("hidden" "oculto")
("high resolution settings" "configurações de alta resolução")
("history" "história")
("homepage" "homepage")
("homoglyph substitutions" "substituições de homoglifos")
("horizontal alignment" "alinhamento horizontal")
("horizontal collapse distance" "distância de colapso horizontal")
("horizontal margins" "margens horizontais")
("hybrid command" "comando híbrido")
("hyphenate as" "hifenizar como")
("icon" "ícone")
("if hyphenated" "se hifenizado")
("ignore" "ignorar")
("impact" "impacto")
("import bibliography" "importar bibliografia")
("import database entry" "importar entrada do banco de dados")
("import entries in buffer" "importar entradas no buffer")
("import entry" "entrada de importação")
("import file" "arquivo de importação")
("import public keys from buffer" "importar chaves públicas do buffer")
("import selected database entries" "importar entradas selecionadas do banco de dados")
("import selected entries" "importar entradas selecionadas")
("import selections as" "importar seleções como")
("import sessions" "sessões de importação")
("import sophisticated objects as pictures" "importa objetos sofisticados como figuras")
("imported bibliographic entries" "entradas bibliográficas importadas")
("in popup windows" "em janelas pop-up")
("inanimated" "inanimado")
("inch" "polegadas")
("incomplete entries found to be filled out" "entradas incompletas encontradas para serem preenchidas")
("increase size" "aumentar tamanho")
("indent paragraphs" "parágrafos de travessão")
("indentation" "recuo")
("indication" "indicação")
("informative flags" "sinalizadores informativos")
("initialize" "inicializar")
("initialize wallet" "inicializar carteira")
("initials" "iniciais")
("ink here" "tinta aqui")
("ink in" "tinta in")
("ink out" "sem tinta")
("inline" "inline")
("inline args" "args em linha")
("inline arguments" "argumentos em linha")
("inline code" "código embutido")
("inline content" "conteúdo embutido")
("inline formula" "fórmula em linha")
("inner bottom" "parte inferior interna")
("inner left" "interior esquerdo")
("inner right" "direito interno")
("inner top" "parte superior interna")
("input command" "comando de entrada")
("input field" "campo de entrada")
("input mode" "modo de entrada")
("input options" "opções de entrada")
("insert a blackboard bold character" "inserir um caractere em negrito do quadro-negro")
("insert a bold calligraphic character" "insira um caractere caligráfico em negrito")
("insert a bold character" "insira um caractere em negrito")
("insert a computer program" "inserir um programa de computador")
("insert a condition" "inserir uma condição")
("insert a control flow instruction" "insira uma instrução de fluxo de controle")
("insert a gap" "insira um espaço")
("insert a list" "inserir uma lista")
("insert a multiple choice" "insira uma escolha múltipla")
("insert a negation" "insira uma negação")
("insert a new entry" "insira uma nova entrada")
("insert a note or a floating object" "insira uma nota ou um objeto flutuante")
("insert a numerical operation" "insira uma operação numérica")
("insert a prominent piece of text" "insira um pedaço de texto proeminente")
("insert a question" "inserir uma pergunta")
("insert a root" "inserir uma raiz")
("insert a script" "inserir um script")
("insert a section block" "inserir um bloco de seção")
("insert a textual operation" "inserir uma operação textual")
("insert a textual operator" "insira um operador textual")
("insert a wide symbol above" "insira um símbolo largo acima")
("insert a wide symbol below" "insira um símbolo largo abaixo")
("insert above" "inserção acima")
("insert abstract" "inserir resumo")
("insert an answer" "insira uma resposta")
("insert an enunciation" "inserir uma enunciação")
("insert an operation on tuples" "inserir uma operação em tuplas")
("insert annotation" "inserir anotação")
("insert arcs" "inserir arcos")
("insert argument after" "inserir argumento depois")
("insert argument before" "inserir argumento antes")
("insert author" "inserir autor")
("insert below" "insira abaixo")
("insert bibliography" "inserir bibliografia")
("insert circles" "inserir círculos")
("insert closed splines" "inserir splines fechados")
("insert copyright and license information" "inserir informações de direitos autorais e licença")
("insert explanatory item" "inserir item explicativo")
("insert field above" "inserir campo acima")
("insert field below" "insira o campo abaixo")
("insert fields" "inserir campos")
("insert hand drawn curves" "inserir curvas desenhadas à mão")
("insert input field above" "inserir campo de entrada acima")
("insert input field below" "inserir campo de entrada abaixo")
("insert large delimiters" "inserir delimitadores grandes")
("insert last name" "inserir sobrenome")
("insert left" "inserir à esquerda")
("insert lines" "inserir linhas")
("insert macro" "inserir macro")
("insert missing invisible operators" "insira operadores invisíveis ausentes")
("insert more names" "insira mais nomes")
("insert multiple paragraphs" "inserir vários parágrafos")
("insert overlay after" "inserir sobreposição depois")
("insert overlay before" "inserir sobreposição antes")
("insert particle" "inserir partícula")
("insert plain text" "inserir texto sem formatação")
("insert points" "inserir pontos")
("insert polygons" "inserir polígonos")
("insert right" "inserir à direita")
("insert similar above" "insira similar acima")
("insert similar below" "insira similar abaixo")
("insert similar block above" "insira bloco semelhante acima")
("insert similar block below" "insira bloco semelhante abaixo")
("insert slide after" "inserir slide depois")
("insert slide before" "inserir slide antes")
("insert splines" "inserir splines")
("insert subscript" "inserir subscrito")
("insert subtable" "inserir subtabela")
("insert superscript" "inserir sobrescrito")
("insert symbol documentation" "inserir documentação do símbolo")
("insert template" "inserir modelo")
("insert text" "inserir texto")
("insert text field" "inserir campo de texto")
("insert text field above" "inserir campo de texto acima")
("insert text field below" "insira o campo de texto abaixo")
("insert title" "inserir título")
("insert title after name" "inserir título após o nome")
("insert user interface related markup" "inserir marcação relacionada à interface do usuário")
("insert value" "inserir valor")
("inserting control points" "inserção de pontos de controle")
("inside mathematics" "dentro da matemática")
("integrate" "integrar")
("interactive command" "comando interativo")
("interactive questions" "perguntas interativas")
("intercharacter compression" "compressão entre caracteres")
("intercharacter stretching" "alongamento entre caracteres")
("interfacing" "interface")
("interfacing TeXmacs with other systems" "interface do TeXmacs com outros sistemas")
("interrupted" "interrompido")
("invalid multi-paragraph selection" "seleção inválida de vários parágrafos")
("invalid renaming" "renomeação inválida")
("invert" "invertido")
("inverted breve" "invertido breve")
("invisible ending" "final invisível")
("invisible newline" "nova linha invisível")
("invisible opening" "abertura invisível")
("inwards" "para dentro")
("join selected cells" "ingressar nas células selecionadas")
("jump in" "pula para dentro")
("junior" "júnior")
("justify" "justificar")
("keep evaluated expressions" "manter expressões avaliadas")
("keep local" "manter local")
("keep remote" "mantenha remoto")
("keep track of source code" "acompanhe o código fonte")
("keep unfolded" "manter desdobrado")
("key manager" "gerenciador de chaves")
("keyboard configuration" "configuração do teclado")
("laTeX errors" "erros laTeX")
("laptop presentations" "apresentações para laptop")
("large brackets" "colchetes grandes")
("large cells" "células grandes")
("large displayed" "grande exibido")
("large displayed fraction" "fração grande exibida")
("large tables" "mesas grandes")
("last" "último")
("last check" "última verificação")
("last difference" "última diferença")
("last error" "último erro")
("last field" "último campo")
("last name" "sobrenome")
("last occurrence" "última ocorrência")
("last similar" "último similar")
("lcm" "cm")
("left arrow" "seta para a esquerda")
("left axis" "eixo esquerdo")
("left baseline" "linha de base esquerda")
("left bottom" "canto inferior esquerdo")
("left cell border" "borda da célula esquerda")
("left cell padding" "preenchimento da célula esquerda")
("left center" "centro esquerdo")
("left click: add point; Right click: undo" "clique esquerdo: adicionar ponto; clique direito: desfazer")
("left click: finish; Right click: undo" "clique esquerdo: concluir; clique direito: desfazer")
("left click: new object" "clique esquerdo: novo objeto")
("left click: operate" "clique esquerdo: operar")
("left down" "esquerda para baixo")
("left on even pages" "restantes nas páginas pares")
("left table border" "borda esquerda da tabela")
("left table padding" "estofamento à esquerda")
("left top" "canto superior esquerdo")
("left up" "esquerda para cima")
("left-right arrow" "seta esquerda-direita")
("leftwards" "para a esquerda")
("let the environment float" "deixe o ambiente flutuar")
("light grey" "cinza claro")
("line arrows" "setas de linha")
("line breaking" "quebra de linha")
("line dashes" "traços de linha")
("line portion" "parte da linha")
("line style" "estilo de linha")
("line width" "largura da linha")
("line wrapping" "quebra de linha")
("line wrapping inside cell" "quebra de linha dentro da célula")
("linear 2D" "2D linear")
("linear algebra" "álgebra linear")
("lines around" "linhas ao redor")
("link image and copies as" "vincule a imagem e copie como")
("link image as" "vincular imagem como")
("link mode" "modo de link")
("link to URL" "link para URL")
("linking tool" "ferramenta de vinculação")
("live" "ao vivo")
("live input-output" "entrada-saída ao vivo")
("load help file" "carregar arquivo de ajuda")
("load remote file" "carregar arquivo remoto")
("loading" "carregando")
("local entries" "entradas locais")
("loci" "loci")
("locus" "locus")
("locus rendering" "renderização do locus")
("logarithm" "logaritmo")
("logarithmic" "logarítmico")
("logarithmic base" "base logarítmica")
("logarithms" "logaritmos")
("logging in" "efetuando login")
("logical and" "lógico e")
("logical implication" "implicação lógica")
("logical not" "não lógico")
("logical or" "lógico ou")
("login" "login")
("logout" "logout")
("long macro" "macro longa")
("long text" "texto longo")
("look for more fonts" "procure mais fontes")
("loops" "loops")
("m modifier" "modificador m")
("macro argument" "argumento macro")
("macro definition" "definição de macro")
("macro editor" "editor de macro")
("macro name" "nome da macro")
("macros" "macros")
("macros editor" "editor de macros")
("magnify horizontally" "ampliar horizontalmente")
("magnify vertically" "ampliar verticalmente")
("main presentation style" "estilo de apresentação principal")
("make a letter environment" "criar um ambiente de letra")
("make a multi-slide presentation" "faça uma apresentação de vários slides")
("make block wide" "tornar o bloco largo")
("make float wide" "faça flutuar largo")
("make floating" "tornar flutuante")
("make footnote wide" "tornar a nota de rodapé larga")
("make link" "criar link")
("make non floating" "tornar não flutuante")
("make wide" "amplie")
("manila paper" "papel pardo")
("map arguments" "argumentos do mapa")
("marginal note" "nota marginal")
("margins from width" "margens da largura")
("margins on paper" "margens no papel")
("margins on screen" "margens na tela")
("marked" "marcado")
("marker" "marcador")
("material" "material")
("math Extra" "matemática extra")
("math Letters" "Letras matemáticas")
("math Symbols" "Símbolos matemáticos")
("mathematical and customized input" "entrada matemática e personalizada")
("mathematical font" "fonte matemática")
("mathematical input" "entrada matemática")
("mathematical output" "saída matemática")
("matrices" "matrizes")
("maximal" "máximo")
("maximal cell height" "altura máxima da célula")
("maximal clustering" "cluster máximo")
("maximal table height" "altura máxima da mesa")
("maximal table width" "largura máxima da tabela")
("maximum" "máximo")
("meander" "meandro")
("medieval" "medieval")
("memory" "memória")
("memory usage" "uso de memória")
("menu" "menu")
("merge lines into paragraphs unless separated by blank lines" "mesclar linhas em parágrafos, a menos que separadas por linhas em branco")
("messages" "mensagens")
("meta data" "metadados")
("metadata" "metadados")
("metal" "metal")
("middle baseline" "linha de base média")
("minimal" "mínimo")
("minimal cell height" "altura mínima da célula")
("minimal cell width" "largura mínima da célula")
("minimal line separation" "separação mínima de linha")
("minimal table height" "altura mínima da mesa")
("minimal table width" "largura mínima da mesa")
("minimum" "mínimo")
("mirror" "espelho")
("miscellaneous features" "recursos diversos")
("miscellanous" "variado")
("mixed" "misto")
("mode dependent icons" "ícones dependentes do modo")
("modify bibliography" "modificar bibliografia")
("modify remote live document" "modificar documento ativo remoto")
("module" "módulo")
("module browser" "módulo de navegação")
("monospaced" "monoespaçado")
("more information about GNU TeXmacs can be found in the Help" "mais informações sobre o GNU TeXmacs podem ser encontradas na Ajuda")
("more information about GNU TeXmacs can be found in the Help-<gtr>About menu" "mais informações sobre o GNU TeXmacs podem ser encontradas no menu Ajuda-<gtr> Sobre")
("motion" "movimento")
("mouse over object" "passar o mouse sobre o objeto")
("move" "movimento")
("move objects" "mover objetos")
("move over object on which to operate" "mova o objeto sobre o qual operar")
("multiline" "multilinha")
("multiline input" "entrada multilinha")
("multiple choice" "múltipla escolha")
("multiple documents share window" "janela de compartilhamento de vários documentos")
("multiple root" "raiz múltipla")
("multiplication" "multiplicação")
("mutator tags" "tags mutadoras")
("my documents" "meus documentos")
("named" "nomeado")
("navigation options" "opções de navegação")
("never" "nunca")
("new account" "nova conta")
("new bibliography dialogue" "novo diálogo bibliográfico")
("new document" "novo documento")
("new double page" "nova página dupla")
("new double page before" "nova página dupla antes")
("new entry" "nova entrada")
("new identity" "nova identidade")
("new locus" "novo locus")
("new macro" "nova macro")
("new passphrase" "nova senha")
("new remote directory" "novo diretório remoto")
("new remote file" "novo arquivo remoto")
("new style fonts" "novas fontes de estilo")
("new style page breaking" "quebra de página de novo estilo")
("new version" "nova versão")
("new window" "nova janela")
("newer version" "versão mais recente")
("next" "próximo")
("next chunk" "próximo pedaço")
("next difference" "próxima diferença")
("next error" "próximo erro")
("next field" "próximo campo")
("next occurrence" "próxima ocorrência")
("next screen" "próxima tela")
("next similar" "próximo similar")
("no animation" "sem animação")
("no clustering" "sem agrupamento")
("no completions" "sem conclusões")
("no errors have been corrected" "nenhum erro foi corrigido")
("no grid" "sem grade")
("no matches found for" "nenhuma correspondência encontrada para")
("no multiple spaces" "sem espaços múltiplos")
("no new public key in document" "nenhuma nova chave pública no documento")
("no page break" "sem quebra de página")
("no page numbers" "sem números de página")
("no parent" "sem pai")
("no selection" "sem seleção")
("no spelling errors" "sem erros de ortografia")
("no spurious spaces" "sem espaços espúrios")
("normal loci" "loci normal")
("not allowed to remove home directory" "não é permitido remover o diretório inicial")
("not connected to server" "não conectado ao servidor")
("not yet implemented" "ainda não implementado")
("notebook" "caderno")
("number of polar steps" "número de etapas polares")
("number of subunit steps" "número de etapas da subunidade")
("numbered" "numerado")
("numbering" "numeração")
("numeric spreadsheet" "planilha numérica")
("oblique" "oblíquo")
("odd page" "página ímpar")
("odd page left margin" "margem esquerda da página ímpar")
("odd page right margin" "margem direita da página ímpar")
("odd page shift" "deslocamento de página ímpar")
("odd pages" "páginas ímpares")
("of fingerprint" "de impressão digital")
("old version" "versão antiga")
("older version" "versão mais antiga")
("on the footer" "no rodapé")
("on your system and set it up from the \"Security\" tab" "no seu sistema e configure-o na guia \"Segurança\"")
("once" "uma vez")
("one column" "uma coluna")
("one error has been corrected" "um erro foi corrigido")
("one lower case letter, one non alpha-numeric symbol" "uma letra minúscula, um símbolo não alfanumérico")
("one numeric character, one upper case letter" "um caractere numérico, uma letra maiúscula")
("only convert changes when re-importing" "apenas converte alterações ao reimportar")
("only convert changes with respect to imported version" "apenas converte alterações em relação à versão importada")
("only convert changes with respect to tracked version" "apenas converte alterações em relação à versão rastreada")
("only implemented for complete subtrees" "implementado apenas para subárvores completas")
("only inline tags" "apenas tags embutidas")
("only keep folded" "apenas manter dobrado")
("only keep unfolded" "apenas desdobrar")
("only show paragraphs with hits" "mostra apenas parágrafos com hits")
("only show semantic focus" "mostra apenas foco semântico")
("opacity" "opacidade")
("open bibliography" "bibliografia aberta")
("open identities" "identidades abertas")
("open in new window" "abrir em uma nova janela")
("open key manager" "gerenciador de chaves abertas")
("open licence agreement" "contrato de licença aberto")
("open mailbox" "caixa de correio aberta")
("open module browser" "navegador de módulo aberto")
("open symbol browser" "navegador de símbolos abertos")
("open tool in separate window" "ferramenta aberta em janela separada")
("operation mode" "modo de operação")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "ou forneça o caminho completo para o comando \"gpg\" ou \"gpg2\"")
("order" "pedido")
("ordinary symbol" "símbolo comum")
("ornamented" "ornamentado")
("other login" "outro login")
("other package" "outro pacote")
("outer bottom" "fundo externo")
("outer left" "exterior esquerdo")
("outer right" "direito externo")
("outer top" "parte superior externa")
("outline" "estrutura de tópicos")
("outlined" "descrito")
("outlined emboss" "relevo delineado")
("outlined engrave" "gravado delineado")
("output options" "opções de saída")
("outwards" "externo")
("oval" "oval")
("overbrace" "ultrapassar")
("overlap" "sobreposição")
("overlay" "sobreposição")
("overlay mode" "modo de sobreposição")
("overlays" "sobreposições")
("overline" "overline")
("overlined" "sublinhado")
("overview of the scheme extension language" "visão geral da linguagem de extensão do esquema")
("padded" "acolchoado")
("page background" "fundo da página")
("page break after" "quebra de página após")
("page breaking algorithm" "algoritmo de quebra de página")
("page format" "formato da página")
("page number" "número da página")
("page number rendering" "renderização do número da página")
("page rendering" "renderização de página")
("page setup" "configuração da página")
("pagedown" "pagedown")
("pageup" "pageup")
("palette" "paleta")
("panorama" "panorama")
("paragraph format" "formato de parágrafo")
("paragraphs" "parágrafos")
("parametric curve" "curva paramétrica")
("parametric surface" "superfície paramétrica")
("parenthesis" "parênteses")
("parenthesized" "entre parênteses")
("particle" "partícula")
("passphrase decryption" "descriptografia de senha")
("passphrase encryption" "criptografia de senha")
("passphrase wallet facilities are not currently available" "")
("passphrases are expected to have at least: 8 characters" "")
("passphrases mismatch" "")
("pastel" "")
("pattern" "")
("pattern selector" "seletor de padrão")
("pause" "")
("pdf version number" "número da versão em pdf")
("pen" "caneta")
("pen width" "")
("permanent footer" "")
("permanent header" "")
("permanently add to dictionary" "")
("permanently insert into dictionary" "")
("permissions" "")
("phantom" "")
("phantoms" "")
("physics and astronomy class" "")
("picture" "")
("pine" "")
("plain" "")
("plain boxes" "")
("plain circles" "")
("play" "")
("play all animations" "reproduzir todas as animações")
("play animation" "")
("please install GnuPG software from https://www.gnupg.org" "")
("plot" "")
("plug-ins" "")
("plugin" "")
("plugins" "")
("plural" "")
("point" "")
("point border" "borda do ponto")
("point size" "tamanho do ponto")
("point style" "estilo de ponto")
("polar" "")
("polygon" "")
("pop server settings" "")
("portion" "porção")
("position of marginal note" "")
("poster formats" "")
("poster theme" "")
("postfix" "")
("preferences for editing mathematical formulas" "")
("preferences for tag" "")
("prefix" "")
("presentation" "")
("presentation tag" "")
("presentation tool" "")
("preserve" "")
("preserve tags" "")
("pretty" "bonita")
("pretty tree output" "")
("preview" "")
("preview command" "")
("previous" "")
("previous difference" "")
("previous error" "")
("previous field" "")
("previous occurrence" "")
("previous screen" "")
("previous similar" "")
("primitive or macro" "")
("print buffer" "")
("print buffer to file" "")
("print document" "imprimir documento")
("print to file" "")
("printer setup" "")
("produce Pdf using native export filter" "produz Pdf usando filtro de exportação nativo")
("produce Postscript using native export filter" "produz Postscript usando filtro de exportação nativo")
("program bracket matching" "")
("program bracket selections" "")
("program commands" "")
("program font" "")
("program interface for buffer management" "")
("programming routines for editing documents" "")
("prominent" "")
("prompts and default input" "")
("provoke C++ error" "")
("provoke menu error" "")
("provoke scheme error" "")
("pseudo code" "")
("public key encryption" "")
("public keys" "")
("pulse" "")
("qt GUI only, sorry. Use \"Export selection\"" "")
("qt-widgets" "widgets qt")
("quantifier" "quantificador")
("quasi" "quase")
("question" "pergunta")
("questions only" "somente perguntas")
("questions with answers" "perguntas com respostas")
("quick evaluation of formulas" "avaliação rápida de fórmulas")
("rank" "classificação")
("raw" "bruto")
("really delete user identity" "realmente exclui a identidade do usuário")
("really tiny" "realmente pequeno")
("rebuild translations file" "recriar arquivo de traduções")
("recent" "recente")
("recent documents" "documentos recentes")
("recipients" "destinatários")
("recognize" "reconhecer")
("recolor" "recolorir")
("recover autosave file" "recuperar arquivo de salvamento automático")
("rectangular" "retangular")
("reduce" "redução")
("reduce trigonometric functions" "reduz funções trigonométricas")
("reduced margins" "margens reduzidas")
("reference guide" "guia de referência")
("reference guide for the TeXmacs primitives" "guia de referência para as primitivas TeXmacs")
("reference guide for the standard TeXmacs styles" "guia de referência para os estilos padrão do TeXmacs")
("regenerate" "regenerar")
("register" "registro")
("register file" "arquivo de registro")
("relate" "relacionar")
("relation" "relação")
("release left button: finish editing" "solte o botão esquerdo: finalize a edição")
("remote" "remoto")
("remote connections" "conexões remotas")
("remote control" "controle remoto")
("remote controllers with keyboard simulation" "controladores remotos com simulação de teclado")
("remote directory" "diretório remoto")
("remote login" "login remoto")
("remote servers" "servidores remotos")
("remote tool" "ferramenta remota")
("remove" "remover")
("remove all output fields" "remover todos os campos de saída")
("remove animation" "remover animação")
("remove argument after" "remover argumento depois")
("remove argument before" "remover argumento antes")
("remove banner" "remover banner")
("remove database entry" "remover entrada do banco de dados")
("remove downwards" "remover para baixo")
("remove entries" "remover entradas")
("remove entry" "remover entrada")
("remove field above" "remover campo acima")
("remove field below" "remover campo abaixo")
("remove fields" "remover campos")
("remove folded" "remover dobrado")
("remove from previous frames" "remover dos quadros anteriores")
("remove from subsequent frames" "remover dos quadros subsequentes")
("remove input field" "remover campo de entrada")
("remove input field above" "remover campo de entrada acima")
("remove last field" "remover último campo")
("remove leftwards" "remova para a esquerda")
("remove link" "remover link")
("remove next field" "remover próximo campo")
("remove overlay after" "remover sobreposição depois")
("remove overlay before" "remover sobreposição antes")
("remove package" "remover pacote")
("remove previous field" "remover campo anterior")
("remove rightwards" "remova para a direita")
("remove selected database entries" "remover entradas selecionadas do banco de dados")
("remove selected entries" "remover entradas selecionadas")
("remove slide after" "remover o slide depois")
("remove slide before" "remova o slide antes")
("remove superfluous invisible operators" "remova operadores invisíveis supérfluos")
("remove tag" "remover etiqueta")
("remove this branch" "remover esta ramificação")
("remove this frame" "remover este quadro")
("remove this switch" "remova esta opção")
("remove unfolded" "remover desdobrado")
("remove upwards" "remova para cima")
("removed entries from database" "entradas removidas do banco de dados")
("removed entry from database" "entrada removida do banco de dados")
("rename" "renomear")
("rename section" "renomear seção")
("rendering" "renderizando")
("rendering options for tag" "opções de renderização para tag")
("repeat" "repetição")
("replace TeXmacs styles with no LaTeX equivalents" "substitua os estilos TeXmacs por nenhum equivalente LaTeX")
("replace all further occurrences" "substituir todas as outras ocorrências")
("replace one occurrence" "substituir uma ocorrência")
("replace toolbar" "substituir barra de ferramentas")
("replace unrecognized styles" "substituir estilos não reconhecidos")
("reset error counters" "redefinir contadores de erros")
("resize" "redimensionar")
("resize objects" "redimensionar objetos")
("restart TeXmacs in order to let changes take effect" "reinicie o TeXmacs para permitir que as alterações entrem em vigor")
("restart in order to let the new look and feel take effect" "reinicie para deixar a nova aparência entrar em vigor")
("retain" "reter")
("retime" "tempo de espera")
("retina settings" "configurações de retina")
("retrieve email" "recuperar email")
("retrieve remote live document" "recuperar documento ativo remoto")
("retrieved contents" "conteúdo recuperado")
("retro" "retro")
("reverse" "reverso")
("reverse ordering" "pedido inverso")
("ridged paper" "papel enrugado")
("right arrow" "seta para a direita")
("right baseline" "linha de base direita")
("right cell border" "borda direita da célula")
("right cell padding" "preenchimento de célula direito")
("right down" "logo abaixo")
("right on even pages" "diretamente nas páginas pares")
("right table border" "borda direita da tabela")
("right table padding" "estofamento à direita")
("right up" "direto")
("rightwards" "para a direita")
("rigid box" "caixa rígida")
("rotate" "girar")
("rotate objects" "rotacionar objetos")
("rough" "aproximado")
("rough paper" "papel áspero")
("round" "redondo")
("round overbrace" "cobertura redonda")
("round underbrace" "barra inferior redonda")
("row above" "linha acima")
("row below" "linha abaixo")
("rows" "linhas")
("run" "corrida")
("run current file" "executar arquivo atual")
("running author" "autor em execução")
("running title" "título em execução")
("same names" "mesmos nomes")
("same screen margins as on paper" "mesmas margens de tela que no papel")
("sample text" "texto de amostra")
("save auxiliary data" "salvar dados auxiliares")
("save entries" "salvar entradas")
("save entry" "salvar entrada")
("save image as" "salvar imagem como")
("save position" "salvar posição")
("save remote file" "salvar arquivo remoto")
("saved modifications in database" "modificações salvas no banco de dados")
("scheme command" "comando do esquema")
("scheme developers guide" "guia do desenvolvedor de esquemas")
("scheme extensions" "extensões de esquema")
("scheme interface for the graphical mode" "interface de esquema para o modo gráfico")
("screen" "tela")
("screen rendering" "renderização de tela")
("screens" "telas")
("screenshot" "captura de tela")
("scripting language" "linguagem de script")
("scripts" "scripts")
("search and replace" "pesquisar e substituir")
("search in database" "pesquisar no banco de dados")
("search results for" "resultados da pesquisa para")
("search toolbar" "barra de ferramentas de pesquisa")
("search words in my documents" "procure palavras nos meus documentos")
("search words in the documentation" "procure palavras na documentação")
("search words in the source code" "procure palavras no código fonte")
("second" "segundo")
("secret keys" "chaves secretas")
("sections" "seções")
("see documentation" "ver documentação")
("select GnuPG recipients" "selecione destinatários do GnuPG")
("select background picture" "selecionar imagem de fundo")
("select document style" "selecionar estilo de documento")
("select pen" "selecionar caneta")
("select the action to be undertaken for each conflict" "selecione a ação a ser realizada para cada conflito")
("select view mode" "selecione o modo de visualização")
("semantic correctness" "correção semântica")
("semantic editing" "edição semântica")
("semantic selections" "seleções semânticas")
("semantics" "semântica")
("sending commands to TeXmacs" "enviando comandos para o TeXmacs")
("senior" "sênior")
("serif" "serifa")
("server" "servidor")
("server licence agreement" "contrato de licença do servidor")
("session commands" "comandos de sessão")
("set default" "definir padrão")
("set difference" "definir diferença")
("set intersection" "definir interseção")
("set number of columns" "definir número de colunas")
("set number of rows" "definir número de linhas")
("set or get environment variables" "definir ou obter variáveis â\x80\x8bâ\x80\x8bde ambiente")
("set properties" "definir propriedades")
("set union" "união do conjunto")
("set user information" "definir informações do usuário")
("seventh" "sétimo")
("several equations" "várias equações")
("shadow" "sombra")
("shadowed" "sombreado")
("shadowed raise" "aumento sombreado")
("shift" "turno")
("short" "curto")
("show all parts" "mostrar todas as peças")
("show current focus" "mostrar foco atual")
("show full context" "mostrar contexto completo")
("show hidden" "show hidden")
("show key presses" "mostrar pressionamentos de tecla")
("show main document" "mostra documento principal")
("show memory usage" "mostra o uso da memória")
("show one part" "mostra uma parte")
("show panorama" "mostrar panorama")
("show preamble" "mostra preâmbulo")
("show several parts" "mostra várias partes")
("show subunits" "mostrar subunidades")
("show table cells" "mostrar células da tabela")
("show timings" "horários de exibição")
("side tools" "ferramentas laterais")
("simple" "simples")
("simple form" "formulário simples")
("simple widget" "widget simples")
("simplification" "simplificação")
("simplified evaluation of formulas" "avaliação simplificada de fórmulas")
("simplified menus" "menus simplificados")
("simplify" "simplificar")
("sine" "seno")
("sixth" "sexto")
("size tag" "etiqueta de tamanho")
("skew" "inclinado")
("skin" "pele")
("skip all" "pular tudo")
("slant" "inclinado")
("slashed fraction" "fração cortada")
("slides" "slides")
("sloppy" "desleixado")
("slovene" "esloveno")
("slow" "lento")
("slow decrease" "diminuição lenta")
("slow increase" "aumento lento")
("small Capitals" "pequenas capitais")
("small capitals" "pequenas capitais")
("small environment box" "pequena caixa de ambiente")
("small focus" "foco pequeno")
("small inline" "pequena linha")
("small inline fraction" "pequena fração embutida")
("smash" "esmagar")
("smooth" "suave")
("smooth end" "final suave")
("smooth extremities" "extremidades lisas")
("smooth start" "início suave")
("snap" "pressão")
("snap distance" "distância do snap")
("snap to curves" "encaixe nas curvas")
("snap to grid" "encaixar na grade")
("snap to grid curve" "ajustar a curva da grade")
("snap to intersections of curves" "encaixe nas interseções das curvas")
("snap to text borders" "ajustar às bordas do texto")
("snap to text corners" "encaixar nos cantos do texto")
("solution" "solução")
("solution to exercise" "solução para exercício")
("solution to problem" "solução para o problema")
("solutions" "soluções")
("sound" "som")
("source" "fonte")
("source macros tool" "ferramenta macros de origem")
("source tags" "tags de origem")
("south" "sul")
("south east" "sudeste")
("space bar in math mode" "barra de espaço no modo matemático")
("space bar in text mode" "barra de espaço no modo de texto")
("space stretchability" "extensibilidade do espaço")
("span" "extensão")
("span over all columns" "abrangem todas as colunas")
("special functions" "funções especiais")
("special properties" "propriedades especiais")
("specific baseline" "linha de base específica")
("specified" "especificado")
("specify color alternation" "especificar alternância de cores")
("specify how to traverse the manual" "especifique como percorrer o manual")
("specify semantics of a symbol or formula" "especificar semântica de um símbolo ou fórmula")
("specify the size of the table" "especifique o tamanho da tabela")
("specify user identity" "especificar identidade do usuário")
("spell check" "verificação ortográfica")
("spline" "spline")
("split program" "programa dividido")
("split session" "sessão dividida")
("square" "quadrado")
("square overbrace" "cobertura quadrada")
("square underbrace" "esquadro quadrado")
("stack" "pilha")
("standard" "padrão")
("standard Output" "Saída padrão")
("standard TeXmacs styles" "estilos TeXmacs padrão")
("standard environment variables" "variáveis â\x80\x8bâ\x80\x8bde ambiente padrão")
("standard formats" "formatos padrão")
("standard fraction" "fração padrão")
("star" "estrela")
("start server" "iniciar servidor")
("statement" "declaração")
("statistics" "estatísticas")
("status" "status")
("status bar" "barra de status")
("stop server" "parar servidor")
("storage" "armazenamento")
("store tracking information in LaTeX files" "armazene informações de rastreamento em arquivos LaTeX")
("stretch" "trecho")
("stretch factor" "fator de alongamento")
("stretched" "esticado")
("strict Ascii" "Ascii estrito")
("strike through" "greve")
("stroke" "curso")
("strokes" "traços")
("structured insert above" "inserção estruturada acima")
("structured insert at the left" "inserto estruturado à esquerda")
("structured insert at the right" "inserto estruturado à direita")
("structured insert below" "inserto estruturado abaixo")
("structured remove downwards" "remoção estruturada para baixo")
("structured remove leftwards" "remoção estruturada para a esquerda")
("structured remove rightwards" "remoção estruturada para a direita")
("structured remove upwards" "estrutura removida para cima")
("structured variant" "variante estruturada")
("style options" "opções de estilo")
("style parameters" "parâmetros de estilo")
("stylesheet language" "idioma da folha de estilo")
("subject" "sujeito")
("submenu" "submenu")
("subscript below" "subscrito abaixo")
("subsubmenu" "submenu")
("subsubsubmenu" "subsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtabela")
("subtitle" "legenda")
("subtraction" "subtração")
("summarized" "resumido")
("summary of the principal TeXmacs tags" "resumo das principais tags TeXmacs")
("superscript above" "sobrescrito acima")
("supported plug-ins" "plug-ins suportados")
("surface" "superfície")
("inflate" "ondulação")
("swiss" "suíço")
("switch" "interruptor")
("switch to buffer" "alternar para buffer")
("switching and folding" "comutação e dobragem")
("symbol browser" "navegador de símbolos")
("symbol properties not found" "propriedades do símbolo não encontradas")
("symbols" "símbolos")
("synchronization status" "status de sincronização")
("synchronize" "sincronizar")
("synchronize bibliographic references" "sincronizar referências bibliográficas")
("synchronize file or directory" "sincronizar arquivo ou diretório")
("synchronize with remote server" "sincronizar com o servidor remoto")
("synopsis" "sinopse")
("system command" "comando do sistema")
("tab-completion" "conclusão da guia")
("tabbed" "com guias")
("table breaking" "quebra de mesa")
("table height" "altura da mesa")
("table properties" "propriedades da tabela")
("table width" "largura da tabela")
("tags with special rendering" "tags com renderização especial")
("tangent" "tangente")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "buffer TeXmacs esperado")
("teXmacs buffer on disk expected" "buffer TeXmacs no disco esperado")
("teXmacs database preferences" "preferências do banco de dados teXmacs")
("teXmacs extensions to scheme and utilities" "extensões TeXmacs para esquemas e utilitários")
("teXmacs macro" "macro TeXmacs")
("teXmacs package" "pacote TeXmacs")
("teXmacs plugins" "plugins TeXmacs")
("teXmacs primitives" "primitivas TeXmacs")
("teXmacs style" "estilo TeXmacs")
("test routine" "rotina de teste")
("testing tree-view" "teste de exibição em árvore")
("text borders" "bordas do texto")
("text box style" "estilo da caixa de texto")
("text corners" "cantos do texto")
("text padding" "preenchimento de texto")
("textual" "textual")
("textual operator" "operador textual")
("textual spreadsheet" "planilha textual")
("the TeXmacs format" "o formato TeXmacs")
("the TeXmacs plug-in system" "o sistema de plug-in TeXmacs")
("the document has not been saved" "o documento não foi salvo")
("theme parameters" "parâmetros do tema")
("these collected public keys will be definitely lost" "essas chaves públicas coletadas serão definitivamente perdidas")
("these public keys will be definitely lost" "essas chaves públicas serão definitivamente perdidas")
("these secret keys will be definitely lost" "essas chaves secretas serão definitivamente perdidas")
("thicken" "engrossar")
("thin" "fino")
("third" "terceiro")
("this" "isso")
("this column" "esta coluna")
("this page footer" "rodapé desta página")
("this page header" "cabeçalho desta página")
("this page number" "este número de página")
("this row" "esta linha")
("this style specifies page margins in the TeX way" "este estilo especifica margens da página da maneira TeX")
("three columns" "três colunas")
("three dots" "três pontos")
("three times" "três vezes")
("through popup windows" "através de janelas pop-up")
("through the menus" "através dos menus")
("thumbnails" "miniaturas")
("time evolution" "evolução do tempo")
("timings" "horários")
("title presentation options" "opções de apresentação do título")
("title style" "estilo do título")
("title suffix" "sufixo do título")
("titled block" "bloco intitulado")
("toggle cell wrapping mode" "alternar modo de quebra de célula")
("toggle here" "alterne aqui")
("toggle name" "alternar nome")
("toggle numbering" "alternar numeração")
("toggle off" "alternar")
("toggle on" "ativar")
("toggle specification" "especificação de alternância")
("toggle titled" "alternar intitulado")
("tolerant" "tolerante")
("top baseline" "linha de base superior")
("top cell border" "borda superior da célula")
("top cell padding" "preenchimento de célula superior")
("top table border" "borda superior da tabela")
("top table padding" "estofamento de mesa")
("transform" "transformação")
("transform cell into subtable" "transformar célula em subtabela")
("translations" "traduções")
("translations loaded" "traduções carregadas")
("transpose" "transposição")
("traversal" "transversal")
("traverse" "transversal")
("triangle" "triângulo")
("triangularize" "triangularizar")
("trigonometric" "trigonométrico")
("trigonometry" "trigonometria")
("turn off" "desligar")
("turn on" "ligar")
("turn on wallet" "ativar carteira")
("twice" "duas vezes")
("two columns" "duas colunas")
("two dots" "dois pontos")
("type a latex command followed by return" "digite um comando de látex seguido de retorno")
("unchanged" "inalterado")
("underbrace" "underbrace")
("underline" "sublinhado")
("underlined" "sublinhado")
("unevaluated argument" "argumento não avaliado")
("unevaluated value" "valor não avaliado")
("unextended" "não estendido")
("unfold" "desdobrar")
("unfold all" "desdobrar tudo")
("unfold all fields" "desdobrar todos os campos")
("unfolded" "desdobrado")
("unit" "unidade")
("unit length" "comprimento da unidade")
("unknown secret key fingerprint" "impressão digital desconhecida da chave secreta")
("unregistered file" "arquivo não registrado")
("unroll" "desenrole")
("unsecure script refused" "script não seguro recusado")
("unsupported link mode" "modo de link não suportado")
("until" "até")
("untitled block" "bloco sem título")
("up to date" "atualizado")
("update buffer" "buffer de atualização")
("update from web" "atualização da web")
("update this buffer" "atualize este buffer")
("update web site" "atualizar site")
("upight" "vertical")
("upload" "upload")
("upload file or directory" "fazer upload de arquivo ou diretório")
("upright" "na posição vertical")
("upwards" "para cima")
("url" "url")
("use CSS for more advanced formatting" "use CSS para formatação mais avançada")
("use MathML" "use MathML")
("use TeXmacs" "use TeXmacs")
("use a bold font" "use uma fonte em negrito")
("use as master" "usar como mestre")
("use extensible brackets" "use colchetes extensíveis")
("use high resolution fonts" "usar fontes de alta resolução")
("use high resolution icons" "use ícones de alta resolução")
("use line wrapping for lines which are longer than 80 characters" "use quebra de linha para linhas com mais de 80 caracteres")
("use margin kerning (protrusion)" "use kerning de margem (saliência)")
("use print dialogue" "use o diálogo de impressão")
("use protrusion" "usar protrusão")
("use relative path" "usar caminho relativo")
("use retina fonts" "usar fontes retina")
("use retina icons" "use ícones de retina")
("use unified toolbars" "usar barras de ferramentas unificadas")
("user interface" "interface do usuário")
("user interface language" "idioma da interface do usuário")
("user preferences" "preferências do usuário")
("users of Cyrillic languages" "usuários de idiomas cirílicos")
("users of oriental languages" "usuários de línguas orientais")
("utf-8 with inputenc" "utf-8 com inputenc")
("utf-8 with inputenc LaTeX package" "utf-8 com pacote inputenc LaTeX")
("utilities" "utilitários")
("vanish" "desaparecer")
("verbose" "detalhado")
("version" "versão")
("versioning tool" "ferramenta de controle de versão")
("vertical alignment" "alinhamento vertical")
("vertical margins" "margens verticais")
("vertical space after" "espaço vertical depois de")
("vertical space before" "espaço vertical antes")
("vertical space stretchability" "elasticidade vertical do espaço")
("visible except here" "visível exceto aqui")
("visible from here on" "visível daqui em diante")
("visible only here" "visível apenas aqui")
("visible until here" "visível até aqui")
("visited loci" "locais visitados")
("wallet" "carteira")
("wave" "onda")
("web" "web")
("weight" "peso")
("when line wrapping" "quando quebra de linha")
("when wrapping" "ao embrulhar")
("whitespace" "espaço em branco")
("wide" "de largura")
("wide bar" "barra larga")
("wide block" "bloco largo")
("wide colored" "de cor larga")
("wide float" "bóia larga")
("wide footnote" "")
("wide tabular" "tabular largo")
("widescreen" "widescreen")
("with newer version" "com versão mais recente")
("with older version" "com versão mais antiga")
("wrap lines" "linhas de quebra automática")
("write a macro" "escreva uma macro")
("writing TeXmacs bibliography styles" "escrevendo estilos de bibliografia TeXmacs")
("writing documentation" "documentação de escrita")
("written with TeXmacs" "escrito com TeXmacs")
("wrong empty passphrase" "frase secreta vazia incorreta")
("wrong passphrase" "senha incorreta")
("year" "ano")
("year, Name" "ano, nome")
("you are attempting to open an encrypted file while" "você está tentando abrir um arquivo criptografado enquanto")
("you might consider enabling the experimental" "você pode considerar ativar o experimental")
("you must add a bibliography file" "você deve adicionar um arquivo de bibliografia")
("you should also make sure that GnuPG is installed" "você também deve ter certeza de que o GnuPG está instalado")
("your language" "seu idioma")
("your personal dictionary has been modified" "seu dicionário pessoal foi modificado")
("zebra" "zebra")
("zoom" "zoom")
("zoom in" "ampliar")
("zoom out" "diminuir o zoom")
("zoom/unzoom objects" "zoom / unzoom objects")
