("\"encryption\" features from the preference panel" "偏好设置面板中的  加密 功能")
("(Re)Build autocompletion index" "(重新)生成自动完成索引")
("a.C.M. computing class" "A.C.M。计算类")
("a.M.S. subject class" "硕士课程")
("abbreviated authors" "名缩写作者")
("abreviated authors" "名缩写作者")
("accept during this pass" "在此通行证期间接受")
("active link types" "活动链接类型")
("add" "添加")
("add abstract information" "添加抽象信息")
("add author information" "添加作者信息")
("add title information" "添加标题信息")
("addition" "增加")
("adjust limits" "调整极限")
("advanced font customization" "高级字体定制")
("affiliation" "从属关系")
("align cell to the decimal comma" "将单元格与小数点对齐")
("align cell to the decimal dot" "将单元格与小数点对齐")
("align table at axis" "将工作台对准轴")
("alignment of balloon" "气球的对准")
("all cells" "所有单元格")
("all data attached to this identity will be lost" "与此身份关联的所有数据都将丢失")
("all saved passphrases will be lost forever" "所有保存的密码短语将永远丢失")
("allowed page height extension" "允许的页面高度扩展")
("allowed page height reduction" "允许页面高度减少")
("allowed positions" "允许的职位")
("allowed positions of floating object" "浮动对象的允许位置")
("alpha transparency" "alpha透明度")
("alter" "更改")
("alternate" "备用")
("alternate except here" "这里除外")
("alternate from here on" "从这里开始的备用")
("alternate only here" "仅在这里替代")
("alternate until here" "直到这里为止")
("amplified" "放大")
("and perform casual settings from the \"Encryption\" tab" "并通过\"加密\"选项卡执行临时设置")
("animate" "动画")
("animate folding" "动画折叠")
("animate unfolding" "动画展开")
("animated" "动画")
("annotate" "注释")
("answer field" "答案字段")
("answer to question" "问题的答案")
("answers only" "仅答案")
("any" "任意")
("appear" "出现")
("approximate" "大约")
("arc cosine" "弧余弦")
("arc sine" "弧形正弦")
("arc tangent" "弧线切线")
("are you sure you want to delete collected public keys" "您确定要删除收集的公共密钥")
("are you sure you want to delete selected public keys" "确定要删除所选的公共密钥")
("are you sure you want to delete selected secret keys" "确定要删除所选的秘密密钥")
("are you sure you want to destroy the wallet" "您确定要销毁钱包")
("art frame" "艺术框架")
("arxiv category" "arxiv类别")
("aspect" "方面")
("auto-save file" "自动保存文件")
("automatic program brackets" "自动程序括号")
("automatically import bibliographies when opening files" "打开文件时自动导入书目")
("automatically remember all passphrases in the wallet" "自动记住钱包中的所有密码短语")
("backtrace errors" "回溯错误")
("beamer formats" "")
("beamer theme" "光束主题")
("bench" "长凳")
("bend bottom" "弯曲底部")
("bend corner" "弯角")
("bend diagonal" "对角弯曲")
("bend in" "弯曲")
("bend out" "弯曲")
("bezier" "贝塞尔曲线")
("bibTeX command" " bibTeX命令")
("bidirectional" "双向")
("big environment box" "大环境箱")
("big focus" "大重点")
("binary operator" "二进制运算符")
("bitmap resolution (dpi)" "位图分辨率(dpi)")
("black floral I" "黑花我")
("black floral II" "黑花II")
("blackboard embold" "黑板框")
("block" "块")
("blur" "模糊")
("bottom baseline" "最低基准")
("bottom tools" "底部工具")
("box" "盒子")
("buffer management" "缓冲区管理")
("buffer must be on disk" "缓冲区必须在磁盘上")
("buffer must have a name" "缓冲区必须有一名称")
("build buffer" "构建缓冲区")
("build buffer in" "在其中建立缓冲区")
("build directory" "构建目录")
("build directory in" "在其中建立目录")
("build link pages" "构建链接页面")
("build-all" "全部构建")
("bump" "颠簸")
("busy" "忙")
("cJK" "cJK")
("cJK spacing" "CJK间距")
("cancelled" "已取消")
("cannot download directory to file" "无法将目录下载到文件")
("cannot rename across different servers" "无法在不同服务器上重命名")
("cannot upload directory to file" "无法将目录上传到文件")
("caps-lock key" "大写锁定键")
("carved wood" "木雕")
("case-insensitive search" "不区分大小写的搜索")
("categories" "类别")
("category" "类别")
("change default unit" "更改默认单位")
("change passphrase" "更改密码")
("change step-size" "更改步长")
("change the style of mathematical formulas" "更改数学公式的样式")
("character contraction" "字符收缩")
("character expansion" "字符扩展")
("checkable field" "可检查字段")
("cipher algorithm for passphrase encryption" "密码短语加密的密码算法")
("classification" "分类")
("clean slate" "干净的石板")
("clear local information" "清除本地信息")
("click Ok button twice to discard this warning" "两次单击\"确定\"按钮以放弃此警告")
("clip" "剪辑")
("clipboard image format" "剪贴板图像格式")
("close animation tool" "关闭动画工具")
("close program" "关闭程序")
("close replace tool" "关闭替换工具")
("close search tool" "关闭搜索工具")
("close spell tool" "关闭拼写工具")
("close translations to rebuild" "要重建的紧密翻译")
("closed bezier" "封闭式贝塞尔曲线")
("closed curve" "闭合曲线")
("closed smooth" "封闭式平滑")
("cluster by affiliation" "从属关系集群")
("collect garbage" "收集垃圾")
("collected keys" "已收集的密钥")
("column separation" "列分离")
("commit file" "提交文件")
("common" "常见")
("commutative diagram" "交换图")
("complete bibliographic reference" "完整书目参考")
("compound" "化合物")
("compress into toolbar" "压缩到工具栏")
("compressed" "压缩")
("conceal" "隐藏")
("configure look and feel" "配置外观")
("confirm database entry" "确认数据库条目")
("confirm entry" "确认输入")
("confirm selected database entries" "确认选定的数据库条目")
("confirm selected entries" "确认选定的条目")
("conservative conversion options" "保守的转换选项")
("constellation" "星座")
("context aids" "上下文辅助工具")
("contextual hints" "上下文提示")
("continue" "继续")
("continued fraction" "连续分数")
("contour" "轮廓")
("contract logarithms" "合同对数")
("convertible" "可转换")
("copyright" "版权")
("cork charset with TeX catcode definition in preamble" "在序言中带有TeX目录定义的软木字符集")
("correct" "正确")
("correct all" "全部纠正")
("correct formula" "正确公式")
("correct manually" "手动更正")
("correct mathematical formulas" "正确的数学公式")
("correction" "更正")
("cosine" "余弦")
("create link" "创建链接")
("create remote directory" "创建远程目录")
("create remote file" "创建远程文件")
("create subprogram" "创建子程序")
("create table macro" "创建表宏")
("creating new account" "创建新帐户")
("crop marks" "裁剪标记")
("cross" "叉号")
("crossed boxes" "交叉框")
("crossed circles" "交叉的圆圈")
("current user version" "当前用户版本")
("cursor" "光标")
("curve intersections" "曲线交叉路口")
("curve points" "曲线点")
("customizations" "自定义")
("custum tab" " custum标签")
("data" "数据")
("database entry" "数据库条目")
("dead" "死亡")
("debugging console" "调试控制台")
("decomposed" "已分解")
("decorated" "已装饰")
("decorated wood" "装饰木")
("decrease size" "减小尺寸")
("decrypt" "解密")
("default size" "默认大小")
("degrade" "降级")
("degraded" "降级")
("delete entries" "删除条目")
("delete link" "删除链接")
("deleted" "已删除")
("destroy" "破坏")
("determine margins from text width" "从文本宽度确定边距")
("device" "设备")
("diamond" "钻石")
("differentiate" "差异化")
("dilate" "膨胀")
("direction of progression" "前进方向")
("direction of translation" "翻译方向")
("disable coloring on paper" "在纸上禁用着色")
("disable encryption" "禁用加密")
("disappear" "消失")
("dissociate joined cells" "分离连接的细胞")
("distort" "失真")
("distorted" "失真")
("division" "部门")
("document font selector" "文档字体选择器")
("document language" "文档语言")
("document page format" "文档页面格式")
("document paragraph format" "文档段落格式")
("document updates run" "运行文档更新")
("dragging" "拖动")
("draw over" "透支")
("drop" "下降")
("due to" "由于")
("ERROR" "ERROR")
("edit animation" "编辑动画")
("edit groups of objects" "对象的编辑组")
("edit macros" "编辑宏")
("edit preamble" "编辑序言")
("effect pen" "效果笔")
("eigenvalues" "特征值")
("eighth" "第八")
("embold" "血栓")
("emboss" "浮雕")
("enable page breaking" "启用分页")
("encrypt" "加密")
("encryption" "加密")
("encryption facilities are not currently available" "加密工具当前不可用")
("encryption facilities have not been enabled for TeXmacs" "尚未为TeXmacs启用加密功能")
("enforce brackets to match" "使括号匹配")
("engrave" "刻")
("enter graphics" "输入图形")
("enter graphics mode" "进入图形模式")
("enter new passphrase for encryption" "输入新的密码短语进行加密")
("enter passphrase for decryption" "输入解密密码")
("enter passphrase for identity" "输入身份验证密码")
("enter title information" "输入标题信息")
("entry up to date in database" "在数据库中输入最新信息")
("enumerate|Alpha" "枚举| Alpha")
("enumerate|Roman" "枚举|罗马")
("enumerate|alpha" "枚举| alpha")
("enumerate|roman" "枚举|罗马")
("environment variable" "环境变量")
("environments" "环境")
("erode" "侵蚀")
("error output" "错误输出")
("error status report" "错误状态报告")
("error: bracket does not match" "错误：括号不匹配")
("error: cyclic or missing chunks detected" "错误：检测到循环或丢失的块")
("error: file not found" "错误：找不到文件")
("error: ghostview does not seem to be installed on your system" "错误：您的系统上似乎未安装ghostview")
("error: one of the alternatives should be filled out" "错误：应填写备选方案之一")
("error: only one alternatives should be filled out" "错误：应仅填写一种替代方法")
("error: should fill out name for referencing" "错误：应填写引用名称")
("error: should fill out required field" "错误：应填写必填字段")
("evaluable field" "可评估字段")
("evaluate fields in order" "按顺序评估字段")
("evaluate script" "评估脚本")
("evaluation switch" "评估开关")
("evaluation tag" "评估标签")
("events" "事件")
("execution of scripts" "脚本执行")
("exit graphics" "退出图形")
("exit graphics mode" "退出图形模式")
("expand TeXmacs macros with no LaTeX equivalents" "扩展没有LaTeX等效项的TeXmacs宏")
("expand beamer slides" "扩展投影仪幻灯片")
("expand logarithms" "展开对数")
("expand trigonometric functions" "展开三角函数")
("expanded" "扩展")
("experimental features (to be used with care)" "实验功能(要小心使用)")
("explain" "解释")
("explanatory item" "解释性的项目")
("explicit keystroke" "明确的击键")
("explicit margins" "明确的边距")
("exponential" "指数")
("export bibliography" "出口书目")
("export entries in buffer" "在缓冲区中导出条目")
("export file" "导出文件")
("export mathematical formulas as MathML" "将数学公式导出为MathML")
("export mathematical formulas as images" "将数学公式导出为图像")
("export selected entries" "导出所选条目")
("export selection" "出口选择")
("export selections as" "导出选择为")
("exported bibliographic entries" "导出的书目条目")
("exported bibliographic references" "导出的书目参考")
("extend" "扩展")
("extended" "扩展")
("extensible left arrow" "可扩展的左箭头")
("extensible right arrow" "可扩展的向右箭头")
("extern" "外部")
("external" "外部")
("extra branch" "额外的分店")
("extra interline space" "额外的行间空间")
("extra name" "全名")
("extract" "摘录")
("extract style file" "提取样式文件")
("extract style package" "提取样式包")
("factor" "因子")
("fade" "渐变")
("fade in" "淡入")
("fade out" "淡出")
("fast" "快速")
("fast decrease" "快速减少")
("fast environments" "快速环境")
("fast increase" "快速增长")
("field reference" "现场参考")
("fifth" "第五")
("file saved" "文件已保存")
("fill out" "填写")
("filter" "过滤器")
("find file" "查找文件")
("finished collecting symbols documentation" "收集符号的完成文档")
("first chunk" "第一块")
("first error" "第一错误")
("first occurrence" "首次出现")
("five columns" "五栏")
("flag is off" "标志已关闭")
("flag is on" "标志已打开")
("flatten" "变平")
("floating phantom" "浮动幻影")
("fold all" "全部折叠")
("fold back" "向后折叠")
("follow external links" "跟随外部链接")
("follow inverse links" "遵循反向链接")
("for each" "每")
("four columns" "四列")
("four dots" "四点")
("fourth" "第四")
("fraktur" "fraktur")
("framed" "带框")
("from" "来自")
("full" "满")
("full author list" "完整作者列表")
("gap" "空白")
("garbage collection" "垃圾收集")
("gaussian" "高斯")
("gcd" "gcd")
("generated LaTeX document contains no errors" "生成的LaTeX文档不包含错误")
("generated field" "生成的字段")
("get arity" "得到善意")
("get label" "获取标签")
("get list with remote versions" "获取带有远程版本的列表")
("glyphs" "字形")
("gnaw" "gna")
("gnawed" "被咬")
("gnuPG command" " gnuPG命令")
("gnuPG error: buffer encryption failed" "gnuPG错误：缓冲区加密失败")
("gnuPG error: cannot find suitable secret key to decrypt" "gnuPG错误：找不到合适的密钥进行解密")
("gnuPG requires name and email to have at least 5 characters" "gnuPG要求名称和电子邮件至少包含5字符")
("go to anchor" "锚点")
("go to anchor or float" "停住或漂浮")
("go to anchor or footnote" "转到锚点或脚注")
("go to float" "浮起来")
("go to footnote" "转到脚注")
("granite" "花岗岩")
("graphical interface font scale" "图形界面字体比例")
("graphics geometry" "图形几何")
("graphics grids" "图形网格")
("greyed" "灰色")
("grid curves" "网格曲线")
("grid points" "网格点")
("grid-curve intersections" "网格曲线交叉点")
("group of objects" "对象组")
("grouped" "分组组")
("guarantee transparent source tracking" "保证透明源跟踪")
("half wide" "半宽")
("hand drawn" "手绘")
("headers" "标题")
("homoglyph substitutions" "象形文字替换")
("horizontal collapse distance" "水平塌陷距离")
("horizontal margins" "水平边距")
("horizontal table alignment" "水平表对齐")
("hyphenate as" "连字符为")
("icon" "图标")
("ignore" "忽略")
("impact" "影响")
("import bibliography" "进口书目")
("import database entry" "导入数据库条目")
("import entries in buffer" "缓冲区中的导入条目")
("import entry" "导入条目")
("import file" "导入文件")
("import selected database entries" "导入选定的数据库条目")
("import selected entries" "导入所选条目")
("import selections as" "将导入内容作为")
("import sophisticated objects as pictures" "将复杂的对象作为图片导入")
("imported bibliographic entries" "年导入的书目条目")
("inanimated" "无生命")
("inch" "英寸")
("incomplete entries found to be filled out" "发现填写不完整的条目")
("increase size" "增加尺寸")
("indent paragraphs" "缩进段落")
("indication" "指示")
("initialize" "初始化")
("ink here" "在这里墨水")
("ink in" "墨水中")
("ink out" "墨水用完")
("inline" "内联")
("inline content" "内联内容")
("inner bottom" "内底")
("inner left" "左内")
("inner right" "右内")
("inner top" "内顶")
("input command" "输入命令")
("input field" "输入字段")
("insert a gap" "插入间隙")
("insert a multiple choice" "插入多项选择")
("insert a new entry" "插入新条目")
("insert a prominent piece of text" "插入突出的文本")
("insert a question" "插入问题")
("insert a root" "插入根")
("insert a section block" "插入节块")
("insert a textual operation" "插入文本操作")
("insert abstract" "插入摘要")
("insert an answer" "插入答案")
("insert an enunciation" "插入一发音")
("insert annotation" "插入注释")
("insert copyright and license information" "插入版权和许可信息")
("insert explanatory item" "插入说明性项目")
("insert large delimiters" "插入大定界符")
("insert last name" "插入姓氏")
("insert missing invisible operators" "插入缺少的不可见运算符")
("insert more names" "插入更多名称")
("insert particle" "插入粒子")
("insert similar above" "在上面插入类似内容")
("insert similar below" "在下面插入类似内容")
("insert similar block above" "在上面插入类似的块")
("insert similar block below" "在下面插入类似的块")
("insert subtable" "插入子表")
("insert symbol documentation" "插入符号文档")
("insert template" "插入模板")
("insert title after name" "在名称后插入标题")
("insert user interface related markup" "插入与用户界面相关的标记")
("inserting control points" "插入控制点")
("integrate" "集成")
("intercharacter compression" "字符间压缩")
("intercharacter stretching" "字符拉伸")
("interrupted" "中断")
("invalid multi-paragraph selection" "无效的多段选择")
("invalid renaming" "无效的重命名")
("invert" "反转")
("inverted breve" "倒置短边")
("invisible ending" "看不见的结尾")
("invisible newline" "不可见的换行符")
("invisible opening" "无形开口")
("join selected cells" "加入所选单元格")
("jump in" "跳入")
("junior" "初级")
("keep evaluated expressions" "保留求值表达式")
("keep local" "保持本地状态")
("keep remote" "保持远程状态")
("keep track of source code" "跟踪源代码")
("keep unfolded" "保持展开")
("large cells" "大单元格")
("large displayed" "大显示")
("large displayed fraction" "大的显示分数")
("large tables" "大桌子")
("last error" "上一错误")
("last name" "姓氏")
("last occurrence" "最后一次出现")
("lcm" "厘米")
("left axis" "左轴")
("left baseline" "左基线")
("left bottom" "左下")
("left center" "左中")
("left click: add point; Right click: undo" "左键单击：添加点；右键单击：撤消")
("left click: finish; Right click: undo" "左键单击：完成；右键单击：撤消")
("left click: new object" "左键单击：新对象")
("left click: operate" "左键单击：操作")
("left down" "左下")
("left on even pages" "留在偶数页上")
("left top" "左上")
("left up" "左上")
("left-right arrow" "左右箭头")
("let the environment float" "让环境浮动")
("line breaking" "换行符")
("line wrapping" "换行")
("linear 2D" "线性2D")
("lines around" "条周围的行")
("link image and copies as" "链接图像并将其复制为")
("link image as" "将图片链接为")
("link mode" "链接模式")
("live" "直播")
("live input-output" "实时输入输出")
("load help file" "加载帮助文件")
("load remote file" "加载远程文件")
("loading" "正在加载")
("local entries" "本地条目")
("loci" "loci")
("locus" "位置")
("locus rendering" "位置绘制")
("logarithm" "对数")
("logging in" "正在登录")
("logical and" "逻辑与")
("logical implication" "逻辑含义")
("logical not" "逻辑不")
("logical or" "逻辑或")
("login" "登录")
("logout" "注销")
("long macro" "长宏")
("long text" "长文本")
("loops" "循环")
("macro argument" "宏参数")
("macro definition" "宏定义")
("macro name" "宏名称")
("magnify horizontally" "水平放大")
("magnify vertically" "垂直放大")
("main presentation style" "主要的介绍方式")
("make a letter environment" "建信环境")
("make a multi-slide presentation" "进行多幻灯片演示")
("make floating" "使浮动")
("make link" "建立链接")
("make non floating" "使非浮动")
("manila paper" "马尼拉纸")
("map arguments" "地图参数")
("marginal note" "边注")
("margins from width" "宽边距")
("margins on paper" "纸上边距")
("margins on screen" "屏幕上的边距")
("marked" "已标记")
("material" "材料")
("matrices" "矩阵")
("maximal cell height" "最大像元高度")
("maximal clustering" "最大聚类")
("maximal table height" "最大工作台高度")
("maximal table width" "最大表格宽度")
("maximum" "最大")
("meander" "曲折")
("menu" "菜单")
("merge lines into paragraphs unless separated by blank lines" "除非另有空白行，否则将行合并为段落")
("messages" "消息")
("meta data" "元数据")
("metal" "金属")
("middle baseline" "中间基准")
("minimal cell height" "最小像元高度")
("minimal cell width" "最小像元宽度")
("minimal line separation" "最小行间距")
("minimal table height" "最小工作台高度")
("minimal table width" "最小表格宽度")
("minimum" "最低")
("mirror" "镜子")
("miscellanous" "其他")
("modify remote live document" "修改远程实时文档")
("module" "模块")
("monospaced" "等距")
("more information about GNU TeXmacs can be found in the Help->About menu" "可以​​在\"帮助->关于\"菜单中找到有关GNU TeXmacs的更多信息")
("more information about GNU TeXmacs can be found in the help" "可以在帮助中找到有关GNU TeXmacs的更多信息")
("motion" "运动")
("mouse over object" "鼠标移到对象上")
("move objects" "移动对象")
("move over object on which to operate" "移至要操作的对象")
("multiline" "多行")
("multiple choice" "多项选择")
("multiplication" "乘法")
("navigation options" "导航选项")
("new account" "新帐户")
("new bibliography dialogue" "新书目对话")
("new entry" "新条目")
("new identity" "新身份")
("new locus" "新轨迹")
("new macro" "新宏")
("new passphrase" "新密码")
("new remote directory" "新的远程目录")
("new remote file" "新的远程文件")
("new style fonts" "新样式字体")
("new style page breaking" "新样式分页符")
("newer version" "较新版本")
("next chunk" "下一块")
("next error" "下一错误")
("next occurrence" "次下一次发生")
("next screen" "下一屏幕")
("no clustering" "无聚类")
("no completions" "未完成")
("no errors have been corrected" "未纠正任何错误")
("no new public key in document" "文档中没有新的公共密钥")
("no page numbers" "无页码")
("no parent" "没有父母")
("no selection" "无选择")
("no spelling errors" "无拼写错误")
("normal loci" "正常基因座")
("not allowed to remove home directory" "不允许删除主目录")
("not connected to server" "未连接到服务器")
("not yet implemented" "尚未实施")
("notebook" "笔记本")
("numeric spreadsheet" "数字电子表格")
("odd page" "奇数页")
("odd pages" "奇数页")
("of fingerprint" "指纹")
("older version" "旧版本")
("on your system and set it up from the \"Security\" tab" "在您的系统上，并通过\"安全\"选项卡进行设置")
("one error has been corrected" "一错误已更正")
("one lower case letter, one non alpha-numeric symbol" "一小写字母，一非字母数字符号")
("one numeric character, one upper case letter" "一数字字符，一大写字母")
("only convert changes when re-importing" "仅在重新导入时才转换更改")
("only convert changes with respect to imported version" "仅转换相对于导入版本的更改")
("only convert changes with respect to tracked version" "仅转换相对于跟踪版本的更改")
("only implemented for complete subtrees" "仅针对完整的子树实现")
("only keep folded" "仅保持折叠")
("only keep unfolded" "仅保持展开")
("only show semantic focus" "仅显示语义焦点")
("open bibliography" "开放书目")
("open identities" "开放身份")
("open key manager" "开放密钥管理器")
("open licence agreement" "开放许可协议")
("open mailbox" "打开邮箱")
("open tool in separate window" "在单独的窗口中打开工具")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "或给出\"gpg\"或\"gpg2\"命令的完整路径")
("order" "命令")
("ordinary symbol" "普通符号")
("ornamented" "已装饰")
("other login" "其他登录名")
("outer bottom" "外底")
("outer left" "左外")
("outer right" "右外")
("outer top" "外顶")
("outline" "大纲")
("outlined" "概述")
("outlined emboss" "轮廓浮雕")
("outlined engrave" "轮廓刻")
("oval" "椭圆形")
("overlap" "重叠")
("overlay" "叠加层")
("overlays" "叠加层")
("overlined" "带上划线的")
("padded" "填充")
("page background" "页面背景")
("page break after" "分页后")
("page breaking algorithm" "分页算法")
("page number" "页码")
("page number rendering" "页码渲染")
("page rendering" "页面呈现")
("panorama" "全景")
("paragraphs" "段")
("parenthesis" "括号")
("parenthesized" "带括号")
("particle" "粒子")
("passphrase encryption" "密码加密")
("passphrase wallet facilities are not currently available" "密码钱包功能目前不可用")
("passphrases are expected to have at least: 8 characters" "密码短语至少应包含：8字符")
("passphrases mismatch" "密码不匹配")
("pastel" "粉彩")
("pattern" "模式")
("pause" "暂停")
("pen width" "笔宽")
("permanently add to dictionary" "永久添加到字典")
("permanently insert into dictionary" "永久插入字典")
("permissions" "权限")
("phantom" "幻像")
("phantoms" "幻像")
("physics and astronomy class" "物理与天文学班")
("picture" "图片")
("pine" "松树")
("plain" "纯文本")
("plain boxes" "普通框")
("plain circles" "普通圈子")
("play" "次播放")
("play animation" "播放动画")
("please install GnuPG software from https://www.gnupg.org" "请从https://www.gnupg.org安装GnuPG软件")
("plural" "复数")
("pop server settings" " pop服务器设置")
("position of marginal note" "注解的位置")
("poster formats" "海报格式")
("poster theme" "海报主题")
("postfix" "后缀")
("preferences for editing mathematical formulas" "编辑数学公式的首选项")
("preferences for tag" "标签首选项")
("prefix" "前缀")
("preserve" "保留")
("preview with ghostview" " ghostview预览")
("previous error" "先前的错误")
("previous occurrence" "以前的事件")
("previous screen" "上一屏幕")
("primitive or macro" "原始或宏")
("print to file" "打印到文件")
("printer setup" "打印机设置")
("program bracket matching" "程序支架匹配")
("program bracket selections" "程序括号选择")
("program commands" "程序命令")
("provoke C++ error" "引发C ++错误")
("provoke menu error" "引发菜单错误")
("provoke scheme error" "挑衅方案错误")
("public key encryption" "公钥加密")
("public keys" "公钥")
("pulse" "脉冲")
("qt GUI only, sorry. Use \"Export selection\"" "仅qt GUI，对不起。使用\"导出选择\"")
("qt-widgets" " qt小部件")
("quantifier" "量化工具")
("quasi" "准")
("questions only" "仅限问题")
("questions with answers" "有疑问的问题")
("quick evaluation of formulas" "公式的快速评估")
("rank" "等级")
("raw" "原始")
("really delete user identity" "确实删除用户身份")
("recipients" "收件人")
("recognize" "识别")
("rectangular" "矩形")
("reduce" "减少")
("reduce trigonometric functions" "减少三角函数")
("reduced margins" "减少的利润")
("regenerate" "重新生成")
("register file" "注册文件")
("relate" "相关")
("relation" "关系")
("release left button: finish editing" "释放左键：完成编辑")
("remote controllers with keyboard simulation" "带有键盘模拟的远程控制器")
("remote directory" "远程目录")
("remote servers" "远程服务器")
("remove database entry" "删除数据库条目")
("remove entries" "删除条目")
("remove entry" "删除条目")
("remove folded" "删除折叠")
("remove link" "删除链接")
("remove selected database entries" "删除选定的数据库条目")
("remove selected entries" "删除选定的条目")
("remove superfluous invisible operators" "删除多余的不可见运算符")
("remove unfolded" "已展开")
("removed entries from database" "从数据库中删除了条目")
("removed entry from database" "从数据库中删除了条目")
("rename section" "重命名部分")
("replace TeXmacs styles with no LaTeX equivalents" "替换没有LaTeX等效项的TeXmacs样式")
("replace all further occurrences" "替换所有后续出现的事件")
("replace one occurrence" "替换一事件")
("reset error counters" "重置错误计数器")
("resize objects" "调整对象大小")
("restart TeXmacs in order to let changes take effect" "重新启动TeXmacs以使更改生效")
("restart in order to let the new look and feel take effect" "重新启动以使新外观生效")
("retime" "重定时")
("retrieve email" "检索电子邮件")
("retrieve remote live document" "检索远程实时文档")
("retrieved contents" "已检索内容")
("reverse" "反向")
("reverse ordering" "反向排序")
("ridged paper" "山脊纸")
("right baseline" "正确的基准")
("right down" "右下")
("right on even pages" "在偶数页上正确")
("right up" "正确起来")
("rigid box" "硬盒")
("rotate objects" "旋转对象")
("rough paper" "粗糙纸")
("round overbrace" "圆形大括号")
("round underbrace" "圆形底括号")
("run current file" "运行当前文件")
("same names" "同名")
("same screen margins as on paper" "与纸上的屏幕边距相同")
("sample text" "示例文字")
("save auxiliary data" "保存辅助数据")
("save entries" "保存条目")
("save entry" "保存条目")
("save image as" "将图像另存为")
("save position" "保存位置")
("save remote file" "保存远程文件")
("saved modifications in database" "数据库中保存的修改")
("screen" "屏幕")
("screen rendering" "屏幕渲染")
("screenshot" "截图")
("scripting language" "脚本语言")
("search and replace" "搜索并替换")
("second" "秒")
("secret keys" "秘密密钥")
("sections" "部分")
("see documentation" "请参阅文档")
("select pen" "选择笔")
("select the action to be undertaken for each conflict" "为每次冲突选择要采取的行动")
("select view mode" "选择视图模式")
("senior" "高级")
("serif" " serif")
("server" "服务器")
("set default" "设置默认值")
("set difference" "设置差异")
("set intersection" "设置交集")
("set properties" "设置属性")
("set union" "设置工会")
("set user information" "设置用户信息")
("seventh" "第七")
("shadow" "阴影")
("shadowed" "阴影")
("shadowed raise" "阴影加薪")
("shift" "班次")
("show current focus" "显示当前焦点")
("show full context" "显示全文")
("show key presses" "显示按键")
("show main document" "显示主文件")
("show table cells" "显示表格单元格")
("side tools" "辅助工具")
("simple" "简单")
("simplified evaluation of formulas" "公式的简化求值")
("simplify" "简化")
("sine" "正弦")
("sixth" "第六")
("skew" "歪斜")
("skip all" "全部跳过")
("slant" "偏斜")
("slashed fraction" "斜线分数")
("slides" "幻灯片")
("slow" "慢")
("slow decrease" "缓慢减少")
("slow increase" "缓慢增加")
("small capitals" "小首都")
("small environment box" "小环境箱")
("small focus" "小焦点")
("small inline" "小内联")
("small inline fraction" "较小的行内分数")
("smash" "粉碎")
("smooth" "流畅")
("smooth end" "平滑结束")
("smooth extremities" "平滑的肢体")
("smooth start" "顺利启动")
("snap" "快照")
("snap distance" "捕捉距离")
("snap to curves" "捕捉到曲线")
("snap to grid" "捕捉到网格")
("snap to grid curve" "捕捉到网格曲线")
("snap to intersections of curves" "捕捉到曲线的交点")
("snap to text borders" "捕捉到文本边框")
("snap to text corners" "捕捉到文本角")
("solution to exercise" "运动解决方案")
("solution to problem" "解决问题")
("solutions" "解决方案")
("south" "南")
("south east" "东南")
("space bar in math mode" "数学模式下的空格键")
("space bar in text mode" "文本模式下的空格键")
("space stretchability" "空间伸缩性")
("span" "跨度")
("span over all columns" "跨越所有列")
("special cell properties" "特殊单元格属性")
("special table properties" "特殊表属性")
("specific baseline" "特定基准")
("specify color alternation" "指定颜色交替")
("specify how to traverse the manual" "指定如何遍历手册")
("specify semantics of a symbol or formula" "指定符号或公式的语义")
("spell check" "拼写检查")
("split program" "拆分程序")
("square overbrace" "方形大括号")
("square underbrace" "方形底括号")
("standard Output" "标准输出")
("standard fraction" "标准分数")
("star" "星级")
("start server" "启动服务器")
("statement" "声明")
("stop server" "停止服务器")
("store tracking information in LaTeX files" "在LaTeX文件中存储跟踪信息")
("stretch factor" "拉伸因子")
("strict Ascii" "严格的Ascii")
("strike through" "strike through")
("structured variant" "结构化变体")
("style options" "样式选项")
("style parameters" "样式参数")
("subject" "主题")
("subscript below" "下标")
("subsubmenu" "子菜单")
("subsubsubmenu" "子子菜单")
("subsubsubsubmenu" " subsubsubsubmenu")
("subtraction" "减")
("summarized" "摘要")
("superscript above" "上方标")
("supported plug-ins" "受支持的插件")
("inflate" "膨胀")
("switch to buffer" "切换到缓冲区")
("symbol properties not found" "未找到符号属性")
("symbols" "符号")
("synchronize" "同步")
("synchronize bibliographic references" "同​​步书目参考")
("synchronize with remote server" "与远程服务器同步")
("synopsis" "简介")
("tabbed" "带标签的")
("table breaking" "破表")
("tags with special rendering" "具有特殊渲染的标签")
("tangent" "正切")
("texmacs DTD" " TeXmacs DTD")
("texmacs buffer expected" "预期TeXmacs缓冲区")
("texmacs buffer on disk expected" "预期磁盘上的TeXmacs缓冲区")
("texmacs macro" " TeXmacs宏")
("texmacs package" " TeXmacs程序包")
("texmacs plugins" " TeXmacs插件")
("texmacs style" "teXmacs样式")
("test routine" "测试例程")
("testing tree-view" "测试树状视图")
("text borders" "文本边框")
("text box style" "文本框样式")
("text corners" "文本角")
("textual" "文字")
("textual spreadsheet" "文本电子表格")
("theme parameters" "主题参数")
("these collected public keys will be definitely lost" "这些收集的公钥肯定会丢失")
("these public keys will be definitely lost" "这些公钥肯定会丢失")
("these secret keys will be definitely lost" "这些秘密密钥肯定会丢失")
("thicken" "变厚")
("third" "第三")
("this" "此")
("this page number" "此页码")
("this style specifies page margins in the TeX way" "此样式以TeX方式指定页边距")
("three columns" "三列")
("three dots" "三点")
("through popup windows" "通过弹出窗口")
("through the menus" "通过菜单")
("time evolution" "时间演变")
("title presentation options" "标题显示选项")
("title style" "标题样式")
("title suffix" "标题后缀")
("titled block" "标题栏")
("toggle cell wrapping mode" "切换单元格包裹模式")
("toggle here" "在此处切换")
("toggle off" "关闭")
("toggle on" "打开")
("tolerant" "宽容")
("top baseline" "最高基准")
("transform cell into subtable" "将单元格转换为子表")
("translations loaded" "已加载翻译")
("transpose" "移调")
("traversal" "遍历")
("traverse" "遍历")
("triangularize" "三角化")
("trigonometric" "三角")
("turn off" "关闭")
("turn on" "打开")
("two dots" "两点")
("type a latex command followed by return" "键入一乳胶命令，然后返回")
("underlined" "带下划线的")
("unevaluated argument" "未经评估的论点")
("unevaluated value" "未评估的价值")
("unfold all" "全部展开")
("unknown secret key fingerprint" "年未知密钥指纹")
("unregistered file" "未注册文件")
("unroll" "展开")
("unsecure script refused" "年不安全的脚本被拒绝")
("unsupported link mode" "不受支持的链接模式")
("until" "直到为止")
("untitled block" "无标题的方块")
("up to date" "最新")
("update buffer" "更新缓冲区")
("upight" "upight")
("upload" "上传")
("use CSS for more advanced formatting" "使用CSS进行更高级的格式设置")
("use MathML" "使用MathML")
("use as master" "")
("use extensible brackets" "年使用可扩展括号")
("use line wrapping for lines which are longer than 80 characters" "对超过80字符的行使用换行")
("use margin kerning (protrusion)" "使用边距字距调整(突出)")
("use protrusion" "使用突起")
("use relative path" "使用相对路径")
("user interface" "用户界面")
("utf-8 with inputenc LaTeX package" "带有inputenc LaTeX软件包的UTF-8")
("vanish" "消失")
("verbose" "详细")
("vertical margins" "垂直边距")
("vertical space after" "之后的垂直空间")
("vertical space before" "之前的垂直空间")
("vertical space stretchability" "垂直空间可拉伸性")
("vertical table alignment" "垂直表对齐")
("visible except here" "除了这里可见")
("visible from here on" "从这里开始可见")
("visible only here" "仅在此处可见")
("visible until here" "直到这里可见")
("visited loci" "访问过的所在地")
("wallet" "钱包")
("wave" "波")
("weight" "重量")
("when line wrapping" "换行时")
("wide" "宽")
("wide block" "宽幅广告")
("wide colored" "彩色")
("wide float" "宽幅浮动")
("wide footnote" "注脚")
("wide tabular" "宽表格")
("widescreen" "宽屏")
("wrong empty passphrase" "错误的空密码")
("wrong passphrase" "错误的密码短语")
("you are attempting to open an encrypted file while" "您正在尝试同时打开加密文件")
("you might consider enabling the experimental" "您可以考虑启用实验性功能")
("you must add a bibliography file" "您必须添加书目文件")
("you should also make sure that GnuPG is installed" "您还应确保已安装GnuPG")
("your personal dictionary has been modified" "您的个人词典已被修改")
