("\"encryption\" features from the preference panel" "\"criptare\" caracteristici din panoul de preferinµe")
("(Re)Build autocompletion index" "(Re) Creeaz  indexul de completare automat ")
("a modifier" "un modificator")
("a series" "o serie")
("a.C.M. computing class" "clasa de calcul a.C.M.")
("a.M.S. subject class" "a.M.S. subiect de clas ")
("abbreviated authors" "autori prescurtaµi")
("abreviated authors" "autori prescurtaµi")
("accent above" "accent deasupra")
("accent below" "accent mai jos")
("accept during this pass" "acceptaµi īn timpul acestui permis")
("acknowledgments" "mulµumiri")
("activate hidden" "activeaz  ascuns")
("activate once" "activeaz  o dat ")
("activation" "activare")
("active link types" "tipuri de leg turi active")
("add" "ad ugaµi")
("add abstract information" "ad ugaµi informaµii abstracte")
("add author information" "ad ugaµi informaµii despre autor")
("add branch after" "ad ugaµi ramur  dup ")
("add branch before" "ad ugaµi ramur  īnainte")
("add other package" "ad ugaµi alt pachet")
("add package" "ad ugaµi pachet")
("add style package" "ad ugaµi pachet de stil")
("add title information" "ad ugaµi informaµii despre titlu")
("addition" "ad ugare")
("adjust" "ajustaµi")
("adjust limits" "ajustarea limitelor")
("advanced font customization" "personalizare avansat  a fontului")
("affiliation" "afiliere")
("align cell to the decimal comma" "aliniaµi celula cu virgula zecimal ")
("align cell to the decimal dot" "aliniaµi celula la punctul zecimal")
("align table at axis" "tabela de aliniere la ax")
("aligned" "aliniat")
("alignment of balloon" "alinierea balonului")
("all cells" "toate celulele")
("all data attached to this identity will be lost" "toate datele ata³ate acestei identit µi vor fi pierdute")
("all saved passphrases will be lost forever" "toate frazele salvate vor fi pierdute pentru totdeauna")
("allow for macro definitions in preamble" "permite definirea macro-urilor īn preambul")
("allowed page height extension" "permisiune de īn lµime a paginii")
("allowed page height reduction" "reducerea īn lµimii permis  a paginii")
("allowed positions" "poziµii permise")
("allowed positions of floating object" "poziµii permise ale obiectului plutitor")
("alpha transparency" "transparenµ  alfa")
("also on paper" "de asemenea, pe hārtie")
("alter" "modificare")
("alternate" "supleant")
("alternate except here" "alternativ, cu excepµia celor de aici")
("alternate from here on" "alterneaz  de aici īncolo")
("alternate only here" "alterneaz  doar aici")
("alternate until here" "alterneaz  pān  aici")
("alternative specification" "specificaµii alternative")
("always" "mereu")
("american" "american")
("amplified" "amplificat")
("and perform casual settings from the \"Encryption\" tab" "³i efectuaµi set ri ocazionale din fila \"Encryption\"")
("angular" "unghiular")
("animate" "animaµi")
("animate folding" "pliere animat ")
("animate unfolding" "animaµi desf ³urarea")
("animated" "animate")
("animation" "animaµie")
("animation toolbar" "Bara de instrumente de animaµie")
("annotate" "adnotaµi")
("answer" "r spuns")
("answer field" "cāmp de r spuns")
("answer to question" "r spuns la īntrebare")
("answers only" "numai r spunsuri")
("any" "oricare")
("appear" "apar")
("apply macro" "aplicaµi macro")
("apply macro once" "aplicaµi macro odat ")
("approximate" "aproximativ")
("arc" "arc")
("arc cosine" "arc cosinus")
("arc sine" "sinus arc")
("arc tangent" "arc tangent")
("arch series" "serie arc")
("are you sure you want to delete collected public keys" "sunteµi sigur c  doriµi s  ³tergeµi cheile publice colectate")
("are you sure you want to delete selected public keys" "sunteµi sigur c  doriµi s  ³tergeµi cheile publice selectate")
("are you sure you want to delete selected secret keys" "sunteµi sigur c  doriµi s  ³tergeµi tastele secrete selectate")
("are you sure you want to destroy the wallet" "sunteµi sigur c  doriµi s  distrugeµi portofelul")
("art frame" "cadru de art ")
("arxiv category" "categorie arxiv")
("as visual grid" "ca gril  vizual ")
("aspect" "aspect")
("attach master" "ata³eaz  maestrul")
("auto" "auto")
("auto-save file" "fi³ier de salvare automat ")
("automatic brackets" "paranteze automate")
("automatic content generation" "generare automat  de conµinut")
("automatic program brackets" "paranteze de program automat")
("automatic quotes" "citate automate")
("automatically close brackets" "īnchideµi automat paranteze")
("automatically import bibliographies when opening files" "import automat bibliografii la deschiderea fi³ierelor")
("automatically remember all passphrases in the wallet" "amintiµi-v  automat toate parolele din portofel")
("automatically save" "salvaµi automat")
("autosave" "autosave")
("axis" "axa")
("b series" "Seria b")
("back" "īnapoi")
("background evaluations" "evalu ri de fond")
("backtrace errors" "erori de backtrace")
("base" "baz ")
("baseline" "linie de baz ")
("basic communication using pipes" "comunicare de baz  cu conducte")
("beamer" "beamer")
("beamer formats" "formate beamer")
("beamer theme" "tema beamer")
("bench" "banc ")
("bend bottom" "partea de jos curbat ")
("bend corner" "colµ de īndoire")
("bend diagonal" "diagonal  de īndoire")
("bend in" "īndoiµi")
("bend out" "īndoiµi-v ")
("bezier" "bezier")
("bibTeX command" "comanda bibTeX")
("bidirectional" "bidirecµional")
("big environment box" "cutie pentru mediu mare")
("big focus" "focalizare mare")
("binary operator" "operator binar")
("bitmap resolution (dpi)" "Rezoluµie bitmap (dpi)")
("black floral I" "I floral negru")
("black floral II" "florale negre II")
("blackboard embold" "embold de tabl ")
("blank column" "coloan  goal ")
("blank row" "rānd liber")
("block" "bloc")
("block content" "conµinut bloc")
("block of code" "bloc de cod")
("blur" "īnceµo³are")
("both versions" "ambele versiuni")
("bottom baseline" "linia de baz  de jos")
("bottom cell border" "marginea celulei de jos")
("bottom cell padding" "c ptu³irea celulelor de jos")
("bottom table border" "marginea tabelului de jos")
("bottom table padding" "c ptu³irea mesei de jos")
("bottom tools" "instrumente de jos")
("box" "cutie")
("broken white" "alb rupt")
("browse back" "r sfoiµi īnapoi")
("browse forward" "r sfoiµi īnainte")
("browse modules documentation" "documentaµia modulelor de navigare")
("buffer management" "gestionarea tamponului")
("buffer must be on disk" "tampon trebuie s  fie pe disc")
("buffer must have a name" "tampon trebuie s  aib  un nume")
("build buffer" "tampon de construire")
("build buffer in" "buffer de īnc rcare")
("build directory" "director de construire")
("build directory in" "construiµi directorul īn")
("build link pages" "creeaz  pagini de leg turi")
("build-all" "build-all")
("bump" "bump")
("busy" "ocupat")
("cJK" "cJK")
("cJK spacing" "distanµare cJK")
("calculus" "calcul")
("cancelled" "anulat")
("cannot download directory to file" "nu poate desc rca directorul īn fi³ier")
("cannot rename across different servers" "nu poate redenumi pe diferite servere")
("cannot upload directory to file" "nu poate īnc rca directorul īn fi³ier")
("cartesian" "cartezian")
("carved wood" "lemn sculptat")
("case-insensitive search" "c utare sensibil  la majuscule")
("categories" "categorii")
("category" "categorie")
("cell properties" "propriet µi ale celulei")
("cells" "celule")
("change default unit" "Modificaµi unitatea implicit ")
("change passphrase" "modificare parol ")
("change step-size" "modificaµi dimensiunea pasului")
("change tags" "modificaµi etichete")
("change the TeXmacs preferences" "modificaµi preferinµele TeXmacs")
("change the border of the table" "modificaµi marginea tabelului")
("change the style of mathematical formulas" "schimb  stilul formulelor matematice")
("character contraction" "contracµie de caracter")
("character encoding" "codare de caractere")
("character expansion" "extinderea caracterelor")
("check for updates" "verificaµi actualiz rile")
("checkable field" "cāmp verificabil")
("cipher algorithm for passphrase encryption" "algoritm de cifrare pentru criptarea parolelor")
("circle" "cerc")
("classification" "clasificare")
("clean slate" "ardezie curat ")
("clear all fields" "³tergeµi toate cāmpurile")
("clear local information" "informaµii locale clare")
("clear menu" "meniu clar")
("clear undo history" "istoric anulat clar")
("click Ok button twice to discard this warning" "faceµi clic pe butonul Ok de dou  ori pentru a arunca acest avertisment")
("clip" "clip")
("clipboard image format" "format imagine clipboard")
("close animation tool" "instrument de animaµie aproape")
("close document" "document de īnchidere")
("close program" "program īnchis")
("close replace tool" "instrument de īnlocuire īnchidere")
("close search tool" "īnchidere instrument de c utare")
("close spell tool" "instrument de īnchidere vraja")
("close translations to rebuild" "traduceri apropiate pentru reconstruire")
("closed bezier" "bezier īnchis")
("closed curve" "curb  īnchis ")
("closed smooth" "īnchis neted")
("closed spline" "spline īnchise")
("closing style" "stil de īnchidere")
("cluster by affiliation" "cluster prin afiliere")
("collect garbage" "colecta gunoiul")
("collected keys" "chei colectate")
("color of the axes" "culoarea axelor")
("color of the subunits" "culoarea subunit µilor")
("color of the units" "culoarea unit µilor")
("colors" "culori")
("column to the left" "coloana la stānga")
("column to the right" "coloana din dreapta")
("columns" "coloane")
("column separation" "separare coloane")
("commit file" "fi³ier de angajare")
("common" "comun")
("common formats" "formate comune")
("commutative diagram" "diagrama comutativ ")
("compact" "compact")
("compactification" "compactificare")
("compactify" "compacteaz ")
("complete bibliographic reference" "referinµ  bibliografic  complet ")
("completion" "completare")
("complex actions" "acµiuni complexe")
("compose" "compun")
("compound" "compus")
("compress" "comprimaµi")
("compress into toolbar" "comprimaµi īn bara de instrumente")
("compressed" "comprimat")
("conceal" "ascundere")
("configure look and feel" "configuraµi aspectul ³i senzaµia")
("confirm database entry" "confirmaµi introducerea bazei de date")
("confirm entry" "confirmaµi intrarea")
("confirm selected database entries" "confirmaµi intr rile selectate īn baza de date")
("confirm selected entries" "confirmaµi intr rile selectate")
("conservative conversion options" "opµiuni de conversie conservatoare")
("consoles" "console")
("constellation" "constelaµie")
("contact" "contact")
("content" "conµinut")
("context aids" "ajutoare de context")
("contextual hints" "indicii contextuale")
("continue" "continu ")
("continued fraction" "fracµie continuat ")
("contour" "contur")
("contract logarithms" "logaritmi de contract")
("contribute" "contribuie")
("control flow" "debit de control")
("control the evaluation of expressions" "controlaµi evaluarea expresiilor")
("convert" "convertiµi")
("converters" "convertitori")
("convertible" "convertibile")
("copyright" "drepturi de autor")
("cork charset with TeX catcode definition in preamble" "carcas  de plut  cu definiµie a codului cat TeX īn preambul")
("correct" "corect")
("correct all" "corectaµi toate")
("correct formula" "formul  corect ")
("correct manually" "corect  manual")
("correct mathematical formulas" "formule matematice corecte")
("correction" "corecµie")
("cosine" "cosinus")
("count characters" "num r de caractere")
("count lines" "linii de num rare")
("count words" "num r  cuvinte")
("create a new document" "creaµi un nou document")
("create link" "creaµi link")
("create preamble" "creaµi preambul")
("create remote directory" "creaµi directorul de la distanµ ")
("create remote file" "creeaz  fi³ier la distanµ ")
("create subprogram" "creaµi subprogram")
("create subsession" "creaµi subsesiune")
("create table macro" "creaµi macrocomand  de tabel")
("create web site" "creaµi un site web")
("creating new account" "crearea unui cont nou")
("creating technical pictures" "crearea de imagini tehnice")
("crop" "recolt ")
("crop marks" "m rci de cultur ")
("cross" "cruce")
("crossed boxes" "cutii īncruci³ate")
("crossed circles" "cercuri īncruci³ate")
("current user version" "versiunea curent  a utilizatorului")
("current version" "versiunea curent ")
("cursor" "cursor")
("curve" "curb ")
("curve intersections" "intersecµii curbe")
("curve points" "puncte curb ")
("customizations" "personaliz ri")
("customizing and extending the user interface" "personalizarea ³i extinderea interfeµei cu utilizatorul")
("dark grey" "gri īnchis")
("data" "date")
("database entry" "intrare īn baza de date")
("database tool" "instrument de baz  de date")
("database toolbar" "Bara de instrumente a bazei de date")
("deactivate once" "dezactivaµi o dat ")
("dead" "morµi")
("debug" "depanare")
("debugging console" "consol  de depanare")
("debugging tool" "instrument de depanare")
("decimal comma" "virgule zecimale")
("decimal dot" "punct zecimal")
("decomposed" "descompus")
("decorated" "decorate")
("decorated wood" "lemn decorat")
("decrease size" "scade dimensiunea")
("decrypt" "decriptaµi")
("default size" "dimensiune implicit ")
("degrade" "degradeaz ")
("degraded" "degradat")
("delete documentation cache" "³tergeµi memoria cache")
("delete entries" "³tergeµi intr rile")
("delete link" "³terge link")
("deleted" "³ters")
("describe" "descrie")
("describe tag" "descrie etichet ")
("destroy" "distruge")
("detach master" "st pān pe maestru")
("detailed" "detaliat")
("detailed menus" "meniuri detaliate")
("details in menus" "detalii īn meniuri")
("determine margins from text width" "determinaµi marjele din l µimea textului")
("developer" "dezvoltator")
("developer tool" "instrument pentru dezvoltatori")
("device" "dispozitiv")
("diamond" "diamant")
("differentiate" "diferenµiaµi")
("dilate" "dilatat")
("direction of progression" "direcµia de progresie")
("direction of translation" "direcµie de traducere")
("disable" "dezactivaµi")
("disable coloring on paper" "dezactivaµi colorarea pe hārtie")
("disable encryption" "dezactivaµi criptarea")
("disappear" "dispar")
("disk" "disc")
("display style" "stil de afi³are")
("displayed formula" "formula afi³at ")
("dissociate joined cells" "disociaz  celulele unite")
("distort" "denatura")
("distorted" "denaturate")
("division" "diviziune")
("do not remap" "nu reaprovocaµi")
("document font selector" "selector de fonturi de document")
("document language" "limb  document")
("document page format" "format pagin  document")
("document paragraph format" "format paragraf document")
("document updates run" "actualiz ri de documente rulate")
("download" "desc rcare")
("downwards" "īn jos")
("dragging" "tārāre")
("draw image" "deseneaz  imaginea")
("draw over" "extragere")
("draw over selection" "extragerea selecµiei")
("drop" "pic tur ")
("due to" "datorat")
("dynamic" "dinamic")
("eRROR" "eRROR")
("edit animation" "editaµi animaµia")
("edit groups of objects" "editaµi grupuri de obiecte")
("edit macro" "editaµi macro")
("edit macros" "editaµi macrocomenzi")
("edit preamble" "preambul de editare")
("edit source" "sursa de editare")
("edit source tree" "editaµi arborele surs ")
("edit style" "stil de editare")
("edit translations file" "editaµi fi³ierul traducerilor")
("education" "educaµie")
("effect pen" "stilou efect")
("eigenvalues" "valori proprii")
("eighth" "a opta")
("embold" "embold")
("emboss" "emboss")
("enable page breaking" "activaµi ruperea paginii")
("encoding" "codificare")
("encrypt" "criptaµi")
("encryption" "criptare")
("encryption facilities are not currently available" "facilit µi de criptare nu sunt disponibile īn prezent")
("encryption facilities have not been enabled for TeXmacs" "facilit µi de criptare nu au fost activate pentru TeXmacs")
("enforce brackets to match" "aplicaµi paranteze pentru a se potrivi")
("engrave" "gravur ")
("enter data" "introduceµi date")
("enter graphics" "introduceµi grafic ")
("enter graphics mode" "intraµi īn modul grafic")
("enter new passphrase for encryption" "introduceµi noua parol  pentru criptare")
("enter passphrase for decryption" "introduceµi parol  pentru decriptare")
("enter passphrase for identity" "introduceµi parol  pentru identitate")
("enter title information" "introduceµi informaµiile despre titlu")
("entire table" "īntregul tabel")
("entry up to date in database" "intrare actualizat  īn baza de date")
("enunciation" "enunµare")
("environment variable" "variabil  de mediu")
("environments" "medii")
("erode" "erodeaz ")
("error messages" "mesaje de eroare")
("error output" "ie³ire de eroare")
("error status report" "raport de stare de eroare")
("error: bracket does not match" "eroare: paranteza nu se potrive³te")
("error: cyclic or missing chunks detected" "eroare: detectate buc µi ciclice sau lips ")
("error: file not found" "eroare: fi³ierul nu a fost g sit")
("error: ghostview does not seem to be installed on your system" "eroare: ghostview nu pare s  fie instalat pe sistemul t u")
("error: one of the alternatives should be filled out" "eroare: una dintre alternative ar trebui completat ")
("error: only one alternatives should be filled out" "eroare: numai o alternativ  ar trebui completat ")
("error: should fill out name for referencing" "eroare: ar trebui s  completeze numele pentru trimitere")
("error: should fill out required field" "eroare: trebuie s  completaµi cāmpul necesar")
("evaluable field" "cāmp evaluabil")
("evaluate above" "evaluaµi mai sus")
("evaluate all" "evaluaµi tot")
("evaluate below" "evaluaµi mai jos")
("evaluate fields" "cāmpuri de evaluare")
("evaluate fields in order" "evaluaµi cāmpurile īn ordine")
("evaluate script" "script de evaluare")
("evaluation" "evaluare")
("evaluation switch" "comutator de evaluare")
("evaluation tag" "etichet  de evaluare")
("even page" "pagin  uniform ")
("even page left margin" "marginea stāng  a paginii stānga")
("even page shift" "schimbare pagin  uniform ")
("even pages" "pagini uniforme")
("events" "evenimente")
("exact" "exact")
("execution of scripts" "executarea scripturilor")
("exit graphics" "grafic  de ie³ire")
("exit graphics mode" "ie³ire din modul grafic")
("exit left" "ie³ire la stānga")
("exit right" "ie³iµi la dreapta")
("exit tag on the left" "etichet  de ie³ire din stānga")
("exit tag on the right" "etichet  de ie³ire din dreapta")
("expand TeXmacs macros with no LaTeX equivalents" "extinde macro-urile TeXmacs f r  echivalente LaTeX")
("expand beamer slides" "extinde diapozitivele beamer")
("expand inclusions" "extinde incluziunile")
("expand logarithms" "extinde logaritmele")
("expand trigonometric functions" "extinde funcµiile trigonometrice")
("expand unrecognized macros" "extinde macro-uri nerecunoscute")
("expand user-defined macros" "extinde macro-uri definite de utilizator")
("expanded" "extins")
("experimental features (to be used with care)" "caracteristici experimentale (pentru a fi utilizate cu grij )")
("explain" "explicaµi")
("explanatory item" "articol explicativ")
("explicit keystroke" "ap sare explicit  a tastei")
("explicit margins" "margini explicite")
("exponential" "exponenµial")
("export bibliographies as links" "export bibliografii sub form  de link-uri")
("export bibliography" "bibliografie la export")
("export entries in buffer" "īnregistr ri de export īn buffer")
("export file" "fi³ier export")
("export formulas as images" "formule de export sub form  de imagini")
("export mathematical formulas as MathML" "export formule matematice ca MathML")
("export mathematical formulas as images" "exporta formule matematice sub form  de imagini")
("export selected entries" "export ri intr ri selectate")
("export selection" "selecµie export")
("export selection as image" "selectarea exportului ca imagine")
("export selections as" "selecµii la export ca")
("export sessions" "sesiuni de export")
("exported bibliographic entries" "intr ri bibliografice exportate")
("exported bibliographic references" "referinµe bibliografice exportate")
("extend" "extinde")
("extended" "extins")
("extensible left arrow" "s geat  stāng  extensibil ")
("extensible right arrow" "s geat  extensibil  dreapta")
("extern" "extern")
("external" "extern")
("extra branch" "sucursal  suplimentar ")
("extra interline space" "spaµiu interline suplimentar")
("extra name" "nume īn plus")
("extract" "extras")
("extract style file" "fi³ier stil extras")
("extract style package" "pachet de stil extras")
("factor" "factor")
("fade" "decolorat")
("fade in" "se estompeaz ")
("fade out" "se estompeaz ")
("fast" "rapid")
("fast decrease" "sc dere rapid ")
("fast environments" "medii rapide")
("fast increase" "cre³tere rapid ")
("field reference" "referinµ  de cāmp")
("fifth" "a cincea")
("file saved" "fi³ier salvat")
("fill color" "culoare de umplere")
("fill out" "completaµi")
("filter" "filtru")
("find file" "fi³ier de g sire")
("finished collecting symbols documentation" "documentare terminat  de colectare a simbolurilor")
("first" "primul")
("first chunk" "prima bucat ")
("first difference" "prima diferenµ ")
("first error" "prima eroare")
("first field" "primul cāmp")
("first occurrence" "prima apariµie")
("first similar" "primul similar")
("fit to screen" "potrivite pe ecran")
("fit to screen width" "se potrivesc la l µimea ecranului")
("five columns" "cinci coloane")
("fixed" "fix")
("flag is off" "steagul este oprit")
("flag is on" "steagul este activat")
("flatten" "aplatizeaz ")
("floating algorithm" "algoritm plutitor")
("floating phantom" "fantom  plutitoare")
("focus" "focalizare")
("focus dependent icons" "pictograme dependente de focalizare")
("fold all" "pliaµi tot")
("fold all fields" "pliaµi toate cāmpurile")
("fold back" "pliere īnapoi")
("fold input field" "cāmp de intrare pliat")
("follow external links" "urmaµi leg turi externe")
("follow inverse links" "urmaµi leg turi invers")
("font effects" "efecte de font")
("font selector" "selector de font")
("font type" "tip de font")
("for each" "pentru fiecare")
("force reloading of translations" "reīnc rcare forµat  a traducerilor")
("formatted and structured output" "ie³ire formatat  ³i structurat ")
("formatting" "formatare")
("forward" "īnainte")
("four columns" "patru coloane")
("four dots" "patru puncte")
("fourth" "al patrulea")
("fraktur" "fraktur")
("framed" "īncadrat")
("from" "din")
("from center" "din centru")
("front matter" "materie frontal ")
("full" "plin")
("full author list" "lista complet  de autori")
("full screen mode" "modul ecran complet")
("functional" "funcµional")
("gap" "gol")
("garbage collection" "colectarea gunoiului")
("gaussian" "gaussian")
("gcd" "LCD")
("general" "general")
("general note" "not  general ")
("generated LaTeX document contains no errors" "documentul LaTeX generat nu conµine erori")
("generated field" "cāmp generat")
("geometry" "geometrie")
("get arity" "obµineµi aritate")
("get label" "obµine etichet ")
("get list with remote versions" "obµine lista cu versiuni la distanµ ")
("glyphs" "glife")
("gnaw" "gnaw")
("gnawed" "īnghiµit")
("gnuPG command" "comand  gnuPG")
("gnuPG error: buffer encryption failed" "eroare gnuPG: criptarea buffer-ului a e³uat")
("gnuPG error: cannot find suitable secret key to decrypt" "eroare gnuPG: nu poate g si o cheie secret  adecvat  pentru a decripta")
("gnuPG requires name and email to have at least 5 characters" "gnuPG necesit  ca numele ³i e-mailul s  aib  cel puµin 5 caractere")
("go to anchor" "mergeµi la ancor ")
("go to anchor or float" "mergeµi la ancor  sau plutesc")
("go to anchor or footnote" "mergeµi la ancor  sau not  de subsol")
("go to first similar tag" "accesaµi prima etichet  similar ")
("go to float" "mergi s  plute³ti")
("go to footnote" "mergeµi la nota de subsol")
("go to last similar tag" "accesaµi ultima etichet  similar ")
("go to next similar tag" "mergeµi la urm toarea etichet  similar ")
("go to previous similar tag" "accesaµi eticheta similar  anterioar ")
("go to section" "mergeµi la secµiune")
("grain" "cereale")
("granite" "granit")
("graphical effects" "efecte grafice")
("graphical interface font scale" "scar  de fonturi de interfaµ  grafic ")
("graphics" "grafic ")
("graphics geometry" "geometrie grafic ")
("graphics grids" "grile grafice")
("greyed" "lacomi")
("grid" "gril ")
("grid curves" "curbe de gril ")
("grid points" "puncte gril ")
("grid-curve intersections" "intersecµii cu curba gril ")
("group of objects" "grup de obiecte")
("group/ungroup" "grup / dezgrup")
("grouped" "grupate")
("guarantee transparent source tracking" "garanteaz  urm rirea transparent  a sursei")
("h modifier" "modificator h")
("half wide" "jum tate l µime")
("hand drawn" "desenat manual")
("headers" "anteturi")
("hidden" "ascunse")
("history" "istoric")
("homepage" "pagina principal ")
("homoglyph substitutions" "substituµii omoglic ")
("horizontal alignment" "aliniere orizontal ")
("horizontal collapse distance" "distanµ  de colaps orizontal ")
("horizontal margins" "margini orizontale")
("hybrid command" "comand  hibrid ")
("hyphenate as" "cratimaµi ca")
("icon" "pictogram ")
("if hyphenated" "dac  sunt cratime")
("ignore" "ignor ")
("impact" "impact")
("import bibliography" "bibliografie de import")
("import database entry" "intrare īn baza de date de import")
("import entries in buffer" "intr ri de import īn buffer")
("import entry" "intrare la import")
("import file" "fi³ier import")
("import selected database entries" "import ri intr ri ale bazei de date selectate")
("import selected entries" "import ri intr ri selectate")
("import selections as" "selecµii de import ca")
("import sessions" "sesiuni de import")
("import sophisticated objects as pictures" "importaµi obiecte sofisticate ca imagini")
("imported bibliographic entries" "intr ri bibliografice importate")
("in popup windows" "īn ferestrele pop-up")
("inanimated" "inanimate")
("inch" "inch")
("incomplete entries found to be filled out" "intr ri incomplete g site a fi completate")
("increase size" "cre³te dimensiunea")
("indent paragraphs" "paragrafe liniuµ ")
("indentation" "indentare")
("indication" "indicaµie")
("informative flags" "steaguri informative")
("initialize" "iniµializare")
("ink here" "cerneal  aici")
("ink in" "cerneal ")
("ink out" "cerneal ")
("inline" "īn linie")
("inline arguments" "argumente inline")
("inline code" "cod inline")
("inline content" "conµinut inline")
("inline formula" "formul  inline")
("inner bottom" "fund interior")
("inner left" "stānga interioar ")
("inner right" "dreapta interioar ")
("inner top" "partea interioar ")
("input command" "comand  de intrare")
("input field" "cāmp de introducere")
("input mode" "modul de introducere")
("input options" "opµiuni de introducere")
("insert a computer program" "introduceµi un program de calculator")
("insert a condition" "introduceµi o condiµie")
("insert a control flow instruction" "introduceµi o instrucµiune a fluxului de control")
("insert a gap" "introduceµi un gol")
("insert a list" "introduceµi o list ")
("insert a multiple choice" "introduceµi o alegere multipl ")
("insert a negation" "introduceµi o negaµie")
("insert a new entry" "introduceµi o nou  intrare")
("insert a note or a floating object" "introduceµi o not  sau un obiect plutitor")
("insert a numerical operation" "introduceµi o operaµie numeric ")
("insert a prominent piece of text" "introduceµi un text proeminent")
("insert a question" "introduceµi o īntrebare")
("insert a root" "introduceµi o r d cin ")
("insert a script" "introduceµi un script")
("insert a section block" "introduceµi un bloc de secµiune")
("insert a textual operation" "introduceµi o operaµie textual ")
("insert a textual operator" "introduceµi un operator textual")
("insert a wide symbol above" "introduceµi un simbol larg deasupra")
("insert a wide symbol below" "introduceµi un simbol larg mai jos")
("insert above" "introduceµi mai sus")
("insert abstract" "inseraµi abstract")
("insert an answer" "introduceµi un r spuns")
("insert an enunciation" "introduceµi o enunµare")
("insert an operation on tuples" "introduceµi o operaµie pe tuple")
("insert annotation" "introduceµi adnotarea")
("insert author" "introduceµi autorul")
("insert below" "introduceµi mai jos")
("insert copyright and license information" "introduceµi informaµii despre drepturi de autor ³i licenµ ")
("insert explanatory item" "introduceµi elementul explicativ")
("insert field above" "introduceµi cāmpul de mai sus")
("insert field below" "introduceµi cāmpul de mai jos")
("insert fields" "introduceµi cāmpuri")
("insert input field above" "introduceµi cāmpul de introducere deasupra")
("insert input field below" "introduceµi cāmpul de introducere mai jos")
("insert large delimiters" "introduceµi delimitatori mari")
("insert last name" "introduceµi prenumele")
("insert left" "introduceµi stānga")
("insert macro" "introduceµi macro")
("insert missing invisible operators" "introduceµi operatori invizibili lipsiµi")
("insert more names" "introduceµi mai multe nume")
("insert particle" "insert particle")
("insert plain text" "introduceµi text simplu")
("insert right" "introduceµi dreapta")
("insert similar above" "introduceµi similar  mai sus")
("insert similar below" "introduceµi similar  mai jos")
("insert similar block above" "introduceµi un bloc similar mai sus")
("insert similar block below" "introduceµi un bloc similar mai jos")
("insert subtable" "inseraµi subtable")
("insert symbol documentation" "introduceµi documentaµia simbolului")
("insert template" "³ablon de inserare")
("insert text field" "introduceµi cāmpul de text")
("insert text field above" "introduceµi cāmpul text de mai sus")
("insert text field below" "introduceµi cāmpul text mai jos")
("insert title" "introduceµi titlul")
("insert title after name" "introduceµi titlul dup  nume")
("insert user interface related markup" "introduceµi marcajul aferent interfeµei de utilizator")
("insert value" "valoare de introducere")
("inserting control points" "introducerea punctelor de control")
("integrate" "integrare")
("interactive command" "comand  interactiv ")
("interactive questions" "īntreb ri interactive")
("intercharacter compression" "compresie īntre intercalare")
("intercharacter stretching" "īntindere īntre interferate")
("interrupted" "īntrerupt")
("invalid multi-paragraph selection" "selecµie nevalid  cu mai multe paragrafe")
("invalid renaming" "redenumire nevalid ")
("invert" "invers")
("inverted breve" "breve inversat")
("invisible ending" "sfār³it invizibil")
("invisible newline" "linie nou  invizibil ")
("invisible opening" "deschidere invizibil ")
("join selected cells" "al turaµi celule selectate")
("jump in" "s riµi")
("junior" "junior")
("keep evaluated expressions" "p straµi expresiile evaluate")
("keep local" "p streaz  local")
("keep remote" "µine la distanµ ")
("keep track of source code" "µine evidenµa codului surs ")
("keep unfolded" "menµineµi desf ³urat")
("keyboard configuration" "configuraµie tastatur ")
("laptop presentations" "prezent ri de laptop")
("large cells" "celule mari")
("large displayed" "afi³at mare")
("large displayed fraction" "fracµie afi³at  mare")
("large tables" "tabele mari")
("last" "ultima")
("last difference" "ultima diferenµ ")
("last error" "ultima eroare")
("last field" "ultimul cāmp")
("last name" "prenume")
("last occurrence" "ultima apariµie")
("last similar" "ultima similar ")
("lcm" "mcm")
("left arrow" "s geata stāng ")
("left axis" "axa stāng ")
("left baseline" "linie de baz  stānga")
("left bottom" "stānga jos")
("left cell border" "graniµa celulei stāngi")
("left cell padding" "c ptu³irea celulelor stāngi")
("left center" "centru stānga")
("left click: add point; Right click: undo" "clic stānga: ad ugare punct; clic dreapta: anulare")
("left click: finish; Right click: undo" "clic stānga: finisare; clic dreapta: anulare")
("left click: new object" "clic stānga: obiect nou")
("left click: operate" "clic stānga: operaµi")
("left down" "stānga jos")
("left on even pages" "stānga pe paginile uniforme")
("left table border" "marginea din stānga")
("left table padding" "c ptu³ire de mas  stāng ")
("left top" "stānga sus")
("left up" "stānga sus")
("left-right arrow" "s geat  stānga-dreapta")
("leftwards" "spre stānga")
("let the environment float" "l saµi mediul s  pluteasc ")
("light grey" "gri deschis")
("line breaking" "rupere de linie")
("line wrapping" "ambalare linie")
("linear 2D" "liniar 2D")
("linear algebra" "algebr  liniar ")
("lines around" "linii īn jurul")
("link image and copies as" "imagine de leg tur  ³i copii ca")
("link image as" "imagine de leg tur  ca")
("link mode" "modul link")
("link to URL" "link c tre URL")
("linking tool" "instrument de conectare")
("live" "live")
("live input-output" "live-input-output")
("load help file" "fi³ier ajutor de īnc rcare")
("load remote file" "īnc rcare fi³ier de la distanµ ")
("loading" "īnc rcare")
("local entries" "intr ri locale")
("loci" "loci")
("locus" "locus")
("locus rendering" "redare locus")
("logarithm" "logaritm")
("logarithmic" "logaritmic")
("logarithmic base" "baz  logaritmic ")
("logarithms" "logaritmi")
("logging in" "logare")
("logical and" "logic ³i")
("logical implication" "implicaµie logic ")
("logical not" "logic nu")
("logical or" "logic sau")
("login" "autentificare")
("logout" "deconectare")
("long macro" "macro lung")
("long text" "text lung")
("look for more fonts" "caut  mai multe fonturi")
("loops" "bucle")
("m modifier" "modificator m")
("macro argument" "argument macro")
("macro definition" "definiµia macro")
("macro name" "nume macro")
("macros" "macros")
("magnify horizontally" "m riµi orizontal")
("magnify vertically" "m riµi vertical")
("main presentation style" "stil principal de prezentare")
("make a letter environment" "faceµi un mediu de scrisori")
("make a multi-slide presentation" "faceµi o prezentare cu mai multe diapozitive")
("make floating" "a face plutitor")
("make link" "face leg tura")
("make non floating" "a face s  nu pluteasc ")
("manila paper" "hārtie manila")
("map arguments" "argumente de hart ")
("marginal note" "not  marginal ")
("margins from width" "margini din l µime")
("margins on paper" "margini pe hārtie")
("margins on screen" "margini pe ecran")
("marked" "marcat")
("material" "material")
("mathematical and customized input" "introducere matematic  ³i personalizat ")
("mathematical font" "font matematic")
("mathematical input" "introducere matematic ")
("mathematical output" "ie³ire matematic ")
("matrices" "matrici")
("maximal" "maxim")
("maximal cell height" "īn lµimea maxim  a celulelor")
("maximal clustering" "agregare maxim ")
("maximal table height" "īn lµimea maxim  a mesei")
("maximal table width" "l µime maxim  a mesei")
("maximum" "maxim")
("meander" "meandro")
("memory" "memorie")
("memory usage" "utilizare a memoriei")
("menu" "meniu")
("merge lines into paragraphs unless separated by blank lines" "īmbin  liniile īn paragrafe, dac  nu sunt separate de linii necompletate")
("messages" "mesaje")
("meta data" "meta date")
("metadata" "metadate")
("metal" "metal")
("middle baseline" "linie de baz  mijlocie")
("minimal" "minim")
("minimal cell height" "īn lµime minim  a celulelor")
("minimal cell width" "l µime minim  a celulei")
("minimal line separation" "separare minim  a liniilor")
("minimal table height" "īn lµimea minim  a mesei")
("minimal table width" "l µime minim  a mesei")
("minimum" "minim")
("mirror" "oglind ")
("miscellaneous features" "funcµii diverse")
("miscellanous" "miscellanous")
("mode dependent icons" "icoane dependente de modul")
("modify remote live document" "modifica documentul live la distanµ ")
("module" "modul")
("monospaced" "monospaµiat")
("more information about GNU TeXmacs can be found in the Help" "mai multe informaµii despre GNU TeXmacs pot fi g site īn Ajutor")
("more information about GNU TeXmacs can be found in the Help->About menu" "mai multe informaµii despre GNU TeXmacs pot fi g site īn meniul Help->Despre")
("motion" "mi³care")
("mouse over object" "mouse peste obiect")
("move" "mutare")
("move objects" "muta obiecte")
("move over object on which to operate" "deplasaµi peste obiectul pe care s -l operaµi")
("multiline" "multiline")
("multiline input" "intrare multilin ")
("multiple choice" "alegere multipl ")
("multiple root" "r d cin  multipl ")
("multiplication" "īnmulµire")
("mutator tags" "etichete mutatoare")
("my documents" "documentele mele")
("navigation options" "opµiuni de navigare")
("never" "niciodat ")
("new account" "cont nou")
("new bibliography dialogue" "dialog nou pentru bibliografie")
("new document" "document nou")
("new double page" "pagin  dubl  nou ")
("new double page before" "pagin  dubl  nou  īnainte")
("new entry" "intrare nou ")
("new identity" "identitate nou ")
("new locus" "locus nou")
("new macro" "macro nou")
("new passphrase" "nou  parol ")
("new remote directory" "nou director la distanµ ")
("new remote file" "fi³ier la distanµ  nou")
("new style fonts" "fonturi stil nou")
("new style page breaking" "rupere de pagini de stil nou")
("new version" "versiune nou ")
("new window" "fereastr  nou ")
("newer version" "versiune mai nou ")
("next" "urm torul")
("next chunk" "urm toarea bucat ")
("next difference" "urm toarea diferenµ ")
("next error" "urm toarea eroare")
("next field" "cāmpul urm tor")
("next occurrence" "urm toarea apariµie")
("next screen" "ecran urm tor")
("next similar" "urm torul similar")
("no clustering" "f r  clustering")
("no completions" "f r  complet ri")
("no errors have been corrected" "nu au fost corectate erori")
("no grid" "f r  gril ")
("no matches found for" "nu s-au g sit meciuri pentru")
("no new public key in document" "f r  cheie public  nou  īn document")
("no page break" "f r  pauz  de pagin ")
("no page numbers" "f r  numere de pagin ")
("no parent" "f r  p rinte")
("no selection" "f r  selecµie")
("no spelling errors" "f r  gre³eli de ortografie")
("normal loci" "loci normali")
("not allowed to remove home directory" "nu este permis s  eliminaµi directorul de acas ")
("not connected to server" "nu este conectat la server")
("not yet implemented" "nu a fost īnc  implementat")
("notebook" "caiet")
("number of polar steps" "num r de pa³i polari")
("number of subunit steps" "num r de pa³i de subunitate")
("numbering" "numerotare")
("numeric spreadsheet" "foaie de calcul numeric ")
("odd page" "pagin  ciudat ")
("odd page left margin" "margine stāng  pagin  ciudat ")
("odd page right margin" "margine dreapta pagin  ciudat ")
("odd page shift" "schimbare pagin  ciudat ")
("odd pages" "pagini ciudate")
("of fingerprint" "amprent ")
("old version" "versiune veche")
("older version" "versiunea mai veche")
("on the footer" "īn subsol")
("on your system and set it up from the \"Security\" tab" "pe sistemul dvs. ³i configuraµi-l din fila \"Securitate\"")
("one column" "o coloan ")
("one error has been corrected" "a fost corectat  o eroare")
("one lower case letter, one non alpha-numeric symbol" "o litere minuscul , un simbol non-alfanumeric")
("one numeric character, one upper case letter" "un caracter numeric, o majuscul ")
("only convert changes when re-importing" "convertiµi modific rile numai la reimportare")
("only convert changes with respect to imported version" "convertiµi doar modific rile faµ  de versiunea importat ")
("only convert changes with respect to tracked version" "convertiµi modific rile doar īn raport cu versiunea urm rit ")
("only implemented for complete subtrees" "implementat doar pentru subtrafe complete")
("only inline tags" "numai etichete inline")
("only keep folded" "p straµi doar pliat")
("only keep unfolded" "p straµi doar desf ³urat")
("only show semantic focus" "arat  doar focalizarea semantic ")
("opacity" "opacitate")
("open bibliography" "bibliografie deschis ")
("open identities" "identit µi deschise")
("open in new window" "deschis īn fereastr  nou ")
("open key manager" "deschis cheie manager")
("open licence agreement" "acord de licenµ  deschis")
("open mailbox" "cutie po³tal  deschis ")
("open module browser" "browser modul deschis")
("open symbol browser" "browser cu simboluri deschise")
("open tool in separate window" "instrument deschis īn fereastr  separat ")
("operation mode" "modul de funcµionare")
("or give the complete path to the \"gpg\" or \"gpg2\" command" "sau daµi calea complet  la comanda \"gpg\" sau \"gpg2\"")
("order" "comand ")
("ordinary symbol" "simbol obi³nuit")
("ornamented" "ornamentat")
("other login" "alt  autentificare")
("other package" "alt pachet")
("outer bottom" "fund exterior")
("outer left" "exterior stānga")
("outer right" "exterior dreapta")
("outer top" "blat exterior")
("outline" "contur")
("outlined" "conturat")
("outlined emboss" "relief  conturat ")
("outlined engrave" "gravur  conturat ")
("output options" "opµiuni de ie³ire")
("oval" "oval")
("overbrace" "overbrace")
("overlap" "suprapunere")
("overlay" "suprapunere")
("overlays" "suprapuneri")
("overline" "overline")
("overlined" "subliniat")
("overview of the scheme extension language" "Prezentare general  a limbajului de extensie a schemei")
("padded" "c ptu³it")
("page background" "fundal pagin ")
("page break after" "pauz  de pagin  dup ")
("page breaking algorithm" "algoritm de rupere de pagini")
("page number" "num r de pagin ")
("page number rendering" "redarea numerelor de pagin ")
("page rendering" "redare pagin ")
("page setup" "configurare pagin ")
("palette" "palet ")
("panorama" "panoram ")
("paragraphs" "alineate")
("parametric curve" "curb  parametric ")
("parametric surface" "suprafaµ  parametric ")
("parenthesis" "parantez ")
("parenthesized" "īntre paranteze")
("particle" "particule")
("passphrase encryption" "criptare cu parol ")
("passphrase wallet facilities are not currently available" "Facilit µile portofelelor cu parol  nu sunt disponibile īn prezent")
("passphrases are expected to have at least: 8 characters" "frazele de parol  sunt de a³teptat s  aib  cel puµin: 8 caractere")
("passphrases mismatch" "nepotrivire a frazelor")
("pastel" "pastel")
("pattern" "model")
("pause" "pauz ")
("pen width" "l µime stilou")
("permanent footer" "subsol permanent")
("permanent header" "antet permanent")
("permanently add to dictionary" "ad ugaµi permanent īn dicµionar")
("permanently insert into dictionary" "introduceµi definitiv īn dicµionar")
("permissions" "permisiuni")
("phantom" "fantom ")
("phantoms" "fantome")
("physics and astronomy class" "clasa de fizic  ³i astronomie")
("picture" "imagine")
("pine" "pin")
("plain" "simplu")
("plain boxes" "cutii simple")
("plain circles" "cercuri simple")
("play" "joc")
("play animation" "animaµie de joc")
("please install GnuPG software from https://www.gnupg.org" "v  rug m s  instalaµi software-ul GnuPG de la https://www.gnupg.org")
("plot" "complot")
("plug-ins" "plug-in-uri")
("plugin" "plugin")
("plugins" "plugin-uri")
("plural" "plural")
("point" "punct")
("polar" "polar")
("polygon" "poligon")
("pop server settings" "set ri server pop")
("position of marginal note" "poziµia notei marginale")
("poster formats" "formate de afi³")
("poster theme" "tema posterului")
("postfix" "postfix")
("preferences for editing mathematical formulas" "preferinµe pentru editarea formulelor matematice")
("preferences for tag" "preferinµe pentru etichet ")
("prefix" "prefix")
("presentation" "prezentare")
("presentation tag" "etichet  de prezentare")
("presentation tool" "instrument de prezentare")
("preserve" "conserv ")
("preserve tags" "etichete p straµi")
("pretty tree output" "ie³ire īn arbore destul")
("preview" "previzualizare")
("preview command" "comand  de previzualizare")
("previous" "anterior")
("previous difference" "diferenµ  anterioar ")
("previous error" "eroare anterioar ")
("previous field" "cāmpul anterior")
("previous occurrence" "apariµia anterioar ")
("previous screen" "ecran anterior")
("previous similar" "anterioare similare")
("primitive or macro" "primitive sau macro")
("print buffer" "tampon de imprimare")
("print buffer to file" "tampon de imprimare īn fi³ier")
("print to file" "tip rire īn fi³ier")
("printer setup" "configurare imprimant ")
("program bracket matching" "potrivire īntre pachetul de programe")
("program bracket selections" "selecµii de parantez  de program")
("program commands" "comenzi de program")
("program font" "font de program")
("program interface for buffer management" "Interfaµ  de program pentru gestionarea tamponului")
("programming routines for editing documents" "rutine de programare pentru editarea documentelor")
("prominent" "proeminent")
("prompts and default input" "solicit ri ³i intrare implicit ")
("provoke C++ error" "provoca eroare C ++")
("provoke menu error" "provoca eroare de meniu")
("provoke scheme error" "provoca eroare de schem ")
("pseudo code" "pseudo-cod")
("public key encryption" "criptare cu cheie public ")
("public keys" "chei publice")
("pulse" "puls")
("qt GUI only, sorry. Use \"Export selection\"" "Numai GUI de qt, scuze. Utilizaµi \"Selectare export\"")
("qt-widgets" "qt-widgets")
("quantifier" "cuantificator")
("quasi" "cvasi")
("question" "īntrebare")
("questions only" "numai īntreb ri")
("questions with answers" "īntreb ri cu r spunsuri")
("quick evaluation of formulas" "evaluare rapid  a formulelor")
("rank" "rang")
("raw" "brut")
("really delete user identity" "³terge cu adev rat identitatea utilizatorului")
("really tiny" "foarte mic")
("rebuild translations file" "fi³ier de refacere a traducerilor")
("recent" "recent")
("recent documents" "documente recente")
("recipients" "destinatari")
("recognize" "recunoa³te")
("recover autosave file" "recupera fi³ierul autosave")
("rectangular" "dreptunghiular")
("reduce" "reduce")
("reduce trigonometric functions" "reduce funcµiile trigonometrice")
("reduced margins" "marje reduse")
("reference guide" "ghid de referinµ ")
("reference guide for the TeXmacs primitives" "ghid de referinµ  pentru primitivele TeXmacs")
("reference guide for the standard TeXmacs styles" "Ghid de referinµ  pentru stilurile TeXmacs standard")
("regenerate" "regenera")
("register file" "fi³ier registru")
("relate" "se refer ")
("relation" "relaµie")
("release left button: finish editing" "eliberare buton stānga: terminare editare")
("remote" "la distanµ ")
("remote connections" "conexiuni la distanµ ")
("remote control" "telecomand ")
("remote controllers with keyboard simulation" "telecomenzi cu simulare de tastatur ")
("remote directory" "director la distanµ ")
("remote servers" "servere la distanµ ")
("remote tool" "instrument la distanµ ")
("remove" "īnl turaµi")
("remove all output fields" "eliminaµi toate cāmpurile de ie³ire")
("remove banner" "elimina banner")
("remove database entry" "eliminaµi intrarea īn baza de date")
("remove downwards" "scoateµi īn jos")
("remove entries" "eliminaµi intr rile")
("remove entry" "eliminaµi intrarea")
("remove field above" "eliminaµi cāmpul de mai sus")
("remove field below" "eliminaµi cāmpul de mai jos")
("remove fields" "eliminaµi cāmpurile")
("remove folded" "elimina pliat")
("remove input field" "eliminaµi cāmpul de intrare")
("remove input field above" "eliminaµi cāmpul de intrare de mai sus")
("remove last field" "eliminaµi ultimul cāmp")
("remove leftwards" "scoateµi spre stānga")
("remove link" "elimina leg tura")
("remove next field" "eliminaµi cāmpul urm tor")
("remove package" "elimina pachetul")
("remove previous field" "eliminaµi cāmpul anterior")
("remove rightwards" "eliminaµi spre dreapta")
("remove selected database entries" "eliminaµi intr rile selectate din baza de date")
("remove selected entries" "eliminaµi intr rile selectate")
("remove superfluous invisible operators" "īndep rtaµi operatorii invizibili de prisos")
("remove tag" "elimina eticheta")
("remove this branch" "eliminaµi aceast  ramur ")
("remove unfolded" "scoateµi desf ³urat")
("remove upwards" "scoateµi īn sus")
("removed entries from database" "intr ri eliminate din baza de date")
("removed entry from database" "intrare eliminat  din baza de date")
("rename" "redenumire")
("rename section" "redenumiµi secµiunea")
("repeat" "repetare")
("replace TeXmacs styles with no LaTeX equivalents" "īnlocuiesc stilurile TeXmacs f r  echivalente LaTeX")
("replace all further occurrences" "īnlocuiµi toate evenimentele suplimentare")
("replace one occurrence" "īnlocuiµi o īntāmplare")
("replace toolbar" "īnlocuie³te bara de instrumente")
("replace unrecognized styles" "īnlocuiµi stiluri nerecunoscute")
("reset error counters" "reseteaz  contoarele de erori")
("resize" "redimensionare")
("resize objects" "redimensiona obiecte")
("restart TeXmacs in order to let changes take effect" "reporniµi TeXmacs pentru ca modific rile s  aib  efect")
("restart in order to let the new look and feel take effect" "reporniµi pentru ca noul aspect s  se simt  efectiv")
("retain" "reµine")
("retime" "reīnc rcare")
("retina settings" "set ri retin ")
("retrieve email" "reg siµi e-mailul")
("retrieve remote live document" "reg siµi documentul live la distanµ ")
("retrieved contents" "conµinut preluat")
("reverse" "invers")
("reverse ordering" "comand  invers ")
("ridged paper" "hārtie ridicat ")
("right arrow" "s geat  dreapta")
("right baseline" "linie de baz  dreapt ")
("right cell border" "marginea celulei drepte")
("right cell padding" "c ptu³irea celulelor drepte")
("right down" "dreapta jos")
("right on even pages" "chiar pe pagini uniforme")
("right table border" "frontiera din dreapta")
("right table padding" "c ptu³ire a mesei drepte")
("right up" "īn sus")
("rightwards" "spre dreapta")
("rigid box" "cutie rigid ")
("rotate" "rotiµi")
("rotate objects" "rotiµi obiecte")
("rough" "dur")
("rough paper" "hārtie brut ")
("round" "rotund")
("round overbrace" "overbrace rotund ")
("round underbrace" "underbrace round")
("row above" "rānd deasupra")
("row below" "rānd mai jos")
("rows" "rānduri")
("run" "a alerga")
("run current file" "executaµi fi³ierul curent")
("same names" "acelea³i nume")
("same screen margins as on paper" "acelea³i margini de ecran ca pe hārtie")
("sample text" "text text")
("save auxiliary data" "salvaµi date auxiliare")
("save entries" "salvaµi intr ri")
("save entry" "salvaµi intrarea")
("save image as" "salvaµi imaginea ca")
("save position" "salvare poziµie")
("save remote file" "salvaµi fi³ierul de la distanµ ")
("saved modifications in database" "modific ri salvate īn baza de date")
("scheme command" "comand  de schem ")
("scheme developers guide" "ghid pentru dezvoltatorii de scheme")
("scheme extensions" "extensii de schem ")
("scheme interface for the graphical mode" "schema de interfaµ  pentru modul grafic")
("screen" "ecran")
("screen rendering" "redare ecran")
("screens" "ecrane")
("screenshot" "captur  de ecran")
("scripting language" "limbaj de scriere")
("scripts" "scripturi")
("search and replace" "c utaµi ³i īnlocuiµi")
("search results for" "Rezultate c utare pentru")
("search toolbar" "Bara de instrumente de c utare")
("search words in my documents" "c utare cuvinte īn documentele mele")
("search words in the documentation" "c utare cuvinte īn documentaµie")
("search words in the source code" "c utare cuvinte īn codul surs ")
("second" "secund ")
("secret keys" "chei secrete")
("sections" "secµiuni")
("see documentation" "vezi documentaµia")
("select pen" "stilou selectat")
("select the action to be undertaken for each conflict" "selectaµi acµiunea care trebuie īntreprins  pentru fiecare conflict")
("select view mode" "selectaµi modul de vizualizare")
("semantic correctness" "corectitudine semantic ")
("semantic editing" "editare semantic ")
("semantic selections" "selecµii semantice")
("semantics" "semantic ")
("sending commands to TeXmacs" "trimiterea de comenzi c tre TeXmacs")
("senior" "senior")
("serif" "serif")
("server" "server")
("session commands" "comenzi de sesiune")
("set default" "setat implicit")
("set difference" "diferenµ  setat ")
("set intersection" "intersecµie setat ")
("set number of columns" "set de num r de coloane")
("set number of rows" "set de num r de rānduri")
("set or get environment variables" "setaµi sau obµineµi variabile de mediu")
("set properties" "set de propriet µi")
("set span" "set set")
("set union" "set de unire")
("set user information" "setare informaµii despre utilizator")
("seventh" "a ³aptea")
("several equations" "mai multe ecuaµii")
("shadow" "umbr ")
("shadowed" "umbrit")
("shadowed raise" "ridicarea īn umbr ")
("shift" "schimbare")
("short" "scurt")
("show all parts" "arat  toate p rµile")
("show current focus" "arat  focalizarea curent ")
("show full context" "arat  contextul complet")
("show hidden" "arat  ascuns")
("show key presses" "Afi³eaz  ap sarea tastelor")
("show main document" "arat  documentul principal")
("show memory usage" "arat  utilizarea memoriei")
("show one part" "arat  o parte")
("show panorama" "arat  panorama")
("show preamble" "arat  preambul")
("show several parts" "arat  mai multe p rµi")
("show subunits" "arat  subunit µi")
("show table cells" "arat  celulele tabelului")
("show timings" "afi³area calendarului")
("side tools" "instrumente laterale")
("simple" "simplu")
("simplification" "simplificare")
("simplified evaluation of formulas" "evaluare simplificat  a formulelor")
("simplified menus" "meniuri simplificate")
("simplify" "simplificaµi")
("sine" "sine")
("sixth" "a ³asea")
("size tag" "tag tag")
("skew" "oblic")
("skip all" "s riµi totul")
("slant" "inclinat")
("slashed fraction" "fracµie zdrobit ")
("slides" "diapozitive")
("slovene" "slovac")
("slow" "lent")
("slow decrease" "sc dere lent ")
("slow increase" "cre³tere lent ")
("small capitals" "capitale mici")
("small environment box" "cutie pentru mediu mic")
("small focus" "focalizare mic ")
("small inline" "linie mic ")
("small inline fraction" "fracµie liniar  mic ")
("smash" "smash")
("smooth" "neted")
("smooth end" "cap t neted")
("smooth extremities" "extremit µi netede")
("smooth start" "pornire lin ")
("snap" "prindere")
("snap distance" "distanµ  instantanee")
("snap to curves" "fixare īn curbe")
("snap to grid" "prindere īn gril ")
("snap to grid curve" "curb  īnclinare la gril ")
("snap to intersections of curves" "prindeµi īn intersecµiile curbelor")
("snap to text borders" "prindere la borduri text")
("snap to text corners" "īnclinare īn colµurile de text")
("solution" "soluµie")
("solution to exercise" "soluµie de exerciµiu")
("solution to problem" "soluµie la problem ")
("solutions" "soluµii")
("sound" "sunet")
("source" "surs ")
("source macros tool" "instrument de macro-uri surs ")
("source tags" "etichete surs ")
("south" "sud")
("south east" "sud-est")
("space bar in math mode" "bara de spaµiu īn modul matematic")
("space bar in text mode" "bara de spaµiu īn modul text")
("space stretchability" "īntindere spaµial ")
("span" "span")
("span over all columns" "īntindere pe toate coloanele")
("special functions" "funcµii speciale")
("special properties" "propriet µi speciale")
("specific baseline" "linie de baz  specific ")
("specify color alternation" "specificaµi alternanµa de culoare")
("specify how to traverse the manual" "specificaµi cum s  parcurgeµi manualul")
("specify semantics of a symbol or formula" "specifica semantica unui simbol sau a unei formule")
("specify the size of the table" "specificaµi dimensiunea tabelului")
("spell check" "verificare ortografic ")
("spline" "spline")
("split program" "program īmp rµit")
("split session" "sesiune divizat ")
("square" "p trat")
("square overbrace" "overbrace p trat")
("square underbrace" "underbrace square")
("stack" "stiv ")
("standard" "standard")
("standard Output" "Ie³ire standard")
("standard TeXmacs styles" "stiluri TeXmacs standard")
("standard environment variables" "variabile standard de mediu")
("standard formats" "formate standard")
("standard fraction" "fracµie standard")
("star" "stea")
("start server" "server de pornire")
("statement" "declaraµie")
("statistics" "statistici")
("status" "stare")
("stop server" "server de oprire")
("storage" "stocare")
("store tracking information in LaTeX files" "stocheaz  informaµii de urm rire īn fi³ierele LaTeX")
("stretch" "īntindere")
("stretch factor" "factor de īntindere")
("stretched" "īntins")
("strict Ascii" "Ascii stricµi")
("strike through" "grev  prin")
("structured insert above" "insert structurat mai sus")
("structured insert at the left" "insert structurat la stānga")
("structured insert at the right" "insert structurat la dreapta")
("structured insert below" "insert structurat mai jos")
("structured remove downwards" "eliminat structurat īn jos")
("structured remove leftwards" "structurat īnl turaµi spre stānga")
("structured remove rightwards" "structurat īnl turaµi spre dreapta")
("structured remove upwards" "eliminare structurat  īn sus")
("structured variant" "variant  structurat ")
("style options" "opµiuni de stil")
("style parameters" "parametri de stil")
("stylesheet language" "limb  cu foi de stil")
("subject" "subiect")
("submenu" "submeniu")
("subscript below" "abonament mai jos")
("subsubmenu" "subsubmenu")
("subsubsubmenu" "subsubsubmenu")
("subsubsubsubmenu" "subsubsubsubmenu")
("subtable" "subtable")
("subtitle" "subtitrare")
("subtraction" "sc dere")
("summarized" "rezumat")
("superposed" "suprapus")
("superscript above" "superscript de mai sus")
("supported plug-ins" "plug-in-uri acceptate")
("surface" "suprafaµ ")
("inflate" "umfl tur ")
("swiss" "suedez")
("switch to buffer" "treceµi la tampon")
("symbol properties not found" "propriet µi ale simbolului nu au fost g site")
("symbols" "simboluri")
("synchronize" "sincronizare")
("synchronize bibliographic references" "sincronizaµi referinµe bibliografice")
("synchronize with remote server" "sincronizare cu serverul de la distanµ ")
("synopsis" "sinopsis")
("system command" "comand  de sistem")
("tab-completion" "completare fil ")
("tabbed" "cu file")
("table breaking" "spargerea mesei")
("table height" "īn lµimea mesei")
("table properties" "propriet µi de tabel")
("table width" "l µime tabel")
("tags with special rendering" "etichete cu randare special ")
("tangent" "tangent")
("teXmacs DTD" "teXmacs DTD")
("teXmacs buffer expected" "Se a³teapt  buffer TeXmacs")
("teXmacs buffer on disk expected" "Se a³teapt  tampon TeXmacs pe disc")
("teXmacs extensions to scheme and utilities" "extensii TeXmacs la schem  ³i utilit µi")
("teXmacs macro" "teXmacs macro")
("teXmacs package" "pachet TeXmacs")
("teXmacs plugins" "plugin-uri TeXmacs")
("teXmacs primitives" "teXmacs primitive")
("teXmacs style" "stil TeXmacs")
("test routine" "rutin  de testare")
("testing tree-view" "testare vizualizare īn arbore")
("text borders" "chenare de text")
("text box style" "stil caset  text")
("text corners" "colµuri de text")
("textual" "textual")
("textual operator" "operator textual")
("textual spreadsheet" "foaie de calcul textual")
("thai" "tailandez")
("the TeXmacs format" "formatul TeXmacs")
("the TeXmacs plug-in system" "sistemul de conectare TeXmacs")
("the document has not been saved" "documentul nu a fost salvat")
("theme parameters" "parametri tem ")
("these collected public keys will be definitely lost" "aceste chei publice colectate vor fi pierdute definitiv")
("these public keys will be definitely lost" "aceste chei publice vor fi pierdute cu siguranµ ")
("these secret keys will be definitely lost" "aceste chei secrete vor fi pierdute cu siguranµ ")
("thicken" "īngro³at")
("third" "al treilea")
("this" "aceasta")
("this column" "aceast  coloan ")
("this page footer" "acest subsol al paginii")
("this page header" "antetul acestei pagini")
("this page number" "acest num r de pagin ")
("this row" "acest rānd")
("this style specifies page margins in the TeX way" "acest stil specific  marginile paginii īn modul TeX")
("three columns" "trei coloane")
("three dots" "trei puncte")
("through popup windows" "prin ferestrele pop-up")
("through the menus" "prin meniuri")
("thumbnails" "miniaturi")
("time evolution" "evoluµia timpului")
("timings" "calendarul")
("title presentation options" "opµiuni de prezentare a titlurilor")
("title style" "stil de titlu")
("title suffix" "sufix de titlu")
("titled block" "bloc intitulat")
("toggle cell wrapping mode" "modul de ambalare a celulelor de comutare")
("toggle here" "comutaµi aici")
("toggle off" "comut ")
("toggle on" "comut ")
("tolerant" "tolerant")
("top baseline" "linia de baz  de sus")
("top cell border" "graniµa celulelor de sus")
("top cell padding" "umplutur  celular  de sus")
("top table border" "marginea de sus a mesei")
("top table padding" "capitonaj de mas  de sus")
("transform" "transformare")
("transform cell into subtable" "transforma celula īn subtile")
("translations" "traduceri")
("translations loaded" "traduceri īnc rcate")
("transpose" "transpun")
("traversal" "traversare")
("traverse" "travers")
("triangle" "triunghi")
("triangularize" "triunghiularizeaz ")
("trigonometric" "trigonometric")
("trigonometry" "trigonometrie")
("turn off" "opriµi")
("turn on" "porniµi")
("two columns" "dou  coloane")
("two dots" "dou  puncte")
("type a latex command followed by return" "tastaµi o comand  latex urmat  de īntoarcere")
("underbrace" "underbrace")
("underline" "subliniat")
("underlined" "subliniat")
("unevaluated argument" "argument neevaluat")
("unevaluated value" "valoare neevaluat ")
("unfold" "desf ³oar ")
("unfold all" "dezv luie tot")
("unfold all fields" "dezv luie toate cāmpurile")
("unit" "unitate")
("unit length" "lungime unitar ")
("unknown secret key fingerprint" "amprent  cheie secret  necunoscut ")
("unregistered file" "fi³ier neīnregistrat")
("unroll" "dezlegare")
("unsecure script refused" "scriptul nesigur a fost refuzat")
("unsupported link mode" "modul de leg tur  neacceptat")
("until" "pān  la")
("untitled block" "bloc f r  titlu")
("up to date" "la zi")
("update buffer" "tampon de actualizare")
("update this buffer" "actualizaµi acest buffer")
("update web site" "site web de actualizare")
("upight" "īn sus")
("upload" "īnc rcare")
("upright" "vertical")
("upwards" "īn sus")
("use CSS for more advanced formatting" "utilizaµi CSS pentru o formatare mai avansat ")
("use MathML" "utilizaµi MathML")
("use as master" "folosiµi ca maestru")
("use extensible brackets" "utilizaµi paranteze extensibile")
("use line wrapping for lines which are longer than 80 characters" "folosiµi īnf ³urarea liniilor pentru linii care au o lungime mai mare de 80 de caractere")
("use margin kerning (protrusion)" "folosiµi kerning margin (proeminenµ )")
("use protrusion" "utilizaµi proeminenµ ")
("use relative path" "utilizaµi calea relativ ")
("user interface" "interfaµ  de utilizator")
("user interface language" "limb  interfaµ  utilizator")
("user preferences" "preferinµe de utilizator")
("users of Cyrillic languages" "utilizatori de limbi chirilice")
("users of oriental languages" "utilizatori de limbi orientale")
("utf-8 with inputenc LaTeX package" "utf-8 cu inputenc pachet LaTeX")
("utilities" "utilit µi")
("vanish" "dispar")
("verbose" "verbose")
("version" "versiune")
("versioning tool" "instrument de versiune")
("vertical alignment" "aliniere vertical ")
("vertical margins" "margini verticale")
("vertical space after" "spaµiu vertical dup ")
("vertical space before" "spaµiu vertical īnainte")
("vertical space stretchability" "īntindere vertical  a spaµiului")
("visible except here" "vizibil, cu excepµia aici")
("visible from here on" "vizibil de aici īncolo")
("visible only here" "vizibil doar aici")
("visible until here" "vizibil pān  aici")
("visited loci" "loci vizitaµi")
("wallet" "portofel")
("wave" "val")
("web" "web")
("weight" "greutate")
("when line wrapping" "cānd se īnf ³oar  linie")
("whitespace" "spaµiu alb")
("wide" "lat")
("wide bar" "bara lat ")
("wide block" "bloc lat")
("wide colored" "colorat larg")
("wide float" "plutitor lat")
("wide footnote" "not  de subsol lat ")
("wide tabular" "tabular lat")
("widescreen" "ecran lat")
("wrap lines" "linii de īnf ³urare")
("write a macro" "scrieµi o macro")
("writing TeXmacs bibliography styles" "scrierea stilurilor de bibliografie TeXmacs")
("writing documentation" "documentaµie de scriere")
("written with TeXmacs" "scris cu TeXmacs")
("wrong empty passphrase" "fraz  de acces goal  gre³it ")
("wrong passphrase" "parol  gre³it ")
("year" "an")
("you are attempting to open an encrypted file while" "īncercaµi s  deschideµi un fi³ier criptat īn timp ce")
("you might consider enabling the experimental" "s-ar putea s  luaµi īn considerare activarea experimentului")
("you must add a bibliography file" "trebuie s  ad ugaµi un fi³ier bibliografie")
("you should also make sure that GnuPG is installed" "ar trebui s  v  asiguraµi, de asemenea, c  GnuPG este instalat")
("your language" "limba ta")
("your personal dictionary has been modified" "dicµionarul personal a fost modificat")
("zoom" "zoom")
("zoom in" "m riµi")
("zoom out" "m riµi")
