<TeXmacs|1.0.6.9>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package|gui-brushed|1.0>

    <\src-purpose>
      Metal brushed rendering of GUI elements
    </src-purpose>

    <src-copyright|2007|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public
      license, version 3 or later|$TEXMACS_PATH/LICENSE>.
      It comes WITHOUT ANY WARRANTY WHATSOEVER.
      You should have received a copy of the license which the software.
      If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <\active*>
    <\src-comment>
      Environment variables for GUI layout
    </src-comment>
  </active*>

  <assign|gui-small-sep|0.25em>

  <assign|gui-med-sep|0.5em>

  <assign|gui-big-sep|0.75em>

  <assign|raised-color|<pattern|metal-brushed-light.png|/2|/2|light grey>>

  <assign|lowered-color|<pattern|metal-brushed-medium.png|/2|/2|grey>>

  <assign|bright-color|<pattern|paper-ridged-bright.png|/2|/2|light grey>>

  <assign|sunny-color|white>

  <assign|shadow-color|dark grey>

  <assign|short-width|0em>

  <\active*>
    <\src-comment>
      Environment variables for buttons
    </src-comment>
  </active*>

  <assign|bg-color|<pattern|ridged-brushed-light.png|/2|/2|light grey>>

  <assign|bg-color|<pattern|ridged-brushed-light.png|65px|65px|light grey>>

  <assign|canvas-color|<pattern|paper-ridged-bright.png|/2|/2|light grey>>

  <assign|ornament-color|<pattern|metal-brushed-light.png|/2|/2|light grey>>

  <assign|canvas-bar-color|<pattern|metal-brushed-medium.png|/2|/2|light
  grey>>

  <assign|button-shape|square>

  <assign|button-color|<pattern|metal-brushed-light.png|/2|/2|light grey>>

  <assign|box-shape|circular>

  <assign|box-color|pastel blue>

  <assign|marker-shape|checked>

  \;
</body>

<\initial>
  <\collection>
    <associate|language|english>
    <associate|preamble|true>
  </collection>
</initial>

<\references>
  <\collection>
    <associate||<tuple|<error|argument body>|?>>
  </collection>
</references>