((Academicons Regular) ())
((Academy\ Engraved\ LET Plain) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=243 lvw=4 lhw=5 uvw=4 uhw=5 fillp=22 vcnt=20 lasprat=113 pasprat=107 loasc=170 lodes=167 dides=104))
((Accanthis\ ADF\ Std\ No3 Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=160 lvw=30 lhw=13 uvw=30 uhw=13 fillp=43 vcnt=42 lasprat=122 pasprat=110 loasc=171 lodes=157 dides=102))
((Accanthis\ ADF\ Std\ No3 Bold\ Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=75 em=156 lvw=26 lhw=14 uvw=30 uhw=14 fillp=37 vcnt=41 lasprat=116 pasprat=119 loasc=166 lodes=156 dides=102))
((Accanthis\ ADF\ Std\ No3 Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=75 em=149 lvw=17 lhw=5 uvw=22 uhw=6 fillp=25 vcnt=28 lasprat=107 pasprat=108 loasc=166 lodes=156 dides=102))
((Accanthis\ ADF\ Std\ No3 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=153 lvw=20 lhw=5 uvw=24 uhw=5 fillp=29 vcnt=28 lasprat=113 pasprat=101 loasc=171 lodes=157 dides=102))
((Al\ Bayan Bold) (slant=0))
((Al\ Bayan Plain) (slant=0))
((Al\ Bayan\ PUA Bold) (slant=0))
((Al\ Bayan\ PUA Plain) (slant=0))
((Al\ Firat Regular) (slant=0))
((Al\ Khalil Bold) (slant=0))
((Al\ Khalil Regular) (slant=0))
((Al\ Nile Bold) ())
((Al\ Nile Regular) ())
((Al\ Nile\ PUA Bold) ())
((Al\ Nile\ PUA Regular) ())
((Al\ Rafidain Regular) (slant=0))
((Al\ Rafidain\ Al\ Fanni Regular) (slant=0))
((Al\ Rafidain\ PUA Regular) ())
((Al\ Tarikh Regular) ())
((Al\ Tarikh\ PUA Regular) ())
((Alegreya Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=173 lvw=38 lhw=22 uvw=46 uhw=26 fillp=63 vcnt=67 lasprat=102 pasprat=101 loasc=155 lodes=151 dides=120))
((Alegreya Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=81 em=166 lvw=35 lhw=34 uvw=45 uhw=27 fillp=59 vcnt=67 lasprat=98 pasprat=101 loasc=153 lodes=151 dides=119))
((Alegreya Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=181 lvw=27 lhw=16 uvw=32 uhw=20 fillp=49 vcnt=48 lasprat=103 pasprat=96 loasc=161 lodes=153 dides=122))
((Alegreya Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=11 italic=yes case=mixed regular=yes ex=79 em=170 lvw=25 lhw=21 uvw=30 uhw=17 fillp=46 vcnt=48 lasprat=93 pasprat=92 loasc=156 lodes=151 dides=121))
((Alegreya ExtraBold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=179 lvw=33 lhw=19 uvw=39 uhw=21 fillp=56 vcnt=58 lasprat=103 pasprat=100 loasc=158 lodes=152 dides=121))
((Alegreya ExtraBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=80 em=168 lvw=30 lhw=25 uvw=38 uhw=22 fillp=52 vcnt=58 lasprat=95 pasprat=98 loasc=155 lodes=151 dides=121))
((Alegreya Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=78 em=174 lvw=16 lhw=14 uvw=17 uhw=10 fillp=31 vcnt=30 lasprat=89 pasprat=85 loasc=158 lodes=152 dides=123))
((Alegreya Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=183 lvw=22 lhw=12 uvw=24 uhw=14 fillp=41 vcnt=39 lasprat=102 pasprat=94 loasc=161 lodes=153 dides=123))
((Alegreya Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=79 em=170 lvw=20 lhw=17 uvw=24 uhw=13 fillp=38 vcnt=39 lasprat=90 pasprat=88 loasc=156 lodes=151 dides=122))
((Alegreya Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=185 lvw=17 lhw=11 uvw=18 uhw=10 fillp=34 vcnt=31 lasprat=102 pasprat=91 loasc=163 lodes=153 dides=123))
((Alegreya\ Sans Black) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=169 lvw=39 lhw=26 uvw=44 uhw=31 fillp=68 vcnt=65 lasprat=101 pasprat=93 loasc=153 lodes=141 dides=120))
((Alegreya\ Sans Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=80 em=167 lvw=35 lhw=32 uvw=43 uhw=31 fillp=61 vcnt=64 lasprat=96 pasprat=96 loasc=150 lodes=141 dides=120))
((Alegreya\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=170 lvw=26 lhw=19 uvw=30 uhw=21 fillp=55 vcnt=48 lasprat=98 pasprat=85 loasc=151 lodes=141 dides=121))
((Alegreya\ Sans Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=yes case=mixed regular=yes ex=79 em=163 lvw=24 lhw=21 uvw=27 uhw=21 fillp=49 vcnt=46 lasprat=91 pasprat=84 loasc=148 lodes=141 dides=121))
((Alegreya\ Sans ExtraBold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=171 lvw=32 lhw=23 uvw=35 uhw=25 fillp=61 vcnt=55 lasprat=100 pasprat=89 loasc=151 lodes=142 dides=121))
((Alegreya\ Sans ExtraBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=yes case=mixed regular=yes ex=79 em=165 lvw=29 lhw=24 uvw=35 uhw=25 fillp=54 vcnt=55 lasprat=94 pasprat=90 loasc=148 lodes=141 dides=121))
((Alegreya\ Sans Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=77 em=163 lvw=14 lhw=12 uvw=16 uhw=14 fillp=34 vcnt=30 lasprat=88 pasprat=76 loasc=153 lodes=142 dides=122))
((Alegreya\ Sans Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=172 lvw=10 lhw=9 uvw=11 uhw=9 fillp=30 vcnt=21 lasprat=96 pasprat=74 loasc=155 lodes=142 dides=122))
((Alegreya\ Sans Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=yes case=mixed regular=yes ex=77 em=162 lvw=10 lhw=7 uvw=10 uhw=9 fillp=24 vcnt=21 lasprat=86 pasprat=74 loasc=153 lodes=142 dides=123))
((Alegreya\ Sans Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=171 lvw=20 lhw=15 uvw=23 uhw=16 fillp=47 vcnt=38 lasprat=98 pasprat=81 loasc=151 lodes=141 dides=122))
((Alegreya\ Sans Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=78 em=162 lvw=19 lhw=15 uvw=21 uhw=16 fillp=41 vcnt=38 lasprat=89 pasprat=81 loasc=150 lodes=142 dides=121))
((Alegreya\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=173 lvw=15 lhw=11 uvw=17 uhw=14 fillp=40 vcnt=30 lasprat=97 pasprat=77 loasc=153 lodes=142 dides=122))
((Alegreya\ Sans Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=173 lvw=4 lhw=4 uvw=4 uhw=4 fillp=15 vcnt=8 lasprat=94 pasprat=69 loasc=156 lodes=142 dides=122))
((Alegreya\ Sans Thin\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=76 em=163 lvw=3 lhw=3 uvw=3 uhw=3 fillp=12 vcnt=9 lasprat=85 pasprat=68 loasc=153 lodes=143 dides=122))
((Alegreya\ Sans\ SC Black) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=86 em=155 lvw=37 lhw=26 uvw=40 uhw=29 fillp=69 vcnt=62 lasprat=102 pasprat=92 loasc=102 lodes=132 dides=118))
((Alegreya\ Sans\ SC Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=no case=smallcaps regular=yes ex=86 em=155 lvw=37 lhw=26 uvw=40 uhw=29 fillp=63 vcnt=62 lasprat=102 pasprat=98 loasc=102 lodes=133 dides=118))
((Alegreya\ Sans\ SC Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=84 em=158 lvw=26 lhw=19 uvw=28 uhw=20 fillp=56 vcnt=46 lasprat=101 pasprat=85 loasc=102 lodes=130 dides=120))
((Alegreya\ Sans\ SC Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=no case=smallcaps regular=yes ex=84 em=153 lvw=25 lhw=19 uvw=26 uhw=20 fillp=50 vcnt=44 lasprat=99 pasprat=88 loasc=102 lodes=132 dides=120))
((Alegreya\ Sans\ SC ExtraBold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=85 em=157 lvw=30 lhw=22 uvw=32 uhw=23 fillp=62 vcnt=53 lasprat=101 pasprat=88 loasc=102 lodes=131 dides=120))
((Alegreya\ Sans\ SC ExtraBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=no case=smallcaps regular=yes ex=85 em=154 lvw=30 lhw=22 uvw=32 uhw=23 fillp=56 vcnt=52 lasprat=100 pasprat=93 loasc=102 lodes=132 dides=120))
((Alegreya\ Sans\ SC Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=no case=smallcaps regular=yes ex=83 em=151 lvw=13 lhw=12 uvw=15 uhw=13 fillp=34 vcnt=27 lasprat=96 pasprat=79 loasc=101 lodes=130 dides=120))
((Alegreya\ Sans\ SC Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=83 em=157 lvw=9 lhw=8 uvw=10 uhw=8 fillp=29 vcnt=20 lasprat=98 pasprat=74 loasc=100 lodes=130 dides=120))
((Alegreya\ Sans\ SC Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=12 italic=no case=smallcaps regular=yes ex=82 em=152 lvw=9 lhw=7 uvw=9 uhw=8 fillp=24 vcnt=19 lasprat=95 pasprat=78 loasc=101 lodes=130 dides=121))
((Alegreya\ Sans\ SC Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=84 em=157 lvw=20 lhw=15 uvw=21 uhw=15 fillp=47 vcnt=36 lasprat=99 pasprat=81 loasc=101 lodes=130 dides=120))
((Alegreya\ Sans\ SC Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=no case=smallcaps regular=yes ex=84 em=151 lvw=19 lhw=14 uvw=20 uhw=15 fillp=41 vcnt=35 lasprat=96 pasprat=83 loasc=101 lodes=130 dides=120))
((Alegreya\ Sans\ SC Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=83 em=159 lvw=15 lhw=13 uvw=15 uhw=13 fillp=40 vcnt=29 lasprat=99 pasprat=77 loasc=102 lodes=130 dides=120))
((Alegreya\ Sans\ SC Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=82 em=158 lvw=3 lhw=3 uvw=3 uhw=3 fillp=15 vcnt=8 lasprat=97 pasprat=69 loasc=100 lodes=128 dides=120))
((Alegreya\ Sans\ SC Thin\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=no case=smallcaps regular=yes ex=82 em=151 lvw=3 lhw=3 uvw=3 uhw=3 fillp=12 vcnt=8 lasprat=94 pasprat=71 loasc=100 lodes=128 dides=120))
((Alegreya\ SC Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=85 em=163 lvw=40 lhw=21 uvw=43 uhw=24 fillp=66 vcnt=64 lasprat=107 pasprat=103 loasc=101 lodes=137 dides=118))
((Alegreya\ SC Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=no case=smallcaps regular=yes ex=85 em=158 lvw=38 lhw=23 uvw=43 uhw=25 fillp=62 vcnt=65 lasprat=104 pasprat=107 loasc=101 lodes=137 dides=118))
((Alegreya\ SC Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=84 em=166 lvw=27 lhw=15 uvw=29 uhw=19 fillp=51 vcnt=46 lasprat=106 pasprat=96 loasc=102 lodes=135 dides=120))
((Alegreya\ SC Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=11 italic=no case=smallcaps regular=yes ex=84 em=160 lvw=26 lhw=14 uvw=28 uhw=16 fillp=47 vcnt=46 lasprat=103 pasprat=99 loasc=102 lodes=135 dides=120))
((Alegreya\ SC ExtraBold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=85 em=164 lvw=32 lhw=17 uvw=36 uhw=20 fillp=58 vcnt=55 lasprat=106 pasprat=100 loasc=101 lodes=136 dides=120))
((Alegreya\ SC ExtraBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=13 italic=no case=smallcaps regular=yes ex=85 em=158 lvw=32 lhw=18 uvw=36 uhw=21 fillp=54 vcnt=56 lasprat=103 pasprat=104 loasc=101 lodes=136 dides=120))
((Alegreya\ SC Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=13 italic=no case=smallcaps regular=yes ex=84 em=161 lvw=16 lhw=9 uvw=16 uhw=9 fillp=31 vcnt=28 lasprat=101 pasprat=93 loasc=101 lodes=134 dides=121))
((Alegreya\ SC Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=85 em=165 lvw=21 lhw=11 uvw=22 uhw=12 fillp=42 vcnt=38 lasprat=104 pasprat=93 loasc=100 lodes=134 dides=121))
((Alegreya\ SC Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=13 italic=no case=smallcaps regular=yes ex=84 em=160 lvw=21 lhw=11 uvw=22 uhw=13 fillp=38 vcnt=37 lasprat=102 pasprat=97 loasc=102 lodes=134 dides=121))
((Alegreya\ SC Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=85 em=165 lvw=16 lhw=9 uvw=16 uhw=9 fillp=34 vcnt=30 lasprat=103 pasprat=90 loasc=100 lodes=134 dides=121))
((Alex\ Toth Regular) (mono=no sans=yes italic=no case=caps regular=no ex=126 em=130 lvw=12 lhw=15 uvw=12 uhw=15 fillp=45 vcnt=60 lasprat=89 pasprat=82 loasc=108 lodes=140 dides=113))
((AlFirat\ PUA Regular) ())
((Algiers Regular) (slant=0))
((Algiers\ PUA Regular) (slant=0))
((AlgolRevived Medium) (Ascii Latin MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=214 lvw=20 lhw=16 uvw=23 uhw=17 fillp=44 vcnt=39 lasprat=123 pasprat=103 loasc=146 lodes=147 dides=102))
((AlgolRevived MediumSlanted) (Ascii Latin MathSymbols mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=78 em=230 lvw=23 lhw=16 uvw=24 uhw=17 fillp=41 vcnt=40 lasprat=124 pasprat=113 loasc=146 lodes=147 dides=102))
((AlgolRevived Regular) (Ascii Latin MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=206 lvw=15 lhw=12 uvw=16 uhw=14 fillp=36 vcnt=31 lasprat=119 pasprat=100 loasc=147 lodes=144 dides=102))
((AlgolRevived Slanted) (Ascii Latin mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=78 em=206 lvw=15 lhw=12 uvw=16 uhw=14 fillp=32 vcnt=31 lasprat=120 pasprat=109 loasc=147 lodes=144 dides=102))
((Alkalami Light) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=224 lvw=22 lhw=10 uvw=22 uhw=12 fillp=35 vcnt=33 lasprat=112 pasprat=106 loasc=178 lodes=162 dides=102))
((Alkalami Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=230 lvw=32 lhw=12 uvw=32 uhw=14 fillp=46 vcnt=45 lasprat=122 pasprat=118 loasc=180 lodes=165 dides=102))
((AlKhalil\ PUA Bold) (slant=0))
((AlKhalil\ PUA Regular) (slant=0))
((ALM\ Fixed Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=15 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=30 lasprat=122 pasprat=104 loasc=143 lodes=152 dides=102))
((Almendra Bold) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=84 em=167 lvw=32 lhw=15 uvw=35 uhw=17 fillp=49 vcnt=52 lasprat=101 pasprat=96 loasc=147 lodes=144 dides=123))
((Almendra Bold\ Italic) (Ascii Latin mono=no sans=yes slant=7 italic=yes case=mixed regular=yes ex=85 em=145 lvw=29 lhw=20 uvw=31 uhw=18 fillp=51 vcnt=53 lasprat=89 pasprat=87 loasc=147 lodes=142 dides=123))
((Almendra Italic) (Ascii Latin mono=no sans=yes slant=7 italic=yes case=mixed regular=yes ex=81 em=145 lvw=14 lhw=12 uvw=17 uhw=14 fillp=32 vcnt=33 lasprat=86 pasprat=80 loasc=154 lodes=144 dides=124))
((Almendra Regular) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=81 em=177 lvw=17 lhw=13 uvw=19 uhw=14 fillp=32 vcnt=32 lasprat=97 pasprat=84 loasc=153 lodes=146 dides=124))
((AlmendraSmallCaps Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=163 lvw=15 lhw=12 uvw=17 uhw=13 fillp=31 vcnt=33 lasprat=95 pasprat=86 loasc=102 lodes=134 dides=103))
((Alpenkreuzer Regular) (mono=no sans=yes italic=no case=caps regular=yes ex=117 em=153 lvw=52 lhw=15 uvw=52 uhw=15 fillp=76 vcnt=91 lasprat=135 pasprat=125 loasc=100 lodes=135 dides=100))
((AlRafidain\ AlFanni\ PUA Regular) ())
((American\ Typewriter Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=210 lvw=30 lhw=23 uvw=36 uhw=27 fillp=60 vcnt=65 lasprat=113 pasprat=111 loasc=142 lodes=141 dides=102))
((American\ Typewriter Condensed) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=143 lvw=13 lhw=13 uvw=15 uhw=13 fillp=39 vcnt=42 lasprat=85 pasprat=79 loasc=137 lodes=139 dides=102))
((American\ Typewriter Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=155 lvw=26 lhw=22 uvw=30 uhw=26 fillp=63 vcnt=68 lasprat=88 pasprat=85 loasc=140 lodes=142 dides=104))
((American\ Typewriter Condensed\ Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=150 lvw=6 lhw=5 uvw=7 uhw=5 fillp=19 vcnt=20 lasprat=88 pasprat=80 loasc=144 lodes=141 dides=101))
((American\ Typewriter Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=185 lvw=6 lhw=4 uvw=6 uhw=4 fillp=15 vcnt=16 lasprat=110 pasprat=105 loasc=140 lodes=139 dides=103))
((American\ Typewriter Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=190 lvw=15 lhw=13 uvw=18 uhw=13 fillp=36 vcnt=39 lasprat=110 pasprat=106 loasc=138 lodes=140 dides=104))
((American\ Typewriter Semibold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=190 lvw=21 lhw=18 uvw=24 uhw=19 fillp=48 vcnt=49 lasprat=110 pasprat=106 loasc=136 lodes=138 dides=104))
((Amiri Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=202 lvw=31 lhw=9 uvw=35 uhw=10 fillp=43 vcnt=40 lasprat=112 pasprat=106 loasc=156 lodes=149 dides=102))
((Amiri Bold\ Slanted) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=74 em=189 lvw=27 lhw=10 uvw=31 uhw=10 fillp=40 vcnt=40 lasprat=100 pasprat=98 loasc=154 lodes=150 dides=102))
((Amiri Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=208 lvw=19 lhw=7 uvw=22 uhw=8 fillp=32 vcnt=29 lasprat=104 pasprat=95 loasc=160 lodes=153 dides=102))
((Amiri Slanted) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=71 em=192 lvw=18 lhw=8 uvw=21 uhw=7 fillp=29 vcnt=28 lasprat=94 pasprat=89 loasc=157 lodes=154 dides=102))
((Amiri\ Quran Regular) (slant=0))
((Amiri\ Quran\ Colored Regular) (slant=0))
((Andale\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=117 lvw=15 lhw=12 uvw=16 uhw=14 fillp=38 vcnt=41 lasprat=117 pasprat=79 loasc=137 lodes=140 dides=102))
((Andika\ Basic Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=175 lvw=18 lhw=15 uvw=19 uhw=16 fillp=40 vcnt=44 lasprat=103 pasprat=86 loasc=159 lodes=148 dides=102))
((Anonymous\ Pro Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=119 lvw=22 lhw=19 uvw=22 uhw=19 fillp=51 vcnt=40 lasprat=119 pasprat=94 loasc=142 lodes=143 dides=102))
((Anonymous\ Pro Bold\ Italic) (Ascii Latin mono=yes sans=yes slant=22 italic=no case=mixed regular=yes ex=76 em=119 lvw=23 lhw=21 uvw=22 uhw=21 fillp=43 vcnt=40 lasprat=119 pasprat=108 loasc=142 lodes=143 dides=102))
((Anonymous\ Pro Italic) (Ascii Latin mono=yes sans=yes slant=22 italic=no case=mixed regular=yes ex=76 em=119 lvw=15 lhw=13 uvw=15 uhw=13 fillp=30 vcnt=28 lasprat=119 pasprat=107 loasc=142 lodes=143 dides=102))
((Anonymous\ Pro Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=119 lvw=15 lhw=13 uvw=15 uhw=13 fillp=36 vcnt=28 lasprat=119 pasprat=93 loasc=142 lodes=143 dides=102))
((Antykwa\ Poltawskiego Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=183 lvw=28 lhw=6 uvw=35 uhw=6 fillp=42 vcnt=41 lasprat=113 pasprat=104 loasc=163 lodes=154 dides=102))
((Antykwa\ Poltawskiego Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=75 em=178 lvw=28 lhw=6 uvw=34 uhw=6 fillp=37 vcnt=41 lasprat=113 pasprat=111 loasc=158 lodes=153 dides=102))
((Antykwa\ Poltawskiego Cond\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=171 lvw=28 lhw=7 uvw=34 uhw=7 fillp=42 vcnt=41 lasprat=106 pasprat=99 loasc=170 lodes=161 dides=102))
((Antykwa\ Poltawskiego Cond\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=72 em=166 lvw=27 lhw=6 uvw=31 uhw=6 fillp=37 vcnt=41 lasprat=106 pasprat=107 loasc=165 lodes=159 dides=102))
((Antykwa\ Poltawskiego Cond\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=72 em=170 lvw=20 lhw=5 uvw=25 uhw=5 fillp=30 vcnt=32 lasprat=104 pasprat=102 loasc=166 lodes=159 dides=102))
((Antykwa\ Poltawskiego Cond\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=175 lvw=22 lhw=5 uvw=24 uhw=5 fillp=34 vcnt=33 lasprat=104 pasprat=94 loasc=170 lodes=161 dides=102))
((Antykwa\ Poltawskiego Expd\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=205 lvw=29 lhw=9 uvw=36 uhw=9 fillp=42 vcnt=41 lasprat=123 pasprat=112 loasc=154 lodes=148 dides=102))
((Antykwa\ Poltawskiego Expd\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=79 em=196 lvw=27 lhw=8 uvw=35 uhw=8 fillp=38 vcnt=41 lasprat=122 pasprat=117 loasc=150 lodes=146 dides=102))
((Antykwa\ Poltawskiego Expd\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=79 em=202 lvw=21 lhw=7 uvw=27 uhw=7 fillp=32 vcnt=34 lasprat=118 pasprat=111 loasc=150 lodes=146 dides=102))
((Antykwa\ Poltawskiego Expd\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=212 lvw=23 lhw=7 uvw=28 uhw=7 fillp=35 vcnt=34 lasprat=121 pasprat=108 loasc=154 lodes=148 dides=102))
((Antykwa\ Poltawskiego Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=75 em=181 lvw=21 lhw=6 uvw=26 uhw=6 fillp=31 vcnt=33 lasprat=107 pasprat=102 loasc=158 lodes=153 dides=102))
((Antykwa\ Poltawskiego Light) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=189 lvw=17 lhw=6 uvw=21 uhw=6 fillp=31 vcnt=30 lasprat=103 pasprat=91 loasc=163 lodes=154 dides=102))
((Antykwa\ Poltawskiego Light\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=184 lvw=26 lhw=6 uvw=31 uhw=6 fillp=38 vcnt=38 lasprat=110 pasprat=101 loasc=163 lodes=154 dides=102))
((Antykwa\ Poltawskiego Light\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=75 em=180 lvw=24 lhw=6 uvw=29 uhw=6 fillp=34 vcnt=37 lasprat=110 pasprat=107 loasc=158 lodes=153 dides=102))
((Antykwa\ Poltawskiego Light\ Cond\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=174 lvw=24 lhw=5 uvw=31 uhw=5 fillp=37 vcnt=37 lasprat=103 pasprat=95 loasc=170 lodes=161 dides=102))
((Antykwa\ Poltawskiego Light\ Cond\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=72 em=169 lvw=23 lhw=5 uvw=29 uhw=5 fillp=33 vcnt=36 lasprat=103 pasprat=102 loasc=165 lodes=159 dides=102))
((Antykwa\ Poltawskiego Light\ Cond\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=72 em=173 lvw=15 lhw=5 uvw=20 uhw=5 fillp=26 vcnt=28 lasprat=95 pasprat=92 loasc=165 lodes=159 dides=102))
((Antykwa\ Poltawskiego Light\ Cond\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=178 lvw=17 lhw=5 uvw=21 uhw=5 fillp=30 vcnt=29 lasprat=96 pasprat=85 loasc=170 lodes=161 dides=102))
((Antykwa\ Poltawskiego Light\ Expd\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=207 lvw=25 lhw=7 uvw=32 uhw=7 fillp=38 vcnt=38 lasprat=121 pasprat=110 loasc=154 lodes=148 dides=102))
((Antykwa\ Poltawskiego Light\ Expd\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=79 em=197 lvw=25 lhw=7 uvw=31 uhw=7 fillp=35 vcnt=38 lasprat=119 pasprat=113 loasc=150 lodes=146 dides=102))
((Antykwa\ Poltawskiego Light\ Expd\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=79 em=207 lvw=17 lhw=7 uvw=22 uhw=7 fillp=28 vcnt=30 lasprat=114 pasprat=107 loasc=150 lodes=146 dides=102))
((Antykwa\ Poltawskiego Light\ Expd\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=216 lvw=18 lhw=7 uvw=22 uhw=7 fillp=31 vcnt=30 lasprat=117 pasprat=103 loasc=154 lodes=148 dides=102))
((Antykwa\ Poltawskiego Light\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=75 em=184 lvw=17 lhw=6 uvw=22 uhw=6 fillp=28 vcnt=29 lasprat=102 pasprat=97 loasc=158 lodes=153 dides=102))
((Antykwa\ Poltawskiego Light\ SemiCond\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=179 lvw=25 lhw=6 uvw=30 uhw=6 fillp=38 vcnt=37 lasprat=107 pasprat=98 loasc=165 lodes=158 dides=102))
((Antykwa\ Poltawskiego Light\ SemiCond\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=74 em=174 lvw=24 lhw=6 uvw=29 uhw=6 fillp=34 vcnt=37 lasprat=107 pasprat=105 loasc=160 lodes=156 dides=102))
((Antykwa\ Poltawskiego Light\ SemiCond\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=74 em=177 lvw=16 lhw=6 uvw=21 uhw=6 fillp=27 vcnt=29 lasprat=98 pasprat=94 loasc=160 lodes=156 dides=102))
((Antykwa\ Poltawskiego Light\ SemiCond\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=181 lvw=16 lhw=6 uvw=22 uhw=6 fillp=31 vcnt=29 lasprat=99 pasprat=88 loasc=165 lodes=158 dides=102))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=25 lhw=8 uvw=32 uhw=8 fillp=39 vcnt=38 lasprat=116 pasprat=106 loasc=158 lodes=150 dides=102))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=77 em=192 lvw=24 lhw=7 uvw=31 uhw=7 fillp=34 vcnt=37 lasprat=117 pasprat=112 loasc=154 lodes=149 dides=102))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=198 lvw=18 lhw=7 uvw=22 uhw=7 fillp=28 vcnt=29 lasprat=109 pasprat=103 loasc=154 lodes=149 dides=102))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=205 lvw=17 lhw=8 uvw=22 uhw=8 fillp=31 vcnt=30 lasprat=111 pasprat=98 loasc=158 lodes=150 dides=102))
((Antykwa\ Poltawskiego Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=186 lvw=21 lhw=6 uvw=27 uhw=6 fillp=35 vcnt=34 lasprat=108 pasprat=97 loasc=163 lodes=154 dides=102))
((Antykwa\ Poltawskiego SemiCond\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=176 lvw=27 lhw=6 uvw=36 uhw=6 fillp=41 vcnt=41 lasprat=109 pasprat=101 loasc=165 lodes=158 dides=102))
((Antykwa\ Poltawskiego SemiCond\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=74 em=171 lvw=27 lhw=6 uvw=33 uhw=6 fillp=37 vcnt=41 lasprat=109 pasprat=109 loasc=160 lodes=156 dides=102))
((Antykwa\ Poltawskiego SemiCond\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=74 em=174 lvw=20 lhw=5 uvw=24 uhw=5 fillp=30 vcnt=32 lasprat=102 pasprat=99 loasc=160 lodes=156 dides=102))
((Antykwa\ Poltawskiego SemiCond\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=179 lvw=20 lhw=5 uvw=26 uhw=5 fillp=34 vcnt=32 lasprat=102 pasprat=93 loasc=165 lodes=158 dides=102))
((Antykwa\ Poltawskiego SemiExpd\ Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=28 lhw=8 uvw=37 uhw=8 fillp=41 vcnt=41 lasprat=119 pasprat=110 loasc=158 lodes=150 dides=102))
((Antykwa\ Poltawskiego SemiExpd\ Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=190 lvw=28 lhw=7 uvw=35 uhw=7 fillp=37 vcnt=41 lasprat=119 pasprat=115 loasc=154 lodes=149 dides=102))
((Antykwa\ Poltawskiego SemiExpd\ Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=197 lvw=22 lhw=6 uvw=25 uhw=6 fillp=31 vcnt=33 lasprat=115 pasprat=109 loasc=154 lodes=149 dides=102))
((Antykwa\ Poltawskiego SemiExpd\ Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=200 lvw=21 lhw=6 uvw=28 uhw=6 fillp=35 vcnt=33 lasprat=114 pasprat=102 loasc=158 lodes=150 dides=102))
((Antykwa\ Torunska Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=217 lvw=29 lhw=10 uvw=31 uhw=11 fillp=42 vcnt=41 lasprat=116 pasprat=105 loasc=150 lodes=143 dides=102))
((Antykwa\ Torunska Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=80 em=215 lvw=28 lhw=10 uvw=32 uhw=11 fillp=39 vcnt=41 lasprat=118 pasprat=113 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Condensed) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=184 lvw=18 lhw=7 uvw=20 uhw=8 fillp=35 vcnt=33 lasprat=99 pasprat=88 loasc=149 lodes=143 dides=102))
((Antykwa\ Torunska Condensed\ Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=202 lvw=29 lhw=10 uvw=32 uhw=11 fillp=44 vcnt=42 lasprat=111 pasprat=99 loasc=150 lodes=143 dides=102))
((Antykwa\ Torunska Condensed\ Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=80 em=193 lvw=27 lhw=10 uvw=32 uhw=11 fillp=41 vcnt=43 lasprat=111 pasprat=106 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Condensed\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=81 em=180 lvw=19 lhw=8 uvw=20 uhw=8 fillp=32 vcnt=33 lasprat=99 pasprat=94 loasc=144 lodes=141 dides=102))
((Antykwa\ Torunska Condensed\ Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=179 lvw=13 lhw=6 uvw=17 uhw=6 fillp=29 vcnt=27 lasprat=96 pasprat=86 loasc=149 lodes=143 dides=102))
((Antykwa\ Torunska Condensed\ Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=80 em=177 lvw=16 lhw=6 uvw=17 uhw=7 fillp=26 vcnt=27 lasprat=96 pasprat=92 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Condensed\ Medium) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=191 lvw=24 lhw=8 uvw=26 uhw=10 fillp=40 vcnt=38 lasprat=103 pasprat=92 loasc=150 lodes=143 dides=102))
((Antykwa\ Torunska Condensed\ Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=80 em=188 lvw=25 lhw=10 uvw=27 uhw=10 fillp=37 vcnt=38 lasprat=105 pasprat=100 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=81 em=200 lvw=20 lhw=8 uvw=20 uhw=8 fillp=30 vcnt=31 lasprat=108 pasprat=103 loasc=144 lodes=141 dides=102))
((Antykwa\ Torunska Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=198 lvw=13 lhw=6 uvw=17 uhw=6 fillp=27 vcnt=25 lasprat=105 pasprat=94 loasc=149 lodes=143 dides=102))
((Antykwa\ Torunska Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=80 em=196 lvw=16 lhw=6 uvw=17 uhw=6 fillp=25 vcnt=25 lasprat=105 pasprat=101 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Medium) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=24 lhw=8 uvw=26 uhw=10 fillp=37 vcnt=36 lasprat=112 pasprat=101 loasc=150 lodes=143 dides=102))
((Antykwa\ Torunska Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=80 em=208 lvw=25 lhw=10 uvw=27 uhw=10 fillp=34 vcnt=36 lasprat=114 pasprat=109 loasc=146 lodes=142 dides=102))
((Antykwa\ Torunska Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=205 lvw=18 lhw=7 uvw=20 uhw=8 fillp=32 vcnt=31 lasprat=108 pasprat=98 loasc=149 lodes=143 dides=102))
((Apex\ Lake Regular) (mono=no sans=no italic=no case=caps regular=yes ex=134 em=138 lvw=2 lhw=2 uvw=2 uhw=2 fillp=30 vcnt=51 lasprat=138 pasprat=132 loasc=100 lodes=124 dides=124))
((Apple\ Braille Outline\ 6\ Dot) ())
((Apple\ Braille Outline\ 8\ Dot) ())
((Apple\ Braille Pinpoint\ 6\ Dot) ())
((Apple\ Braille Pinpoint\ 8\ Dot) ())
((Apple\ Braille Regular) ())
((Apple\ Chancery Chancery) (Ascii Latin mono=no sans=no slant=12 italic=yes case=mixed regular=yes ex=78 em=211 lvw=16 lhw=15 uvw=20 uhw=11 fillp=25 vcnt=29 lasprat=97 pasprat=104 loasc=185 lodes=188 dides=141))
((Apple\ Color\ Emoji Regular) ())
((Apple\ Color\ Emoji\ UI Regular) ())
((Apple\ LiGothic Medium) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=66 em=169 lvw=24 lhw=21 uvw=27 uhw=25 fillp=51 vcnt=46 lasprat=100 pasprat=89 loasc=174 lodes=153 dides=106))
((Apple\ LiSung Light) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=195 lvw=15 lhw=5 uvw=19 uhw=5 fillp=28 vcnt=26 lasprat=101 pasprat=93 loasc=152 lodes=139 dides=102))
((Apple\ SD\ Gothic\ Neo Bold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=151 lvw=20 lhw=16 uvw=23 uhw=17 fillp=52 vcnt=45 lasprat=90 pasprat=75 loasc=139 lodes=119 dides=100))
((Apple\ SD\ Gothic\ Neo ExtraBold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=150 lvw=24 lhw=17 uvw=26 uhw=19 fillp=56 vcnt=51 lasprat=89 pasprat=76 loasc=138 lodes=121 dides=100))
((Apple\ SD\ Gothic\ Neo Heavy) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=156 lvw=31 lhw=20 uvw=35 uhw=24 fillp=65 vcnt=60 lasprat=95 pasprat=82 loasc=137 lodes=119 dides=100))
((Apple\ SD\ Gothic\ Neo Light) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=145 lvw=12 lhw=8 uvw=13 uhw=10 fillp=35 vcnt=27 lasprat=85 pasprat=68 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ Neo Medium) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=146 lvw=16 lhw=12 uvw=17 uhw=13 fillp=43 vcnt=36 lasprat=86 pasprat=71 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ Neo Regular) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=147 lvw=14 lhw=11 uvw=15 uhw=12 fillp=40 vcnt=32 lasprat=87 pasprat=70 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ Neo SemiBold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=147 lvw=18 lhw=13 uvw=20 uhw=15 fillp=47 vcnt=41 lasprat=87 pasprat=73 loasc=141 lodes=119 dides=100))
((Apple\ SD\ Gothic\ Neo Thin) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=144 lvw=4 lhw=3 uvw=5 uhw=4 fillp=19 vcnt=11 lasprat=84 pasprat=63 loasc=143 lodes=120 dides=100))
((Apple\ SD\ Gothic\ Neo UltraLight) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=144 lvw=10 lhw=7 uvw=10 uhw=8 fillp=31 vcnt=23 lasprat=84 pasprat=68 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ NeoI Bold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=151 lvw=20 lhw=16 uvw=23 uhw=17 fillp=52 vcnt=45 lasprat=90 pasprat=75 loasc=139 lodes=119 dides=100))
((Apple\ SD\ Gothic\ NeoI ExtraBold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=150 lvw=24 lhw=17 uvw=26 uhw=19 fillp=56 vcnt=51 lasprat=89 pasprat=76 loasc=138 lodes=121 dides=100))
((Apple\ SD\ Gothic\ NeoI Heavy) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=156 lvw=31 lhw=20 uvw=35 uhw=24 fillp=65 vcnt=60 lasprat=95 pasprat=82 loasc=137 lodes=119 dides=100))
((Apple\ SD\ Gothic\ NeoI Light) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=145 lvw=12 lhw=8 uvw=13 uhw=10 fillp=35 vcnt=27 lasprat=85 pasprat=68 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ NeoI Medium) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=146 lvw=16 lhw=12 uvw=17 uhw=13 fillp=43 vcnt=36 lasprat=86 pasprat=71 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ NeoI Regular) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=147 lvw=14 lhw=11 uvw=15 uhw=12 fillp=40 vcnt=32 lasprat=87 pasprat=70 loasc=142 lodes=120 dides=100))
((Apple\ SD\ Gothic\ NeoI SemiBold) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=147 lvw=18 lhw=13 uvw=20 uhw=15 fillp=47 vcnt=41 lasprat=87 pasprat=73 loasc=141 lodes=119 dides=100))
((Apple\ SD\ Gothic\ NeoI Thin) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=144 lvw=4 lhw=3 uvw=5 uhw=4 fillp=19 vcnt=11 lasprat=84 pasprat=63 loasc=143 lodes=120 dides=100))
((Apple\ SD\ Gothic\ NeoI UltraLight) (Ascii Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=144 lvw=10 lhw=7 uvw=10 uhw=8 fillp=31 vcnt=23 lasprat=84 pasprat=68 loasc=142 lodes=120 dides=100))
((Apple\ Symbols Regular) (Ascii Greek MathSymbols MathExtra mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=65 em=143 lvw=16 lhw=13 uvw=18 uhw=13 fillp=42 vcnt=33 lasprat=97 pasprat=80 loasc=143 lodes=141 dides=104))
((AppleGothic Regular) (Ascii CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=170 lvw=14 lhw=12 uvw=15 uhw=13 fillp=36 vcnt=39 lasprat=94 pasprat=82 loasc=149 lodes=138 dides=103))
((Aqua\ Kana Bold) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=175 lvw=23 lhw=19 uvw=24 uhw=21 fillp=49 vcnt=59 lasprat=108 pasprat=95 loasc=141 lodes=137 dides=105))
((Aqua\ Kana Regular) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=173 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=39 lasprat=101 pasprat=85 loasc=141 lodes=139 dides=102))
((AR\ PL\ KaitiM\ Big5 Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=16 lhw=4 uvw=14 uhw=4 fillp=31 vcnt=25 lasprat=103 pasprat=84 loasc=141 lodes=112 dides=100))
((AR\ PL\ KaitiM\ GB Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=102 lvw=16 lhw=4 uvw=14 uhw=4 fillp=32 vcnt=25 lasprat=102 pasprat=84 loasc=143 lodes=112 dides=100))
((AR\ PL\ Mingti2L\ Big5 Reguler) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=11 lhw=4 uvw=11 uhw=4 fillp=24 vcnt=19 lasprat=103 pasprat=85 loasc=141 lodes=112 dides=100))
((AR\ PL\ New\ Sung Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=106 lvw=15 lhw=7 uvw=15 uhw=7 fillp=29 vcnt=31 lasprat=102 pasprat=93 loasc=164 lodes=124 dides=100))
((AR\ PL\ SungtiL\ GB Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=102 lvw=11 lhw=4 uvw=11 uhw=4 fillp=24 vcnt=19 lasprat=102 pasprat=85 loasc=143 lodes=112 dides=100))
((AR\ PL\ UMing\ CN Light) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=9 lhw=4 uvw=9 uhw=4 fillp=24 vcnt=22 lasprat=103 pasprat=85 loasc=143 lodes=111 dides=100))
((AR\ PL\ UMing\ HK Light) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=9 lhw=4 uvw=9 uhw=4 fillp=24 vcnt=22 lasprat=103 pasprat=85 loasc=143 lodes=111 dides=100))
((AR\ PL\ UMing\ TW Light) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=9 lhw=4 uvw=9 uhw=4 fillp=24 vcnt=22 lasprat=103 pasprat=85 loasc=143 lodes=111 dides=100))
((AR\ PL\ UMing\ TW\ MBE Light) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=9 lhw=4 uvw=9 uhw=4 fillp=24 vcnt=22 lasprat=103 pasprat=85 loasc=143 lodes=111 dides=100))
((AR\ PL\ ZenKai\ Uni Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=151 lvw=17 lhw=7 uvw=17 uhw=7 fillp=31 vcnt=30 lasprat=128 pasprat=100 loasc=152 lodes=132 dides=100))
((Arabic\ UI\ Display Black) ())
((Arabic\ UI\ Display Bold) ())
((Arabic\ UI\ Display Heavy) ())
((Arabic\ UI\ Display Light) ())
((Arabic\ UI\ Display Medium) ())
((Arabic\ UI\ Display Regular) ())
((Arabic\ UI\ Display Semibold) ())
((Arabic\ UI\ Display Thin) ())
((Arabic\ UI\ Display Ultralight) ())
((Arabic\ UI\ Text Bold) ())
((Arabic\ UI\ Text Heavy) ())
((Arabic\ UI\ Text Light) ())
((Arabic\ UI\ Text Medium) ())
((Arabic\ UI\ Text Regular) ())
((Arabic\ UI\ Text Semibold) ())
((Architext Regular) (Ascii mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=79 em=235 lvw=8 lhw=8 uvw=8 uhw=8 fillp=20 vcnt=18 lasprat=153 pasprat=135 loasc=100 lodes=117 dides=101))
((Arial Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=181 lvw=37 lhw=25 uvw=42 uhw=32 fillp=66 vcnt=74 lasprat=117 pasprat=104 loasc=140 lodes=140 dides=102))
((Arial Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=162 lvw=26 lhw=20 uvw=27 uhw=24 fillp=56 vcnt=61 lasprat=103 pasprat=88 loasc=140 lodes=140 dides=102))
((Arial Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=87 em=158 lvw=26 lhw=20 uvw=27 uhw=24 fillp=48 vcnt=54 lasprat=103 pasprat=102 loasc=140 lodes=140 dides=102))
((Arial Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=12 uvw=18 uhw=14 fillp=34 vcnt=39 lasprat=94 pasprat=91 loasc=140 lodes=139 dides=102))
((Arial Narrow) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=131 lvw=13 lhw=13 uvw=14 uhw=16 fillp=43 vcnt=45 lasprat=77 pasprat=65 loasc=140 lodes=140 dides=102))
((Arial Narrow\ Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=131 lvw=21 lhw=21 uvw=24 uhw=24 fillp=57 vcnt=62 lasprat=84 pasprat=72 loasc=140 lodes=140 dides=102))
((Arial Narrow\ Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=87 em=131 lvw=21 lhw=20 uvw=22 uhw=24 fillp=47 vcnt=54 lasprat=84 pasprat=83 loasc=140 lodes=140 dides=102))
((Arial Narrow\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=87 em=131 lvw=13 lhw=12 uvw=14 uhw=14 fillp=35 vcnt=40 lasprat=77 pasprat=75 loasc=140 lodes=139 dides=102))
((Arial Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=157 lvw=17 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=46 lasprat=93 pasprat=79 loasc=140 lodes=140 dides=102))
((Arial\ Hebrew Bold) (slant=0))
((Arial\ Hebrew Light) (slant=0))
((Arial\ Hebrew Regular) (slant=0))
((Arial\ Hebrew\ Desk\ Interface Bold) (slant=0))
((Arial\ Hebrew\ Desk\ Interface Light) (slant=0))
((Arial\ Hebrew\ Desk\ Interface Regular) (slant=0))
((Arial\ Hebrew\ Scholar Bold) (slant=0))
((Arial\ Hebrew\ Scholar Light) (slant=0))
((Arial\ Hebrew\ Scholar Regular) (slant=0))
((Arial\ Rounded\ MT Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=25 lhw=19 uvw=27 uhw=21 fillp=53 vcnt=59 lasprat=103 pasprat=88 loasc=138 lodes=139 dides=102))
((Arial\ Unicode\ MS Regular) (Ascii Latin Greek Cyrillic CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=45 lasprat=94 pasprat=80 loasc=140 lodes=140 dides=102))
((Arimo Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=27 lhw=18 uvw=26 uhw=21 fillp=55 vcnt=50 lasprat=102 pasprat=85 loasc=137 lodes=140 dides=102))
((Arimo Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=19 italic=no case=mixed regular=yes ex=88 em=157 lvw=27 lhw=18 uvw=27 uhw=21 fillp=46 vcnt=49 lasprat=102 pasprat=98 loasc=137 lodes=139 dides=102))
((Arimo Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=19 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=12 uvw=17 uhw=14 fillp=34 vcnt=35 lasprat=92 pasprat=89 loasc=137 lodes=139 dides=102))
((Arimo Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=12 uvw=18 uhw=14 fillp=42 vcnt=36 lasprat=93 pasprat=78 loasc=137 lodes=139 dides=102))
((Asana\ Math Regular) (Ascii Latin Greek MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=20 lhw=7 uvw=23 uhw=8 fillp=32 vcnt=34 lasprat=109 pasprat=101 loasc=157 lodes=160 dides=103))
((Asap Symbol) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=160 lvw=21 lhw=17 uvw=22 uhw=19 fillp=50 vcnt=46 lasprat=94 pasprat=77 loasc=144 lodes=139 dides=101))
((Astroneo ASTRONEO) (Latin mono=no sans=no italic=no case=caps regular=yes ex=105 em=180 lvw=44 lhw=27 uvw=44 uhw=6 fillp=61 vcnt=64 lasprat=177 pasprat=158 loasc=100 lodes=100 dides=100))
((Athelas Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=211 lvw=29 lhw=9 uvw=31 uhw=11 fillp=41 vcnt=38 lasprat=115 pasprat=106 loasc=162 lodes=156 dides=143))
((Athelas Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=74 em=197 lvw=25 lhw=13 uvw=29 uhw=9 fillp=38 vcnt=39 lasprat=100 pasprat=98 loasc=160 lodes=156 dides=144))
((Athelas Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=74 em=194 lvw=18 lhw=9 uvw=22 uhw=9 fillp=31 vcnt=31 lasprat=98 pasprat=92 loasc=160 lodes=156 dides=143))
((Athelas Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=211 lvw=22 lhw=8 uvw=23 uhw=11 fillp=34 vcnt=31 lasprat=112 pasprat=102 loasc=164 lodes=157 dides=143))
((Aurulent\ Sans Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=173 lvw=29 lhw=18 uvw=30 uhw=19 fillp=53 vcnt=59 lasprat=105 pasprat=87 loasc=150 lodes=139 dides=104))
((Aurulent\ Sans BoldItalic) (Ascii mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=173 lvw=28 lhw=18 uvw=30 uhw=19 fillp=44 vcnt=52 lasprat=105 pasprat=102 loasc=150 lodes=139 dides=104))
((Aurulent\ Sans Italic) (Ascii mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=157 lvw=19 lhw=13 uvw=19 uhw=14 fillp=35 vcnt=40 lasprat=92 pasprat=90 loasc=148 lodes=138 dides=103))
((Aurulent\ Sans Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=19 lhw=13 uvw=20 uhw=14 fillp=43 vcnt=47 lasprat=93 pasprat=76 loasc=148 lodes=138 dides=103))
((Aurulent\ Sans\ Mono Regular) (Ascii mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=19 lhw=13 uvw=20 uhw=14 fillp=40 vcnt=46 lasprat=113 pasprat=87 loasc=148 lodes=138 dides=103))
((Avenir Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=195 lvw=30 lhw=27 uvw=33 uhw=29 fillp=59 vcnt=56 lasprat=110 pasprat=97 loasc=158 lodes=149 dides=102))
((Avenir Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=193 lvw=25 lhw=22 uvw=27 uhw=22 fillp=51 vcnt=47 lasprat=110 pasprat=94 loasc=161 lodes=150 dides=102))
((Avenir Heavy\ Oblique) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=80 em=193 lvw=26 lhw=22 uvw=28 uhw=22 fillp=45 vcnt=47 lasprat=110 pasprat=104 loasc=161 lodes=150 dides=102))
((Avenir Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=192 lvw=12 lhw=11 uvw=14 uhw=12 fillp=33 vcnt=27 lasprat=107 pasprat=86 loasc=166 lodes=151 dides=102))
((Avenir Light\ Oblique) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=77 em=192 lvw=12 lhw=11 uvw=14 uhw=12 fillp=27 vcnt=27 lasprat=107 pasprat=97 loasc=166 lodes=151 dides=102))
((Avenir Oblique) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=79 em=191 lvw=21 lhw=17 uvw=21 uhw=18 fillp=38 vcnt=38 lasprat=107 pasprat=100 loasc=162 lodes=159 dides=102))
((Avenir Oblique\ Black) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=81 em=195 lvw=30 lhw=27 uvw=34 uhw=29 fillp=52 vcnt=56 lasprat=110 pasprat=107 loasc=158 lodes=149 dides=102))
((Avenir Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=191 lvw=20 lhw=17 uvw=21 uhw=18 fillp=44 vcnt=38 lasprat=107 pasprat=89 loasc=162 lodes=159 dides=102))
((Avenir Roman) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=193 lvw=17 lhw=15 uvw=19 uhw=16 fillp=40 vcnt=34 lasprat=107 pasprat=89 loasc=164 lodes=151 dides=102))
((Avenir\ Book Oblique) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=78 em=191 lvw=15 lhw=12 uvw=16 uhw=14 fillp=30 vcnt=30 lasprat=106 pasprat=98 loasc=164 lodes=161 dides=102))
((Avenir\ Book Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=191 lvw=15 lhw=12 uvw=16 uhw=14 fillp=36 vcnt=30 lasprat=106 pasprat=87 loasc=164 lodes=161 dides=102))
((Avenir\ Next Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=32 lhw=28 uvw=36 uhw=30 fillp=61 vcnt=59 lasprat=111 pasprat=97 loasc=153 lodes=147 dides=103))
((Avenir\ Next Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=84 em=189 lvw=32 lhw=26 uvw=34 uhw=29 fillp=52 vcnt=58 lasprat=110 pasprat=108 loasc=154 lodes=147 dides=103))
((Avenir\ Next Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=145 lvw=17 lhw=15 uvw=17 uhw=15 fillp=48 vcnt=42 lasprat=81 pasprat=65 loasc=154 lodes=147 dides=102))
((Avenir\ Next Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=146 lvw=29 lhw=27 uvw=30 uhw=29 fillp=66 vcnt=64 lasprat=88 pasprat=76 loasc=148 lodes=146 dides=103))
((Avenir\ Next Condensed\ Bold\ Italic) (Ascii Latin mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=87 em=147 lvw=26 lhw=25 uvw=31 uhw=27 fillp=54 vcnt=62 lasprat=86 pasprat=87 loasc=149 lodes=145 dides=102))
((Avenir\ Next Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=83 em=142 lvw=13 lhw=12 uvw=13 uhw=12 fillp=31 vcnt=33 lasprat=78 pasprat=74 loasc=155 lodes=148 dides=102))
((Avenir\ Next DemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=191 lvw=25 lhw=21 uvw=28 uhw=23 fillp=51 vcnt=47 lasprat=109 pasprat=93 loasc=160 lodes=150 dides=103))
((Avenir\ Next DemiBold\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=144 lvw=22 lhw=19 uvw=24 uhw=22 fillp=56 vcnt=52 lasprat=83 pasprat=69 loasc=151 lodes=146 dides=102))
((Avenir\ Next DemiBold\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=85 em=145 lvw=21 lhw=18 uvw=22 uhw=21 fillp=45 vcnt=50 lasprat=83 pasprat=81 loasc=152 lodes=147 dides=102))
((Avenir\ Next DemiBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=80 em=192 lvw=23 lhw=20 uvw=26 uhw=22 fillp=43 vcnt=46 lasprat=109 pasprat=105 loasc=160 lodes=150 dides=103))
((Avenir\ Next Heavy) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=192 lvw=40 lhw=37 uvw=47 uhw=42 fillp=72 vcnt=74 lasprat=115 pasprat=105 loasc=151 lodes=145 dides=103))
((Avenir\ Next Heavy\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=150 lvw=35 lhw=33 uvw=40 uhw=40 fillp=75 vcnt=78 lasprat=92 pasprat=83 loasc=147 lodes=144 dides=103))
((Avenir\ Next Heavy\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=90 em=148 lvw=34 lhw=34 uvw=38 uhw=38 fillp=63 vcnt=76 lasprat=91 pasprat=94 loasc=146 lodes=144 dides=103))
((Avenir\ Next Heavy\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=88 em=190 lvw=40 lhw=35 uvw=45 uhw=39 fillp=63 vcnt=73 lasprat=113 pasprat=116 loasc=151 lodes=146 dides=103))
((Avenir\ Next Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=79 em=187 lvw=15 lhw=11 uvw=15 uhw=12 fillp=28 vcnt=28 lasprat=107 pasprat=97 loasc=160 lodes=150 dides=103))
((Avenir\ Next Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=187 lvw=20 lhw=16 uvw=22 uhw=18 fillp=44 vcnt=38 lasprat=108 pasprat=89 loasc=160 lodes=150 dides=103))
((Avenir\ Next Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=196 lvw=3 lhw=3 uvw=3 uhw=3 fillp=14 vcnt=9 lasprat=106 pasprat=78 loasc=166 lodes=154 dides=102))
((Avenir\ Next Thin\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=139 lvw=3 lhw=3 uvw=3 uhw=3 fillp=17 vcnt=11 lasprat=73 pasprat=52 loasc=158 lodes=149 dides=102))
((Avenir\ Next Thin\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=81 em=139 lvw=3 lhw=3 uvw=3 uhw=3 fillp=12 vcnt=12 lasprat=73 pasprat=65 loasc=158 lodes=149 dides=102))
((Avenir\ Next Thin\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=77 em=194 lvw=3 lhw=3 uvw=3 uhw=3 fillp=10 vcnt=9 lasprat=105 pasprat=90 loasc=166 lodes=154 dides=102))
((Avocado Regular) (mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=73 em=154 lvw=21 lhw=54 uvw=20 uhw=89 fillp=31 vcnt=34 lasprat=84 pasprat=90 loasc=168 lodes=176 dides=106))
((Ayuthaya Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=109 lvw=17 lhw=14 uvw=17 uhw=14 fillp=40 vcnt=48 lasprat=109 pasprat=87 loasc=147 lodes=141 dides=104))
((Baekmuk\ Batang Regular) (Ascii CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=204 lvw=15 lhw=4 uvw=15 uhw=8 fillp=23 vcnt=21 lasprat=108 pasprat=96 loasc=153 lodes=143 dides=104))
((Baekmuk\ Dotum Regular) (Ascii CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=143 lvw=12 lhw=10 uvw=13 uhw=9 fillp=33 vcnt=29 lasprat=88 pasprat=78 loasc=145 lodes=139 dides=103))
((Baekmuk\ Gulim Regular) (Ascii CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=167 lvw=13 lhw=11 uvw=13 uhw=11 fillp=31 vcnt=32 lasprat=110 pasprat=83 loasc=133 lodes=141 dides=119))
((Baekmuk\ Headline Regular) (Ascii CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=133 lvw=29 lhw=22 uvw=27 uhw=21 fillp=56 vcnt=53 lasprat=104 pasprat=94 loasc=150 lodes=134 dides=101))
((Baghdad Regular) (slant=0))
((Baghdad\ PUA Regular) (slant=0))
((Bahnschrift Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=152 lvw=18 lhw=18 uvw=20 uhw=18 fillp=48 vcnt=41 lasprat=98 pasprat=76 loasc=140 lodes=142 dides=102))
((Balham Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=216 lvw=19 lhw=5 uvw=24 uhw=6 fillp=31 vcnt=31 lasprat=109 pasprat=83 loasc=187 lodes=147 dides=119))
((Bangla\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=101 em=183 lvw=31 lhw=11 uvw=35 uhw=10 fillp=51 vcnt=55 lasprat=106 pasprat=94 loasc=147 lodes=140 dides=102))
((Bangla\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=178 lvw=22 lhw=7 uvw=25 uhw=6 fillp=39 vcnt=40 lasprat=100 pasprat=89 loasc=151 lodes=146 dides=103))
((Bangla\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=150 lvw=19 lhw=17 uvw=19 uhw=17 fillp=47 vcnt=46 lasprat=95 pasprat=79 loasc=142 lodes=142 dides=102))
((Bangla\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=148 lvw=14 lhw=12 uvw=14 uhw=12 fillp=39 vcnt=37 lasprat=94 pasprat=77 loasc=144 lodes=144 dides=102))
((Bank\ Gothic Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=71 em=212 lvw=18 lhw=15 uvw=21 uhw=16 fillp=43 vcnt=24 lasprat=144 pasprat=111 loasc=100 lodes=129 dides=102))
((Bank\ Gothic Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=71 em=216 lvw=23 lhw=19 uvw=28 uhw=22 fillp=51 vcnt=31 lasprat=150 pasprat=118 loasc=100 lodes=125 dides=102))
((Baoli\ SC Regular) (Ascii CJK mono=no sans=yes slant=29 italic=no case=mixed regular=no ex=60 em=231 lvw=33 lhw=20 uvw=36 uhw=15 fillp=39 vcnt=26 lasprat=140 pasprat=117 loasc=151 lodes=133 dides=103))
((Baskervaldx Bol) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=236 lvw=33 lhw=11 uvw=40 uhw=11 fillp=46 vcnt=44 lasprat=121 pasprat=113 loasc=161 lodes=161 dides=104))
((Baskervaldx Bold\ Italic) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=75 em=206 lvw=28 lhw=10 uvw=36 uhw=9 fillp=39 vcnt=42 lasprat=105 pasprat=104 loasc=161 lodes=156 dides=101))
((Baskervaldx Ita) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=76 em=181 lvw=18 lhw=7 uvw=25 uhw=7 fillp=32 vcnt=34 lasprat=93 pasprat=90 loasc=157 lodes=155 dides=101))
((Baskervaldx Reg) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=209 lvw=22 lhw=6 uvw=27 uhw=8 fillp=34 vcnt=33 lasprat=110 pasprat=100 loasc=161 lodes=161 dides=102))
((Baskerville Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=246 lvw=41 lhw=13 uvw=50 uhw=16 fillp=50 vcnt=51 lasprat=134 pasprat=127 loasc=168 lodes=162 dides=110))
((Baskerville Bold\ Italic) (Ascii Latin mono=no sans=no slant=33 italic=yes case=mixed regular=yes ex=69 em=234 lvw=36 lhw=11 uvw=42 uhw=13 fillp=42 vcnt=43 lasprat=129 pasprat=131 loasc=165 lodes=160 dides=107))
((Baskerville Italic) (Ascii Latin mono=no sans=no slant=33 italic=yes case=mixed regular=yes ex=69 em=211 lvw=14 lhw=4 uvw=21 uhw=5 fillp=24 vcnt=24 lasprat=90 pasprat=95 loasc=162 lodes=157 dides=108))
((Baskerville Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=231 lvw=20 lhw=4 uvw=28 uhw=5 fillp=29 vcnt=29 lasprat=112 pasprat=104 loasc=167 lodes=161 dides=111))
((Baskerville SemiBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=241 lvw=32 lhw=11 uvw=38 uhw=14 fillp=43 vcnt=43 lasprat=132 pasprat=123 loasc=168 lodes=161 dides=108))
((Baskerville SemiBold\ Italic) (Ascii Latin mono=no sans=no slant=32 italic=yes case=mixed regular=yes ex=69 em=228 lvw=28 lhw=10 uvw=33 uhw=10 fillp=37 vcnt=37 lasprat=124 pasprat=127 loasc=163 lodes=159 dides=107))
((BaskervilleF Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=233 lvw=29 lhw=7 uvw=36 uhw=7 fillp=37 vcnt=37 lasprat=115 pasprat=109 loasc=174 lodes=149 dides=102))
((BaskervilleF Bold\ Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=73 em=241 lvw=28 lhw=6 uvw=35 uhw=6 fillp=33 vcnt=36 lasprat=111 pasprat=113 loasc=169 lodes=149 dides=102))
((BaskervilleF Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=73 em=209 lvw=17 lhw=5 uvw=24 uhw=5 fillp=27 vcnt=29 lasprat=95 pasprat=96 loasc=169 lodes=149 dides=102))
((BaskervilleF Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=221 lvw=22 lhw=4 uvw=26 uhw=4 fillp=29 vcnt=28 lasprat=111 pasprat=103 loasc=173 lodes=150 dides=104))
((Basra Bold) ())
((Basra Regular) ())
((Basra\ PUA Bold) ())
((Basra\ PUA Regular) ())
((Batang Regular) (Ascii Latin Greek CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=186 lvw=13 lhw=5 uvw=13 uhw=5 fillp=24 vcnt=26 lasprat=111 pasprat=94 loasc=153 lodes=130 dides=103))
((BB\ Petie\ Boy Destroyed) (sans=no))
((BB\ Petie\ Boy Heavy) (mono=no sans=no slant=0 italic=no case=caps regular=yes ex=112 em=108 lvw=0 lhw=2 uvw=0 uhw=2 fillp=27 vcnt=29 lasprat=87 pasprat=80 loasc=103 lodes=108 dides=100))
((BB\ Petie\ Boy Light) (mono=no sans=no slant=0 italic=no case=caps regular=yes ex=115 em=112 lvw=2 lhw=0 uvw=2 uhw=0 fillp=13 vcnt=14 lasprat=89 pasprat=80 loasc=100 lodes=112 dides=100))
((BB\ Petie\ Boy Medium) (mono=no sans=no slant=0 italic=no case=caps regular=yes ex=111 em=109 lvw=1 lhw=0 uvw=1 uhw=0 fillp=20 vcnt=21 lasprat=88 pasprat=80 loasc=103 lodes=109 dides=100))
((Beirut Regular) (slant=0))
((Beirut\ PUA Regular) (slant=0))
((Berenis\ ADF\ Pro Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=208 lvw=35 lhw=4 uvw=41 uhw=5 fillp=42 vcnt=42 lasprat=129 pasprat=120 loasc=182 lodes=149 dides=102))
((Berenis\ ADF\ Pro Bold\ Italic) (Ascii Latin mono=no sans=no slant=30 italic=yes case=mixed regular=yes ex=69 em=202 lvw=30 lhw=4 uvw=37 uhw=5 fillp=37 vcnt=43 lasprat=117 pasprat=116 loasc=176 lodes=147 dides=102))
((Berenis\ ADF\ Pro Italic) (Ascii Latin mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=67 em=195 lvw=19 lhw=2 uvw=26 uhw=4 fillp=27 vcnt=32 lasprat=105 pasprat=105 loasc=182 lodes=149 dides=104))
((Berenis\ ADF\ Pro Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=195 lvw=23 lhw=2 uvw=29 uhw=4 fillp=32 vcnt=33 lasprat=112 pasprat=105 loasc=182 lodes=149 dides=104))
((Berenis\ ADF\ Pro\ SC Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=68 em=205 lvw=30 lhw=4 uvw=41 uhw=5 fillp=43 vcnt=40 lasprat=116 pasprat=103 loasc=101 lodes=127 dides=102))
((Berenis\ ADF\ Pro\ SC Bold\ Italic) (Ascii Latin mono=no sans=no slant=29 italic=no case=smallcaps regular=yes ex=67 em=208 lvw=31 lhw=4 uvw=38 uhw=5 fillp=36 vcnt=39 lasprat=117 pasprat=121 loasc=102 lodes=128 dides=102))
((Berenis\ ADF\ Pro\ SC Italic) (Ascii Latin mono=no sans=no slant=31 italic=no case=smallcaps regular=yes ex=67 em=195 lvw=20 lhw=4 uvw=26 uhw=4 fillp=29 vcnt=31 lasprat=102 pasprat=114 loasc=101 lodes=128 dides=104))
((Berenis\ ADF\ Pro\ SC Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=67 em=195 lvw=23 lhw=4 uvw=29 uhw=4 fillp=35 vcnt=32 lasprat=102 pasprat=97 loasc=101 lodes=128 dides=104))
((Beroga Regular) (Latin mono=no sans=yes slant=20 italic=no case=caps regular=yes ex=112 em=163 lvw=30 lhw=16 uvw=30 uhw=16 fillp=49 vcnt=64 lasprat=117 pasprat=114 loasc=136 lodes=137 dides=138))
((Beuron Condensed) (mono=no sans=yes italic=no case=caps regular=yes ex=111 em=134 lvw=10 lhw=10 uvw=10 uhw=10 fillp=35 vcnt=26 lasprat=108 pasprat=76 loasc=102 lodes=102))
((Beuron Extended) (mono=no sans=yes italic=no case=caps regular=yes ex=111 em=167 lvw=10 lhw=10 uvw=10 uhw=10 fillp=31 vcnt=23 lasprat=135 pasprat=96 loasc=102 lodes=102))
((Beuron Regular) (mono=no sans=yes italic=no case=caps regular=yes ex=111 em=150 lvw=11 lhw=10 uvw=11 uhw=10 fillp=33 vcnt=24 lasprat=121 pasprat=86 loasc=102 lodes=102))
((BiauKai Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=195 lvw=19 lhw=5 uvw=23 uhw=7 fillp=30 vcnt=30 lasprat=109 pasprat=103 loasc=156 lodes=139 dides=102))
((Big\ Caslon Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=210 lvw=18 lhw=3 uvw=26 uhw=3 fillp=29 vcnt=32 lasprat=96 pasprat=96 loasc=153 lodes=153 dides=154))
((Bimbo\ JVE Regular) (mono=no sans=yes italic=no case=mixed regular=no ex=86 em=129 lvw=18 lhw=19 uvw=20 uhw=19 fillp=55 vcnt=58 lasprat=75 pasprat=59 loasc=141 lodes=143 dides=102))
((Bitstream\ Vera\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=182 lvw=32 lhw=23 uvw=35 uhw=24 fillp=60 vcnt=69 lasprat=116 pasprat=98 loasc=139 lodes=139 dides=102))
((Bitstream\ Vera\ Sans Bold\ Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=182 lvw=32 lhw=23 uvw=36 uhw=24 fillp=51 vcnt=60 lasprat=116 pasprat=111 loasc=139 lodes=139 dides=102))
((Bitstream\ Vera\ Sans Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=14 uvw=19 uhw=14 fillp=34 vcnt=39 lasprat=103 pasprat=95 loasc=139 lodes=138 dides=102))
((Bitstream\ Vera\ Sans Roman) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=14 uvw=18 uhw=14 fillp=43 vcnt=47 lasprat=103 pasprat=81 loasc=139 lodes=138 dides=102))
((Bitstream\ Vera\ Sans\ Mono Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=24 fillp=56 vcnt=65 lasprat=110 pasprat=88 loasc=149 lodes=138 dides=102))
((Bitstream\ Vera\ Sans\ Mono Bold\ Oblique) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=23 fillp=48 vcnt=56 lasprat=110 pasprat=99 loasc=149 lodes=138 dides=102))
((Bitstream\ Vera\ Sans\ Mono Oblique) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=35 vcnt=41 lasprat=110 pasprat=93 loasc=139 lodes=138 dides=102))
((Bitstream\ Vera\ Sans\ Mono Roman) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=41 vcnt=47 lasprat=110 pasprat=82 loasc=139 lodes=138 dides=102))
((Bitstream\ Vera\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=212 lvw=36 lhw=10 uvw=40 uhw=11 fillp=48 vcnt=56 lasprat=120 pasprat=112 loasc=145 lodes=142 dides=102))
((Bitstream\ Vera\ Serif Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=196 lvw=20 lhw=9 uvw=21 uhw=10 fillp=35 vcnt=40 lasprat=109 pasprat=98 loasc=145 lodes=142 dides=102))
((Bitter Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=162 lvw=28 lhw=22 uvw=31 uhw=23 fillp=55 vcnt=58 lasprat=107 pasprat=99 loasc=147 lodes=147 dides=103))
((Bitter Italic) (Ascii Latin mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=89 em=165 lvw=17 lhw=15 uvw=20 uhw=16 fillp=38 vcnt=41 lasprat=100 pasprat=92 loasc=146 lodes=146 dides=102))
((Bitter Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=164 lvw=19 lhw=15 uvw=21 uhw=16 fillp=42 vcnt=42 lasprat=104 pasprat=92 loasc=147 lodes=147 dides=102))
((BlackChancery Regular) (Ascii mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=72 em=225 lvw=20 lhw=12 uvw=30 uhw=9 fillp=31 vcnt=34 lasprat=96 pasprat=98 loasc=154 lodes=176 dides=161))
((Blackmoor\ LET Plain) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=162 lvw=52 lhw=24 uvw=34 uhw=10 fillp=51 vcnt=55 lasprat=72 pasprat=69 loasc=141 lodes=133 dides=106))
((BlairMdITC\ TT Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=103 em=200 lvw=20 lhw=17 uvw=20 uhw=17 fillp=43 vcnt=39 lasprat=137 pasprat=116 loasc=102 lodes=113 dides=101))
((BloomingGrove Medium) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=69 em=165 lvw=10 lhw=10 uvw=10 uhw=10 fillp=22 vcnt=24 lasprat=118 pasprat=99 loasc=192 lodes=192 dides=100))
((BloomingGroveAltBold Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=70 em=165 lvw=21 lhw=21 uvw=21 uhw=20 fillp=42 vcnt=47 lasprat=119 pasprat=100 loasc=191 lodes=190 dides=101))
((BloomingGroveAlternate Alternate) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=69 em=166 lvw=10 lhw=10 uvw=10 uhw=10 fillp=22 vcnt=24 lasprat=118 pasprat=99 loasc=192 lodes=192 dides=100))
((BloomingGroveBold Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=70 em=165 lvw=21 lhw=21 uvw=21 uhw=20 fillp=42 vcnt=47 lasprat=119 pasprat=100 loasc=191 lodes=191 dides=101))
((Bodoni\ 72 Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=181 lvw=34 lhw=4 uvw=40 uhw=4 fillp=39 vcnt=42 lasprat=105 pasprat=107 loasc=163 lodes=159 dides=105))
((Bodoni\ 72 Book) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=172 lvw=21 lhw=4 uvw=26 uhw=4 fillp=30 vcnt=31 lasprat=95 pasprat=94 loasc=160 lodes=158 dides=104))
((Bodoni\ 72 Book\ Italic) (Ascii Latin mono=no sans=no slant=37 italic=yes case=mixed regular=yes ex=72 em=179 lvw=19 lhw=4 uvw=23 uhw=4 fillp=24 vcnt=29 lasprat=98 pasprat=114 loasc=165 lodes=161 dides=102))
((Bodoni\ 72\ Oldstyle Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=181 lvw=34 lhw=4 uvw=40 uhw=4 fillp=39 vcnt=42 lasprat=105 pasprat=107 loasc=163 lodes=159 dides=152))
((Bodoni\ 72\ Oldstyle Book) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=172 lvw=21 lhw=4 uvw=26 uhw=4 fillp=30 vcnt=31 lasprat=95 pasprat=94 loasc=160 lodes=158 dides=152))
((Bodoni\ 72\ Oldstyle Book\ Italic) (Ascii mono=no sans=no slant=37 italic=yes case=mixed regular=yes ex=72 em=179 lvw=19 lhw=2 uvw=23 uhw=2 fillp=23 vcnt=29 lasprat=98 pasprat=114 loasc=165 lodes=161 dides=150))
((Bodoni\ 72\ Smallcaps Book) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=76 em=165 lvw=21 lhw=3 uvw=25 uhw=3 fillp=31 vcnt=29 lasprat=97 pasprat=92 loasc=102 lodes=130 dides=150))
((Bodoni\ Ornaments Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=129 em=47 lvw=5 lhw=11 uvw=6 uhw=3 fillp=29 vcnt=41 lasprat=137 pasprat=125 loasc=104 lodes=124 dides=124))
((Bodoni\ Ornaments\ ITC\ TT Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=129 em=47 lvw=6 lhw=10 uvw=5 uhw=3 fillp=29 vcnt=40 lasprat=137 pasprat=125 loasc=104 lodes=124 dides=124))
((Bodoni\ SvtyTwo\ ITC\ TT Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=181 lvw=34 lhw=4 uvw=41 uhw=4 fillp=39 vcnt=42 lasprat=105 pasprat=107 loasc=163 lodes=159 dides=105))
((Bodoni\ SvtyTwo\ ITC\ TT Book) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=172 lvw=20 lhw=4 uvw=26 uhw=4 fillp=30 vcnt=31 lasprat=95 pasprat=94 loasc=160 lodes=158 dides=104))
((Bodoni\ SvtyTwo\ ITC\ TT BookIta) (Ascii Latin mono=no sans=no slant=36 italic=yes case=mixed regular=yes ex=72 em=179 lvw=19 lhw=4 uvw=23 uhw=4 fillp=24 vcnt=29 lasprat=98 pasprat=114 loasc=165 lodes=161 dides=104))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=181 lvw=34 lhw=4 uvw=41 uhw=4 fillp=39 vcnt=42 lasprat=105 pasprat=107 loasc=163 lodes=159 dides=152))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT Book) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=172 lvw=20 lhw=4 uvw=26 uhw=4 fillp=30 vcnt=31 lasprat=95 pasprat=94 loasc=160 lodes=158 dides=152))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT BookIt) (Ascii mono=no sans=no slant=36 italic=yes case=mixed regular=yes ex=72 em=179 lvw=19 lhw=2 uvw=23 uhw=2 fillp=23 vcnt=29 lasprat=98 pasprat=114 loasc=165 lodes=161 dides=150))
((Bodoni\ SvtyTwo\ SC\ ITC\ TT Book) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=76 em=165 lvw=21 lhw=3 uvw=25 uhw=3 fillp=31 vcnt=29 lasprat=97 pasprat=92 loasc=102 lodes=130 dides=150))
((Book\ Antiqua Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=27 lhw=10 uvw=31 uhw=11 fillp=42 vcnt=42 lasprat=112 pasprat=102 loasc=153 lodes=155 dides=103))
((Book\ Antiqua Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=79 em=200 lvw=24 lhw=12 uvw=30 uhw=8 fillp=36 vcnt=38 lasprat=107 pasprat=102 loasc=154 lodes=158 dides=102))
((Book\ Antiqua Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=79 em=200 lvw=16 lhw=8 uvw=17 uhw=7 fillp=27 vcnt=28 lasprat=96 pasprat=91 loasc=153 lodes=159 dides=103))
((Book\ Antiqua Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=200 lvw=18 lhw=8 uvw=21 uhw=8 fillp=31 vcnt=31 lasprat=108 pasprat=99 loasc=154 lodes=160 dides=103))
((Bookman\ Old\ Style Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=193 lvw=35 lhw=22 uvw=38 uhw=22 fillp=56 vcnt=57 lasprat=120 pasprat=112 loasc=148 lodes=145 dides=104))
((Bookman\ Old\ Style Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=85 em=169 lvw=32 lhw=20 uvw=36 uhw=20 fillp=51 vcnt=57 lasprat=116 pasprat=115 loasc=141 lodes=143 dides=104))
((Bookman\ Old\ Style Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=81 em=177 lvw=18 lhw=9 uvw=19 uhw=9 fillp=30 vcnt=33 lasprat=111 pasprat=108 loasc=148 lodes=146 dides=104))
((Bookman\ Old\ Style Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=194 lvw=20 lhw=8 uvw=21 uhw=10 fillp=34 vcnt=33 lasprat=115 pasprat=107 loasc=151 lodes=148 dides=105))
((Bordeaux\ Roman\ LET Bold\ Plain) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=73 lvw=13 lhw=1 uvw=16 uhw=1 fillp=39 vcnt=36 lasprat=48 pasprat=44 loasc=153 lodes=150 dides=101))
((BPreplay Bold) (Ascii Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=157 lvw=26 lhw=23 uvw=27 uhw=26 fillp=60 vcnt=73 lasprat=88 pasprat=76 loasc=139 lodes=140 dides=103))
((BPreplay Bold\ Italic) (Ascii Greek mono=no sans=yes slant=10 italic=yes case=mixed regular=yes ex=98 em=157 lvw=26 lhw=23 uvw=27 uhw=26 fillp=56 vcnt=69 lasprat=90 pasprat=83 loasc=139 lodes=140 dides=103))
((BPreplay Italic) (Ascii Greek mono=no sans=yes slant=11 italic=yes case=mixed regular=yes ex=93 em=160 lvw=13 lhw=12 uvw=13 uhw=13 fillp=33 vcnt=39 lasprat=92 pasprat=81 loasc=139 lodes=143 dides=103))
((BPreplay Regular) (Ascii Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=162 lvw=13 lhw=12 uvw=13 uhw=12 fillp=38 vcnt=41 lasprat=92 pasprat=72 loasc=141 lodes=143 dides=103))
((Bradley\ Hand Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=72 em=202 lvw=0 lhw=16 uvw=16 uhw=19 fillp=33 vcnt=29 lasprat=117 pasprat=109 loasc=170 lodes=193 dides=169))
((Braganza Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=55 em=280 lvw=38 lhw=10 uvw=43 uhw=7 fillp=31 vcnt=33 lasprat=161 pasprat=157 loasc=269 lodes=332 dides=227))
((Brewsky Regular) (mono=no sans=no slant=0 italic=no case=caps regular=no ex=100 em=107 lvw=8 lhw=8 uvw=8 uhw=8 fillp=45 vcnt=51 lasprat=77 pasprat=76 loasc=109 lodes=139 dides=116))
((Brush\ Script\ MT Italic) (Ascii Latin mono=no sans=no slant=55 italic=yes case=mixed regular=no ex=62 em=224 lvw=17 lhw=17 uvw=22 uhw=12 fillp=37 vcnt=38 lasprat=92 pasprat=100 loasc=175 lodes=169 dides=104))
((Cabin Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=165 lvw=23 lhw=20 uvw=26 uhw=23 fillp=53 vcnt=49 lasprat=97 pasprat=83 loasc=150 lodes=150 dides=103))
((Cabin Bold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=84 em=160 lvw=25 lhw=21 uvw=27 uhw=23 fillp=46 vcnt=49 lasprat=95 pasprat=92 loasc=150 lodes=150 dides=103))
((Cabin Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=144 lvw=20 lhw=18 uvw=21 uhw=20 fillp=50 vcnt=45 lasprat=84 pasprat=72 loasc=151 lodes=150 dides=103))
((Cabin Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=145 lvw=23 lhw=20 uvw=25 uhw=23 fillp=56 vcnt=52 lasprat=84 pasprat=72 loasc=150 lodes=150 dides=103))
((Cabin Condensed\ BoldItalic) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=83 em=146 lvw=24 lhw=20 uvw=26 uhw=26 fillp=43 vcnt=52 lasprat=85 pasprat=93 loasc=150 lodes=150 dides=102))
((Cabin Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=82 em=143 lvw=18 lhw=15 uvw=20 uhw=18 fillp=35 vcnt=41 lasprat=85 pasprat=92 loasc=153 lodes=151 dides=102))
((Cabin Italic) (Ascii Latin mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=82 em=152 lvw=19 lhw=17 uvw=20 uhw=17 fillp=38 vcnt=39 lasprat=90 pasprat=86 loasc=153 lodes=151 dides=103))
((Cabin Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=165 lvw=20 lhw=18 uvw=22 uhw=20 fillp=48 vcnt=43 lasprat=96 pasprat=82 loasc=151 lodes=150 dides=103))
((Cabin SemiBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=166 lvw=22 lhw=19 uvw=25 uhw=21 fillp=50 vcnt=46 lasprat=97 pasprat=84 loasc=150 lodes=150 dides=103))
((Cabin SemiBold\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=145 lvw=21 lhw=19 uvw=24 uhw=21 fillp=53 vcnt=49 lasprat=84 pasprat=74 loasc=150 lodes=150 dides=103))
((Cabin SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=83 em=159 lvw=22 lhw=19 uvw=25 uhw=21 fillp=44 vcnt=47 lasprat=94 pasprat=91 loasc=150 lodes=150 dides=103))
((Cake\ Frosting Decorative) (mono=no sans=no italic=no case=caps regular=yes ex=118 em=136 lvw=5 lhw=4 uvw=5 uhw=4 fillp=39 vcnt=46 lasprat=99 pasprat=89 loasc=107 lodes=102 dides=104))
((Caladea Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=174 lvw=30 lhw=11 uvw=34 uhw=12 fillp=49 vcnt=48 lasprat=108 pasprat=100 loasc=146 lodes=145 dides=103))
((Caladea Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=83 em=163 lvw=28 lhw=10 uvw=32 uhw=12 fillp=46 vcnt=49 lasprat=102 pasprat=99 loasc=143 lodes=144 dides=103))
((Caladea Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=174 lvw=19 lhw=10 uvw=21 uhw=10 fillp=37 vcnt=34 lasprat=104 pasprat=93 loasc=152 lodes=147 dides=102))
((Calibri Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=187 lvw=26 lhw=20 uvw=28 uhw=23 fillp=57 vcnt=48 lasprat=100 pasprat=84 loasc=146 lodes=138 dides=102))
((Calibri Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=78 em=187 lvw=26 lhw=20 uvw=28 uhw=23 fillp=48 vcnt=48 lasprat=100 pasprat=97 loasc=146 lodes=138 dides=102))
((Calibri Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=78 em=183 lvw=17 lhw=14 uvw=19 uhw=15 fillp=36 vcnt=34 lasprat=97 pasprat=90 loasc=146 lodes=138 dides=102))
((Calibri Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=183 lvw=12 lhw=11 uvw=14 uhw=11 fillp=35 vcnt=25 lasprat=97 pasprat=75 loasc=149 lodes=138 dides=102))
((Calibri Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=77 em=183 lvw=12 lhw=10 uvw=14 uhw=11 fillp=28 vcnt=25 lasprat=96 pasprat=88 loasc=149 lodes=138 dides=102))
((Calibri Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=183 lvw=17 lhw=14 uvw=19 uhw=15 fillp=44 vcnt=34 lasprat=97 pasprat=78 loasc=146 lodes=138 dides=102))
((Cambria Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=174 lvw=30 lhw=9 uvw=32 uhw=12 fillp=50 vcnt=47 lasprat=108 pasprat=98 loasc=144 lodes=144 dides=101))
((Cambria Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=81 em=169 lvw=27 lhw=9 uvw=30 uhw=12 fillp=44 vcnt=47 lasprat=105 pasprat=104 loasc=144 lodes=144 dides=101))
((Cambria Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=78 em=169 lvw=17 lhw=8 uvw=20 uhw=8 fillp=32 vcnt=33 lasprat=100 pasprat=96 loasc=150 lodes=146 dides=101))
((Cambria Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=174 lvw=19 lhw=7 uvw=21 uhw=8 fillp=37 vcnt=33 lasprat=104 pasprat=91 loasc=150 lodes=146 dides=101))
((Candara Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=184 lvw=26 lhw=19 uvw=29 uhw=23 fillp=53 vcnt=46 lasprat=105 pasprat=91 loasc=151 lodes=153 dides=142))
((Candara Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=10 italic=yes case=mixed regular=yes ex=78 em=173 lvw=26 lhw=19 uvw=28 uhw=23 fillp=48 vcnt=45 lasprat=102 pasprat=93 loasc=151 lodes=153 dides=142))
((Candara Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=10 italic=yes case=mixed regular=yes ex=78 em=166 lvw=17 lhw=12 uvw=17 uhw=14 fillp=35 vcnt=32 lasprat=99 pasprat=87 loasc=151 lodes=153 dides=142))
((Candara Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=183 lvw=9 lhw=7 uvw=9 uhw=7 fillp=24 vcnt=17 lasprat=102 pasprat=80 loasc=151 lodes=154 dides=142))
((Candara Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=11 italic=yes case=mixed regular=yes ex=78 em=161 lvw=10 lhw=7 uvw=10 uhw=8 fillp=23 vcnt=19 lasprat=98 pasprat=82 loasc=150 lodes=153 dides=142))
((Candara Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=183 lvw=17 lhw=12 uvw=19 uhw=14 fillp=39 vcnt=31 lasprat=102 pasprat=85 loasc=151 lodes=153 dides=142))
((Cantarell Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=182 lvw=27 lhw=23 uvw=27 uhw=23 fillp=52 vcnt=48 lasprat=105 pasprat=91 loasc=154 lodes=146 dides=102))
((Cantarell Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=177 lvw=8 lhw=7 uvw=8 uhw=8 fillp=23 vcnt=17 lasprat=98 pasprat=75 loasc=156 lodes=147 dides=102))
((Cantarell Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=183 lvw=16 lhw=15 uvw=17 uhw=15 fillp=39 vcnt=31 lasprat=104 pasprat=81 loasc=156 lodes=147 dides=102))
((Cantarell\ Extra Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=181 lvw=35 lhw=29 uvw=36 uhw=30 fillp=62 vcnt=61 lasprat=106 pasprat=97 loasc=153 lodes=147 dides=102))
((Cantarell\ Thin Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=173 lvw=3 lhw=3 uvw=3 uhw=3 fillp=12 vcnt=8 lasprat=95 pasprat=72 loasc=156 lodes=147 dides=102))
((Capitals Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=111 em=144 lvw=27 lhw=8 uvw=27 uhw=8 fillp=47 vcnt=55 lasprat=98 pasprat=90 loasc=103 lodes=124 dides=102))
((Carlito Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=180 lvw=25 lhw=19 uvw=27 uhw=22 fillp=54 vcnt=48 lasprat=96 pasprat=83 loasc=145 lodes=135 dides=102))
((Carlito Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=81 em=180 lvw=25 lhw=19 uvw=25 uhw=20 fillp=47 vcnt=47 lasprat=96 pasprat=91 loasc=145 lodes=135 dides=102))
((Carlito Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=80 em=178 lvw=17 lhw=13 uvw=18 uhw=15 fillp=37 vcnt=34 lasprat=94 pasprat=86 loasc=145 lodes=136 dides=102))
((Carlito Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=178 lvw=18 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=35 lasprat=95 pasprat=79 loasc=143 lodes=135 dides=101))
((Casa\ Sans Regular) (Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=180 lvw=17 lhw=16 uvw=17 uhw=16 fillp=33 vcnt=36 lasprat=161 pasprat=138 loasc=145 lodes=168 dides=110))
((Catenary\ Stamp Regular) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=111 lvw=2 lhw=24 uvw=23 uhw=23 fillp=55 vcnt=57 lasprat=85 pasprat=71 loasc=101 lodes=100 dides=100))
((CCIcons Medium) ())
((Century\ Gothic Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=168 lvw=24 lhw=22 uvw=25 uhw=24 fillp=56 vcnt=52 lasprat=102 pasprat=89 loasc=140 lodes=138 dides=103))
((Century\ Gothic Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=15 italic=no case=mixed regular=yes ex=89 em=168 lvw=24 lhw=22 uvw=24 uhw=23 fillp=49 vcnt=51 lasprat=102 pasprat=95 loasc=140 lodes=138 dides=103))
((Century\ Gothic Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=15 italic=no case=mixed regular=yes ex=89 em=171 lvw=12 lhw=11 uvw=13 uhw=12 fillp=29 vcnt=29 lasprat=101 pasprat=91 loasc=140 lodes=138 dides=103))
((Century\ Gothic Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=171 lvw=13 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=30 lasprat=101 pasprat=85 loasc=140 lodes=138 dides=103))
((Century\ Schoolbook Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=76 em=215 lvw=32 lhw=9 uvw=38 uhw=10 fillp=43 vcnt=43 lasprat=130 pasprat=116 loasc=163 lodes=143 dides=103))
((Century\ Schoolbook Bold\ Italic) (Ascii Latin mono=no sans=no slant=26 italic=yes case=mixed regular=yes ex=81 em=195 lvw=28 lhw=8 uvw=34 uhw=8 fillp=39 vcnt=42 lasprat=119 pasprat=110 loasc=151 lodes=139 dides=103))
((Century\ Schoolbook Italic) (Ascii Latin mono=no sans=no slant=26 italic=yes case=mixed regular=yes ex=78 em=202 lvw=19 lhw=7 uvw=24 uhw=7 fillp=30 vcnt=32 lasprat=110 pasprat=101 loasc=157 lodes=141 dides=102))
((Century\ Schoolbook Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=207 lvw=19 lhw=7 uvw=27 uhw=7 fillp=33 vcnt=33 lasprat=114 pasprat=102 loasc=161 lodes=142 dides=102))
((Chalkboard Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=163 lvw=25 lhw=26 uvw=26 uhw=25 fillp=53 vcnt=61 lasprat=100 pasprat=87 loasc=147 lodes=156 dides=110))
((Chalkboard Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=164 lvw=17 lhw=17 uvw=17 uhw=17 fillp=41 vcnt=44 lasprat=99 pasprat=82 loasc=146 lodes=154 dides=107))
((Chalkboard\ SE Bold) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=163 lvw=25 lhw=26 uvw=26 uhw=25 fillp=53 vcnt=54 lasprat=100 pasprat=87 loasc=147 lodes=156 dides=110))
((Chalkboard\ SE Light) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=164 lvw=17 lhw=17 uvw=17 uhw=17 fillp=41 vcnt=38 lasprat=99 pasprat=82 loasc=146 lodes=154 dides=107))
((Chalkboard\ SE Regular) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=166 lvw=21 lhw=19 uvw=21 uhw=19 fillp=46 vcnt=43 lasprat=100 pasprat=85 loasc=146 lodes=155 dides=106))
((Chalkduster Regular) (Ascii mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=87 em=160 lvw=24 lhw=17 uvw=31 uhw=24 fillp=37 vcnt=46 lasprat=121 pasprat=112 loasc=182 lodes=205 dides=119))
((Charakterny Regular) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=no ex=66 em=184 lvw=18 lhw=6 uvw=19 uhw=6 fillp=25 vcnt=26 lasprat=102 pasprat=99 loasc=151 lodes=175 dides=142))
((Charis\ SIL Bold) (Ascii Latin Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=186 lvw=29 lhw=11 uvw=33 uhw=13 fillp=46 vcnt=50 lasprat=111 pasprat=103 loasc=153 lodes=148 dides=103))
((Charis\ SIL Bold\ Italic) (Ascii Latin Cyrillic MathSymbols mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=84 em=179 lvw=28 lhw=11 uvw=30 uhw=13 fillp=44 vcnt=48 lasprat=101 pasprat=102 loasc=147 lodes=145 dides=113))
((Charis\ SIL Italic) (Ascii Latin Cyrillic MathSymbols mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=83 em=173 lvw=20 lhw=9 uvw=21 uhw=9 fillp=35 vcnt=37 lasprat=93 pasprat=94 loasc=148 lodes=145 dides=110))
((Charis\ SIL Regular) (Ascii Latin Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=182 lvw=22 lhw=10 uvw=23 uhw=11 fillp=37 vcnt=40 lasprat=104 pasprat=95 loasc=153 lodes=147 dides=103))
((Charter Black) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=195 lvw=37 lhw=12 uvw=40 uhw=14 fillp=52 vcnt=53 lasprat=119 pasprat=113 loasc=152 lodes=145 dides=110))
((Charter Black\ Italic) (Ascii Latin mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=83 em=197 lvw=34 lhw=13 uvw=37 uhw=15 fillp=48 vcnt=52 lasprat=115 pasprat=114 loasc=149 lodes=143 dides=112))
((Charter Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=181 lvw=28 lhw=11 uvw=30 uhw=12 fillp=45 vcnt=45 lasprat=107 pasprat=101 loasc=153 lodes=145 dides=111))
((Charter Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=82 em=181 lvw=25 lhw=2 uvw=28 uhw=2 fillp=38 vcnt=41 lasprat=103 pasprat=101 loasc=150 lodes=143 dides=102))
((Charter Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=82 em=170 lvw=17 lhw=2 uvw=19 uhw=9 fillp=29 vcnt=31 lasprat=95 pasprat=91 loasc=150 lodes=143 dides=102))
((Charter Roman) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=181 lvw=18 lhw=10 uvw=21 uhw=10 fillp=35 vcnt=34 lasprat=102 pasprat=94 loasc=155 lodes=145 dides=111))
((Chartrand Medium) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=202 lvw=19 lhw=14 uvw=27 uhw=19 fillp=36 vcnt=39 lasprat=122 pasprat=114 loasc=155 lodes=157 dides=106))
((Chess\ Alpha\ Diagram Regular) ())
((Chivo Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=196 lvw=41 lhw=23 uvw=43 uhw=30 fillp=68 vcnt=67 lasprat=109 pasprat=97 loasc=142 lodes=136 dides=102))
((Chivo Black\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=196 lvw=40 lhw=23 uvw=42 uhw=30 fillp=62 vcnt=67 lasprat=110 pasprat=106 loasc=142 lodes=136 dides=102))
((Chivo Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=189 lvw=28 lhw=20 uvw=30 uhw=24 fillp=58 vcnt=53 lasprat=106 pasprat=89 loasc=142 lodes=136 dides=102))
((Chivo Bold\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=85 em=189 lvw=28 lhw=20 uvw=30 uhw=24 fillp=52 vcnt=53 lasprat=106 pasprat=99 loasc=143 lodes=136 dides=102))
((Chivo ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=192 lvw=34 lhw=21 uvw=37 uhw=27 fillp=63 vcnt=60 lasprat=108 pasprat=93 loasc=142 lodes=136 dides=102))
((Chivo ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=192 lvw=32 lhw=21 uvw=36 uhw=27 fillp=57 vcnt=60 lasprat=108 pasprat=102 loasc=142 lodes=136 dides=102))
((Chivo Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=183 lvw=17 lhw=15 uvw=18 uhw=17 fillp=39 vcnt=38 lasprat=103 pasprat=90 loasc=143 lodes=136 dides=102))
((Chivo Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=182 lvw=14 lhw=11 uvw=14 uhw=12 fillp=37 vcnt=29 lasprat=103 pasprat=78 loasc=143 lodes=136 dides=102))
((Chivo Light\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=85 em=182 lvw=14 lhw=11 uvw=14 uhw=12 fillp=31 vcnt=29 lasprat=103 pasprat=87 loasc=143 lodes=136 dides=102))
((Chivo Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=187 lvw=22 lhw=17 uvw=24 uhw=21 fillp=51 vcnt=45 lasprat=104 pasprat=85 loasc=143 lodes=136 dides=102))
((Chivo Medium\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=187 lvw=22 lhw=17 uvw=24 uhw=21 fillp=45 vcnt=45 lasprat=104 pasprat=94 loasc=142 lodes=136 dides=102))
((Chivo Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=183 lvw=17 lhw=15 uvw=18 uhw=17 fillp=45 vcnt=38 lasprat=103 pasprat=81 loasc=143 lodes=136 dides=102))
((Chivo Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=181 lvw=9 lhw=9 uvw=9 uhw=9 fillp=28 vcnt=21 lasprat=102 pasprat=75 loasc=143 lodes=136 dides=102))
((Chivo Thin\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=181 lvw=9 lhw=9 uvw=9 uhw=9 fillp=24 vcnt=21 lasprat=103 pasprat=84 loasc=143 lodes=136 dides=102))
((Chronicles\ of\ Arkmar Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=no ex=117 em=160 lvw=9 lhw=8 uvw=6 uhw=11 fillp=33 vcnt=49 lasprat=70 pasprat=74 loasc=137 lodes=130 dides=110))
((Cinzel Black) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=100 em=161 lvw=34 lhw=8 uvw=37 uhw=8 fillp=46 vcnt=51 lasprat=108 pasprat=110 loasc=107 lodes=146 dides=113))
((Cinzel Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=100 em=159 lvw=25 lhw=7 uvw=28 uhw=7 fillp=38 vcnt=41 lasprat=107 pasprat=105 loasc=105 lodes=142 dides=110))
((Cinzel Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=100 em=155 lvw=13 lhw=5 uvw=13 uhw=5 fillp=22 vcnt=22 lasprat=106 pasprat=99 loasc=103 lodes=136 dides=107))
((Cinzel\ Decorative Black\ Black) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=117 em=141 lvw=31 lhw=6 uvw=31 uhw=6 fillp=39 vcnt=56 lasprat=107 pasprat=107 loasc=103 lodes=143 dides=124))
((Cinzel\ Decorative Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=117 em=137 lvw=23 lhw=5 uvw=23 uhw=5 fillp=32 vcnt=45 lasprat=103 pasprat=101 loasc=103 lodes=140 dides=122))
((Cinzel\ Decorative Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=117 em=132 lvw=11 lhw=4 uvw=11 uhw=4 fillp=19 vcnt=25 lasprat=97 pasprat=90 loasc=102 lodes=134 dides=119))
((Clara Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=219 lvw=26 lhw=12 uvw=29 uhw=12 fillp=42 vcnt=38 lasprat=112 pasprat=105 loasc=156 lodes=154 dides=102))
((Clara Bold-Italic) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=73 em=191 lvw=23 lhw=13 uvw=28 uhw=13 fillp=37 vcnt=37 lasprat=102 pasprat=102 loasc=150 lodes=152 dides=102))
((Clara Book) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=212 lvw=19 lhw=11 uvw=23 uhw=11 fillp=36 vcnt=33 lasprat=104 pasprat=97 loasc=156 lodes=154 dides=102))
((Clara Italic) (Greek Cyrillic mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=73 em=194 lvw=20 lhw=10 uvw=24 uhw=10 fillp=31 vcnt=31 lasprat=94 pasprat=94 loasc=149 lodes=152 dides=102))
((Clear\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=158 lvw=25 lhw=22 uvw=26 uhw=23 fillp=55 vcnt=50 lasprat=101 pasprat=83 loasc=144 lodes=137 dides=103))
((Clear\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=154 lvw=25 lhw=22 uvw=26 uhw=23 fillp=46 vcnt=50 lasprat=99 pasprat=97 loasc=144 lodes=137 dides=103))
((Clear\ Sans Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=147 lvw=16 lhw=15 uvw=18 uhw=15 fillp=34 vcnt=35 lasprat=95 pasprat=89 loasc=144 lodes=138 dides=103))
((Clear\ Sans Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=147 lvw=12 lhw=11 uvw=12 uhw=11 fillp=34 vcnt=27 lasprat=95 pasprat=71 loasc=144 lodes=138 dides=103))
((Clear\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=154 lvw=20 lhw=18 uvw=22 uhw=18 fillp=50 vcnt=43 lasprat=99 pasprat=79 loasc=144 lodes=138 dides=103))
((Clear\ Sans\ Thin Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=144 lvw=8 lhw=6 uvw=9 uhw=6 fillp=24 vcnt=18 lasprat=92 pasprat=67 loasc=144 lodes=138 dides=103))
((CMU\ Bright Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=206 lvw=29 lhw=16 uvw=31 uhw=17 fillp=53 vcnt=55 lasprat=105 pasprat=90 loasc=149 lodes=140 dides=105))
((CMU\ Bright BoldOblique) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=79 em=206 lvw=27 lhw=16 uvw=31 uhw=17 fillp=45 vcnt=48 lasprat=105 pasprat=106 loasc=149 lodes=140 dides=105))
((CMU\ Bright Oblique) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=79 em=186 lvw=13 lhw=11 uvw=15 uhw=11 fillp=27 vcnt=28 lasprat=97 pasprat=94 loasc=149 lodes=139 dides=103))
((CMU\ Bright Roman) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=186 lvw=13 lhw=11 uvw=15 uhw=11 fillp=34 vcnt=32 lasprat=97 pasprat=78 loasc=149 lodes=139 dides=103))
((CMU\ Bright SemiBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=186 lvw=20 lhw=16 uvw=22 uhw=16 fillp=45 vcnt=45 lasprat=97 pasprat=82 loasc=149 lodes=139 dides=103))
((CMU\ Bright SemiBoldOblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=79 em=186 lvw=20 lhw=16 uvw=22 uhw=16 fillp=37 vcnt=39 lasprat=97 pasprat=97 loasc=149 lodes=137 dides=103))
((CMU\ Classical\ Serif Italic) (Ascii Latin mono=no sans=no slant=26 italic=yes case=mixed regular=yes ex=74 em=201 lvw=17 lhw=5 uvw=20 uhw=6 fillp=26 vcnt=27 lasprat=104 pasprat=91 loasc=159 lodes=145 dides=143))
((CMU\ Concrete Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=227 lvw=20 lhw=16 uvw=20 uhw=17 fillp=40 vcnt=42 lasprat=119 pasprat=105 loasc=148 lodes=141 dides=102))
((CMU\ Concrete BoldItalic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=80 em=237 lvw=18 lhw=16 uvw=21 uhw=17 fillp=36 vcnt=38 lasprat=120 pasprat=110 loasc=146 lodes=141 dides=140))
((CMU\ Concrete Italic) (Ascii Latin mono=no sans=no slant=26 italic=yes case=mixed regular=yes ex=78 em=203 lvw=15 lhw=12 uvw=16 uhw=14 fillp=31 vcnt=32 lasprat=106 pasprat=96 loasc=150 lodes=142 dides=139))
((CMU\ Concrete Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=198 lvw=15 lhw=13 uvw=17 uhw=14 fillp=34 vcnt=35 lasprat=107 pasprat=95 loasc=153 lodes=143 dides=102))
((CMU\ Sans\ Serif Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=214 lvw=28 lhw=17 uvw=30 uhw=18 fillp=53 vcnt=54 lasprat=109 pasprat=90 loasc=160 lodes=144 dides=105))
((CMU\ Sans\ Serif BoldOblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=76 em=214 lvw=28 lhw=17 uvw=30 uhw=18 fillp=44 vcnt=48 lasprat=109 pasprat=106 loasc=160 lodes=144 dides=105))
((CMU\ Sans\ Serif DemiCondensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=24 lhw=15 uvw=25 uhw=15 fillp=50 vcnt=52 lasprat=91 pasprat=76 loasc=149 lodes=139 dides=103))
((CMU\ Sans\ Serif Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=13 uvw=20 uhw=13 fillp=39 vcnt=38 lasprat=103 pasprat=82 loasc=164 lodes=145 dides=105))
((CMU\ Sans\ Serif Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=13 uvw=20 uhw=13 fillp=31 vcnt=33 lasprat=103 pasprat=98 loasc=164 lodes=145 dides=105))
((CMU\ Sans\ Serif\ Demi Condensed\ DemiCondensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=24 lhw=15 uvw=25 uhw=15 fillp=50 vcnt=43 lasprat=91 pasprat=76 loasc=149 lodes=139 dides=103))
((CMU\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=245 lvw=28 lhw=9 uvw=33 uhw=9 fillp=39 vcnt=40 lasprat=126 pasprat=111 loasc=158 lodes=144 dides=102))
((CMU\ Serif BoldItalic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=76 em=235 lvw=25 lhw=7 uvw=30 uhw=9 fillp=36 vcnt=39 lasprat=118 pasprat=109 loasc=153 lodes=144 dides=142))
((CMU\ Serif Italic) (Ascii Latin mono=no sans=no slant=26 italic=yes case=mixed regular=yes ex=74 em=201 lvw=17 lhw=5 uvw=20 uhw=5 fillp=26 vcnt=27 lasprat=104 pasprat=95 loasc=159 lodes=145 dides=143))
((CMU\ Serif Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=5 uvw=23 uhw=5 fillp=28 vcnt=29 lasprat=113 pasprat=101 loasc=163 lodes=147 dides=105))
((CMU\ Serif\ Extra BoldNonextended) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=213 lvw=28 lhw=9 uvw=33 uhw=9 fillp=42 vcnt=44 lasprat=110 pasprat=99 loasc=158 lodes=144 dides=102))
((CMU\ Serif\ Extra BoldSlanted) (Ascii Latin mono=no sans=no slant=16 italic=no case=mixed regular=yes ex=74 em=245 lvw=28 lhw=9 uvw=32 uhw=9 fillp=36 vcnt=38 lasprat=126 pasprat=117 loasc=158 lodes=144 dides=102))
((CMU\ Serif\ Extra RomanSlanted) (Ascii Latin mono=no sans=no slant=19 italic=no case=mixed regular=yes ex=72 em=212 lvw=18 lhw=5 uvw=23 uhw=5 fillp=26 vcnt=27 lasprat=113 pasprat=108 loasc=163 lodes=147 dides=105))
((CMU\ Serif\ Upright Italic\ UprightItalic) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=74 em=218 lvw=18 lhw=5 uvw=22 uhw=6 fillp=28 vcnt=25 lasprat=113 pasprat=99 loasc=159 lodes=145 dides=143))
((CMU\ Serif\ Upright\ Italic UprightItalic) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=74 em=218 lvw=18 lhw=5 uvw=22 uhw=6 fillp=28 vcnt=29 lasprat=113 pasprat=99 loasc=159 lodes=145 dides=143))
((CMU\ Typewriter\ Text Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=118 lvw=18 lhw=17 uvw=18 uhw=17 fillp=44 vcnt=42 lasprat=118 pasprat=103 loasc=139 lodes=151 dides=101))
((CMU\ Typewriter\ Text BoldItalic) (Ascii Latin mono=yes sans=no slant=27 italic=yes case=mixed regular=yes ex=75 em=117 lvw=18 lhw=17 uvw=29 uhw=17 fillp=42 vcnt=41 lasprat=117 pasprat=99 loasc=137 lodes=150 dides=149))
((CMU\ Typewriter\ Text Italic) (Ascii Latin mono=yes sans=no slant=25 italic=yes case=mixed regular=yes ex=72 em=122 lvw=16 lhw=13 uvw=19 uhw=13 fillp=36 vcnt=35 lasprat=122 pasprat=100 loasc=143 lodes=152 dides=151))
((CMU\ Typewriter\ Text Light) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=13 lhw=12 uvw=13 uhw=12 fillp=33 vcnt=32 lasprat=122 pasprat=103 loasc=143 lodes=152 dides=101))
((CMU\ Typewriter\ Text LightOblique) (Ascii Latin mono=yes sans=no slant=17 italic=no case=mixed regular=yes ex=72 em=122 lvw=13 lhw=12 uvw=15 uhw=12 fillp=32 vcnt=30 lasprat=122 pasprat=107 loasc=143 lodes=152 dides=101))
((CMU\ Typewriter\ Text Oblique) (Ascii Latin mono=yes sans=no slant=16 italic=no case=mixed regular=yes ex=72 em=122 lvw=16 lhw=13 uvw=16 uhw=13 fillp=35 vcnt=34 lasprat=122 pasprat=108 loasc=143 lodes=152 dides=102))
((CMU\ Typewriter\ Text Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=16 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=36 lasprat=122 pasprat=104 loasc=143 lodes=152 dides=102))
((CMU\ Typewriter\ Text\ Variable\ Width Italic) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=73 em=231 lvw=16 lhw=13 uvw=16 uhw=13 fillp=33 vcnt=31 lasprat=126 pasprat=110 loasc=141 lodes=152 dides=150))
((CMU\ Typewriter\ Text\ Variable\ Width Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=216 lvw=16 lhw=13 uvw=16 uhw=13 fillp=34 vcnt=32 lasprat=118 pasprat=107 loasc=143 lodes=152 dides=102))
((Cochin Bold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=63 em=249 lvw=34 lhw=9 uvw=38 uhw=9 fillp=38 vcnt=37 lasprat=130 pasprat=127 loasc=188 lodes=166 dides=104))
((Cochin Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=36 italic=yes case=mixed regular=yes ex=65 em=204 lvw=32 lhw=83 uvw=36 uhw=13 fillp=35 vcnt=35 lasprat=115 pasprat=124 loasc=184 lodes=160 dides=104))
((Cochin Italic) (Ascii Latin Cyrillic mono=no sans=no slant=36 italic=yes case=mixed regular=yes ex=65 em=218 lvw=20 lhw=15 uvw=24 uhw=9 fillp=25 vcnt=25 lasprat=104 pasprat=108 loasc=183 lodes=160 dides=104))
((Cochin Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=62 em=259 lvw=24 lhw=8 uvw=27 uhw=8 fillp=29 vcnt=28 lasprat=127 pasprat=120 loasc=191 lodes=167 dides=104))
((Cochineal Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=204 lvw=32 lhw=9 uvw=36 uhw=9 fillp=42 vcnt=41 lasprat=113 pasprat=107 loasc=156 lodes=148 dides=102))
((Cochineal BoldItalic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=77 em=187 lvw=27 lhw=11 uvw=31 uhw=10 fillp=39 vcnt=41 lasprat=99 pasprat=98 loasc=151 lodes=149 dides=102))
((Cochineal Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=73 em=193 lvw=17 lhw=9 uvw=21 uhw=6 fillp=29 vcnt=29 lasprat=95 pasprat=89 loasc=158 lodes=154 dides=101))
((Cochineal Roman) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=19 lhw=6 uvw=22 uhw=8 fillp=32 vcnt=29 lasprat=104 pasprat=95 loasc=158 lodes=152 dides=101))
((Coelacanth Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=28 lhw=13 uvw=35 uhw=16 fillp=39 vcnt=40 lasprat=111 pasprat=104 loasc=189 lodes=186 dides=162))
((Coelacanth ExtraLt) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=13 lhw=7 uvw=14 uhw=8 fillp=22 vcnt=21 lasprat=111 pasprat=101 loasc=191 lodes=186 dides=162))
((Coelacanth Heavy) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=35 lhw=16 uvw=44 uhw=17 fillp=46 vcnt=47 lasprat=111 pasprat=106 loasc=189 lodes=188 dides=162))
((Coelacanth Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=68 em=230 lvw=19 lhw=11 uvw=23 uhw=13 fillp=26 vcnt=29 lasprat=101 pasprat=101 loasc=188 lodes=185 dides=161))
((Coelacanth Lt) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=14 lhw=8 uvw=19 uhw=10 fillp=25 vcnt=25 lasprat=111 pasprat=102 loasc=189 lodes=186 dides=162))
((Coelacanth Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=17 lhw=10 uvw=22 uhw=11 fillp=29 vcnt=29 lasprat=111 pasprat=102 loasc=189 lodes=186 dides=162))
((Coelacanth Semibd) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=238 lvw=23 lhw=11 uvw=29 uhw=13 fillp=34 vcnt=34 lasprat=111 pasprat=103 loasc=191 lodes=186 dides=162))
((Comfortaa Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=142 lvw=20 lhw=20 uvw=20 uhw=18 fillp=45 vcnt=49 lasprat=98 pasprat=88 loasc=141 lodes=142 dides=103))
((Comfortaa Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=151 lvw=10 lhw=10 uvw=10 uhw=10 fillp=26 vcnt=25 lasprat=106 pasprat=84 loasc=143 lodes=140 dides=100))
((Comfortaa Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=147 lvw=14 lhw=14 uvw=14 uhw=14 fillp=36 vcnt=37 lasprat=104 pasprat=87 loasc=142 lodes=141 dides=100))
((Comic\ Neue Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=177 lvw=19 lhw=18 uvw=19 uhw=19 fillp=47 vcnt=39 lasprat=101 pasprat=79 loasc=137 lodes=136 dides=101))
((Comic\ Neue Bold\ Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=177 lvw=20 lhw=18 uvw=19 uhw=19 fillp=38 vcnt=39 lasprat=101 pasprat=95 loasc=137 lodes=136 dides=101))
((Comic\ Neue Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=169 lvw=7 lhw=6 uvw=7 uhw=7 fillp=22 vcnt=17 lasprat=94 pasprat=76 loasc=142 lodes=140 dides=101))
((Comic\ Neue Light\ Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=169 lvw=7 lhw=6 uvw=7 uhw=7 fillp=16 vcnt=17 lasprat=94 pasprat=92 loasc=142 lodes=140 dides=101))
((Comic\ Neue Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=172 lvw=12 lhw=9 uvw=10 uhw=10 fillp=24 vcnt=25 lasprat=96 pasprat=93 loasc=139 lodes=139 dides=101))
((Comic\ Neue Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=172 lvw=12 lhw=9 uvw=10 uhw=10 fillp=30 vcnt=25 lasprat=96 pasprat=77 loasc=139 lodes=139 dides=101))
((Comic\ Neue\ Angular Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=173 lvw=18 lhw=17 uvw=18 uhw=18 fillp=46 vcnt=39 lasprat=97 pasprat=77 loasc=132 lodes=136 dides=102))
((Comic\ Neue\ Angular Bold\ Oblique) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=85 em=175 lvw=20 lhw=17 uvw=18 uhw=18 fillp=39 vcnt=39 lasprat=99 pasprat=92 loasc=134 lodes=136 dides=102))
((Comic\ Neue\ Angular Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=172 lvw=7 lhw=6 uvw=7 uhw=7 fillp=22 vcnt=17 lasprat=93 pasprat=75 loasc=140 lodes=140 dides=101))
((Comic\ Neue\ Angular Light\ Oblique) (Ascii Latin mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=83 em=172 lvw=7 lhw=6 uvw=6 uhw=7 fillp=16 vcnt=17 lasprat=94 pasprat=90 loasc=140 lodes=140 dides=101))
((Comic\ Neue\ Angular Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=84 em=171 lvw=11 lhw=9 uvw=10 uhw=10 fillp=24 vcnt=24 lasprat=94 pasprat=90 loasc=138 lodes=139 dides=101))
((Comic\ Neue\ Angular Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=171 lvw=11 lhw=9 uvw=10 uhw=10 fillp=30 vcnt=24 lasprat=94 pasprat=76 loasc=140 lodes=139 dides=101))
((Comic\ Sans\ MS Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=163 lvw=25 lhw=23 uvw=25 uhw=24 fillp=51 vcnt=61 lasprat=97 pasprat=87 loasc=145 lodes=154 dides=108))
((Comic\ Sans\ MS Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=87 em=168 lvw=26 lhw=25 uvw=27 uhw=25 fillp=46 vcnt=56 lasprat=100 pasprat=98 loasc=150 lodes=156 dides=109))
((Comic\ Sans\ MS Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=90 em=163 lvw=17 lhw=18 uvw=18 uhw=18 fillp=37 vcnt=42 lasprat=96 pasprat=88 loasc=145 lodes=154 dides=108))
((Comic\ Sans\ MS Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=163 lvw=17 lhw=17 uvw=18 uhw=18 fillp=41 vcnt=49 lasprat=96 pasprat=80 loasc=145 lodes=154 dides=108))
((Consolas Bold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=110 lvw=25 lhw=20 uvw=25 uhw=21 fillp=52 vcnt=46 lasprat=110 pasprat=91 loasc=143 lodes=140 dides=102))
((Consolas Bold\ Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=20 italic=yes case=mixed regular=yes ex=83 em=110 lvw=25 lhw=20 uvw=25 uhw=21 fillp=46 vcnt=46 lasprat=110 pasprat=101 loasc=143 lodes=140 dides=102))
((Consolas Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=20 italic=yes case=mixed regular=yes ex=82 em=112 lvw=17 lhw=14 uvw=18 uhw=15 fillp=36 vcnt=34 lasprat=112 pasprat=98 loasc=142 lodes=141 dides=101))
((Consolas Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=112 lvw=17 lhw=14 uvw=18 uhw=15 fillp=41 vcnt=34 lasprat=112 pasprat=87 loasc=142 lodes=141 dides=101))
((Constantia Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=205 lvw=32 lhw=10 uvw=35 uhw=10 fillp=43 vcnt=43 lasprat=118 pasprat=110 loasc=161 lodes=155 dides=150))
((Constantia Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=77 em=201 lvw=31 lhw=10 uvw=35 uhw=10 fillp=40 vcnt=42 lasprat=115 pasprat=109 loasc=159 lodes=154 dides=149))
((Constantia Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=76 em=196 lvw=19 lhw=9 uvw=22 uhw=9 fillp=31 vcnt=32 lasprat=104 pasprat=99 loasc=161 lodes=153 dides=150))
((Constantia Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=198 lvw=22 lhw=7 uvw=23 uhw=9 fillp=34 vcnt=33 lasprat=107 pasprat=100 loasc=161 lodes=153 dides=150))
((Constanze Regular) (mono=no sans=no italic=no case=caps regular=yes ex=116 em=140 lvw=15 lhw=17 uvw=15 uhw=17 fillp=18 vcnt=21 lasprat=106 pasprat=102 loasc=106 lodes=108))
((Copperplate Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=73 em=190 lvw=30 lhw=23 uvw=34 uhw=27 fillp=55 vcnt=46 lasprat=137 pasprat=115 loasc=105 lodes=119 dides=104))
((Copperplate Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=73 em=190 lvw=15 lhw=12 uvw=19 uhw=15 fillp=36 vcnt=29 lasprat=131 pasprat=104 loasc=105 lodes=116 dides=104))
((Copperplate Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=73 em=190 lvw=21 lhw=16 uvw=24 uhw=19 fillp=46 vcnt=37 lasprat=133 pasprat=109 loasc=105 lodes=121 dides=102))
((Corbel Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=174 lvw=25 lhw=20 uvw=26 uhw=21 fillp=52 vcnt=44 lasprat=104 pasprat=88 loasc=151 lodes=150 dides=143))
((Corbel Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=79 em=168 lvw=24 lhw=20 uvw=25 uhw=21 fillp=44 vcnt=45 lasprat=100 pasprat=101 loasc=151 lodes=150 dides=143))
((Corbel Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=77 em=171 lvw=16 lhw=14 uvw=18 uhw=15 fillp=33 vcnt=32 lasprat=97 pasprat=95 loasc=155 lodes=151 dides=144))
((Corbel Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=177 lvw=9 lhw=7 uvw=10 uhw=9 fillp=26 vcnt=18 lasprat=97 pasprat=73 loasc=155 lodes=151 dides=144))
((Corbel Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=76 em=171 lvw=9 lhw=7 uvw=9 uhw=9 fillp=20 vcnt=19 lasprat=93 pasprat=88 loasc=157 lodes=152 dides=144))
((Corbel Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=177 lvw=16 lhw=14 uvw=16 uhw=15 fillp=40 vcnt=31 lasprat=101 pasprat=81 loasc=155 lodes=151 dides=144))
((Cormorant\ Garamond Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=220 lvw=27 lhw=6 uvw=30 uhw=7 fillp=34 vcnt=30 lasprat=114 pasprat=106 loasc=186 lodes=173 dides=170))
((Cormorant\ Garamond Bold\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=66 em=187 lvw=24 lhw=10 uvw=28 uhw=9 fillp=32 vcnt=31 lasprat=101 pasprat=100 loasc=183 lodes=172 dides=171))
((Cormorant\ Garamond Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=66 em=184 lvw=13 lhw=7 uvw=15 uhw=7 fillp=22 vcnt=20 lasprat=99 pasprat=95 loasc=183 lodes=172 dides=171))
((Cormorant\ Garamond Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=212 lvw=15 lhw=4 uvw=16 uhw=6 fillp=21 vcnt=17 lasprat=113 pasprat=100 loasc=186 lodes=173 dides=172))
((Cormorant\ Garamond Light\ Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=66 em=184 lvw=12 lhw=7 uvw=13 uhw=7 fillp=19 vcnt=18 lasprat=99 pasprat=94 loasc=183 lodes=172 dides=171))
((Cormorant\ Garamond Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=215 lvw=18 lhw=6 uvw=21 uhw=6 fillp=26 vcnt=22 lasprat=113 pasprat=102 loasc=186 lodes=173 dides=172))
((Cormorant\ Garamond Medium\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=66 em=186 lvw=18 lhw=9 uvw=19 uhw=7 fillp=25 vcnt=24 lasprat=100 pasprat=97 loasc=183 lodes=172 dides=171))
((Cormorant\ Garamond Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=213 lvw=16 lhw=6 uvw=20 uhw=6 fillp=24 vcnt=20 lasprat=113 pasprat=101 loasc=186 lodes=173 dides=172))
((Cormorant\ Garamond SemiBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=218 lvw=24 lhw=6 uvw=27 uhw=7 fillp=31 vcnt=27 lasprat=113 pasprat=105 loasc=186 lodes=173 dides=170))
((Cormorant\ Garamond SemiBold\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=66 em=186 lvw=21 lhw=9 uvw=24 uhw=7 fillp=29 vcnt=27 lasprat=101 pasprat=99 loasc=183 lodes=172 dides=171))
((Corsiva\ Hebrew Bold) (slant=20))
((Corsiva\ Hebrew Regular) (slant=20))
((Countries\ of\ Europe Regular) (mono=no sans=yes italic=no case=mixed regular=yes ex=85 em=157 lvw=17 lhw=15 uvw=20 uhw=16 fillp=47 vcnt=42 lasprat=90 pasprat=70 loasc=148 lodes=144))
((Courier\ New Bold) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=135 lvw=22 lhw=22 uvw=22 uhw=22 fillp=51 vcnt=48 lasprat=135 pasprat=120 loasc=143 lodes=147 dides=102))
((Courier\ New Bold\ Italic) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=74 em=135 lvw=21 lhw=21 uvw=21 uhw=21 fillp=45 vcnt=43 lasprat=135 pasprat=130 loasc=143 lodes=147 dides=102))
((Courier\ New Italic) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=9 uhw=9 fillp=23 vcnt=21 lasprat=140 pasprat=119 loasc=149 lodes=143 dides=102))
((Courier\ New Regular) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=9 uhw=9 fillp=25 vcnt=23 lasprat=140 pasprat=111 loasc=149 lodes=143 dides=102))
((Crimson Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=31 lhw=9 uvw=36 uhw=9 fillp=42 vcnt=40 lasprat=114 pasprat=107 loasc=158 lodes=148 dides=102))
((Crimson BoldItalic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=191 lvw=26 lhw=10 uvw=31 uhw=10 fillp=39 vcnt=39 lasprat=101 pasprat=97 loasc=154 lodes=150 dides=102))
((Crimson Italic) (Ascii Latin mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=71 em=191 lvw=16 lhw=8 uvw=21 uhw=7 fillp=29 vcnt=28 lasprat=94 pasprat=88 loasc=157 lodes=154 dides=101))
((Crimson Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=211 lvw=20 lhw=7 uvw=22 uhw=8 fillp=32 vcnt=29 lasprat=106 pasprat=97 loasc=162 lodes=152 dides=101))
((Crimson Semibold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=208 lvw=25 lhw=9 uvw=29 uhw=9 fillp=38 vcnt=34 lasprat=110 pasprat=100 loasc=160 lodes=150 dides=101))
((Crimson SemiboldItalic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=72 em=193 lvw=22 lhw=9 uvw=26 uhw=8 fillp=35 vcnt=34 lasprat=98 pasprat=94 loasc=155 lodes=151 dides=101))
((Crimson\ Pro Black) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=205 lvw=39 lhw=16 uvw=42 uhw=19 fillp=54 vcnt=49 lasprat=117 pasprat=114 loasc=157 lodes=152 dides=105))
((Crimson\ Pro Black\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=74 em=202 lvw=37 lhw=25 uvw=43 uhw=20 fillp=50 vcnt=49 lasprat=115 pasprat=118 loasc=155 lodes=151 dides=104))
((Crimson\ Pro Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=201 lvw=31 lhw=13 uvw=36 uhw=16 fillp=48 vcnt=42 lasprat=114 pasprat=108 loasc=158 lodes=152 dides=104))
((Crimson\ Pro Bold\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=73 em=198 lvw=30 lhw=16 uvw=34 uhw=16 fillp=44 vcnt=42 lasprat=107 pasprat=109 loasc=156 lodes=152 dides=104))
((Crimson\ Pro ExtraBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=36 lhw=15 uvw=38 uhw=18 fillp=52 vcnt=45 lasprat=117 pasprat=110 loasc=158 lodes=152 dides=104))
((Crimson\ Pro ExtraBold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=74 em=200 lvw=33 lhw=20 uvw=39 uhw=17 fillp=48 vcnt=45 lasprat=110 pasprat=111 loasc=154 lodes=151 dides=104))
((Crimson\ Pro Italic) (Ascii Latin mono=no sans=no slant=22 italic=yes case=mixed regular=yes ex=71 em=194 lvw=18 lhw=11 uvw=22 uhw=11 fillp=32 vcnt=29 lasprat=96 pasprat=96 loasc=160 lodes=153 dides=104))
((Crimson\ Pro Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=194 lvw=17 lhw=10 uvw=20 uhw=11 fillp=32 vcnt=26 lasprat=107 pasprat=95 loasc=162 lodes=154 dides=104))
((Crimson\ Pro Light\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=71 em=191 lvw=16 lhw=9 uvw=19 uhw=9 fillp=29 vcnt=26 lasprat=94 pasprat=90 loasc=160 lodes=154 dides=104))
((Crimson\ Pro Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=197 lvw=23 lhw=11 uvw=25 uhw=12 fillp=39 vcnt=33 lasprat=109 pasprat=98 loasc=160 lodes=153 dides=104))
((Crimson\ Pro SemiBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=201 lvw=28 lhw=12 uvw=32 uhw=15 fillp=45 vcnt=39 lasprat=113 pasprat=106 loasc=160 lodes=153 dides=104))
((Crimson\ Pro SemiBold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=195 lvw=26 lhw=13 uvw=30 uhw=15 fillp=41 vcnt=38 lasprat=102 pasprat=102 loasc=156 lodes=152 dides=104))
((Crimson\ Pro\ ExtraLight Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=70 em=192 lvw=12 lhw=10 uvw=17 uhw=10 fillp=27 vcnt=24 lasprat=93 pasprat=89 loasc=162 lodes=155 dides=104))
((Crimson\ Pro\ ExtraLight Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=192 lvw=14 lhw=8 uvw=17 uhw=10 fillp=30 vcnt=23 lasprat=106 pasprat=91 loasc=162 lodes=154 dides=104))
((Cuprum Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=151 lvw=23 lhw=13 uvw=23 uhw=14 fillp=56 vcnt=59 lasprat=89 pasprat=72 loasc=139 lodes=141 dides=102))
((Cuprum Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=84 em=151 lvw=23 lhw=13 uvw=23 uhw=14 fillp=45 vcnt=50 lasprat=89 pasprat=87 loasc=139 lodes=141 dides=102))
((Cuprum Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=84 em=147 lvw=17 lhw=10 uvw=17 uhw=11 fillp=38 vcnt=42 lasprat=84 pasprat=81 loasc=139 lodes=141 dides=102))
((Cuprum Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=147 lvw=17 lhw=10 uvw=17 uhw=11 fillp=48 vcnt=50 lasprat=84 pasprat=66 loasc=139 lodes=141 dides=102))
((Cyen Regular) (mono=no sans=no italic=no case=mixed regular=yes ex=81 em=200 lvw=9 lhw=11 uvw=11 uhw=11 fillp=27 vcnt=29 lasprat=110 pasprat=98 loasc=156 lodes=154 dides=103))
((Cyklop Italic) (Ascii Latin mono=no sans=yes slant=27 italic=no case=mixed regular=yes ex=85 em=224 lvw=62 lhw=12 uvw=82 uhw=12 fillp=58 vcnt=64 lasprat=162 pasprat=158 loasc=140 lodes=144 dides=103))
((Cyklop Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=217 lvw=61 lhw=12 uvw=78 uhw=12 fillp=65 vcnt=64 lasprat=156 pasprat=136 loasc=140 lodes=144 dides=103))
((Damascus Bold) ())
((Damascus Light) ())
((Damascus Medium) ())
((Damascus Regular) ())
((Damascus Semi\ Bold) ())
((Damascus\ PUA Bold) ())
((Damascus\ PUA Light) ())
((Damascus\ PUA Medium) ())
((Damascus\ PUA Regular) ())
((Damascus\ PUA Semi\ Bold) ())
((Dante Bold) ())
((Dante Bold-Italic) ())
((Dante Italic) ())
((Dante Normal) ())
((Dark\ Garden Regular) (mono=no sans=no italic=no case=smallcaps regular=no ex=146 em=95 lvw=13 lhw=3 uvw=0 uhw=3 fillp=33 vcnt=52 lasprat=66 pasprat=62 loasc=104 lodes=127))
((Dear\ Joe\ Four Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=no ex=57 em=277 lvw=17 lhw=66 uvw=17 uhw=17 fillp=21 vcnt=32 lasprat=122 pasprat=163 loasc=228 lodes=275 dides=194))
((Dear\ Joe\ Four Small) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=35 italic=yes case=mixed regular=no ex=46 em=239 lvw=17 lhw=19 uvw=21 uhw=21 fillp=26 vcnt=23 lasprat=121 pasprat=130 loasc=228 lodes=276 dides=169))
((Dear\ Joe\ Four Small\ Semibold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=35 italic=yes case=mixed regular=yes ex=47 em=225 lvw=23 lhw=23 uvw=23 uhw=23 fillp=32 vcnt=30 lasprat=113 pasprat=126 loasc=208 lodes=242 dides=148))
((DecoType\ Naskh Regular) (slant=0))
((DecoType\ Naskh\ PUA Regular) (slant=0))
((DejaVu\ Sans Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=182 lvw=32 lhw=23 uvw=35 uhw=24 fillp=60 vcnt=69 lasprat=116 pasprat=98 loasc=139 lodes=139 dides=102))
((DejaVu\ Sans Bold\ Condensed) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=163 lvw=29 lhw=22 uvw=31 uhw=25 fillp=61 vcnt=69 lasprat=104 pasprat=87 loasc=139 lodes=139 dides=102))
((DejaVu\ Sans Bold\ Condensed\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=92 em=163 lvw=30 lhw=22 uvw=32 uhw=25 fillp=52 vcnt=61 lasprat=103 pasprat=99 loasc=139 lodes=139 dides=103))
((DejaVu\ Sans Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=182 lvw=32 lhw=23 uvw=36 uhw=24 fillp=51 vcnt=60 lasprat=116 pasprat=111 loasc=139 lodes=139 dides=102))
((DejaVu\ Sans Book) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=14 uvw=18 uhw=14 fillp=43 vcnt=47 lasprat=103 pasprat=81 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=163 lvw=29 lhw=23 uvw=31 uhw=24 fillp=61 vcnt=57 lasprat=104 pasprat=86 loasc=139 lodes=139 dides=102))
((DejaVu\ Sans Condensed\ Bold\ Oblique) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=91 em=163 lvw=29 lhw=23 uvw=31 uhw=25 fillp=52 vcnt=57 lasprat=104 pasprat=98 loasc=139 lodes=139 dides=102))
((DejaVu\ Sans Condensed\ Book) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=141 lvw=15 lhw=14 uvw=17 uhw=14 fillp=43 vcnt=47 lasprat=92 pasprat=72 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans Condensed\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=92 em=141 lvw=15 lhw=14 uvw=17 uhw=14 fillp=34 vcnt=40 lasprat=91 pasprat=85 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans ExtraLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=156 lvw=8 lhw=7 uvw=9 uhw=7 fillp=27 vcnt=27 lasprat=102 pasprat=72 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans Light\ ExtraLight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=158 lvw=8 lhw=7 uvw=9 uhw=6 fillp=27 vcnt=19 lasprat=103 pasprat=72 loasc=139 lodes=137 dides=102))
((DejaVu\ Sans Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=14 uvw=19 uhw=14 fillp=34 vcnt=39 lasprat=103 pasprat=95 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans\ Mono Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=24 fillp=56 vcnt=65 lasprat=110 pasprat=88 loasc=149 lodes=138 dides=102))
((DejaVu\ Sans\ Mono Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=23 fillp=48 vcnt=56 lasprat=110 pasprat=99 loasc=149 lodes=138 dides=102))
((DejaVu\ Sans\ Mono Book) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=41 vcnt=47 lasprat=110 pasprat=82 loasc=139 lodes=138 dides=102))
((DejaVu\ Sans\ Mono Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=35 vcnt=41 lasprat=110 pasprat=93 loasc=139 lodes=138 dides=102))
((DejaVu\ Serif Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=212 lvw=36 lhw=10 uvw=40 uhw=11 fillp=48 vcnt=56 lasprat=120 pasprat=112 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Bold\ Condensed) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=190 lvw=33 lhw=10 uvw=35 uhw=11 fillp=48 vcnt=56 lasprat=107 pasprat=101 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Bold\ Condensed\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=87 em=190 lvw=33 lhw=10 uvw=35 uhw=11 fillp=45 vcnt=52 lasprat=108 pasprat=102 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=87 em=212 lvw=35 lhw=10 uvw=40 uhw=11 fillp=45 vcnt=51 lasprat=120 pasprat=114 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Book) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=196 lvw=20 lhw=9 uvw=21 uhw=10 fillp=35 vcnt=40 lasprat=109 pasprat=98 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Condensed\ Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=190 lvw=33 lhw=10 uvw=36 uhw=11 fillp=48 vcnt=52 lasprat=107 pasprat=100 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Condensed\ Bold\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=87 em=190 lvw=33 lhw=10 uvw=35 uhw=11 fillp=45 vcnt=51 lasprat=107 pasprat=102 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Condensed\ Book) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=177 lvw=18 lhw=9 uvw=19 uhw=10 fillp=35 vcnt=40 lasprat=98 pasprat=88 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Condensed\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=87 em=177 lvw=18 lhw=9 uvw=18 uhw=10 fillp=32 vcnt=36 lasprat=98 pasprat=88 loasc=145 lodes=142 dides=102))
((DejaVu\ Serif Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=87 em=196 lvw=19 lhw=9 uvw=20 uhw=10 fillp=32 vcnt=36 lasprat=109 pasprat=98 loasc=145 lodes=142 dides=102))
((Delius Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=158 lvw=13 lhw=12 uvw=16 uhw=13 fillp=35 vcnt=39 lasprat=98 pasprat=81 loasc=147 lodes=144 dides=102))
((Delius\ Swash\ Caps Regular) (Ascii Latin mono=no sans=yes slant=0 italic=yes case=mixed regular=yes ex=86 em=191 lvw=13 lhw=12 uvw=15 uhw=13 fillp=35 vcnt=40 lasprat=98 pasprat=81 loasc=147 lodes=144 dides=102))
((Delius\ Unicase Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=127 em=119 lvw=18 lhw=16 uvw=18 uhw=16 fillp=48 vcnt=63 lasprat=95 pasprat=81 loasc=100 lodes=111 dides=101))
((Delius\ Unicase Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=128 em=113 lvw=12 lhw=10 uvw=12 uhw=10 fillp=36 vcnt=46 lasprat=94 pasprat=78 loasc=100 lodes=112 dides=102))
((Denise Regular) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=no ex=71 em=177 lvw=11 lhw=11 uvw=12 uhw=12 fillp=26 vcnt=25 lasprat=75 pasprat=83 loasc=157 lodes=150 dides=108))
((Designer\ Notes Bold) (mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=72 em=148 lvw=23 lhw=23 uvw=23 uhw=22 fillp=47 vcnt=47 lasprat=107 pasprat=98 loasc=162 lodes=165 dides=120))
((Designer\ Notes Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=67 em=162 lvw=13 lhw=11 uvw=11 uhw=11 fillp=27 vcnt=26 lasprat=105 pasprat=99 loasc=173 lodes=176 dides=125))
((Devanagari\ MT Bold) (slant=0))
((Devanagari\ MT Regular) (slant=0))
((Devanagari\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=147 lvw=22 lhw=16 uvw=22 uhw=16 fillp=50 vcnt=47 lasprat=94 pasprat=83 loasc=142 lodes=142 dides=102))
((Devanagari\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=150 lvw=15 lhw=13 uvw=15 uhw=13 fillp=39 vcnt=34 lasprat=94 pasprat=78 loasc=144 lodes=144 dides=102))
((Didot Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=213 lvw=31 lhw=2 uvw=37 uhw=2 fillp=35 vcnt=37 lasprat=120 pasprat=110 loasc=168 lodes=168 dides=102))
((Didot Italic) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=74 em=191 lvw=16 lhw=2 uvw=20 uhw=2 fillp=21 vcnt=23 lasprat=106 pasprat=108 loasc=171 lodes=164 dides=106))
((Didot Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=202 lvw=23 lhw=2 uvw=26 uhw=4 fillp=27 vcnt=28 lasprat=116 pasprat=106 loasc=169 lodes=166 dides=102))
((Dijla Regular) (slant=0))
((Dijla\ PUA Regular) ())
((Din Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=109 lvw=20 lhw=20 uvw=20 uhw=20 fillp=59 vcnt=55 lasprat=68 pasprat=59 loasc=140 lodes=141 dides=101))
((DIN\ Alternate Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=150 lvw=19 lhw=20 uvw=20 uhw=21 fillp=49 vcnt=43 lasprat=93 pasprat=75 loasc=141 lodes=141 dides=101))
((Dinosaur\ Skin Regular) (mono=no sans=no italic=no case=mixed regular=yes ex=101 em=157 lvw=8 lhw=0 uvw=8 uhw=10 fillp=28 vcnt=37 lasprat=89 pasprat=75 loasc=152 lodes=148 dides=100))
((Diwan\ Kufi Regular) ())
((Diwan\ Kufi\ PUA Regular) ())
((Diwan\ Thuluth Regular) (slant=0))
((Domitian Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=29 lhw=10 uvw=31 uhw=11 fillp=42 vcnt=41 lasprat=112 pasprat=100 loasc=151 lodes=155 dides=103))
((Domitian Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=78 em=201 lvw=24 lhw=12 uvw=29 uhw=8 fillp=36 vcnt=38 lasprat=109 pasprat=102 loasc=155 lodes=158 dides=103))
((Domitian Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=81 em=193 lvw=14 lhw=9 uvw=17 uhw=8 fillp=27 vcnt=28 lasprat=93 pasprat=86 loasc=150 lodes=156 dides=102))
((Domitian Roman) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=20 lhw=8 uvw=23 uhw=8 fillp=32 vcnt=31 lasprat=109 pasprat=100 loasc=155 lodes=160 dides=103))
((Doris\ PP bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=195 lvw=32 lhw=22 uvw=33 uhw=25 fillp=60 vcnt=55 lasprat=113 pasprat=98 loasc=153 lodes=144 dides=102))
((Double\ Strike Regular) (mono=no sans=no italic=no case=caps regular=yes ex=119 em=149 lvw=3 lhw=2 uvw=3 uhw=2 fillp=17 vcnt=19 lasprat=85 pasprat=75 loasc=105 lodes=101 dides=102))
((Doulos\ SIL Regular) (Ascii Latin Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=198 lvw=20 lhw=8 uvw=25 uhw=8 fillp=32 vcnt=33 lasprat=102 pasprat=97 loasc=154 lodes=148 dides=102))
((Droid\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=167 lvw=28 lhw=21 uvw=28 uhw=24 fillp=58 vcnt=66 lasprat=99 pasprat=83 loasc=140 lodes=143 dides=102))
((Droid\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=161 lvw=16 lhw=14 uvw=17 uhw=15 fillp=42 vcnt=46 lasprat=92 pasprat=73 loasc=142 lodes=144 dides=102))
((Droid\ Sans\ Mono Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=111 lvw=16 lhw=14 uvw=16 uhw=15 fillp=39 vcnt=45 lasprat=111 pasprat=82 loasc=142 lodes=144 dides=102))
((Droid\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=176 lvw=27 lhw=12 uvw=30 uhw=12 fillp=47 vcnt=54 lasprat=108 pasprat=98 loasc=143 lodes=144 dides=102))
((Droid\ Serif Bold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=90 em=176 lvw=27 lhw=14 uvw=30 uhw=13 fillp=43 vcnt=49 lasprat=108 pasprat=103 loasc=143 lodes=144 dides=102))
((Droid\ Serif Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=90 em=173 lvw=18 lhw=10 uvw=20 uhw=10 fillp=33 vcnt=37 lasprat=97 pasprat=92 loasc=143 lodes=144 dides=102))
((Droid\ Serif Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=17 lhw=10 uvw=20 uhw=10 fillp=36 vcnt=41 lasprat=101 pasprat=90 loasc=143 lodes=144 dides=102))
((Druk Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=84 lvw=24 lhw=21 uvw=25 uhw=24 fillp=73 vcnt=79 lasprat=58 pasprat=55 loasc=137 lodes=136 dides=102))
((Druk Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=82 lvw=25 lhw=22 uvw=25 uhw=24 fillp=57 vcnt=79 lasprat=56 pasprat=67 loasc=137 lodes=136 dides=102))
((Druk Bold\ Wide) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=243 lvw=51 lhw=28 uvw=54 uhw=37 fillp=68 vcnt=74 lasprat=150 pasprat=144 loasc=137 lodes=136 dides=103))
((Druk Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=92 lvw=30 lhw=24 uvw=32 uhw=28 fillp=77 vcnt=86 lasprat=67 pasprat=64 loasc=137 lodes=136 dides=102))
((Druk Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=90 lvw=28 lhw=24 uvw=31 uhw=28 fillp=62 vcnt=86 lasprat=65 pasprat=76 loasc=137 lodes=136 dides=102))
((Druk Italic\ Bold\ Wide) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=235 lvw=50 lhw=28 uvw=54 uhw=37 fillp=62 vcnt=74 lasprat=146 pasprat=150 loasc=137 lodes=136 dides=103))
((Druk Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=80 lvw=20 lhw=18 uvw=21 uhw=20 fillp=69 vcnt=74 lasprat=53 pasprat=49 loasc=137 lodes=136 dides=102))
((Druk Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=77 lvw=20 lhw=18 uvw=21 uhw=21 fillp=52 vcnt=74 lasprat=51 pasprat=62 loasc=137 lodes=135 dides=102))
((Druk Super) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=101 lvw=35 lhw=26 uvw=37 uhw=32 fillp=81 vcnt=91 lasprat=77 pasprat=74 loasc=137 lodes=136 dides=102))
((Druk Super\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=98 lvw=34 lhw=27 uvw=37 uhw=33 fillp=67 vcnt=91 lasprat=75 pasprat=86 loasc=137 lodes=136 dides=102))
((Druk Wide\ Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=235 lvw=42 lhw=26 uvw=45 uhw=33 fillp=62 vcnt=67 lasprat=142 pasprat=135 loasc=137 lodes=136 dides=103))
((Druk Wide\ Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=90 em=227 lvw=41 lhw=26 uvw=44 uhw=33 fillp=57 vcnt=67 lasprat=138 pasprat=141 loasc=138 lodes=136 dides=103))
((Druk\ Text Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=118 lvw=28 lhw=20 uvw=29 uhw=25 fillp=70 vcnt=68 lasprat=83 pasprat=71 loasc=136 lodes=135 dides=102))
((DuCahier\ xp Regular) (mono=no sans=no slant=-79 italic=yes case=mixed regular=yes ex=38 em=413 lvw=10 lhw=7 uvw=21 uhw=10 fillp=17 vcnt=17 lasprat=139 pasprat=139 loasc=310 lodes=292 dides=100))
((Dufay Normal) ())
((Dustismo \ Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=145 lvw=17 lhw=17 uvw=17 uhw=17 fillp=44 vcnt=45 lasprat=102 pasprat=85 loasc=138 lodes=138 dides=140))
((Dustismo \ Bold\ Italic) (Ascii mono=no sans=yes slant=20 italic=yes case=mixed regular=no ex=83 em=143 lvw=16 lhw=16 uvw=16 uhw=16 fillp=35 vcnt=37 lasprat=100 pasprat=94 loasc=133 lodes=139 dides=142))
((Dustismo \ Italic) (Ascii mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=82 em=142 lvw=13 lhw=13 uvw=13 uhw=13 fillp=30 vcnt=31 lasprat=99 pasprat=93 loasc=135 lodes=140 dides=142))
((Dustismo Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=144 lvw=13 lhw=13 uvw=13 uhw=13 fillp=37 vcnt=37 lasprat=101 pasprat=84 loasc=140 lodes=140 dides=141))
((Dustismo\ Roman Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=155 lvw=23 lhw=9 uvw=24 uhw=11 fillp=42 vcnt=46 lasprat=102 pasprat=90 loasc=150 lodes=146 dides=102))
((Dustismo\ Roman Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=84 em=179 lvw=22 lhw=16 uvw=23 uhw=10 fillp=36 vcnt=40 lasprat=104 pasprat=99 loasc=146 lodes=148 dides=102))
((Dustismo\ Roman Italic) (Ascii Latin Greek mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=84 em=179 lvw=19 lhw=11 uvw=20 uhw=5 fillp=29 vcnt=32 lasprat=104 pasprat=97 loasc=146 lodes=151 dides=102))
((Dustismo\ Roman Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=159 lvw=20 lhw=6 uvw=22 uhw=6 fillp=35 vcnt=38 lasprat=104 pasprat=91 loasc=154 lodes=153 dides=102))
((EB\ Garamond Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=215 lvw=32 lhw=11 uvw=39 uhw=11 fillp=44 vcnt=43 lasprat=112 pasprat=107 loasc=166 lodes=167 dides=112))
((EB\ Garamond Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=72 em=229 lvw=30 lhw=9 uvw=33 uhw=8 fillp=37 vcnt=42 lasprat=112 pasprat=117 loasc=165 lodes=168 dides=109))
((EB\ Garamond ExtraBold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=213 lvw=34 lhw=12 uvw=43 uhw=11 fillp=46 vcnt=46 lasprat=113 pasprat=108 loasc=163 lodes=166 dides=112))
((EB\ Garamond ExtraBold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=73 em=226 lvw=35 lhw=10 uvw=35 uhw=9 fillp=40 vcnt=45 lasprat=113 pasprat=119 loasc=161 lodes=167 dides=109))
((EB\ Garamond Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=69 em=239 lvw=15 lhw=7 uvw=21 uhw=7 fillp=25 vcnt=27 lasprat=102 pasprat=106 loasc=172 lodes=169 dides=110))
((EB\ Garamond Medium) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=215 lvw=24 lhw=8 uvw=28 uhw=10 fillp=35 vcnt=34 lasprat=107 pasprat=100 loasc=168 lodes=168 dides=110))
((EB\ Garamond Medium\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=70 em=235 lvw=21 lhw=8 uvw=25 uhw=8 fillp=30 vcnt=33 lasprat=105 pasprat=110 loasc=170 lodes=168 dides=110))
((EB\ Garamond Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=220 lvw=20 lhw=7 uvw=23 uhw=10 fillp=30 vcnt=28 lasprat=107 pasprat=99 loasc=173 lodes=170 dides=110))
((EB\ Garamond SemiBold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=217 lvw=28 lhw=10 uvw=34 uhw=11 fillp=40 vcnt=39 lasprat=111 pasprat=104 loasc=168 lodes=168 dides=111))
((EB\ Garamond SemiBold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=71 em=232 lvw=26 lhw=9 uvw=29 uhw=8 fillp=34 vcnt=37 lasprat=109 pasprat=113 loasc=167 lodes=169 dides=109))
((EB\ Garamond\ 12 Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=69 em=242 lvw=14 lhw=7 uvw=18 uhw=8 fillp=25 vcnt=27 lasprat=100 pasprat=102 loasc=171 lodes=169 dides=150))
((EB\ Garamond\ 12 Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=220 lvw=20 lhw=7 uvw=23 uhw=10 fillp=30 vcnt=28 lasprat=107 pasprat=99 loasc=173 lodes=170 dides=147))
((EB\ Garamond\ Initials Regular) ())
((Ebrima Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=146 dides=102))
((Ebrima Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=148 lodes=146 dides=102))
((Elvifrance Regular) (mono=no sans=yes italic=no case=caps regular=yes ex=152 em=100 lvw=17 lhw=17 uvw=17 uhw=17 fillp=46 vcnt=68 lasprat=81 pasprat=76 loasc=106 lodes=100 dides=101))
((Erewhon Bold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=185 lvw=32 lhw=8 uvw=34 uhw=8 fillp=48 vcnt=46 lasprat=109 pasprat=103 loasc=151 lodes=148 dides=102))
((Erewhon Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=79 em=182 lvw=30 lhw=8 uvw=32 uhw=8 fillp=41 vcnt=46 lasprat=104 pasprat=107 loasc=148 lodes=148 dides=102))
((Erewhon Italic) (Ascii Latin Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=79 em=182 lvw=20 lhw=7 uvw=21 uhw=7 fillp=30 vcnt=32 lasprat=100 pasprat=98 loasc=148 lodes=148 dides=102))
((Erewhon Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=192 lvw=20 lhw=7 uvw=22 uhw=7 fillp=34 vcnt=32 lasprat=104 pasprat=97 loasc=150 lodes=149 dides=102))
((Erewhon\ Math Regular) (Ascii Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=192 lvw=20 lhw=7 uvw=22 uhw=7 fillp=34 vcnt=32 lasprat=104 pasprat=97 loasc=150 lodes=149 dides=102))
((Essays1743 Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=160 lvw=25 lhw=21 uvw=39 uhw=23 fillp=54 vcnt=62 lasprat=89 pasprat=86 loasc=160 lodes=147 dides=155))
((Essays1743 BoldItalic) (Ascii Latin mono=no sans=no slant=38 italic=yes case=mixed regular=no ex=83 em=186 lvw=24 lhw=22 uvw=27 uhw=15 fillp=47 vcnt=56 lasprat=90 pasprat=106 loasc=151 lodes=157 dides=167))
((Essays1743 Italic) (Ascii Latin mono=no sans=no slant=36 italic=yes case=mixed regular=no ex=75 em=200 lvw=16 lhw=14 uvw=25 uhw=10 fillp=36 vcnt=41 lasprat=90 pasprat=106 loasc=166 lodes=158 dides=168))
((Essays1743 Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=175 lvw=20 lhw=12 uvw=33 uhw=17 fillp=41 vcnt=45 lasprat=88 pasprat=85 loasc=163 lodes=153 dides=163))
((Estrangelo\ Edessa Regular) (slant=0))
((ETbb Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=225 lvw=26 lhw=13 uvw=31 uhw=13 fillp=41 vcnt=41 lasprat=110 pasprat=105 loasc=176 lodes=166 dides=105))
((ETbb BoldItalic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=75 em=209 lvw=20 lhw=21 uvw=25 uhw=8 fillp=32 vcnt=35 lasprat=98 pasprat=95 loasc=176 lodes=164 dides=105))
((ETbb Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=208 lvw=16 lhw=17 uvw=21 uhw=6 fillp=28 vcnt=30 lasprat=96 pasprat=92 loasc=180 lodes=164 dides=105))
((ETbb Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=219 lvw=20 lhw=8 uvw=26 uhw=8 fillp=33 vcnt=33 lasprat=110 pasprat=103 loasc=176 lodes=166 dides=105))
((Euphemia\ UCAS Bold) (Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=164 lvw=24 lhw=15 uvw=26 uhw=20 fillp=49 vcnt=57 lasprat=103 pasprat=87 loasc=144 lodes=142 dides=102))
((Euphemia\ UCAS Italic) (Latin mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=89 em=144 lvw=15 lhw=11 uvw=16 uhw=13 fillp=30 vcnt=36 lasprat=93 pasprat=89 loasc=148 lodes=141 dides=102))
((Euphemia\ UCAS Regular) (Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=144 lvw=14 lhw=11 uvw=15 uhw=13 fillp=37 vcnt=41 lasprat=93 pasprat=78 loasc=144 lodes=141 dides=102))
((EvilClown Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=48 em=112 lvw=50 lhw=95 uvw=31 uhw=97 fillp=21 vcnt=28 lasprat=53 pasprat=51 loasc=202 lodes=189 dides=189))
((Fandol\ Braille\ Display Regular) (Ascii mono=yes sans=no slant=0 italic=no case=caps regular=yes ex=124 em=89 lvw=1 lhw=1 uvw=1 uhw=1 fillp=18 vcnt=16 lasprat=89 pasprat=52 loasc=100 lodes=120 dides=120))
((Fandol\ Braille\ Regular Regular) (Ascii mono=yes sans=no slant=35 italic=no case=caps regular=no ex=124 em=89 lvw=16 lhw=16 uvw=16 uhw=16 fillp=18 vcnt=11 lasprat=89 pasprat=50 loasc=100 lodes=119 dides=100))
((FandolFang Regular) (Ascii Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=196 lvw=15 lhw=12 uvw=16 uhw=14 fillp=34 vcnt=31 lasprat=106 pasprat=93 loasc=151 lodes=142 dides=102))
((FandolFang\ R Regular) (Ascii Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=196 lvw=16 lhw=12 uvw=16 uhw=14 fillp=34 vcnt=31 lasprat=106 pasprat=95 loasc=151 lodes=144 dides=102))
((FandolHei Bold) (Ascii Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=24 lhw=15 uvw=25 uhw=15 fillp=50 vcnt=43 lasprat=91 pasprat=76 loasc=149 lodes=137 dides=103))
((FandolHei Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=14 uvw=20 uhw=14 fillp=39 vcnt=31 lasprat=103 pasprat=82 loasc=164 lodes=145 dides=105))
((FandolKai Regular) (Ascii Greek Cyrillic CJK mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=74 em=218 lvw=18 lhw=5 uvw=22 uhw=6 fillp=28 vcnt=25 lasprat=113 pasprat=99 loasc=159 lodes=145 dides=143))
((FandolSong Bold) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=213 lvw=28 lhw=9 uvw=35 uhw=9 fillp=42 vcnt=40 lasprat=110 pasprat=101 loasc=158 lodes=144 dides=102))
((FandolSong Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=5 uvw=25 uhw=5 fillp=28 vcnt=26 lasprat=113 pasprat=101 loasc=163 lodes=147 dides=105))
((FangSong_GB2312 Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=13 lhw=4 uvw=16 uhw=7 fillp=31 vcnt=32 lasprat=103 pasprat=76 loasc=149 lodes=125 dides=100))
((Farah Regular) ())
((Farah\ PUA Regular) ())
((Farisi Regular) (slant=0))
((Fava Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=157 lvw=42 lhw=30 uvw=45 uhw=32 fillp=74 vcnt=85 lasprat=98 pasprat=95 loasc=134 lodes=133 dides=103))
((Fbb Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=218 lvw=26 lhw=8 uvw=30 uhw=10 fillp=38 vcnt=38 lasprat=117 pasprat=107 loasc=178 lodes=169 dides=102))
((Fbb Bold\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=75 em=208 lvw=24 lhw=86 uvw=29 uhw=10 fillp=35 vcnt=39 lasprat=102 pasprat=102 loasc=180 lodes=170 dides=108))
((Fbb Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=73 em=209 lvw=16 lhw=16 uvw=21 uhw=4 fillp=26 vcnt=27 lasprat=99 pasprat=96 loasc=183 lodes=171 dides=104))
((Fbb Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=215 lvw=17 lhw=5 uvw=23 uhw=8 fillp=30 vcnt=29 lasprat=110 pasprat=100 loasc=183 lodes=171 dides=105))
((FdSymbol Bold) (MathSymbols slant=0))
((FdSymbol Book) (MathSymbols slant=0))
((FdSymbol Medium) (MathSymbols slant=0))
((FdSymbol Regular) (MathSymbols slant=0))
((Fedorovsk\ Unicode Medium) (Ascii Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=195 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=107 pasprat=99 loasc=163 lodes=152 dides=168))
((Fedorovsk\ Unicode\ TT Medium) (Ascii Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=195 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=107 pasprat=99 loasc=163 lodes=152 dides=168))
((Fira\ Math Regular) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=147 lvw=18 lhw=13 uvw=19 uhw=14 fillp=43 vcnt=38 lasprat=96 pasprat=77 loasc=147 lodes=140 dides=104))
((Fira\ Mono Bold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=30 lhw=21 uvw=31 uhw=22 fillp=58 vcnt=56 lasprat=112 pasprat=92 loasc=152 lodes=141 dides=105))
((Fira\ Mono BoldOblique) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=18 italic=no case=mixed regular=yes ex=88 em=113 lvw=30 lhw=22 uvw=31 uhw=22 fillp=50 vcnt=56 lasprat=113 pasprat=106 loasc=153 lodes=142 dides=105))
((Fira\ Mono Medium) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=22 lhw=15 uvw=22 uhw=17 fillp=46 vcnt=42 lasprat=113 pasprat=87 loasc=148 lodes=140 dides=105))
((Fira\ Mono Oblique) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=18 italic=no case=mixed regular=yes ex=88 em=113 lvw=18 lhw=13 uvw=17 uhw=13 fillp=33 vcnt=33 lasprat=113 pasprat=95 loasc=146 lodes=139 dides=104))
((Fira\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=17 lhw=13 uvw=17 uhw=13 fillp=38 vcnt=33 lasprat=113 pasprat=83 loasc=146 lodes=139 dides=104))
((Fira\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=147 lvw=31 lhw=21 uvw=31 uhw=22 fillp=60 vcnt=61 lasprat=97 pasprat=87 loasc=152 lodes=141 dides=105))
((Fira\ Sans Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=89 em=144 lvw=29 lhw=22 uvw=30 uhw=22 fillp=53 vcnt=61 lasprat=95 pasprat=95 loasc=152 lodes=141 dides=105))
((Fira\ Sans Book) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=146 lvw=17 lhw=12 uvw=17 uhw=13 fillp=41 vcnt=35 lasprat=95 pasprat=76 loasc=147 lodes=139 dides=104))
((Fira\ Sans Book\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=88 em=146 lvw=17 lhw=12 uvw=17 uhw=13 fillp=35 vcnt=35 lasprat=95 pasprat=84 loasc=147 lodes=140 dides=104))
((Fira\ Sans ExtraBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=148 lvw=34 lhw=24 uvw=35 uhw=24 fillp=63 vcnt=67 lasprat=97 pasprat=90 loasc=153 lodes=142 dides=106))
((Fira\ Sans ExtraBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=89 em=144 lvw=33 lhw=24 uvw=35 uhw=25 fillp=57 vcnt=67 lasprat=96 pasprat=98 loasc=153 lodes=142 dides=106))
((Fira\ Sans ExtraLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=147 lvw=9 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=20 lasprat=94 pasprat=71 loasc=142 lodes=139 dides=103))
((Fira\ Sans ExtraLight\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=87 em=147 lvw=9 lhw=8 uvw=9 uhw=8 fillp=22 vcnt=20 lasprat=94 pasprat=80 loasc=142 lodes=139 dides=103))
((Fira\ Sans Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=148 lvw=38 lhw=26 uvw=40 uhw=26 fillp=67 vcnt=73 lasprat=98 pasprat=94 loasc=156 lodes=142 dides=106))
((Fira\ Sans Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=89 em=146 lvw=37 lhw=26 uvw=39 uhw=28 fillp=61 vcnt=73 lasprat=96 pasprat=101 loasc=156 lodes=142 dides=106))
((Fira\ Sans Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=88 em=146 lvw=18 lhw=13 uvw=19 uhw=14 fillp=38 vcnt=38 lasprat=95 pasprat=86 loasc=147 lodes=140 dides=104))
((Fira\ Sans Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=147 lvw=11 lhw=9 uvw=12 uhw=10 fillp=31 vcnt=25 lasprat=94 pasprat=72 loasc=143 lodes=140 dides=104))
((Fira\ Sans Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=87 em=147 lvw=11 lhw=9 uvw=11 uhw=10 fillp=26 vcnt=25 lasprat=95 pasprat=82 loasc=143 lodes=140 dides=104))
((Fira\ Sans Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=147 lvw=26 lhw=18 uvw=26 uhw=19 fillp=53 vcnt=50 lasprat=97 pasprat=83 loasc=151 lodes=140 dides=105))
((Fira\ Sans Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=88 em=146 lvw=23 lhw=18 uvw=26 uhw=19 fillp=47 vcnt=51 lasprat=96 pasprat=91 loasc=151 lodes=142 dides=105))
((Fira\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=147 lvw=18 lhw=13 uvw=19 uhw=14 fillp=43 vcnt=38 lasprat=96 pasprat=77 loasc=147 lodes=140 dides=104))
((Fira\ Sans SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=148 lvw=28 lhw=20 uvw=29 uhw=20 fillp=56 vcnt=55 lasprat=97 pasprat=86 loasc=152 lodes=142 dides=105))
((Fira\ Sans SemiBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=88 em=146 lvw=27 lhw=20 uvw=28 uhw=21 fillp=50 vcnt=55 lasprat=96 pasprat=94 loasc=152 lodes=142 dides=105))
((Fira\ Sans Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=145 lvw=4 lhw=4 uvw=4 uhw=4 fillp=15 vcnt=10 lasprat=92 pasprat=67 loasc=141 lodes=137 dides=103))
((Fira\ Sans Thin\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=87 em=145 lvw=3 lhw=4 uvw=4 uhw=4 fillp=11 vcnt=10 lasprat=93 pasprat=76 loasc=141 lodes=137 dides=103))
((Fira\ Sans UltraLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=147 lvw=6 lhw=5 uvw=6 uhw=5 fillp=21 vcnt=16 lasprat=93 pasprat=69 loasc=141 lodes=137 dides=103))
((Fira\ Sans UltraLight\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=87 em=147 lvw=6 lhw=5 uvw=6 uhw=5 fillp=17 vcnt=15 lasprat=93 pasprat=77 loasc=141 lodes=137 dides=103))
((Foglihten Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=193 lvw=16 lhw=6 uvw=18 uhw=6 fillp=25 vcnt=27 lasprat=109 pasprat=101 loasc=163 lodes=153 dides=103))
((FoglihtenBlackPcs BlackPcs) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=caps regular=yes ex=76 em=232 lvw=61 lhw=2 uvw=61 uhw=2 fillp=52 vcnt=42 lasprat=171 pasprat=164 loasc=109 lodes=148 dides=101))
((FoglihtenBPS01 Regular) (Ascii mono=no sans=yes slant=18 italic=no case=caps regular=no ex=57 em=82 lvw=66 lhw=66 uvw=66 uhw=66 fillp=75 vcnt=27 lasprat=100 pasprat=84 loasc=159 lodes=126 dides=100))
((FoglihtenFr01 Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=118 em=57 lvw=0 lhw=2 uvw=14 uhw=4 fillp=21 vcnt=24 lasprat=71 pasprat=72 loasc=100 lodes=110 dides=100))
((FoglihtenFr02 Regular) (slant=0 italic=no regular=yes))
((FoglihtenNo01 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=76 em=150 lvw=5 lhw=5 uvw=5 uhw=5 fillp=22 vcnt=18 lasprat=111 pasprat=102 loasc=109 lodes=142 dides=103))
((FoglihtenNo03 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=89 em=139 lvw=2 lhw=3 uvw=2 uhw=3 fillp=17 vcnt=14 lasprat=104 pasprat=96 loasc=110 lodes=128 dides=100))
((FoglihtenNo04 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=77 em=189 lvw=16 lhw=5 uvw=18 uhw=5 fillp=16 vcnt=22 lasprat=108 pasprat=155 loasc=198 lodes=170 dides=140))
((FoglihtenNo06 Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=caps regular=yes ex=120 em=125 lvw=12 lhw=2 uvw=12 uhw=2 fillp=22 vcnt=27 lasprat=87 pasprat=84 loasc=108 lodes=133 dides=100))
((FoglihtenPCS Petitecaps) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=77 em=193 lvw=15 lhw=6 uvw=18 uhw=6 fillp=25 vcnt=25 lasprat=111 pasprat=103 loasc=109 lodes=141 dides=103))
((Font\ Awesome\ 5\ Brands\ Regular Regular) (mono=no sans=yes italic=no case=mixed regular=yes ex=102 em=139 lvw=13 lhw=10 uvw=13 uhw=11 fillp=38 vcnt=32 lasprat=85 pasprat=70 loasc=139 lodes=119 dides=100))
((Font\ Awesome\ 5\ Free\ Regular Regular) (mono=no sans=yes italic=no case=mixed regular=yes ex=102 em=139 lvw=13 lhw=10 uvw=13 uhw=11 fillp=38 vcnt=32 lasprat=85 pasprat=70 loasc=139 lodes=119 dides=100))
((Font\ Awesome\ 5\ Free\ Solid Solid) (mono=no sans=yes italic=no case=mixed regular=yes ex=102 em=139 lvw=13 lhw=10 uvw=13 uhw=11 fillp=38 vcnt=32 lasprat=85 pasprat=70 loasc=139 lodes=119 dides=100))
((Font-mfizz mfizz) ())
((FontAwesome Regular) ())
((Forgotten\ Futurist Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=120 lvw=23 lhw=23 uvw=24 uhw=24 fillp=62 vcnt=56 lasprat=86 pasprat=73 loasc=136 lodes=131 dides=100))
((Forgotten\ Futurist Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=86 em=120 lvw=27 lhw=23 uvw=25 uhw=24 fillp=50 vcnt=56 lasprat=86 pasprat=88 loasc=136 lodes=131 dides=100))
((Forgotten\ Futurist Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=86 em=119 lvw=15 lhw=15 uvw=16 uhw=15 fillp=35 vcnt=38 lasprat=86 pasprat=84 loasc=136 lodes=131 dides=100))
((Forgotten\ Futurist Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=119 lvw=15 lhw=15 uvw=15 uhw=15 fillp=45 vcnt=38 lasprat=86 pasprat=70 loasc=136 lodes=131 dides=100))
((Forgotten\ Futurist Shadow) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=128 lvw=3 lhw=10 uvw=3 uhw=10 fillp=33 vcnt=33 lasprat=95 pasprat=82 loasc=135 lodes=140 dides=110))
((Forum Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=197 lvw=21 lhw=14 uvw=22 uhw=8 fillp=38 vcnt=33 lasprat=118 pasprat=101 loasc=160 lodes=154 dides=102))
((Foulis\ Greek Regular) (Ascii Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=218 lvw=18 lhw=7 uvw=23 uhw=8 fillp=31 vcnt=28 lasprat=105 pasprat=97 loasc=175 lodes=165 dides=104))
((FourierOrns Bold) (sans=no))
((FourierOrns BoldItalic) (sans=no))
((FourierOrns Italic) (sans=no))
((FourierOrns Regular) (sans=no))
((Franklin\ Gothic Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=82 em=162 lvw=23 lhw=18 uvw=25 uhw=19 fillp=45 vcnt=46 lasprat=96 pasprat=93 loasc=140 lodes=137 dides=102))
((Franklin\ Gothic Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=163 lvw=24 lhw=18 uvw=26 uhw=19 fillp=53 vcnt=46 lasprat=96 pasprat=82 loasc=139 lodes=136 dides=102))
((Frederika2016 Normal) (Greek slant=56))
((FreeMono Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=21 uhw=21 fillp=50 vcnt=47 lasprat=136 pasprat=121 loasc=143 lodes=145 dides=102))
((FreeMono Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=22 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=47 vcnt=43 lasprat=136 pasprat=128 loasc=143 lodes=145 dides=102))
((FreeMono BoldOblique) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=46 vcnt=43 lasprat=136 pasprat=128 loasc=143 lodes=145 dides=102))
((FreeMono Medium) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=8 uhw=10 fillp=25 vcnt=23 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((FreeMono Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=22 vcnt=20 lasprat=142 pasprat=120 loasc=150 lodes=144 dides=102))
((FreeMono Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=8 uhw=10 fillp=25 vcnt=18 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((FreeSans Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=152 lvw=25 lhw=20 uvw=27 uhw=24 fillp=57 vcnt=64 lasprat=98 pasprat=84 loasc=134 lodes=139 dides=104))
((FreeSans Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=152 lvw=26 lhw=20 uvw=27 uhw=24 fillp=48 vcnt=55 lasprat=98 pasprat=98 loasc=134 lodes=139 dides=104))
((FreeSans BoldOblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=91 em=152 lvw=26 lhw=20 uvw=27 uhw=24 fillp=47 vcnt=54 lasprat=98 pasprat=98 loasc=134 lodes=139 dides=104))
((FreeSans Medium) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=159 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=93 pasprat=77 loasc=139 lodes=140 dides=104))
((FreeSans Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=18 uhw=15 fillp=33 vcnt=38 lasprat=93 pasprat=92 loasc=139 lodes=140 dides=103))
((FreeSans Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=159 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=39 lasprat=93 pasprat=77 loasc=139 lodes=140 dides=104))
((FreeSerif Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=6 fillp=45 vcnt=47 lasprat=106 pasprat=98 loasc=150 lodes=144 dides=102))
((FreeSerif Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=78 em=192 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=98 pasprat=99 loasc=150 lodes=143 dides=102))
((FreeSerif BoldItalic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=78 em=192 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=98 pasprat=99 loasc=150 lodes=143 dides=102))
((FreeSerif Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=186 lvw=18 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=100 pasprat=98 loasc=155 lodes=147 dides=104))
((FreeSerif Medium) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=194 lvw=19 lhw=6 uvw=25 uhw=7 fillp=33 vcnt=34 lasprat=101 pasprat=93 loasc=151 lodes=147 dides=105))
((FreeSerif Regular) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=194 lvw=19 lhw=6 uvw=25 uhw=7 fillp=33 vcnt=32 lasprat=101 pasprat=93 loasc=151 lodes=147 dides=105))
((FreeSerifb Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=6 fillp=45 vcnt=44 lasprat=105 pasprat=98 loasc=149 lodes=145 dides=103))
((FreeSerifb BoldItalic) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=193 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=145 dides=103))
((FreeSerifb Italic) (Ascii Latin mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=186 lvw=18 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=100 pasprat=98 loasc=155 lodes=147 dides=104))
((FreeSerifb Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((FreeSerifb SmallCaps) (mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=81 em=182 lvw=19 lhw=4 uvw=23 uhw=7 fillp=33 vcnt=30 lasprat=102 pasprat=95 loasc=103 lodes=127 dides=141))
((FreeSerifb SmallCapsAlt) (mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=81 em=182 lvw=19 lhw=4 uvw=23 uhw=7 fillp=33 vcnt=30 lasprat=102 pasprat=95 loasc=103 lodes=127 dides=141))
((Futura Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=201 lvw=37 lhw=31 uvw=39 uhw=37 fillp=63 vcnt=64 lasprat=119 pasprat=105 loasc=163 lodes=150 dides=104))
((Futura Condensed\ ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=164 lvw=37 lhw=27 uvw=39 uhw=34 fillp=72 vcnt=85 lasprat=95 pasprat=85 loasc=161 lodes=145 dides=100))
((Futura Condensed\ Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=113 lvw=20 lhw=16 uvw=20 uhw=17 fillp=56 vcnt=63 lasprat=70 pasprat=57 loasc=166 lodes=141 dides=101))
((Futura Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=203 lvw=24 lhw=21 uvw=24 uhw=22 fillp=49 vcnt=53 lasprat=107 pasprat=89 loasc=177 lodes=154 dides=105))
((Futura Medium\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=77 em=210 lvw=23 lhw=18 uvw=23 uhw=23 fillp=41 vcnt=46 lasprat=110 pasprat=98 loasc=179 lodes=157 dides=106))
((Gabriola Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=60 em=180 lvw=15 lhw=10 uvw=20 uhw=8 fillp=28 vcnt=25 lasprat=97 pasprat=98 loasc=185 lodes=171 dides=150))
((Gadugi Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Gadugi Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Galberik Regular) (Ascii Latin mono=no sans=no slant=10 italic=yes case=mixed regular=no ex=70 em=244 lvw=18 lhw=4 uvw=18 uhw=4 fillp=20 vcnt=20 lasprat=136 pasprat=163 loasc=174 lodes=177 dides=128))
((Garamond Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=221 lvw=28 lhw=7 uvw=39 uhw=11 fillp=40 vcnt=37 lasprat=116 pasprat=108 loasc=156 lodes=160 dides=104))
((Garamond Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=37 italic=yes case=mixed regular=yes ex=67 em=213 lvw=26 lhw=7 uvw=32 uhw=8 fillp=36 vcnt=37 lasprat=113 pasprat=120 loasc=159 lodes=162 dides=102))
((Garamond Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=67 em=204 lvw=13 lhw=5 uvw=17 uhw=5 fillp=22 vcnt=23 lasprat=91 pasprat=103 loasc=165 lodes=165 dides=102))
((Garamond Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=213 lvw=20 lhw=4 uvw=23 uhw=4 fillp=26 vcnt=24 lasprat=112 pasprat=104 loasc=169 lodes=167 dides=104))
((Garamond\ Libre Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=235 lvw=26 lhw=10 uvw=33 uhw=11 fillp=40 vcnt=38 lasprat=119 pasprat=103 loasc=175 lodes=155 dides=107))
((Garamond\ Libre Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=75 em=180 lvw=17 lhw=9 uvw=22 uhw=9 fillp=28 vcnt=31 lasprat=96 pasprat=97 loasc=170 lodes=153 dides=106))
((Garamond\ Libre Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=221 lvw=20 lhw=8 uvw=24 uhw=10 fillp=32 vcnt=31 lasprat=112 pasprat=101 loasc=173 lodes=157 dides=107))
((Garamond-Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=220 lvw=20 lhw=7 uvw=23 uhw=10 fillp=30 vcnt=28 lasprat=107 pasprat=99 loasc=173 lodes=172 dides=110))
((Gargi Medium) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=160 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=94 pasprat=78 loasc=139 lodes=142 dides=104))
((Garineldo Regular) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=64 em=170 lvw=7 lhw=4 uvw=7 uhw=4 fillp=15 vcnt=14 lasprat=88 pasprat=85 loasc=164 lodes=173 dides=101))
((GarineldoNo01 Regular) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=no ex=64 em=157 lvw=7 lhw=4 uvw=7 uhw=4 fillp=14 vcnt=13 lasprat=86 pasprat=98 loasc=164 lodes=173 dides=101))
((GarineldoNo02 Regular) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=no ex=64 em=157 lvw=7 lhw=4 uvw=7 uhw=4 fillp=14 vcnt=13 lasprat=86 pasprat=101 loasc=164 lodes=193 dides=101))
((Garuda Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=165 lvw=20 lhw=16 uvw=22 uhw=19 fillp=52 vcnt=56 lasprat=93 pasprat=75 loasc=137 lodes=143 dides=102))
((Garuda BoldOblique) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=87 em=165 lvw=20 lhw=17 uvw=22 uhw=19 fillp=41 vcnt=47 lasprat=93 pasprat=90 loasc=137 lodes=143 dides=102))
((Garuda Book) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=45 lasprat=93 pasprat=79 loasc=140 lodes=140 dides=102))
((Garuda Oblique) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=13 uvw=18 uhw=16 fillp=34 vcnt=38 lasprat=93 pasprat=94 loasc=140 lodes=140 dides=102))
((Garuda Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=39 lasprat=93 pasprat=79 loasc=139 lodes=140 dides=102))
((Gatometrix Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=80 em=130 lvw=12 lhw=10 uvw=12 uhw=10 fillp=37 vcnt=29 lasprat=82 pasprat=68 loasc=102 lodes=122 dides=101))
((Gautami Regular) (slant=0))
((Gears\ of\ Peace Regular) (mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=122 em=146 lvw=13 lhw=13 uvw=27 uhw=27 fillp=57 vcnt=76 lasprat=62 pasprat=58 loasc=100 lodes=100 dides=100))
((Geeza\ Pro Bold) ())
((Geeza\ Pro Regular) ())
((Geeza\ Pro\ Interface Bold) ())
((Geeza\ Pro\ Interface Light) ())
((Geeza\ Pro\ Interface Regular) ())
((Geeza\ Pro\ PUA Bold) ())
((Geeza\ Pro\ PUA Regular) ())
((Geeza\ PUA Bold) ())
((Geeza\ PUA Regular) ())
((Gentium Italic) (Ascii Latin Greek mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=76 em=161 lvw=15 lhw=14 uvw=15 uhw=14 fillp=30 vcnt=30 lasprat=92 pasprat=89 loasc=163 lodes=153 dides=105))
((Gentium Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=176 lvw=15 lhw=11 uvw=17 uhw=13 fillp=32 vcnt=32 lasprat=103 pasprat=94 loasc=165 lodes=153 dides=105))
((Gentium\ Basic Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=185 lvw=27 lhw=13 uvw=27 uhw=14 fillp=43 vcnt=44 lasprat=109 pasprat=104 loasc=167 lodes=152 dides=105))
((Gentium\ Basic Bold\ Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=76 em=172 lvw=25 lhw=18 uvw=26 uhw=15 fillp=40 vcnt=41 lasprat=99 pasprat=99 loasc=163 lodes=153 dides=105))
((Gentium\ Basic Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=76 em=161 lvw=15 lhw=14 uvw=15 uhw=14 fillp=29 vcnt=30 lasprat=92 pasprat=89 loasc=163 lodes=153 dides=105))
((Gentium\ Basic Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=177 lvw=17 lhw=11 uvw=17 uhw=13 fillp=32 vcnt=32 lasprat=103 pasprat=94 loasc=165 lodes=153 dides=105))
((Gentium\ Book\ Basic Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=189 lvw=30 lhw=14 uvw=30 uhw=15 fillp=46 vcnt=47 lasprat=111 pasprat=107 loasc=165 lodes=152 dides=105))
((Gentium\ Book\ Basic Bold\ Italic) (Ascii Latin mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=76 em=176 lvw=28 lhw=23 uvw=28 uhw=15 fillp=43 vcnt=44 lasprat=101 pasprat=103 loasc=163 lodes=153 dides=105))
((Gentium\ Book\ Basic Italic) (Ascii Latin mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=77 em=163 lvw=18 lhw=14 uvw=19 uhw=15 fillp=34 vcnt=34 lasprat=93 pasprat=91 loasc=161 lodes=153 dides=105))
((Gentium\ Book\ Basic Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=180 lvw=19 lhw=11 uvw=19 uhw=13 fillp=36 vcnt=36 lasprat=105 pasprat=98 loasc=165 lodes=153 dides=105))
((Gentium\ Plus Italic) (Ascii Latin mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=76 em=161 lvw=15 lhw=13 uvw=15 uhw=14 fillp=30 vcnt=29 lasprat=92 pasprat=88 loasc=161 lodes=153 dides=103))
((Gentium\ Plus Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=176 lvw=15 lhw=11 uvw=15 uhw=13 fillp=32 vcnt=30 lasprat=102 pasprat=94 loasc=165 lodes=153 dides=103))
((Gentium\ Plus\ Compact Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=76 em=161 lvw=15 lhw=14 uvw=17 uhw=14 fillp=30 vcnt=30 lasprat=92 pasprat=89 loasc=163 lodes=153 dides=105))
((Gentium\ Plus\ Compact Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=177 lvw=15 lhw=10 uvw=15 uhw=13 fillp=32 vcnt=30 lasprat=102 pasprat=95 loasc=165 lodes=153 dides=105))
((GentiumAlt Italic) (Ascii Latin Greek mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=76 em=161 lvw=15 lhw=14 uvw=15 uhw=14 fillp=30 vcnt=30 lasprat=92 pasprat=89 loasc=163 lodes=153 dides=105))
((GentiumAlt Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=176 lvw=15 lhw=11 uvw=17 uhw=13 fillp=32 vcnt=32 lasprat=103 pasprat=94 loasc=165 lodes=153 dides=105))
((Georgia Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=211 lvw=37 lhw=7 uvw=40 uhw=9 fillp=46 vcnt=50 lasprat=120 pasprat=116 loasc=156 lodes=144 dides=138))
((Georgia Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=82 em=210 lvw=35 lhw=8 uvw=39 uhw=9 fillp=42 vcnt=46 lasprat=122 pasprat=121 loasc=153 lodes=143 dides=137))
((Georgia Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=82 em=189 lvw=20 lhw=7 uvw=23 uhw=8 fillp=31 vcnt=34 lasprat=104 pasprat=101 loasc=153 lodes=143 dides=136))
((Georgia Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=193 lvw=21 lhw=7 uvw=25 uhw=8 fillp=35 vcnt=38 lasprat=104 pasprat=98 loasc=157 lodes=145 dides=137))
((GFS\ Artemisia Bold) (Ascii Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=200 lvw=30 lhw=6 uvw=34 uhw=9 fillp=40 vcnt=40 lasprat=113 pasprat=105 loasc=145 lodes=148 dides=104))
((GFS\ Artemisia Bold\ Italic) (Ascii Greek mono=no sans=no slant=20 italic=no case=mixed regular=yes ex=79 em=212 lvw=30 lhw=6 uvw=35 uhw=10 fillp=36 vcnt=40 lasprat=117 pasprat=118 loasc=150 lodes=149 dides=105))
((GFS\ Artemisia Italic) (Ascii Latin Greek mono=no sans=no slant=21 italic=no case=mixed regular=yes ex=80 em=196 lvw=20 lhw=5 uvw=25 uhw=7 fillp=28 vcnt=31 lasprat=103 pasprat=104 loasc=147 lodes=148 dides=105))
((GFS\ Artemisia Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=186 lvw=19 lhw=6 uvw=24 uhw=7 fillp=31 vcnt=31 lasprat=101 pasprat=93 loasc=146 lodes=148 dides=106))
((GFS\ Baskerville Regular) (Greek slant=0))
((GFS\ Bodoni Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=206 lvw=25 lhw=7 uvw=27 uhw=7 fillp=36 vcnt=36 lasprat=110 pasprat=101 loasc=148 lodes=155 dides=106))
((GFS\ Bodoni Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=86 em=183 lvw=23 lhw=6 uvw=25 uhw=6 fillp=32 vcnt=37 lasprat=111 pasprat=108 loasc=139 lodes=152 dides=105))
((GFS\ Bodoni Italic) (Ascii Latin Greek mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=83 em=192 lvw=16 lhw=4 uvw=20 uhw=6 fillp=26 vcnt=29 lasprat=110 pasprat=106 loasc=145 lodes=153 dides=107))
((GFS\ Bodoni Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=196 lvw=18 lhw=5 uvw=21 uhw=6 fillp=28 vcnt=27 lasprat=116 pasprat=104 loasc=150 lodes=155 dides=107))
((GFS\ Complutum Regular) (Greek slant=0))
((GFS\ Didot Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=207 lvw=28 lhw=11 uvw=32 uhw=9 fillp=41 vcnt=39 lasprat=114 pasprat=106 loasc=153 lodes=158 dides=105))
((GFS\ Didot Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=78 em=194 lvw=24 lhw=11 uvw=29 uhw=7 fillp=35 vcnt=38 lasprat=109 pasprat=102 loasc=151 lodes=157 dides=103))
((GFS\ Didot Italic) (Ascii Latin Greek mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=78 em=197 lvw=15 lhw=8 uvw=23 uhw=7 fillp=28 vcnt=30 lasprat=94 pasprat=89 loasc=152 lodes=158 dides=105))
((GFS\ Didot Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=197 lvw=19 lhw=7 uvw=24 uhw=7 fillp=32 vcnt=31 lasprat=109 pasprat=100 loasc=153 lodes=159 dides=102))
((GFS\ DidotClassic Regular) (Greek slant=0))
((GFS\ Neohellenic Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=226 lvw=23 lhw=24 uvw=35 uhw=32 fillp=52 vcnt=42 lasprat=108 pasprat=92 loasc=163 lodes=158 dides=106))
((GFS\ Neohellenic Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=65 em=233 lvw=24 lhw=24 uvw=35 uhw=33 fillp=45 vcnt=42 lasprat=112 pasprat=110 loasc=164 lodes=158 dides=107))
((GFS\ Neohellenic Italic) (Ascii Latin Greek mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=65 em=200 lvw=16 lhw=13 uvw=18 uhw=16 fillp=30 vcnt=27 lasprat=105 pasprat=103 loasc=164 lodes=160 dides=107))
((GFS\ Neohellenic Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=65 em=203 lvw=15 lhw=13 uvw=18 uhw=16 fillp=36 vcnt=27 lasprat=103 pasprat=86 loasc=158 lodes=156 dides=107))
((GFS\ Neohellenic\ Math Regular) (Ascii Latin Greek MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=171 lvw=14 lhw=13 uvw=17 uhw=16 fillp=36 vcnt=28 lasprat=101 pasprat=83 loasc=152 lodes=159 dides=102))
((GFS\ Olga Regular) (slant=21))
((GFS\ Porson Regular) (Greek slant=0))
((GFS\ Solomos Regular) (Greek slant=30))
((Gill\ Sans Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=192 lvw=37 lhw=26 uvw=40 uhw=34 fillp=63 vcnt=66 lasprat=115 pasprat=102 loasc=138 lodes=146 dides=102))
((Gill\ Sans Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=15 italic=yes case=mixed regular=yes ex=83 em=207 lvw=33 lhw=27 uvw=36 uhw=30 fillp=54 vcnt=59 lasprat=107 pasprat=102 loasc=138 lodes=146 dides=101))
((Gill\ Sans Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=16 italic=yes case=mixed regular=yes ex=75 em=181 lvw=20 lhw=14 uvw=20 uhw=18 fillp=37 vcnt=39 lasprat=91 pasprat=87 loasc=154 lodes=150 dides=102))
((Gill\ Sans Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=173 lvw=10 lhw=10 uvw=13 uhw=10 fillp=29 vcnt=26 lasprat=96 pasprat=82 loasc=153 lodes=150 dides=102))
((Gill\ Sans Light\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=15 italic=yes case=mixed regular=yes ex=75 em=178 lvw=10 lhw=9 uvw=12 uhw=10 fillp=22 vcnt=23 lasprat=90 pasprat=85 loasc=153 lodes=150 dides=101))
((Gill\ Sans Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=173 lvw=20 lhw=17 uvw=22 uhw=21 fillp=45 vcnt=44 lasprat=99 pasprat=85 loasc=154 lodes=150 dides=102))
((Gill\ Sans SemiBold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=180 lvw=27 lhw=18 uvw=29 uhw=24 fillp=52 vcnt=45 lasprat=105 pasprat=92 loasc=150 lodes=149 dides=101))
((Gill\ Sans SemiBold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=76 em=197 lvw=23 lhw=19 uvw=25 uhw=22 fillp=44 vcnt=44 lasprat=99 pasprat=93 loasc=152 lodes=150 dides=101))
((Gill\ Sans UltraBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=179 lvw=43 lhw=41 uvw=52 uhw=56 fillp=76 vcnt=81 lasprat=123 pasprat=111 loasc=128 lodes=128 dides=102))
((Gillius\ ADF Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=170 lvw=26 lhw=20 uvw=26 uhw=20 fillp=49 vcnt=41 lasprat=112 pasprat=89 loasc=154 lodes=153 dides=102))
((Gillius\ ADF Bold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=162 lvw=25 lhw=20 uvw=25 uhw=20 fillp=41 vcnt=41 lasprat=106 pasprat=98 loasc=154 lodes=153 dides=102))
((Gillius\ ADF Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=160 lvw=16 lhw=16 uvw=16 uhw=14 fillp=31 vcnt=32 lasprat=98 pasprat=91 loasc=154 lodes=153 dides=102))
((Gillius\ ADF Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=160 lvw=16 lhw=14 uvw=16 uhw=14 fillp=39 vcnt=31 lasprat=103 pasprat=81 loasc=154 lodes=153 dides=102))
((Gillius\ ADF\ Cond Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=152 lvw=25 lhw=20 uvw=24 uhw=20 fillp=51 vcnt=41 lasprat=100 pasprat=78 loasc=154 lodes=153 dides=102))
((Gillius\ ADF\ Cond Bold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=142 lvw=21 lhw=20 uvw=21 uhw=20 fillp=40 vcnt=40 lasprat=94 pasprat=86 loasc=154 lodes=153 dides=102))
((Gillius\ ADF\ Cond Italic) (Ascii Latin mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=75 em=121 lvw=13 lhw=16 uvw=13 uhw=14 fillp=30 vcnt=31 lasprat=86 pasprat=80 loasc=154 lodes=153 dides=102))
((Gillius\ ADF\ Cond Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=142 lvw=16 lhw=14 uvw=16 uhw=14 fillp=41 vcnt=33 lasprat=92 pasprat=71 loasc=154 lodes=153 dides=102))
((Gillius\ ADF\ No2 Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=180 lvw=26 lhw=20 uvw=26 uhw=20 fillp=49 vcnt=41 lasprat=111 pasprat=89 loasc=154 lodes=153 dides=104))
((Gillius\ ADF\ No2 Bold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=176 lvw=25 lhw=20 uvw=25 uhw=20 fillp=41 vcnt=41 lasprat=105 pasprat=98 loasc=153 lodes=153 dides=104))
((Gillius\ ADF\ No2 Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=170 lvw=16 lhw=14 uvw=16 uhw=14 fillp=31 vcnt=31 lasprat=97 pasprat=90 loasc=154 lodes=153 dides=104))
((Gillius\ ADF\ No2 Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=169 lvw=16 lhw=16 uvw=16 uhw=14 fillp=38 vcnt=31 lasprat=101 pasprat=80 loasc=154 lodes=153 dides=104))
((Gillius\ ADF\ No2\ Cond Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=157 lvw=26 lhw=21 uvw=26 uhw=21 fillp=51 vcnt=43 lasprat=101 pasprat=81 loasc=154 lodes=153 dides=104))
((Gillius\ ADF\ No2\ Cond Bold\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=153 lvw=25 lhw=21 uvw=25 uhw=20 fillp=42 vcnt=43 lasprat=96 pasprat=90 loasc=153 lodes=153 dides=104))
((Gillius\ ADF\ No2\ Cond Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=75 em=146 lvw=16 lhw=14 uvw=14 uhw=14 fillp=32 vcnt=33 lasprat=88 pasprat=82 loasc=154 lodes=153 dides=104))
((Gillius\ ADF\ No2\ Cond Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=145 lvw=16 lhw=14 uvw=16 uhw=14 fillp=40 vcnt=32 lasprat=91 pasprat=72 loasc=154 lodes=153 dides=104))
((Go Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=27 lhw=16 uvw=28 uhw=18 fillp=53 vcnt=50 lasprat=100 pasprat=82 loasc=145 lodes=138 dides=104))
((Go Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=154 lvw=27 lhw=17 uvw=28 uhw=18 fillp=45 vcnt=50 lasprat=100 pasprat=97 loasc=145 lodes=138 dides=104))
((Go Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=156 lvw=23 lhw=14 uvw=24 uhw=16 fillp=48 vcnt=46 lasprat=96 pasprat=81 loasc=147 lodes=139 dides=104))
((Go Regular-Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=89 em=158 lvw=19 lhw=13 uvw=20 uhw=14 fillp=35 vcnt=38 lasprat=94 pasprat=89 loasc=147 lodes=139 dides=104))
((Go\ Mono Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=28 lhw=15 uvw=26 uhw=15 fillp=51 vcnt=52 lasprat=112 pasprat=98 loasc=147 lodes=139 dides=104))
((Go\ Mono Bold\ Italic) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=89 em=112 lvw=28 lhw=15 uvw=26 uhw=16 fillp=45 vcnt=52 lasprat=112 pasprat=108 loasc=147 lodes=139 dides=104))
((Go\ Mono Italic) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=89 em=112 lvw=19 lhw=11 uvw=17 uhw=12 fillp=34 vcnt=37 lasprat=112 pasprat=101 loasc=147 lodes=139 dides=104))
((Go\ Mono Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=19 lhw=11 uvw=19 uhw=12 fillp=39 vcnt=37 lasprat=112 pasprat=92 loasc=147 lodes=139 dides=104))
((GoSmallcaps Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=smallcaps regular=yes ex=97 em=143 lvw=17 lhw=11 uvw=18 uhw=13 fillp=35 vcnt=37 lasprat=95 pasprat=91 loasc=102 lodes=120 dides=104))
((GoSmallcaps Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=97 em=143 lvw=17 lhw=11 uvw=18 uhw=13 fillp=41 vcnt=37 lasprat=95 pasprat=79 loasc=102 lodes=120 dides=104))
((Gotika Regular) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=65 em=187 lvw=0 lhw=0 uvw=0 uhw=0 fillp=35 vcnt=32 lasprat=125 pasprat=100 loasc=163 lodes=163 dides=100))
((Gotika\ Apvalus Regular) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=65 em=187 lvw=0 lhw=0 uvw=0 uhw=0 fillp=38 vcnt=36 lasprat=125 pasprat=100 loasc=163 lodes=163 dides=100))
((Gotika\ Brokas Regular) (Ascii Greek Cyrillic mono=no sans=no slant=-8 italic=no case=mixed regular=no ex=64 em=190 lvw=67 lhw=96 uvw=100 uhw=160 fillp=27 vcnt=26 lasprat=127 pasprat=109 loasc=170 lodes=168 dides=106))
((Gotika\ Serifai\ A Regular) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=65 em=187 lvw=12 lhw=12 uvw=12 uhw=12 fillp=35 vcnt=28 lasprat=114 pasprat=93 loasc=153 lodes=150 dides=100))
((Gotika\ Serifai\ B Regular) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=65 em=187 lvw=12 lhw=12 uvw=12 uhw=12 fillp=33 vcnt=26 lasprat=114 pasprat=92 loasc=153 lodes=150 dides=100))
((Goudy\ Bookletter\ 1911 Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=237 lvw=18 lhw=11 uvw=22 uhw=14 fillp=32 vcnt=34 lasprat=104 pasprat=99 loasc=172 lodes=155 dides=151))
((Greciliae regular) ())
((Greciliae-hole hole) ())
((Greciliae-hollow hollow) ())
((Greciliae-op op) ())
((Greciliae-op-hole op-hole) ())
((Greciliae-op-hollow op-hollow) ())
((Greextra Medium) ())
((Gregall regular) ())
((Grelaon regular) ())
((Gresgmodern Normal) ())
((Grunge\ Handwriting Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=no ex=75 em=201 lvw=0 lhw=1 uvw=2 uhw=1 fillp=22 vcnt=23 lasprat=99 pasprat=90 loasc=177 lodes=213 dides=100))
((Gujarati\ MT Bold) (slant=0))
((Gujarati\ MT Regular) (slant=0))
((Gujarati\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=21 lhw=16 uvw=21 uhw=16 fillp=50 vcnt=44 lasprat=95 pasprat=82 loasc=142 lodes=142 dides=101))
((Gujarati\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=33 lasprat=94 pasprat=77 loasc=145 lodes=144 dides=102))
((Gurmukhi\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=94 loasc=147 lodes=140 dides=103))
((Gurmukhi\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=179 lvw=22 lhw=8 uvw=25 uhw=6 fillp=39 vcnt=35 lasprat=100 pasprat=89 loasc=151 lodes=145 dides=103))
((Gurmukhi\ MT Regular) (slant=0))
((Gurmukhi\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=24 lhw=16 uvw=24 uhw=16 fillp=51 vcnt=49 lasprat=94 pasprat=84 loasc=142 lodes=143 dides=102))
((Gurmukhi\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=33 lasprat=93 pasprat=77 loasc=143 lodes=144 dides=102))
((Hairline\ Quadrata Medium) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=40 em=200 lvw=35 lhw=12 uvw=7 uhw=7 fillp=25 vcnt=17 lasprat=89 pasprat=58 loasc=197 lodes=192 dides=170))
((Hand\ Drawn\ Shapes Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=78 em=156 lvw=19 lhw=19 uvw=19 uhw=28 fillp=53 vcnt=55 lasprat=97 pasprat=86 loasc=158 lodes=162 dides=100))
((Handserif Medium) (Ascii Latin mono=no sans=yes slant=-5 italic=no case=mixed regular=yes ex=68 em=179 lvw=23 lhw=8 uvw=20 uhw=10 fillp=35 vcnt=35 lasprat=96 pasprat=86 loasc=176 lodes=170 dides=164))
((Hannotate\ SC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=163 lvw=22 lhw=18 uvw=22 uhw=18 fillp=45 vcnt=39 lasprat=108 pasprat=90 loasc=153 lodes=150 dides=107))
((Hannotate\ SC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=159 lvw=16 lhw=14 uvw=18 uhw=14 fillp=38 vcnt=33 lasprat=104 pasprat=86 loasc=153 lodes=150 dides=107))
((Hannotate\ TC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=163 lvw=22 lhw=18 uvw=22 uhw=18 fillp=45 vcnt=39 lasprat=108 pasprat=90 loasc=153 lodes=150 dides=107))
((Hannotate\ TC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=159 lvw=16 lhw=14 uvw=18 uhw=14 fillp=38 vcnt=33 lasprat=104 pasprat=86 loasc=153 lodes=150 dides=107))
((HanziPen\ SC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=66 em=204 lvw=19 lhw=21 uvw=21 uhw=22 fillp=37 vcnt=35 lasprat=117 pasprat=99 loasc=195 lodes=157 dides=119))
((HanziPen\ SC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=66 em=198 lvw=13 lhw=16 uvw=15 uhw=16 fillp=30 vcnt=28 lasprat=112 pasprat=94 loasc=195 lodes=157 dides=119))
((HanziPen\ TC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=66 em=204 lvw=19 lhw=21 uvw=21 uhw=22 fillp=37 vcnt=35 lasprat=117 pasprat=99 loasc=195 lodes=157 dides=119))
((HanziPen\ TC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=66 em=198 lvw=13 lhw=16 uvw=15 uhw=16 fillp=30 vcnt=28 lasprat=112 pasprat=94 loasc=195 lodes=157 dides=119))
((Harano\ Aji\ Gothic Bold) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=152 lvw=26 lhw=21 uvw=26 uhw=22 fillp=55 vcnt=55 lasprat=101 pasprat=86 loasc=146 lodes=144 dides=102))
((Harano\ Aji\ Gothic Heavy) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=95 em=153 lvw=31 lhw=25 uvw=31 uhw=27 fillp=61 vcnt=63 lasprat=102 pasprat=89 loasc=146 lodes=142 dides=102))
((Harano\ Aji\ Gothic Light) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=147 lvw=12 lhw=8 uvw=12 uhw=10 fillp=30 vcnt=25 lasprat=95 pasprat=75 loasc=151 lodes=147 dides=102))
((Harano\ Aji\ Gothic Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=150 lvw=21 lhw=17 uvw=20 uhw=18 fillp=47 vcnt=45 lasprat=98 pasprat=81 loasc=147 lodes=144 dides=102))
((Harano\ Aji\ Gothic\ ExtraLight Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=145 lvw=6 lhw=6 uvw=7 uhw=6 fillp=21 vcnt=17 lasprat=93 pasprat=72 loasc=153 lodes=148 dides=102))
((Harano\ Aji\ Gothic\ Normal Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=148 lvw=15 lhw=12 uvw=15 uhw=13 fillp=37 vcnt=34 lasprat=97 pasprat=78 loasc=150 lodes=146 dides=102))
((Harano\ Aji\ Mincho Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=187 lvw=25 lhw=6 uvw=28 uhw=7 fillp=39 vcnt=42 lasprat=109 pasprat=101 loasc=155 lodes=150 dides=103))
((Harano\ Aji\ Mincho Heavy) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=185 lvw=30 lhw=6 uvw=32 uhw=6 fillp=43 vcnt=49 lasprat=110 pasprat=103 loasc=153 lodes=149 dides=103))
((Harano\ Aji\ Mincho Light) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=190 lvw=14 lhw=7 uvw=16 uhw=8 fillp=27 vcnt=27 lasprat=108 pasprat=96 loasc=160 lodes=152 dides=103))
((Harano\ Aji\ Mincho Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=189 lvw=19 lhw=8 uvw=21 uhw=9 fillp=33 vcnt=35 lasprat=107 pasprat=97 loasc=157 lodes=152 dides=104))
((Harano\ Aji\ Mincho SemiBold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=188 lvw=21 lhw=7 uvw=23 uhw=9 fillp=35 vcnt=38 lasprat=108 pasprat=98 loasc=156 lodes=152 dides=104))
((Harano\ Aji\ Mincho\ ExtraLight Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=189 lvw=12 lhw=5 uvw=14 uhw=7 fillp=24 vcnt=24 lasprat=107 pasprat=95 loasc=160 lodes=152 dides=103))
((HeadLineA Regular) (Ascii Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=113 lvw=27 lhw=17 uvw=31 uhw=18 fillp=77 vcnt=82 lasprat=67 pasprat=59 loasc=122 lodes=117 dides=102))
((Hei Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=214 lvw=16 lhw=12 uvw=21 uhw=16 fillp=43 vcnt=41 lasprat=112 pasprat=83 loasc=153 lodes=134 dides=103))
((Heiti\ SC Light) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=11 lhw=11 uvw=13 uhw=12 fillp=35 vcnt=37 lasprat=91 pasprat=76 loasc=135 lodes=122 dides=100))
((Heiti\ SC Medium) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=101 em=151 lvw=13 lhw=12 uvw=14 uhw=13 fillp=40 vcnt=43 lasprat=89 pasprat=76 loasc=134 lodes=121 dides=100))
((Heiti\ TC Light) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=11 lhw=11 uvw=13 uhw=12 fillp=35 vcnt=37 lasprat=91 pasprat=76 loasc=135 lodes=122 dides=100))
((Heiti\ TC Medium) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=101 em=151 lvw=13 lhw=12 uvw=14 uhw=13 fillp=40 vcnt=43 lasprat=89 pasprat=76 loasc=134 lodes=121 dides=100))
((HeitiUI\ GB18030PUA Thin) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=156 lvw=10 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=92 pasprat=76 loasc=136 lodes=123 dides=100))
((HeitiUI\ GB18030PUA Ultra\ Light) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=8 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=21 lasprat=91 pasprat=73 loasc=135 lodes=123 dides=100))
((HeitiUI\ J Thin) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=156 lvw=10 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=92 pasprat=76 loasc=136 lodes=123 dides=100))
((HeitiUI\ J Ultra\ Light) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=8 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=21 lasprat=91 pasprat=73 loasc=135 lodes=123 dides=100))
((HeitiUI\ K Thin) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=156 lvw=10 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=92 pasprat=76 loasc=136 lodes=123 dides=100))
((HeitiUI\ K Ultra\ Light) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=8 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=21 lasprat=91 pasprat=73 loasc=135 lodes=123 dides=100))
((HeitiUI\ SC Thin) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=156 lvw=10 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=92 pasprat=76 loasc=136 lodes=123 dides=100))
((HeitiUI\ SC Ultra\ Light) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=8 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=21 lasprat=91 pasprat=73 loasc=135 lodes=123 dides=100))
((HeitiUI\ TC Thin) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=98 em=156 lvw=10 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=92 pasprat=76 loasc=136 lodes=123 dides=100))
((HeitiUI\ TC Ultra\ Light) (CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=8 lhw=8 uvw=9 uhw=8 fillp=26 vcnt=21 lasprat=91 pasprat=73 loasc=135 lodes=123 dides=100))
((Helvetica Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=156 lvw=26 lhw=21 uvw=28 uhw=23 fillp=58 vcnt=55 lasprat=101 pasprat=86 loasc=135 lodes=140 dides=103))
((Helvetica Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=89 em=156 lvw=28 lhw=21 uvw=28 uhw=23 fillp=47 vcnt=55 lasprat=101 pasprat=103 loasc=135 lodes=140 dides=103))
((Helvetica Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=11 lhw=9 uvw=12 uhw=11 fillp=33 vcnt=28 lasprat=96 pasprat=77 loasc=141 lodes=140 dides=102))
((Helvetica Light\ Oblique) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=87 em=159 lvw=12 lhw=9 uvw=12 uhw=11 fillp=26 vcnt=28 lasprat=96 pasprat=92 loasc=141 lodes=140 dides=102))
((Helvetica Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=87 em=159 lvw=18 lhw=13 uvw=19 uhw=16 fillp=34 vcnt=39 lasprat=93 pasprat=95 loasc=139 lodes=142 dides=103))
((Helvetica Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=18 uhw=16 fillp=44 vcnt=39 lasprat=93 pasprat=78 loasc=139 lodes=142 dides=103))
((Helvetica\ Neue Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=175 lvw=27 lhw=20 uvw=30 uhw=25 fillp=58 vcnt=55 lasprat=104 pasprat=91 loasc=138 lodes=138 dides=102))
((Helvetica\ Neue Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=86 em=175 lvw=27 lhw=20 uvw=30 uhw=25 fillp=49 vcnt=55 lasprat=104 pasprat=104 loasc=139 lodes=138 dides=102))
((Helvetica\ Neue Condensed\ Black) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=140 lvw=33 lhw=21 uvw=35 uhw=23 fillp=71 vcnt=73 lasprat=87 pasprat=80 loasc=134 lodes=133 dides=102))
((Helvetica\ Neue Condensed\ Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=136 lvw=25 lhw=17 uvw=25 uhw=20 fillp=62 vcnt=60 lasprat=83 pasprat=72 loasc=134 lodes=133 dides=102))
((Helvetica\ Neue Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=168 lvw=16 lhw=13 uvw=18 uhw=15 fillp=34 vcnt=38 lasprat=95 pasprat=94 loasc=140 lodes=140 dides=102))
((Helvetica\ Neue Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=161 lvw=12 lhw=10 uvw=12 uhw=11 fillp=34 vcnt=30 lasprat=92 pasprat=80 loasc=138 lodes=139 dides=102))
((Helvetica\ Neue Light\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=86 em=165 lvw=12 lhw=10 uvw=12 uhw=11 fillp=27 vcnt=30 lasprat=92 pasprat=92 loasc=138 lodes=139 dides=102))
((Helvetica\ Neue Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=172 lvw=22 lhw=17 uvw=24 uhw=19 fillp=50 vcnt=47 lasprat=101 pasprat=87 loasc=138 lodes=139 dides=102))
((Helvetica\ Neue Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=172 lvw=22 lhw=17 uvw=24 uhw=19 fillp=42 vcnt=47 lasprat=100 pasprat=99 loasc=138 lodes=139 dides=102))
((Helvetica\ Neue Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=168 lvw=17 lhw=13 uvw=18 uhw=15 fillp=42 vcnt=38 lasprat=97 pasprat=82 loasc=140 lodes=140 dides=102))
((Helvetica\ Neue Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=156 lvw=8 lhw=6 uvw=9 uhw=6 fillp=24 vcnt=20 lasprat=88 pasprat=76 loasc=140 lodes=138 dides=102))
((Helvetica\ Neue Thin\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=86 em=158 lvw=8 lhw=6 uvw=8 uhw=6 fillp=18 vcnt=20 lasprat=88 pasprat=89 loasc=140 lodes=138 dides=102))
((Helvetica\ Neue UltraLight) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=151 lvw=3 lhw=3 uvw=3 uhw=4 fillp=15 vcnt=10 lasprat=83 pasprat=73 loasc=138 lodes=134 dides=101))
((Helvetica\ Neue UltraLight\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=86 em=154 lvw=3 lhw=3 uvw=3 uhw=4 fillp=10 vcnt=12 lasprat=83 pasprat=86 loasc=138 lodes=134 dides=101))
((Helvetica\ Neue\ DeskInterface Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=175 lvw=27 lhw=20 uvw=30 uhw=25 fillp=58 vcnt=56 lasprat=103 pasprat=91 loasc=137 lodes=137 dides=102))
((Helvetica\ Neue\ DeskInterface Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=175 lvw=27 lhw=20 uvw=30 uhw=25 fillp=49 vcnt=56 lasprat=103 pasprat=104 loasc=138 lodes=137 dides=102))
((Helvetica\ Neue\ DeskInterface Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=177 lvw=32 lhw=25 uvw=36 uhw=30 fillp=63 vcnt=64 lasprat=108 pasprat=95 loasc=137 lodes=135 dides=102))
((Helvetica\ Neue\ DeskInterface Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=168 lvw=15 lhw=14 uvw=18 uhw=14 fillp=34 vcnt=39 lasprat=95 pasprat=94 loasc=139 lodes=140 dides=102))
((Helvetica\ Neue\ DeskInterface Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=159 lvw=12 lhw=10 uvw=13 uhw=11 fillp=34 vcnt=31 lasprat=92 pasprat=79 loasc=137 lodes=139 dides=102))
((Helvetica\ Neue\ DeskInterface Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=171 lvw=23 lhw=18 uvw=25 uhw=20 fillp=53 vcnt=50 lasprat=100 pasprat=87 loasc=137 lodes=138 dides=102))
((Helvetica\ Neue\ DeskInterface Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=171 lvw=22 lhw=18 uvw=25 uhw=21 fillp=44 vcnt=51 lasprat=99 pasprat=99 loasc=137 lodes=138 dides=102))
((Helvetica\ Neue\ DeskInterface Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=168 lvw=17 lhw=14 uvw=18 uhw=14 fillp=42 vcnt=39 lasprat=96 pasprat=81 loasc=138 lodes=140 dides=102))
((Helvetica\ Neue\ DeskInterface Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=157 lvw=6 lhw=6 uvw=8 uhw=6 fillp=24 vcnt=20 lasprat=88 pasprat=76 loasc=141 lodes=137 dides=102))
((Helvetica\ Neue\ DeskInterface UltraLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=151 lvw=4 lhw=3 uvw=4 uhw=3 fillp=18 vcnt=13 lasprat=84 pasprat=74 loasc=139 lodes=136 dides=102))
((Herculanum Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=101 em=193 lvw=11 lhw=10 uvw=11 uhw=10 fillp=29 vcnt=28 lasprat=101 pasprat=81 loasc=103 lodes=124 dides=113))
((Heuristica Bold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=184 lvw=31 lhw=9 uvw=36 uhw=9 fillp=48 vcnt=50 lasprat=107 pasprat=103 loasc=150 lodes=148 dides=102))
((Heuristica Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=84 em=183 lvw=29 lhw=9 uvw=33 uhw=9 fillp=41 vcnt=49 lasprat=104 pasprat=108 loasc=148 lodes=147 dides=102))
((Heuristica Italic) (Ascii Latin Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=84 em=182 lvw=20 lhw=7 uvw=21 uhw=7 fillp=30 vcnt=34 lasprat=100 pasprat=98 loasc=148 lodes=148 dides=102))
((Heuristica Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=21 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=34 lasprat=104 pasprat=97 loasc=151 lodes=148 dides=102))
((Hiragino\ Kaku\ Gothic\ Interface W0) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=188 lvw=4 lhw=4 uvw=3 uhw=4 fillp=15 vcnt=10 lasprat=97 pasprat=77 loasc=147 lodes=145 dides=102))
((Hiragino\ Kaku\ Gothic\ Interface W1) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=171 lvw=10 lhw=8 uvw=10 uhw=8 fillp=26 vcnt=23 lasprat=97 pasprat=79 loasc=142 lodes=140 dides=100))
((Hiragino\ Kaku\ Gothic\ Interface W2) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=12 lhw=10 uvw=12 uhw=11 fillp=30 vcnt=27 lasprat=99 pasprat=82 loasc=142 lodes=140 dides=101))
((Hiragino\ Kaku\ Gothic\ Interface W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=173 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=33 lasprat=101 pasprat=85 loasc=141 lodes=138 dides=102))
((Hiragino\ Kaku\ Gothic\ Interface W4) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=92 em=173 lvw=17 lhw=14 uvw=18 uhw=15 fillp=39 vcnt=38 lasprat=103 pasprat=87 loasc=141 lodes=138 dides=103))
((Hiragino\ Kaku\ Gothic\ Interface W5) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=93 em=174 lvw=19 lhw=16 uvw=20 uhw=18 fillp=44 vcnt=45 lasprat=105 pasprat=91 loasc=140 lodes=137 dides=104))
((Hiragino\ Kaku\ Gothic\ Interface W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=175 lvw=23 lhw=19 uvw=24 uhw=21 fillp=49 vcnt=52 lasprat=108 pasprat=95 loasc=141 lodes=137 dides=105))
((Hiragino\ Kaku\ Gothic\ Interface W7) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=95 em=176 lvw=27 lhw=22 uvw=29 uhw=25 fillp=55 vcnt=61 lasprat=112 pasprat=100 loasc=142 lodes=136 dides=107))
((Hiragino\ Kaku\ Gothic\ Interface W8) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=97 em=176 lvw=31 lhw=25 uvw=36 uhw=29 fillp=60 vcnt=71 lasprat=115 pasprat=105 loasc=141 lodes=139 dides=109))
((Hiragino\ Kaku\ Gothic\ Interface W9) (Ascii Latin Greek CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=98 em=179 lvw=38 lhw=30 uvw=42 uhw=35 fillp=65 vcnt=81 lasprat=121 pasprat=113 loasc=141 lodes=140 dides=111))
((Hiragino\ Kaku\ Gothic\ Pro W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=39 lasprat=101 pasprat=84 loasc=142 lodes=138 dides=102))
((Hiragino\ Kaku\ Gothic\ Pro W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=176 lvw=22 lhw=19 uvw=24 uhw=21 fillp=48 vcnt=59 lasprat=109 pasprat=93 loasc=142 lodes=137 dides=105))
((Hiragino\ Kaku\ Gothic\ ProN W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=39 lasprat=101 pasprat=84 loasc=142 lodes=138 dides=102))
((Hiragino\ Kaku\ Gothic\ ProN W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=176 lvw=22 lhw=19 uvw=24 uhw=21 fillp=48 vcnt=59 lasprat=109 pasprat=93 loasc=142 lodes=137 dides=105))
((Hiragino\ Kaku\ Gothic\ Std W8) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=97 em=178 lvw=31 lhw=26 uvw=35 uhw=29 fillp=60 vcnt=78 lasprat=116 pasprat=104 loasc=141 lodes=139 dides=109))
((Hiragino\ Kaku\ Gothic\ StdN W8) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=97 em=178 lvw=31 lhw=26 uvw=35 uhw=29 fillp=60 vcnt=78 lasprat=116 pasprat=104 loasc=141 lodes=139 dides=109))
((Hiragino\ Maru\ Gothic\ Pro W4) (Ascii Latin CJK MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=172 lvw=16 lhw=13 uvw=18 uhw=16 fillp=41 vcnt=47 lasprat=97 pasprat=81 loasc=141 lodes=141 dides=104))
((Hiragino\ Maru\ Gothic\ ProN W4) (Ascii Latin CJK MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=172 lvw=16 lhw=13 uvw=18 uhw=16 fillp=41 vcnt=47 lasprat=97 pasprat=81 loasc=141 lodes=141 dides=104))
((Hiragino\ Mincho\ Pro W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=16 lhw=4 uvw=18 uhw=4 fillp=30 vcnt=33 lasprat=98 pasprat=86 loasc=143 lodes=134 dides=100))
((Hiragino\ Mincho\ Pro W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=180 lvw=25 lhw=4 uvw=27 uhw=4 fillp=37 vcnt=43 lasprat=103 pasprat=95 loasc=145 lodes=137 dides=100))
((Hiragino\ Mincho\ ProN W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=16 lhw=4 uvw=18 uhw=4 fillp=30 vcnt=33 lasprat=98 pasprat=86 loasc=143 lodes=134 dides=100))
((Hiragino\ Mincho\ ProN W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=180 lvw=25 lhw=4 uvw=27 uhw=4 fillp=37 vcnt=43 lasprat=103 pasprat=95 loasc=145 lodes=137 dides=100))
((Hiragino\ Sans W0) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=188 lvw=4 lhw=4 uvw=3 uhw=4 fillp=15 vcnt=10 lasprat=97 pasprat=77 loasc=147 lodes=145 dides=102))
((Hiragino\ Sans W1) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=171 lvw=10 lhw=8 uvw=10 uhw=8 fillp=26 vcnt=23 lasprat=97 pasprat=79 loasc=142 lodes=140 dides=100))
((Hiragino\ Sans W2) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=12 lhw=10 uvw=12 uhw=11 fillp=30 vcnt=27 lasprat=99 pasprat=82 loasc=142 lodes=140 dides=101))
((Hiragino\ Sans W3) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=173 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=33 lasprat=101 pasprat=85 loasc=141 lodes=138 dides=102))
((Hiragino\ Sans W4) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=92 em=173 lvw=17 lhw=14 uvw=18 uhw=15 fillp=39 vcnt=38 lasprat=103 pasprat=87 loasc=141 lodes=138 dides=103))
((Hiragino\ Sans W5) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=93 em=174 lvw=19 lhw=16 uvw=20 uhw=18 fillp=44 vcnt=45 lasprat=105 pasprat=91 loasc=140 lodes=137 dides=104))
((Hiragino\ Sans W6) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=175 lvw=23 lhw=19 uvw=24 uhw=21 fillp=49 vcnt=52 lasprat=108 pasprat=95 loasc=141 lodes=137 dides=105))
((Hiragino\ Sans W7) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=95 em=176 lvw=27 lhw=22 uvw=29 uhw=25 fillp=55 vcnt=61 lasprat=112 pasprat=100 loasc=142 lodes=136 dides=107))
((Hiragino\ Sans W8) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=97 em=176 lvw=31 lhw=25 uvw=36 uhw=29 fillp=60 vcnt=71 lasprat=115 pasprat=105 loasc=141 lodes=139 dides=109))
((Hiragino\ Sans W9) (Ascii Latin Greek CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=98 em=179 lvw=38 lhw=30 uvw=42 uhw=35 fillp=65 vcnt=81 lasprat=121 pasprat=113 loasc=141 lodes=140 dides=111))
((Hiragino\ Sans\ GB W3) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=39 lasprat=101 pasprat=84 loasc=142 lodes=138 dides=102))
((Hiragino\ Sans\ GB W6) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=176 lvw=22 lhw=19 uvw=24 uhw=21 fillp=48 vcnt=59 lasprat=109 pasprat=93 loasc=142 lodes=137 dides=105))
((Hiragino\ Sans\ GB\ Interface W3) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=173 lvw=14 lhw=12 uvw=14 uhw=13 fillp=35 vcnt=33 lasprat=101 pasprat=85 loasc=141 lodes=138 dides=102))
((Hiragino\ Sans\ GB\ Interface W6) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=175 lvw=23 lhw=19 uvw=24 uhw=21 fillp=49 vcnt=52 lasprat=108 pasprat=95 loasc=141 lodes=137 dides=105))
((Hoefler\ Text Black) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=239 lvw=40 lhw=10 uvw=47 uhw=10 fillp=47 vcnt=51 lasprat=125 pasprat=123 loasc=163 lodes=163 dides=151))
((Hoefler\ Text Black\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=76 em=231 lvw=35 lhw=10 uvw=43 uhw=10 fillp=44 vcnt=48 lasprat=116 pasprat=124 loasc=161 lodes=160 dides=152))
((Hoefler\ Text Italic) (Ascii Latin Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=73 em=219 lvw=20 lhw=6 uvw=23 uhw=6 fillp=29 vcnt=31 lasprat=99 pasprat=106 loasc=167 lodes=163 dides=152))
((Hoefler\ Text Ornaments) ())
((Hoefler\ Text Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=228 lvw=23 lhw=7 uvw=25 uhw=7 fillp=32 vcnt=33 lasprat=111 pasprat=106 loasc=170 lodes=166 dides=154))
((Hoefler\ Text\ Ornaments Ornaments) ())
((Hopper\ Script Regular) (Ascii Latin mono=no sans=yes slant=47 italic=yes case=mixed regular=no ex=76 em=247 lvw=15 lhw=18 uvw=21 uhw=23 fillp=18 vcnt=48 lasprat=109 pasprat=174 loasc=263 lodes=280 dides=110))
((IBM\ Plex\ Mono Bold) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=30 lhw=20 uvw=31 uhw=23 fillp=57 vcnt=54 lasprat=116 pasprat=97 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono Bold\ Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=88 em=113 lvw=27 lhw=20 uvw=28 uhw=22 fillp=51 vcnt=54 lasprat=113 pasprat=102 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Mono Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=88 em=113 lvw=14 lhw=12 uvw=15 uhw=13 fillp=33 vcnt=32 lasprat=113 pasprat=93 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Mono Light) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=11 lhw=10 uvw=12 uhw=10 fillp=29 vcnt=24 lasprat=116 pasprat=85 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono Light\ Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=89 em=112 lvw=10 lhw=8 uvw=11 uhw=8 fillp=25 vcnt=24 lasprat=112 pasprat=90 loasc=140 lodes=139 dides=102))
((IBM\ Plex\ Mono Regular) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=22 lhw=17 uvw=23 uhw=18 fillp=47 vcnt=42 lasprat=116 pasprat=92 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono SemiBold) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=25 lhw=19 uvw=26 uhw=20 fillp=52 vcnt=47 lasprat=116 pasprat=94 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono SemiBold\ Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=89 em=112 lvw=23 lhw=19 uvw=24 uhw=20 fillp=47 vcnt=48 lasprat=112 pasprat=98 loasc=140 lodes=139 dides=102))
((IBM\ Plex\ Mono\ ExtraLight Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=88 em=113 lvw=6 lhw=5 uvw=6 uhw=5 fillp=16 vcnt=15 lasprat=113 pasprat=89 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Mono\ ExtraLight Regular) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=6 lhw=5 uvw=8 uhw=5 fillp=18 vcnt=15 lasprat=116 pasprat=82 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono\ Text Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=88 em=113 lvw=17 lhw=14 uvw=17 uhw=15 fillp=37 vcnt=37 lasprat=113 pasprat=95 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Mono\ Text Regular) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=19 lhw=15 uvw=19 uhw=16 fillp=42 vcnt=37 lasprat=116 pasprat=90 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Mono\ Thin Italic) (Ascii Latin Cyrillic mono=yes sans=yes slant=17 italic=yes case=mixed regular=yes ex=88 em=113 lvw=4 lhw=3 uvw=4 uhw=3 fillp=10 vcnt=9 lasprat=113 pasprat=88 loasc=140 lodes=139 dides=102))
((IBM\ Plex\ Mono\ Thin Regular) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=116 lvw=4 lhw=3 uvw=4 uhw=3 fillp=12 vcnt=9 lasprat=116 pasprat=81 loasc=144 lodes=140 dides=102))
((IBM\ Plex\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=155 lvw=29 lhw=21 uvw=30 uhw=26 fillp=58 vcnt=55 lasprat=101 pasprat=87 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Sans Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=88 em=152 lvw=26 lhw=21 uvw=28 uhw=25 fillp=49 vcnt=54 lasprat=98 pasprat=97 loasc=140 lodes=139 dides=102))
((IBM\ Plex\ Sans Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=141 lvw=20 lhw=16 uvw=21 uhw=18 fillp=48 vcnt=44 lasprat=90 pasprat=74 loasc=142 lodes=140 dides=102))
((IBM\ Plex\ Sans Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=139 lvw=28 lhw=21 uvw=29 uhw=23 fillp=58 vcnt=56 lasprat=92 pasprat=79 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Sans Condensed\ Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=88 em=137 lvw=25 lhw=20 uvw=26 uhw=22 fillp=49 vcnt=55 lasprat=90 pasprat=91 loasc=140 lodes=139 dides=102))
((IBM\ Plex\ Sans Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=86 em=139 lvw=15 lhw=12 uvw=15 uhw=12 fillp=32 vcnt=34 lasprat=87 pasprat=83 loasc=144 lodes=140 dides=102))
((IBM\ Plex\ Sans Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=86 em=152 lvw=15 lhw=12 uvw=15 uhw=13 fillp=32 vcnt=33 lasprat=96 pasprat=89 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=157 lvw=11 lhw=10 uvw=12 uhw=10 fillp=30 vcnt=25 lasprat=97 pasprat=76 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans Light\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=142 lvw=11 lhw=9 uvw=12 uhw=10 fillp=30 vcnt=26 lasprat=87 pasprat=69 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans Light\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=85 em=140 lvw=10 lhw=9 uvw=10 uhw=9 fillp=24 vcnt=25 lasprat=86 pasprat=81 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=85 em=152 lvw=10 lhw=9 uvw=10 uhw=9 fillp=24 vcnt=24 lasprat=95 pasprat=87 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=156 lvw=21 lhw=17 uvw=22 uhw=19 fillp=48 vcnt=43 lasprat=99 pasprat=82 loasc=142 lodes=140 dides=102))
((IBM\ Plex\ Sans SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=156 lvw=25 lhw=19 uvw=26 uhw=22 fillp=53 vcnt=49 lasprat=101 pasprat=84 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans SemiBold\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=141 lvw=24 lhw=18 uvw=25 uhw=20 fillp=53 vcnt=50 lasprat=91 pasprat=77 loasc=142 lodes=140 dides=102))
((IBM\ Plex\ Sans SemiBold\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=139 lvw=21 lhw=18 uvw=22 uhw=20 fillp=44 vcnt=49 lasprat=89 pasprat=89 loasc=142 lodes=140 dides=102))
((IBM\ Plex\ Sans SemiBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=152 lvw=22 lhw=19 uvw=24 uhw=21 fillp=45 vcnt=49 lasprat=98 pasprat=96 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans\ ExtraLight Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=141 lvw=7 lhw=5 uvw=8 uhw=5 fillp=21 vcnt=17 lasprat=86 pasprat=65 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans\ ExtraLight Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=85 em=138 lvw=7 lhw=5 uvw=7 uhw=5 fillp=16 vcnt=17 lasprat=85 pasprat=78 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans\ ExtraLight Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=85 em=152 lvw=7 lhw=5 uvw=7 uhw=5 fillp=16 vcnt=16 lasprat=94 pasprat=84 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans\ ExtraLight Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=156 lvw=7 lhw=5 uvw=8 uhw=5 fillp=19 vcnt=15 lasprat=95 pasprat=72 loasc=144 lodes=141 dides=102))
((IBM\ Plex\ Sans\ Text Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=141 lvw=18 lhw=15 uvw=19 uhw=16 fillp=44 vcnt=39 lasprat=89 pasprat=73 loasc=144 lodes=140 dides=102))
((IBM\ Plex\ Sans\ Text Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=86 em=139 lvw=16 lhw=15 uvw=17 uhw=16 fillp=36 vcnt=38 lasprat=88 pasprat=85 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans\ Text Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=86 em=152 lvw=17 lhw=15 uvw=18 uhw=16 fillp=36 vcnt=38 lasprat=97 pasprat=91 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans\ Text Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=156 lvw=19 lhw=15 uvw=19 uhw=17 fillp=43 vcnt=38 lasprat=99 pasprat=80 loasc=143 lodes=140 dides=102))
((IBM\ Plex\ Sans\ Thin Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=142 lvw=4 lhw=3 uvw=4 uhw=3 fillp=13 vcnt=10 lasprat=86 pasprat=64 loasc=146 lodes=141 dides=102))
((IBM\ Plex\ Sans\ Thin Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=139 lvw=3 lhw=3 uvw=4 uhw=3 fillp=10 vcnt=10 lasprat=85 pasprat=76 loasc=146 lodes=141 dides=102))
((IBM\ Plex\ Sans\ Thin Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=154 lvw=4 lhw=3 uvw=4 uhw=3 fillp=10 vcnt=10 lasprat=94 pasprat=84 loasc=146 lodes=141 dides=102))
((IBM\ Plex\ Sans\ Thin Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=158 lvw=4 lhw=3 uvw=4 uhw=3 fillp=13 vcnt=10 lasprat=95 pasprat=71 loasc=146 lodes=141 dides=102))
((IBM\ Plex\ Serif Bold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=171 lvw=29 lhw=13 uvw=33 uhw=13 fillp=50 vcnt=50 lasprat=108 pasprat=98 loasc=147 lodes=140 dides=103))
((IBM\ Plex\ Serif Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=90 em=152 lvw=26 lhw=10 uvw=28 uhw=12 fillp=43 vcnt=50 lasprat=97 pasprat=99 loasc=141 lodes=138 dides=102))
((IBM\ Plex\ Serif Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=88 em=151 lvw=15 lhw=7 uvw=15 uhw=9 fillp=29 vcnt=33 lasprat=91 pasprat=90 loasc=144 lodes=139 dides=102))
((IBM\ Plex\ Serif Light) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=169 lvw=12 lhw=7 uvw=12 uhw=8 fillp=25 vcnt=23 lasprat=103 pasprat=87 loasc=149 lodes=141 dides=102))
((IBM\ Plex\ Serif Light\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=87 em=154 lvw=10 lhw=5 uvw=10 uhw=6 fillp=22 vcnt=24 lasprat=89 pasprat=86 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Serif Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=22 lhw=11 uvw=24 uhw=11 fillp=41 vcnt=40 lasprat=105 pasprat=92 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Serif SemiBold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=170 lvw=26 lhw=12 uvw=28 uhw=12 fillp=46 vcnt=45 lasprat=107 pasprat=94 loasc=145 lodes=140 dides=102))
((IBM\ Plex\ Serif SemiBold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=89 em=152 lvw=23 lhw=10 uvw=24 uhw=11 fillp=39 vcnt=45 lasprat=96 pasprat=97 loasc=142 lodes=139 dides=102))
((IBM\ Plex\ Serif\ ExtraLight Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=87 em=155 lvw=6 lhw=4 uvw=6 uhw=4 fillp=15 vcnt=16 lasprat=87 pasprat=82 loasc=145 lodes=141 dides=102))
((IBM\ Plex\ Serif\ ExtraLight Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=168 lvw=7 lhw=4 uvw=8 uhw=4 fillp=17 vcnt=16 lasprat=100 pasprat=85 loasc=148 lodes=141 dides=102))
((IBM\ Plex\ Serif\ Text Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=88 em=153 lvw=18 lhw=9 uvw=19 uhw=10 fillp=32 vcnt=36 lasprat=93 pasprat=92 loasc=144 lodes=139 dides=102))
((IBM\ Plex\ Serif\ Text Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=169 lvw=19 lhw=10 uvw=20 uhw=11 fillp=38 vcnt=36 lasprat=105 pasprat=92 loasc=147 lodes=140 dides=102))
((IBM\ Plex\ Serif\ Thin Italic) (Ascii Latin Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=86 em=158 lvw=4 lhw=3 uvw=4 uhw=3 fillp=10 vcnt=11 lasprat=87 pasprat=81 loasc=147 lodes=140 dides=102))
((IBM\ Plex\ Serif\ Thin Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=169 lvw=3 lhw=3 uvw=3 uhw=3 fillp=10 vcnt=9 lasprat=100 pasprat=84 loasc=151 lodes=142 dides=102))
((IM\ FELL\ English Italic) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=75 em=224 lvw=16 lhw=9 uvw=24 uhw=14 fillp=30 vcnt=36 lasprat=88 pasprat=96 loasc=165 lodes=178 dides=153))
((IM\ FELL\ English Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=23 lhw=9 uvw=24 uhw=14 fillp=34 vcnt=35 lasprat=101 pasprat=95 loasc=159 lodes=162 dides=151))
((IM\ FELL\ English\ SC Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=72 em=218 lvw=25 lhw=6 uvw=26 uhw=13 fillp=35 vcnt=32 lasprat=111 pasprat=104 loasc=106 lodes=165 dides=155))
((Impact Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=108 em=111 lvw=30 lhw=17 uvw=31 uhw=20 fillp=78 vcnt=98 lasprat=71 pasprat=65 loasc=122 lodes=117 dides=102))
((InaiMathi Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=22 lhw=19 uvw=22 uhw=19 fillp=53 vcnt=49 lasprat=93 pasprat=81 loasc=140 lodes=140 dides=102))
((InaiMathi Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=133 lvw=14 lhw=12 uvw=16 uhw=14 fillp=42 vcnt=41 lasprat=88 pasprat=73 loasc=140 lodes=140 dides=102))
((InconsolataN Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=96 lvw=24 lhw=19 uvw=24 uhw=21 fillp=54 vcnt=48 lasprat=96 pasprat=83 loasc=146 lodes=137 dides=103))
((InconsolataN Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=98 lvw=15 lhw=13 uvw=15 uhw=14 fillp=38 vcnt=31 lasprat=98 pasprat=80 loasc=147 lodes=138 dides=102))
((Inconsolatazi4 Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=105 lvw=24 lhw=18 uvw=24 uhw=21 fillp=51 vcnt=45 lasprat=105 pasprat=88 loasc=145 lodes=137 dides=103))
((Inconsolatazi4 Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=109 lvw=15 lhw=13 uvw=14 uhw=15 fillp=36 vcnt=29 lasprat=109 pasprat=86 loasc=147 lodes=138 dides=102))
((Indiction\ Unicode Normal) (Ascii Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=58 em=193 lvw=20 lhw=6 uvw=22 uhw=6 fillp=32 vcnt=24 lasprat=108 pasprat=99 loasc=162 lodes=151 dides=101))
((Indiction\ Unicode\ TT Normal) (Ascii Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=58 em=193 lvw=20 lhw=6 uvw=22 uhw=6 fillp=32 vcnt=24 lasprat=108 pasprat=99 loasc=162 lodes=151 dides=101))
((Ink\ Free Regular) (Ascii Latin mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=88 em=153 lvw=9 lhw=9 uvw=10 uhw=9 fillp=23 vcnt=22 lasprat=87 pasprat=75 loasc=144 lodes=162 dides=123))
((Inria\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=162 lvw=23 lhw=20 uvw=24 uhw=22 fillp=54 vcnt=47 lasprat=98 pasprat=81 loasc=147 lodes=143 dides=102))
((Inria\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=85 em=162 lvw=23 lhw=20 uvw=24 uhw=22 fillp=45 vcnt=46 lasprat=99 pasprat=93 loasc=147 lodes=143 dides=102))
((Inria\ Sans Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=83 em=166 lvw=16 lhw=14 uvw=18 uhw=16 fillp=35 vcnt=35 lasprat=98 pasprat=89 loasc=151 lodes=144 dides=102))
((Inria\ Sans Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=170 lvw=12 lhw=11 uvw=13 uhw=12 fillp=35 vcnt=26 lasprat=98 pasprat=73 loasc=154 lodes=145 dides=102))
((Inria\ Sans Light\ Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=81 em=170 lvw=12 lhw=11 uvw=13 uhw=12 fillp=28 vcnt=26 lasprat=99 pasprat=86 loasc=154 lodes=145 dides=102))
((Inria\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=166 lvw=16 lhw=14 uvw=18 uhw=16 fillp=44 vcnt=36 lasprat=97 pasprat=77 loasc=151 lodes=144 dides=102))
((Inria\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=170 lvw=24 lhw=7 uvw=24 uhw=7 fillp=38 vcnt=38 lasprat=104 pasprat=97 loasc=147 lodes=143 dides=102))
((Inria\ Serif Bold\ Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=86 em=168 lvw=24 lhw=6 uvw=24 uhw=6 fillp=36 vcnt=38 lasprat=103 pasprat=97 loasc=145 lodes=143 dides=102))
((Inria\ Serif Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=84 em=170 lvw=16 lhw=5 uvw=17 uhw=5 fillp=28 vcnt=29 lasprat=103 pasprat=94 loasc=148 lodes=144 dides=102))
((Inria\ Serif Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=175 lvw=13 lhw=6 uvw=14 uhw=6 fillp=26 vcnt=23 lasprat=106 pasprat=91 loasc=154 lodes=145 dides=102))
((Inria\ Serif Light\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=83 em=171 lvw=13 lhw=6 uvw=13 uhw=6 fillp=23 vcnt=23 lasprat=103 pasprat=90 loasc=150 lodes=144 dides=102))
((Inria\ Serif Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=172 lvw=18 lhw=6 uvw=19 uhw=6 fillp=31 vcnt=30 lasprat=105 pasprat=94 loasc=150 lodes=144 dides=102))
((Iowan\ Old\ Style Black) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=208 lvw=38 lhw=16 uvw=45 uhw=21 fillp=51 vcnt=55 lasprat=121 pasprat=115 loasc=156 lodes=153 dides=104))
((Iowan\ Old\ Style Black\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=80 em=202 lvw=38 lhw=17 uvw=43 uhw=20 fillp=47 vcnt=53 lasprat=115 pasprat=116 loasc=160 lodes=155 dides=105))
((Iowan\ Old\ Style Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=195 lvw=27 lhw=13 uvw=30 uhw=16 fillp=41 vcnt=42 lasprat=111 pasprat=103 loasc=155 lodes=154 dides=103))
((Iowan\ Old\ Style Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=80 em=187 lvw=25 lhw=13 uvw=28 uhw=13 fillp=38 vcnt=41 lasprat=101 pasprat=99 loasc=158 lodes=155 dides=103))
((Iowan\ Old\ Style Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=79 em=181 lvw=17 lhw=11 uvw=20 uhw=11 fillp=31 vcnt=32 lasprat=93 pasprat=90 loasc=160 lodes=155 dides=105))
((Iowan\ Old\ Style Roman) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=188 lvw=18 lhw=10 uvw=22 uhw=11 fillp=32 vcnt=33 lasprat=104 pasprat=95 loasc=157 lodes=155 dides=103))
((Iowan\ Old\ Style Titling) (sans=no slant=0))
((IPAexGothic Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=177 lvw=17 lhw=14 uvw=18 uhw=15 fillp=40 vcnt=35 lasprat=102 pasprat=82 loasc=148 lodes=138 dides=101))
((IPAexMincho Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=193 lvw=14 lhw=7 uvw=17 uhw=7 fillp=27 vcnt=27 lasprat=107 pasprat=97 loasc=150 lodes=141 dides=103))
((IPAGothic Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=94 lvw=14 lhw=13 uvw=15 uhw=13 fillp=45 vcnt=46 lasprat=94 pasprat=65 loasc=142 lodes=118 dides=100))
((IPAMincho Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=95 lvw=12 lhw=5 uvw=13 uhw=5 fillp=29 vcnt=31 lasprat=94 pasprat=72 loasc=146 lodes=118 dides=100))
((IPAPGothic Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=176 lvw=17 lhw=12 uvw=18 uhw=15 fillp=40 vcnt=42 lasprat=101 pasprat=82 loasc=149 lodes=138 dides=101))
((IPAPMincho Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=195 lvw=14 lhw=7 uvw=17 uhw=8 fillp=27 vcnt=30 lasprat=108 pasprat=97 loasc=150 lodes=140 dides=103))
((IPAUIGothic Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=176 lvw=17 lhw=12 uvw=18 uhw=15 fillp=40 vcnt=42 lasprat=101 pasprat=82 loasc=149 lodes=138 dides=101))
((Isabella Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=76 em=182 lvw=18 lhw=19 uvw=9 uhw=9 fillp=36 vcnt=41 lasprat=76 pasprat=74 loasc=176 lodes=146 dides=122))
((ISL_Andvari Regular) (mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=150 em=100 lvw=11 lhw=11 uvw=11 uhw=11 fillp=39 vcnt=59 lasprat=88 pasprat=67 loasc=100 lodes=100 dides=100))
((ISL_Jupiter Regular) (mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=53 em=196 lvw=22 lhw=22 uvw=22 uhw=22 fillp=50 vcnt=31 lasprat=121 pasprat=108 loasc=132 lodes=147 dides=100))
((ITF\ Devanagari Bold) (slant=0))
((ITF\ Devanagari Book) (slant=0))
((ITF\ Devanagari Demi) (slant=0))
((ITF\ Devanagari Light) (slant=0))
((ITF\ Devanagari Medium) (slant=0))
((ITF\ Devanagari\ Marathi Bold) (slant=0))
((ITF\ Devanagari\ Marathi Book) (slant=0))
((ITF\ Devanagari\ Marathi Demi) (slant=0))
((ITF\ Devanagari\ Marathi Light) (slant=0))
((ITF\ Devanagari\ Marathi Medium) (slant=0))
((Itsadzoke Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=102 em=208 lvw=30 lhw=3 uvw=30 uhw=3 fillp=43 vcnt=45 lasprat=122 pasprat=113 loasc=125 lodes=122 dides=101))
((ItsadzokeS01 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=102 em=208 lvw=3 lhw=3 uvw=3 uhw=3 fillp=32 vcnt=33 lasprat=122 pasprat=113 loasc=125 lodes=122 dides=101))
((ItsadzokeS02 Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=102 em=208 lvw=3 lhw=3 uvw=3 uhw=3 fillp=28 vcnt=29 lasprat=122 pasprat=113 loasc=126 lodes=121 dides=101))
((Iwona Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=210 lvw=26 lhw=13 uvw=29 uhw=14 fillp=45 vcnt=38 lasprat=105 pasprat=85 loasc=157 lodes=153 dides=102))
((Iwona Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=210 lvw=26 lhw=13 uvw=29 uhw=14 fillp=37 vcnt=39 lasprat=105 pasprat=102 loasc=157 lodes=153 dides=102))
((Iwona Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=214 lvw=30 lhw=14 uvw=32 uhw=16 fillp=48 vcnt=42 lasprat=105 pasprat=88 loasc=157 lodes=153 dides=102))
((Iwona Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=214 lvw=30 lhw=16 uvw=33 uhw=16 fillp=40 vcnt=43 lasprat=106 pasprat=105 loasc=157 lodes=153 dides=102))
((Iwona Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=198 lvw=20 lhw=9 uvw=21 uhw=10 fillp=29 vcnt=29 lasprat=101 pasprat=95 loasc=157 lodes=153 dides=102))
((Iwona Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=192 lvw=14 lhw=6 uvw=16 uhw=8 fillp=28 vcnt=22 lasprat=98 pasprat=76 loasc=157 lodes=153 dides=101))
((Iwona Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=192 lvw=14 lhw=6 uvw=16 uhw=8 fillp=22 vcnt=22 lasprat=98 pasprat=92 loasc=157 lodes=153 dides=101))
((Iwona Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=198 lvw=20 lhw=9 uvw=21 uhw=10 fillp=35 vcnt=29 lasprat=101 pasprat=79 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=186 lvw=26 lhw=13 uvw=29 uhw=14 fillp=48 vcnt=41 lasprat=92 pasprat=74 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=186 lvw=26 lhw=14 uvw=29 uhw=14 fillp=39 vcnt=42 lasprat=92 pasprat=92 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=190 lvw=29 lhw=14 uvw=32 uhw=16 fillp=52 vcnt=46 lasprat=93 pasprat=78 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=190 lvw=29 lhw=16 uvw=32 uhw=17 fillp=42 vcnt=46 lasprat=93 pasprat=95 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=176 lvw=18 lhw=9 uvw=21 uhw=10 fillp=31 vcnt=31 lasprat=89 pasprat=85 loasc=157 lodes=153 dides=102))
((Iwona\ Cond Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=176 lvw=14 lhw=6 uvw=16 uhw=8 fillp=30 vcnt=24 lasprat=89 pasprat=69 loasc=157 lodes=153 dides=101))
((Iwona\ Cond Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=176 lvw=14 lhw=6 uvw=16 uhw=8 fillp=23 vcnt=24 lasprat=89 pasprat=85 loasc=157 lodes=153 dides=101))
((Iwona\ Cond Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=176 lvw=20 lhw=9 uvw=21 uhw=10 fillp=38 vcnt=31 lasprat=89 pasprat=69 loasc=157 lodes=153 dides=102))
((Javanese\ Text Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=224 lvw=23 lhw=8 uvw=26 uhw=10 fillp=34 vcnt=32 lasprat=117 pasprat=108 loasc=173 lodes=166 dides=136))
((Jazz\ LET Plain) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=173 lvw=10 lhw=8 uvw=8 uhw=8 fillp=46 vcnt=46 lasprat=119 pasprat=113 loasc=142 lodes=153 dides=103))
((Junicode Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=214 lvw=30 lhw=10 uvw=31 uhw=11 fillp=40 vcnt=41 lasprat=108 pasprat=105 loasc=175 lodes=165 dides=105))
((Junicode Bold\ Italic) (Ascii Latin mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=70 em=224 lvw=24 lhw=12 uvw=27 uhw=10 fillp=35 vcnt=38 lasprat=100 pasprat=103 loasc=174 lodes=165 dides=105))
((Junicode Italic) (Ascii Latin Greek mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=69 em=227 lvw=15 lhw=11 uvw=18 uhw=8 fillp=26 vcnt=26 lasprat=96 pasprat=96 loasc=175 lodes=165 dides=104))
((Junicode Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=218 lvw=17 lhw=7 uvw=23 uhw=8 fillp=30 vcnt=31 lasprat=105 pasprat=97 loasc=175 lodes=166 dides=104))
((Jura Book) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=138 lvw=10 lhw=10 uvw=10 uhw=10 fillp=30 vcnt=28 lasprat=120 pasprat=89 loasc=136 lodes=141 dides=103))
((Jura DemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=146 lvw=15 lhw=15 uvw=15 uhw=14 fillp=39 vcnt=36 lasprat=129 pasprat=98 loasc=138 lodes=141 dides=103))
((Jura Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=133 lvw=9 lhw=9 uvw=9 uhw=7 fillp=26 vcnt=24 lasprat=116 pasprat=85 loasc=136 lodes=141 dides=103))
((Jura Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=142 lvw=12 lhw=12 uvw=12 uhw=12 fillp=35 vcnt=32 lasprat=125 pasprat=94 loasc=137 lodes=141 dides=103))
((Justus Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=200 lvw=31 lhw=6 uvw=35 uhw=6 fillp=41 vcnt=45 lasprat=117 pasprat=108 loasc=148 lodes=145 dides=102))
((Justus Italic) (Ascii Latin mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=84 em=191 lvw=20 lhw=4 uvw=22 uhw=4 fillp=28 vcnt=31 lasprat=106 pasprat=104 loasc=145 lodes=144 dides=102))
((Justus ItalicOldstyle) (Ascii Latin mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=84 em=191 lvw=20 lhw=4 uvw=22 uhw=4 fillp=28 vcnt=31 lasprat=106 pasprat=104 loasc=145 lodes=144 dides=144))
((Justus Oldstyle) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=23 lhw=4 uvw=26 uhw=6 fillp=33 vcnt=36 lasprat=110 pasprat=100 loasc=148 lodes=145 dides=145))
((Justus Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=192 lvw=23 lhw=4 uvw=26 uhw=6 fillp=33 vcnt=36 lasprat=110 pasprat=100 loasc=148 lodes=145 dides=102))
((Justus Versalitas) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=86 em=183 lvw=22 lhw=4 uvw=25 uhw=5 fillp=33 vcnt=34 lasprat=112 pasprat=99 loasc=102 lodes=127 dides=102))
((KacstOne Medium) (slant=0))
((Kai Regular) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=201 lvw=14 lhw=7 uvw=18 uhw=9 fillp=29 vcnt=29 lasprat=101 pasprat=91 loasc=151 lodes=136 dides=103))
((Kailasa Bold) ())
((Kailasa Regular) ())
((Kaiti\ SC Black) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=210 lvw=28 lhw=8 uvw=32 uhw=8 fillp=40 vcnt=36 lasprat=101 pasprat=95 loasc=161 lodes=133 dides=100))
((Kaiti\ SC Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=21 lhw=6 uvw=25 uhw=6 fillp=32 vcnt=29 lasprat=102 pasprat=92 loasc=162 lodes=140 dides=100))
((Kaiti\ SC Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=16 lhw=4 uvw=20 uhw=4 fillp=27 vcnt=24 lasprat=102 pasprat=90 loasc=162 lodes=140 dides=100))
((Kaiti\ TC Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=21 lhw=6 uvw=25 uhw=6 fillp=32 vcnt=29 lasprat=102 pasprat=92 loasc=162 lodes=140 dides=100))
((Kaiti\ TC Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=16 lhw=4 uvw=20 uhw=4 fillp=27 vcnt=24 lasprat=102 pasprat=90 loasc=162 lodes=140 dides=100))
((KaiTi_GB2312 Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=103 lvw=13 lhw=4 uvw=16 uhw=7 fillp=31 vcnt=32 lasprat=103 pasprat=76 loasc=149 lodes=125 dides=100))
((Kannada\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=44 lasprat=106 pasprat=95 loasc=147 lodes=141 dides=103))
((Kannada\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=177 lvw=22 lhw=7 uvw=25 uhw=6 fillp=39 vcnt=32 lasprat=100 pasprat=89 loasc=150 lodes=146 dides=102))
((Kannada\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=151 lvw=21 lhw=16 uvw=22 uhw=17 fillp=50 vcnt=50 lasprat=91 pasprat=81 loasc=142 lodes=142 dides=102))
((Kannada\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=151 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=36 lasprat=91 pasprat=77 loasc=144 lodes=144 dides=102))
((Kartika Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=55 em=160 lvw=18 lhw=12 uvw=18 uhw=16 fillp=44 vcnt=29 lasprat=94 pasprat=79 loasc=138 lodes=140 dides=101))
((Kawoszeh Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=171 lvw=15 lhw=8 uvw=15 uhw=7 fillp=28 vcnt=29 lasprat=102 pasprat=95 loasc=151 lodes=150 dides=101))
((Kedage Bold) ())
((Kedage Normal) ())
((Kefa Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=181 lvw=31 lhw=18 uvw=34 uhw=20 fillp=52 vcnt=51 lasprat=109 pasprat=99 loasc=141 lodes=143 dides=102))
((Kefa Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=174 lvw=23 lhw=13 uvw=24 uhw=14 fillp=43 vcnt=40 lasprat=104 pasprat=91 loasc=143 lodes=144 dides=102))
((Kepler\ Std Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=195 lvw=26 lhw=6 uvw=29 uhw=6 fillp=37 vcnt=35 lasprat=109 pasprat=103 loasc=156 lodes=156 dides=104))
((Kerkis Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=186 lvw=35 lhw=19 uvw=38 uhw=20 fillp=55 vcnt=58 lasprat=115 pasprat=110 loasc=146 lodes=148 dides=102))
((Kerkis BoldItalic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=87 em=164 lvw=32 lhw=17 uvw=35 uhw=18 fillp=50 vcnt=56 lasprat=113 pasprat=112 loasc=145 lodes=140 dides=102))
((Kerkis BoldSmallCaps) (mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=85 em=184 lvw=32 lhw=21 uvw=36 uhw=20 fillp=58 vcnt=53 lasprat=120 pasprat=103 loasc=102 lodes=138 dides=137))
((Kerkis Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=84 em=170 lvw=19 lhw=8 uvw=21 uhw=9 fillp=32 vcnt=36 lasprat=107 pasprat=107 loasc=145 lodes=144 dides=102))
((Kerkis Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=20 lhw=8 uvw=24 uhw=9 fillp=34 vcnt=36 lasprat=112 pasprat=108 loasc=150 lodes=149 dides=102))
((Kerkis SmallCaps) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=85 em=180 lvw=17 lhw=8 uvw=22 uhw=9 fillp=34 vcnt=32 lasprat=108 pasprat=99 loasc=102 lodes=128 dides=141))
((Kerkis-Calligraphic Calligraphic) (Ascii mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=84 em=238 lvw=19 lhw=8 uvw=16 uhw=13 fillp=29 vcnt=31 lasprat=107 pasprat=107 loasc=145 lodes=144 dides=102))
((Kerkis-SemiBold SemiBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=25 lhw=13 uvw=29 uhw=16 fillp=44 vcnt=46 lasprat=112 pasprat=108 loasc=151 lodes=149 dides=102))
((Kerkis-SemiBold SemiBold-Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=84 em=170 lvw=23 lhw=13 uvw=26 uhw=14 fillp=41 vcnt=46 lasprat=107 pasprat=108 loasc=144 lodes=144 dides=102))
((KerkisSans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=163 lvw=27 lhw=24 uvw=27 uhw=25 fillp=59 vcnt=55 lasprat=98 pasprat=88 loasc=132 lodes=140 dides=102))
((KerkisSans BoldItalic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=85 em=163 lvw=27 lhw=24 uvw=28 uhw=25 fillp=51 vcnt=55 lasprat=98 pasprat=98 loasc=132 lodes=140 dides=102))
((KerkisSans Italic) (Ascii Latin mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=82 em=173 lvw=17 lhw=14 uvw=17 uhw=15 fillp=34 vcnt=35 lasprat=98 pasprat=96 loasc=134 lodes=139 dides=102))
((KerkisSans Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=173 lvw=15 lhw=14 uvw=17 uhw=15 fillp=41 vcnt=35 lasprat=98 pasprat=85 loasc=134 lodes=139 dides=102))
((KerkisSans SmallCaps) (mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=86 em=165 lvw=15 lhw=13 uvw=16 uhw=15 fillp=42 vcnt=37 lasprat=86 pasprat=81 loasc=101 lodes=102 dides=102))
((Keyboard Regular) ())
((Keytin Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=63 lvw=4 lhw=4 uvw=4 uhw=4 fillp=32 vcnt=31 lasprat=37 pasprat=28 loasc=142 lodes=134 dides=101))
((Khmer\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=181 lvw=31 lhw=11 uvw=35 uhw=10 fillp=51 vcnt=41 lasprat=106 pasprat=94 loasc=147 lodes=140 dides=102))
((Khmer\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=178 lvw=22 lhw=8 uvw=25 uhw=6 fillp=39 vcnt=30 lasprat=100 pasprat=89 loasc=152 lodes=145 dides=104))
((Khmer\ OS Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=92 pasprat=77 loasc=139 lodes=142 dides=104))
((Khmer\ OS\ System Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=92 pasprat=77 loasc=139 lodes=142 dides=104))
((Khmer\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=32 lasprat=94 pasprat=77 loasc=143 lodes=144 dides=102))
((Kinnari Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=187 lvw=22 lhw=12 uvw=26 uhw=13 fillp=42 vcnt=45 lasprat=96 pasprat=94 loasc=151 lodes=145 dides=103))
((Kinnari BoldItalic) (Ascii mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=6 uvw=33 uhw=7 fillp=38 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=145 dides=102))
((Kinnari BoldOblique) (Ascii mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=79 em=187 lvw=25 lhw=12 uvw=29 uhw=13 fillp=37 vcnt=40 lasprat=96 pasprat=104 loasc=151 lodes=145 dides=103))
((Kinnari Italic) (Ascii mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=187 lvw=20 lhw=5 uvw=24 uhw=6 fillp=28 vcnt=29 lasprat=100 pasprat=98 loasc=154 lodes=147 dides=104))
((Kinnari Medium) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=18 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=93 loasc=152 lodes=148 dides=105))
((Kinnari Oblique) (Ascii mono=no sans=no slant=20 italic=no case=mixed regular=yes ex=75 em=197 lvw=21 lhw=8 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=101 pasprat=104 loasc=152 lodes=148 dides=105))
((Kinnari Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=21 lhw=8 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=152 lodes=149 dides=105))
((Klee Demibold) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=176 lvw=14 lhw=12 uvw=13 uhw=13 fillp=34 vcnt=28 lasprat=106 pasprat=83 loasc=146 lodes=135 dides=103))
((Klee Medium) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=178 lvw=11 lhw=11 uvw=12 uhw=11 fillp=30 vcnt=24 lasprat=107 pasprat=83 loasc=148 lodes=137 dides=103))
((Kochi\ Gothic Regular) (Ascii CJK MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=95 lvw=17 lhw=14 uvw=17 uhw=14 fillp=46 vcnt=49 lasprat=95 pasprat=73 loasc=142 lodes=128 dides=103))
((Kohinoor\ Bangla Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=159 lvw=27 lhw=21 uvw=27 uhw=22 fillp=59 vcnt=57 lasprat=96 pasprat=83 loasc=142 lodes=138 dides=102))
((Kohinoor\ Bangla Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=155 lvw=11 lhw=10 uvw=11 uhw=11 fillp=31 vcnt=27 lasprat=91 pasprat=70 loasc=142 lodes=141 dides=102))
((Kohinoor\ Bangla Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=156 lvw=18 lhw=15 uvw=18 uhw=16 fillp=45 vcnt=41 lasprat=93 pasprat=76 loasc=140 lodes=140 dides=102))
((Kohinoor\ Bangla Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=156 lvw=14 lhw=12 uvw=15 uhw=13 fillp=38 vcnt=34 lasprat=92 pasprat=73 loasc=141 lodes=140 dides=102))
((Kohinoor\ Bangla Semibold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=158 lvw=23 lhw=18 uvw=22 uhw=19 fillp=52 vcnt=49 lasprat=94 pasprat=79 loasc=141 lodes=138 dides=102))
((Kohinoor\ Devanagari Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=94 em=159 lvw=27 lhw=21 uvw=27 uhw=22 fillp=59 vcnt=57 lasprat=96 pasprat=83 loasc=142 lodes=138 dides=102))
((Kohinoor\ Devanagari Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=155 lvw=11 lhw=10 uvw=11 uhw=11 fillp=31 vcnt=27 lasprat=91 pasprat=70 loasc=141 lodes=141 dides=102))
((Kohinoor\ Devanagari Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=156 lvw=18 lhw=15 uvw=18 uhw=16 fillp=45 vcnt=41 lasprat=93 pasprat=76 loasc=140 lodes=140 dides=102))
((Kohinoor\ Devanagari Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=156 lvw=14 lhw=12 uvw=15 uhw=13 fillp=38 vcnt=34 lasprat=92 pasprat=73 loasc=140 lodes=140 dides=102))
((Kohinoor\ Devanagari Semibold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=158 lvw=23 lhw=18 uvw=22 uhw=19 fillp=52 vcnt=49 lasprat=94 pasprat=79 loasc=141 lodes=138 dides=102))
((Kohinoor\ Telugu Bold) (slant=0))
((Kohinoor\ Telugu Light) (slant=0))
((Kohinoor\ Telugu Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=156 lvw=18 lhw=15 uvw=18 uhw=16 fillp=45 vcnt=41 lasprat=93 pasprat=76 loasc=140 lodes=140 dides=102))
((Kohinoor\ Telugu Regular) (slant=0))
((Kohinoor\ Telugu Semibold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=158 lvw=23 lhw=18 uvw=22 uhw=19 fillp=52 vcnt=49 lasprat=94 pasprat=79 loasc=141 lodes=139 dides=102))
((Kohinoor\ Telugu\ Semibold Regular) (slant=0))
((Kokonor Regular) ())
((Koufi\ Abjadi Regular) (slant=0))
((Koufi\ Abjadi\ PUA Regular) ())
((KpMath Bold) (Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=212 lvw=31 lhw=10 uvw=33 uhw=12 fillp=43 vcnt=39 lasprat=120 pasprat=105 loasc=164 lodes=163 dides=104))
((KpMath Light) (Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=209 lvw=17 lhw=6 uvw=19 uhw=8 fillp=28 vcnt=25 lasprat=116 pasprat=100 loasc=164 lodes=160 dides=104))
((KpMath Regular) (Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=206 lvw=21 lhw=8 uvw=22 uhw=9 fillp=32 vcnt=29 lasprat=115 pasprat=100 loasc=162 lodes=159 dides=104))
((KpMath Semibold) (Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=209 lvw=26 lhw=9 uvw=29 uhw=10 fillp=38 vcnt=34 lasprat=118 pasprat=101 loasc=161 lodes=161 dides=104))
((KpMathSans Regular) (Greek MathSymbols MathLetters mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=174 lvw=18 lhw=12 uvw=20 uhw=13 fillp=37 vcnt=30 lasprat=112 pasprat=93 loasc=145 lodes=143 dides=102))
((KpMono Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=117 lvw=22 lhw=9 uvw=24 uhw=13 fillp=44 vcnt=36 lasprat=117 pasprat=87 loasc=142 lodes=144 dides=104))
((KpMono BoldItalic) (Ascii Latin mono=yes sans=yes slant=19 italic=no case=mixed regular=yes ex=75 em=117 lvw=22 lhw=9 uvw=24 uhw=13 fillp=38 vcnt=36 lasprat=117 pasprat=99 loasc=142 lodes=144 dides=104))
((KpMono Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=74 em=118 lvw=18 lhw=6 uvw=21 uhw=10 fillp=33 vcnt=30 lasprat=118 pasprat=100 loasc=141 lodes=143 dides=104))
((KpMono Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=118 lvw=20 lhw=6 uvw=21 uhw=10 fillp=38 vcnt=30 lasprat=118 pasprat=88 loasc=141 lodes=143 dides=104))
((KpRoman Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=212 lvw=31 lhw=10 uvw=33 uhw=12 fillp=43 vcnt=39 lasprat=120 pasprat=105 loasc=164 lodes=163 dides=104))
((KpRoman BoldItalic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=197 lvw=25 lhw=14 uvw=29 uhw=9 fillp=38 vcnt=37 lasprat=111 pasprat=100 loasc=155 lodes=158 dides=103))
((KpRoman Italic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=196 lvw=16 lhw=10 uvw=19 uhw=7 fillp=28 vcnt=27 lasprat=101 pasprat=91 loasc=155 lodes=159 dides=102))
((KpRoman Light) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=209 lvw=17 lhw=6 uvw=19 uhw=8 fillp=28 vcnt=25 lasprat=116 pasprat=100 loasc=165 lodes=160 dides=105))
((KpRoman LightItalic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=78 em=193 lvw=14 lhw=8 uvw=15 uhw=7 fillp=24 vcnt=23 lasprat=100 pasprat=87 loasc=155 lodes=158 dides=102))
((KpRoman Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=206 lvw=21 lhw=8 uvw=22 uhw=9 fillp=32 vcnt=29 lasprat=115 pasprat=100 loasc=162 lodes=159 dides=105))
((KpRoman Semibold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=209 lvw=26 lhw=9 uvw=29 uhw=10 fillp=38 vcnt=35 lasprat=118 pasprat=102 loasc=161 lodes=161 dides=104))
((KpRoman SemiboldItalic) (Ascii Latin Greek mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=197 lvw=22 lhw=11 uvw=25 uhw=9 fillp=34 vcnt=32 lasprat=111 pasprat=96 loasc=155 lodes=159 dides=103))
((KpSans Bold) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=187 lvw=24 lhw=16 uvw=27 uhw=17 fillp=45 vcnt=37 lasprat=118 pasprat=100 loasc=145 lodes=144 dides=102))
((KpSans BoldItalic) (Ascii Latin Greek mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=74 em=187 lvw=25 lhw=16 uvw=27 uhw=17 fillp=38 vcnt=37 lasprat=120 pasprat=112 loasc=145 lodes=144 dides=102))
((KpSans Italic) (Ascii Latin Greek mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=74 em=174 lvw=18 lhw=12 uvw=20 uhw=13 fillp=31 vcnt=30 lasprat=112 pasprat=105 loasc=145 lodes=143 dides=102))
((KpSans Regular) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=174 lvw=18 lhw=12 uvw=20 uhw=13 fillp=37 vcnt=30 lasprat=112 pasprat=93 loasc=145 lodes=143 dides=102))
((Krungthep Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=97 em=172 lvw=28 lhw=14 uvw=28 uhw=14 fillp=62 vcnt=72 lasprat=108 pasprat=82 loasc=128 lodes=143 dides=100))
((KufiStandardGK Regular) (slant=0))
((KufiStandardGK\ PUA Regular) (slant=0))
((Kurier Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=210 lvw=26 lhw=13 uvw=29 uhw=14 fillp=43 vcnt=37 lasprat=110 pasprat=91 loasc=157 lodes=154 dides=102))
((Kurier Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=210 lvw=26 lhw=13 uvw=29 uhw=14 fillp=36 vcnt=38 lasprat=110 pasprat=107 loasc=157 lodes=153 dides=102))
((Kurier Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=214 lvw=30 lhw=14 uvw=32 uhw=16 fillp=47 vcnt=41 lasprat=111 pasprat=93 loasc=157 lodes=153 dides=102))
((Kurier Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=214 lvw=29 lhw=16 uvw=33 uhw=16 fillp=39 vcnt=42 lasprat=111 pasprat=111 loasc=157 lodes=153 dides=102))
((Kurier Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=198 lvw=20 lhw=9 uvw=21 uhw=10 fillp=28 vcnt=28 lasprat=107 pasprat=101 loasc=157 lodes=153 dides=102))
((Kurier Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=192 lvw=14 lhw=6 uvw=16 uhw=8 fillp=27 vcnt=22 lasprat=103 pasprat=81 loasc=157 lodes=153 dides=101))
((Kurier Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=192 lvw=14 lhw=6 uvw=16 uhw=8 fillp=22 vcnt=22 lasprat=103 pasprat=98 loasc=157 lodes=153 dides=101))
((Kurier Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=198 lvw=20 lhw=9 uvw=21 uhw=10 fillp=34 vcnt=28 lasprat=107 pasprat=85 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=186 lvw=26 lhw=13 uvw=29 uhw=14 fillp=47 vcnt=40 lasprat=98 pasprat=80 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=186 lvw=26 lhw=13 uvw=29 uhw=14 fillp=38 vcnt=41 lasprat=98 pasprat=98 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=190 lvw=29 lhw=14 uvw=32 uhw=16 fillp=50 vcnt=45 lasprat=99 pasprat=83 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=75 em=190 lvw=29 lhw=16 uvw=32 uhw=17 fillp=41 vcnt=45 lasprat=99 pasprat=101 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=176 lvw=20 lhw=9 uvw=21 uhw=10 fillp=30 vcnt=31 lasprat=94 pasprat=91 loasc=157 lodes=153 dides=102))
((Kurier\ Cond Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=176 lvw=14 lhw=6 uvw=16 uhw=8 fillp=29 vcnt=23 lasprat=94 pasprat=75 loasc=157 lodes=153 dides=101))
((Kurier\ Cond Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=176 lvw=14 lhw=6 uvw=16 uhw=8 fillp=23 vcnt=23 lasprat=94 pasprat=91 loasc=157 lodes=153 dides=101))
((Kurier\ Cond Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=176 lvw=20 lhw=9 uvw=21 uhw=10 fillp=37 vcnt=31 lasprat=94 pasprat=74 loasc=157 lodes=153 dides=102))
((Laimoon Regular) (slant=0))
((Laimoon\ PUA Regular) ())
((Laksaman Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=169 lvw=17 lhw=15 uvw=17 uhw=16 fillp=40 vcnt=38 lasprat=105 pasprat=92 loasc=150 lodes=144 dides=104))
((Laksaman Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=86 em=167 lvw=18 lhw=16 uvw=18 uhw=16 fillp=33 vcnt=38 lasprat=105 pasprat=105 loasc=150 lodes=144 dides=104))
((Laksaman Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=85 em=161 lvw=11 lhw=9 uvw=11 uhw=10 fillp=22 vcnt=25 lasprat=99 pasprat=99 loasc=151 lodes=150 dides=103))
((Laksaman Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=159 lvw=11 lhw=9 uvw=11 uhw=9 fillp=29 vcnt=26 lasprat=97 pasprat=83 loasc=151 lodes=148 dides=102))
((Lampoon Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=104 em=110 lvw=20 lhw=20 uvw=20 uhw=20 fillp=67 vcnt=71 lasprat=67 pasprat=58 loasc=120 lodes=120 dides=100))
((Lantinghei\ SC Demibold) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=191 lvw=22 lhw=16 uvw=24 uhw=19 fillp=45 vcnt=47 lasprat=111 pasprat=97 loasc=150 lodes=152 dides=111))
((Lantinghei\ SC Extralight) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=11 lhw=7 uvw=12 uhw=8 fillp=28 vcnt=25 lasprat=98 pasprat=83 loasc=141 lodes=144 dides=108))
((Lantinghei\ SC Heavy) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=192 lvw=35 lhw=26 uvw=37 uhw=30 fillp=58 vcnt=70 lasprat=125 pasprat=114 loasc=158 lodes=165 dides=118))
((Lantinghei\ TC Demibold) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=191 lvw=22 lhw=16 uvw=24 uhw=19 fillp=45 vcnt=47 lasprat=111 pasprat=97 loasc=150 lodes=152 dides=111))
((Lantinghei\ TC Extralight) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=11 lhw=7 uvw=12 uhw=8 fillp=28 vcnt=25 lasprat=98 pasprat=83 loasc=141 lodes=144 dides=108))
((Lantinghei\ TC Heavy) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=192 lvw=35 lhw=26 uvw=37 uhw=30 fillp=58 vcnt=70 lasprat=125 pasprat=114 loasc=158 lodes=165 dides=118))
((Lao\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Lao\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=21 lhw=6 uvw=25 uhw=6 fillp=38 vcnt=35 lasprat=99 pasprat=88 loasc=150 lodes=146 dides=103))
((Lao\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=32 lasprat=94 pasprat=77 loasc=143 lodes=144 dides=102))
((LastResort Regular) (mono=yes sans=no slant=0 italic=no case=caps regular=yes ex=125 em=152 lvw=12 lhw=12 uvw=12 uhw=12 fillp=36 vcnt=57 lasprat=152 pasprat=127 loasc=100 lodes=127 dides=127))
((Latha Regular) (slant=0))
((Latin\ Modern\ Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=5 uvw=25 uhw=5 fillp=28 vcnt=26 lasprat=113 pasprat=101 loasc=163 lodes=147 dides=105))
((Lato Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=180 lvw=29 lhw=21 uvw=32 uhw=26 fillp=58 vcnt=64 lasprat=100 pasprat=86 loasc=144 lodes=134 dides=101))
((Lato Black\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=87 em=165 lvw=28 lhw=21 uvw=31 uhw=24 fillp=54 vcnt=61 lasprat=93 pasprat=89 loasc=143 lodes=134 dides=101))
((Lato Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=180 lvw=24 lhw=18 uvw=26 uhw=22 fillp=51 vcnt=55 lasprat=98 pasprat=85 loasc=144 lodes=134 dides=101))
((Lato Bold\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=86 em=166 lvw=23 lhw=18 uvw=25 uhw=20 fillp=47 vcnt=52 lasprat=92 pasprat=86 loasc=144 lodes=134 dides=101))
((Lato Hairline) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=182 lvw=2 lhw=2 uvw=2 uhw=2 fillp=10 vcnt=7 lasprat=94 pasprat=71 loasc=147 lodes=137 dides=101))
((Lato Hairline\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=82 em=168 lvw=2 lhw=2 uvw=2 uhw=2 fillp=7 vcnt=7 lasprat=86 pasprat=74 loasc=147 lodes=137 dides=101))
((Lato Heavy) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=184 lvw=27 lhw=19 uvw=29 uhw=24 fillp=55 vcnt=53 lasprat=98 pasprat=86 loasc=145 lodes=134 dides=102))
((Lato Heavy\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=86 em=172 lvw=26 lhw=19 uvw=29 uhw=22 fillp=49 vcnt=53 lasprat=93 pasprat=90 loasc=145 lodes=136 dides=102))
((Lato Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=85 em=165 lvw=16 lhw=14 uvw=18 uhw=15 fillp=37 vcnt=41 lasprat=90 pasprat=82 loasc=144 lodes=135 dides=101))
((Lato Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=183 lvw=9 lhw=7 uvw=10 uhw=8 fillp=26 vcnt=25 lasprat=95 pasprat=76 loasc=146 lodes=137 dides=101))
((Lato Light\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=83 em=167 lvw=9 lhw=7 uvw=9 uhw=8 fillp=23 vcnt=24 lasprat=88 pasprat=79 loasc=146 lodes=137 dides=101))
((Lato Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=182 lvw=18 lhw=15 uvw=22 uhw=17 fillp=44 vcnt=40 lasprat=97 pasprat=82 loasc=145 lodes=136 dides=102))
((Lato Medium\ Italic) (Ascii Latin mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=85 em=170 lvw=18 lhw=15 uvw=20 uhw=16 fillp=39 vcnt=40 lasprat=91 pasprat=85 loasc=145 lodes=136 dides=102))
((Lato Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=180 lvw=17 lhw=12 uvw=18 uhw=16 fillp=41 vcnt=43 lasprat=97 pasprat=79 loasc=144 lodes=135 dides=101))
((Lato Semibold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=183 lvw=22 lhw=16 uvw=23 uhw=20 fillp=47 vcnt=43 lasprat=97 pasprat=83 loasc=145 lodes=136 dides=102))
((Lato Semibold\ Italic) (Ascii Latin mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=85 em=170 lvw=21 lhw=16 uvw=23 uhw=18 fillp=42 vcnt=43 lasprat=92 pasprat=86 loasc=145 lodes=136 dides=102))
((Lato Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=180 lvw=6 lhw=4 uvw=4 uhw=4 fillp=17 vcnt=11 lasprat=95 pasprat=71 loasc=145 lodes=138 dides=102))
((Lato Thin\ Italic) (Ascii Latin mono=no sans=yes slant=12 italic=yes case=mixed regular=yes ex=83 em=167 lvw=4 lhw=4 uvw=4 uhw=4 fillp=13 vcnt=11 lasprat=88 pasprat=74 loasc=145 lodes=138 dides=102))
((Leelawadee\ UI Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=56 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Leelawadee\ UI Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Leelawadee\ UI SemiLight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=11 lhw=10 uvw=14 uhw=11 fillp=34 vcnt=28 lasprat=95 pasprat=77 loasc=148 lodes=146 dides=102))
((Lexend\ Deca Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=165 lvw=19 lhw=18 uvw=20 uhw=19 fillp=45 vcnt=41 lasprat=105 pasprat=87 loasc=148 lodes=144 dides=101))
((Lexend\ Exa Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=189 lvw=19 lhw=18 uvw=21 uhw=19 fillp=43 vcnt=35 lasprat=132 pasprat=98 loasc=148 lodes=144 dides=101))
((Lexend\ Giga Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=198 lvw=20 lhw=18 uvw=20 uhw=19 fillp=43 vcnt=34 lasprat=142 pasprat=101 loasc=148 lodes=144 dides=101))
((Lexend\ Mega Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=203 lvw=20 lhw=18 uvw=20 uhw=19 fillp=42 vcnt=33 lasprat=148 pasprat=104 loasc=148 lodes=144 dides=101))
((Lexend\ Peta Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=209 lvw=19 lhw=18 uvw=20 uhw=19 fillp=42 vcnt=32 lasprat=153 pasprat=106 loasc=148 lodes=144 dides=101))
((Lexend\ Tera Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=213 lvw=19 lhw=18 uvw=20 uhw=19 fillp=42 vcnt=32 lasprat=158 pasprat=108 loasc=148 lodes=144 dides=101))
((Lexend\ Zetta Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=225 lvw=19 lhw=18 uvw=21 uhw=19 fillp=41 vcnt=30 lasprat=172 pasprat=113 loasc=147 lodes=144 dides=101))
((Liberation\ Mono Bold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=27 lhw=18 uvw=27 uhw=21 fillp=54 vcnt=58 lasprat=113 pasprat=93 loasc=139 lodes=139 dides=102))
((Liberation\ Mono Bold\ Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=113 lvw=27 lhw=18 uvw=27 uhw=21 fillp=47 vcnt=52 lasprat=113 pasprat=104 loasc=139 lodes=139 dides=102))
((Liberation\ Mono Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=22 italic=no case=mixed regular=yes ex=88 em=113 lvw=17 lhw=12 uvw=18 uhw=14 fillp=35 vcnt=38 lasprat=113 pasprat=97 loasc=137 lodes=139 dides=102))
((Liberation\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=17 lhw=12 uvw=18 uhw=14 fillp=40 vcnt=43 lasprat=113 pasprat=87 loasc=137 lodes=139 dides=102))
((Liberation\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=160 lvw=27 lhw=18 uvw=27 uhw=21 fillp=55 vcnt=58 lasprat=102 pasprat=87 loasc=137 lodes=139 dides=102))
((Liberation\ Sans Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=156 lvw=27 lhw=18 uvw=27 uhw=21 fillp=46 vcnt=52 lasprat=102 pasprat=100 loasc=137 lodes=139 dides=102))
((Liberation\ Sans Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=12 uvw=18 uhw=14 fillp=34 vcnt=38 lasprat=92 pasprat=91 loasc=137 lodes=139 dides=102))
((Liberation\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=155 lvw=17 lhw=12 uvw=18 uhw=14 fillp=42 vcnt=43 lasprat=92 pasprat=78 loasc=137 lodes=139 dides=102))
((Liberation\ Serif Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=205 lvw=31 lhw=10 uvw=35 uhw=10 fillp=47 vcnt=48 lasprat=106 pasprat=98 loasc=153 lodes=146 dides=102))
((Liberation\ Serif Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=192 lvw=28 lhw=10 uvw=32 uhw=10 fillp=43 vcnt=44 lasprat=100 pasprat=98 loasc=153 lodes=146 dides=102))
((Liberation\ Serif Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=180 lvw=18 lhw=9 uvw=20 uhw=9 fillp=32 vcnt=33 lasprat=96 pasprat=90 loasc=153 lodes=146 dides=102))
((Liberation\ Serif Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=192 lvw=19 lhw=9 uvw=22 uhw=9 fillp=34 vcnt=35 lasprat=99 pasprat=91 loasc=153 lodes=146 dides=102))
((Libertinus\ Keyboard Regular) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=125 em=146 lvw=4 lhw=10 uvw=4 uhw=10 fillp=32 vcnt=42 lasprat=146 pasprat=117 loasc=100 lodes=128 dides=128))
((Libertinus\ Math Regular) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=194 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=108 pasprat=99 loasc=161 lodes=155 dides=104))
((Libertinus\ Mono Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=133 lvw=20 lhw=8 uvw=20 uhw=7 fillp=32 vcnt=28 lasprat=133 pasprat=112 loasc=146 lodes=148 dides=103))
((Libertinus\ Sans Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=213 lvw=33 lhw=11 uvw=37 uhw=12 fillp=48 vcnt=40 lasprat=122 pasprat=102 loasc=162 lodes=155 dides=102))
((Libertinus\ Sans Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=22 italic=yes case=mixed regular=yes ex=72 em=193 lvw=22 lhw=9 uvw=23 uhw=9 fillp=31 vcnt=30 lasprat=102 pasprat=101 loasc=161 lodes=155 dides=102))
((Libertinus\ Sans Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=20 lhw=9 uvw=23 uhw=9 fillp=37 vcnt=29 lasprat=107 pasprat=87 loasc=161 lodes=154 dides=102))
((Libertinus\ Serif Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=205 lvw=31 lhw=9 uvw=34 uhw=9 fillp=42 vcnt=39 lasprat=119 pasprat=109 loasc=158 lodes=154 dides=102))
((Libertinus\ Serif Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=197 lvw=30 lhw=13 uvw=32 uhw=9 fillp=39 vcnt=40 lasprat=115 pasprat=111 loasc=158 lodes=154 dides=109))
((Libertinus\ Serif Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=73 em=183 lvw=19 lhw=10 uvw=20 uhw=8 fillp=29 vcnt=29 lasprat=102 pasprat=97 loasc=160 lodes=154 dides=104))
((Libertinus\ Serif Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=194 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=108 pasprat=100 loasc=162 lodes=155 dides=104))
((Libertinus\ Serif SemiBold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=194 lvw=27 lhw=9 uvw=28 uhw=9 fillp=40 vcnt=37 lasprat=110 pasprat=99 loasc=160 lodes=154 dides=102))
((Libertinus\ Serif SemiBold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=191 lvw=28 lhw=12 uvw=30 uhw=10 fillp=38 vcnt=37 lasprat=114 pasprat=106 loasc=158 lodes=154 dides=106))
((Libertinus\ Serif\ Display Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=198 lvw=17 lhw=5 uvw=21 uhw=5 fillp=29 vcnt=26 lasprat=109 pasprat=96 loasc=169 lodes=159 dides=104))
((Libertinus\ Serif\ Initials Regular) (sans=no))
((Libian\ SC Regular) (Ascii CJK mono=no sans=yes slant=28 italic=yes case=mixed regular=no ex=67 em=205 lvw=19 lhw=11 uvw=17 uhw=14 fillp=29 vcnt=22 lasprat=117 pasprat=96 loasc=159 lodes=137 dides=113))
((Libre\ Baskerville Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=214 lvw=29 lhw=12 uvw=32 uhw=12 fillp=41 vcnt=46 lasprat=114 pasprat=106 loasc=156 lodes=149 dides=102))
((Libre\ Baskerville BoldItalic) (Ascii Latin mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=89 em=214 lvw=28 lhw=11 uvw=31 uhw=12 fillp=36 vcnt=46 lasprat=114 pasprat=117 loasc=156 lodes=148 dides=102))
((Libre\ Baskerville Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=90 em=188 lvw=20 lhw=10 uvw=23 uhw=10 fillp=32 vcnt=39 lasprat=96 pasprat=97 loasc=154 lodes=148 dides=102))
((Libre\ Baskerville Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=204 lvw=20 lhw=10 uvw=24 uhw=11 fillp=33 vcnt=36 lasprat=110 pasprat=100 loasc=156 lodes=149 dides=102))
((Libre\ Bodoni Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=206 lvw=34 lhw=8 uvw=42 uhw=8 fillp=41 vcnt=44 lasprat=119 pasprat=113 loasc=169 lodes=172 dides=102))
((Libre\ Bodoni Bold\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=77 em=196 lvw=33 lhw=7 uvw=38 uhw=6 fillp=38 vcnt=45 lasprat=111 pasprat=114 loasc=166 lodes=170 dides=102))
((Libre\ Bodoni Italic) (Ascii Latin mono=no sans=no slant=22 italic=yes case=mixed regular=yes ex=77 em=190 lvw=24 lhw=5 uvw=31 uhw=6 fillp=31 vcnt=36 lasprat=107 pasprat=107 loasc=166 lodes=170 dides=102))
((Libre\ Bodoni Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=29 lhw=6 uvw=36 uhw=6 fillp=35 vcnt=38 lasprat=113 pasprat=104 loasc=170 lodes=172 dides=106))
((Libre\ Caslon\ Text Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=203 lvw=30 lhw=10 uvw=36 uhw=11 fillp=44 vcnt=50 lasprat=114 pasprat=107 loasc=157 lodes=148 dides=105))
((Libre\ Caslon\ Text BoldItalic) (Ascii Latin mono=no sans=no slant=27 italic=no case=mixed regular=yes ex=88 em=203 lvw=30 lhw=10 uvw=35 uhw=11 fillp=38 vcnt=50 lasprat=114 pasprat=125 loasc=157 lodes=148 dides=105))
((Libre\ Caslon\ Text Italic) (Ascii Latin mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=90 em=184 lvw=17 lhw=6 uvw=21 uhw=8 fillp=27 vcnt=36 lasprat=99 pasprat=107 loasc=154 lodes=147 dides=102))
((Libre\ Caslon\ Text Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=192 lvw=19 lhw=9 uvw=23 uhw=9 fillp=32 vcnt=35 lasprat=102 pasprat=92 loasc=156 lodes=148 dides=103))
((Libre\ Franklin Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=185 lvw=37 lhw=23 uvw=44 uhw=29 fillp=67 vcnt=68 lasprat=107 pasprat=96 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Black\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=185 lvw=37 lhw=23 uvw=44 uhw=29 fillp=60 vcnt=67 lasprat=107 pasprat=104 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=179 lvw=28 lhw=19 uvw=34 uhw=23 fillp=58 vcnt=56 lasprat=104 pasprat=89 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Bold\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=179 lvw=28 lhw=19 uvw=32 uhw=23 fillp=51 vcnt=55 lasprat=104 pasprat=98 loasc=140 lodes=132 dides=102))
((Libre\ Franklin ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=182 lvw=32 lhw=21 uvw=39 uhw=26 fillp=63 vcnt=62 lasprat=105 pasprat=92 loasc=140 lodes=132 dides=102))
((Libre\ Franklin ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=182 lvw=32 lhw=21 uvw=38 uhw=26 fillp=56 vcnt=62 lasprat=105 pasprat=101 loasc=140 lodes=132 dides=102))
((Libre\ Franklin ExtraLight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=168 lvw=9 lhw=9 uvw=11 uhw=9 fillp=29 vcnt=22 lasprat=98 pasprat=75 loasc=140 lodes=132 dides=102))
((Libre\ Franklin ExtraLight\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=168 lvw=9 lhw=9 uvw=11 uhw=9 fillp=23 vcnt=22 lasprat=98 pasprat=85 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=171 lvw=15 lhw=12 uvw=18 uhw=13 fillp=34 vcnt=34 lasprat=100 pasprat=89 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=169 lvw=12 lhw=10 uvw=14 uhw=11 fillp=34 vcnt=28 lasprat=99 pasprat=77 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Light\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=169 lvw=12 lhw=10 uvw=14 uhw=11 fillp=28 vcnt=28 lasprat=99 pasprat=87 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=173 lvw=19 lhw=14 uvw=23 uhw=17 fillp=46 vcnt=41 lasprat=101 pasprat=83 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Medium\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=173 lvw=19 lhw=14 uvw=22 uhw=17 fillp=40 vcnt=41 lasprat=101 pasprat=92 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=171 lvw=15 lhw=12 uvw=18 uhw=13 fillp=40 vcnt=34 lasprat=100 pasprat=80 loasc=140 lodes=132 dides=102))
((Libre\ Franklin SemiBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=177 lvw=23 lhw=17 uvw=28 uhw=20 fillp=52 vcnt=49 lasprat=103 pasprat=86 loasc=140 lodes=132 dides=102))
((Libre\ Franklin SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=177 lvw=23 lhw=17 uvw=28 uhw=20 fillp=46 vcnt=49 lasprat=103 pasprat=95 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=167 lvw=7 lhw=7 uvw=9 uhw=7 fillp=26 vcnt=19 lasprat=97 pasprat=74 loasc=140 lodes=132 dides=102))
((Libre\ Franklin Thin\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=88 em=167 lvw=7 lhw=7 uvw=9 uhw=7 fillp=19 vcnt=19 lasprat=97 pasprat=84 loasc=140 lodes=132 dides=102))
((LiHei\ Pro Medium) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=160 lvw=20 lhw=18 uvw=20 uhw=18 fillp=46 vcnt=49 lasprat=101 pasprat=86 loasc=141 lodes=126 dides=100))
((Lilith Regular) (mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=125 em=80 lvw=9 lhw=9 uvw=9 uhw=9 fillp=25 vcnt=32 lasprat=80 pasprat=66 loasc=101 lodes=101 dides=100))
((Linesquare\ Rounded Extended) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=42 em=135 lvw=23 lhw=23 uvw=23 uhw=23 fillp=58 vcnt=26 lasprat=126 pasprat=114 loasc=126 lodes=138 dides=100))
((Linguistics\ Pro Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=32 lhw=9 uvw=35 uhw=9 fillp=48 vcnt=48 lasprat=110 pasprat=104 loasc=153 lodes=149 dides=102))
((Linguistics\ Pro Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=84 em=183 lvw=29 lhw=9 uvw=34 uhw=9 fillp=41 vcnt=48 lasprat=104 pasprat=108 loasc=147 lodes=147 dides=102))
((Linguistics\ Pro Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=84 em=182 lvw=19 lhw=7 uvw=21 uhw=7 fillp=30 vcnt=34 lasprat=100 pasprat=98 loasc=147 lodes=147 dides=102))
((Linguistics\ Pro Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=20 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=35 lasprat=104 pasprat=97 loasc=151 lodes=150 dides=102))
((Linux\ Biolinum Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=212 lvw=32 lhw=10 uvw=36 uhw=10 fillp=48 vcnt=47 lasprat=120 pasprat=101 loasc=160 lodes=154 dides=102))
((Linux\ Biolinum Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=yes case=mixed regular=yes ex=73 em=190 lvw=19 lhw=8 uvw=24 uhw=9 fillp=30 vcnt=31 lasprat=101 pasprat=100 loasc=160 lodes=153 dides=102))
((Linux\ Biolinum Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=202 lvw=17 lhw=8 uvw=23 uhw=9 fillp=37 vcnt=35 lasprat=106 pasprat=86 loasc=160 lodes=153 dides=102))
((Linux\ Biolinum\ Capitals Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=78 em=198 lvw=30 lhw=10 uvw=34 uhw=10 fillp=48 vcnt=44 lasprat=116 pasprat=100 loasc=102 lodes=139 dides=102))
((Linux\ Biolinum\ Capitals Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=no case=smallcaps regular=yes ex=78 em=178 lvw=19 lhw=7 uvw=23 uhw=8 fillp=31 vcnt=29 lasprat=105 pasprat=99 loasc=102 lodes=137 dides=102))
((Linux\ Biolinum\ Capitals Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=78 em=189 lvw=16 lhw=7 uvw=21 uhw=8 fillp=36 vcnt=32 lasprat=105 pasprat=87 loasc=102 lodes=137 dides=102))
((Linux\ Biolinum\ Keyboard Regular) (Ascii mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=126 em=146 lvw=4 lhw=10 uvw=4 uhw=10 fillp=32 vcnt=52 lasprat=146 pasprat=116 loasc=100 lodes=127 dides=127))
((Linux\ Biolinum\ Keyboard\ O Regular) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=125 em=146 lvw=4 lhw=10 uvw=4 uhw=10 fillp=32 vcnt=42 lasprat=146 pasprat=117 loasc=101 lodes=128 dides=128))
((Linux\ Biolinum\ O Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=213 lvw=33 lhw=12 uvw=37 uhw=12 fillp=48 vcnt=40 lasprat=122 pasprat=102 loasc=161 lodes=156 dides=102))
((Linux\ Biolinum\ O Bold\ Oblique) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=72 em=213 lvw=31 lhw=12 uvw=37 uhw=13 fillp=40 vcnt=40 lasprat=122 pasprat=121 loasc=161 lodes=156 dides=102))
((Linux\ Biolinum\ O Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=72 em=193 lvw=22 lhw=9 uvw=25 uhw=11 fillp=31 vcnt=30 lasprat=102 pasprat=101 loasc=161 lodes=155 dides=102))
((Linux\ Biolinum\ O Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=20 lhw=9 uvw=23 uhw=11 fillp=38 vcnt=29 lasprat=107 pasprat=87 loasc=161 lodes=155 dides=102))
((Linux\ Biolinum\ Outline Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=212 lvw=2 lhw=1 uvw=2 uhw=1 fillp=10 vcnt=10 lasprat=120 pasprat=101 loasc=160 lodes=154 dides=102))
((Linux\ Biolinum\ Outline Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=73 em=190 lvw=2 lhw=1 uvw=2 uhw=1 fillp=9 vcnt=9 lasprat=101 pasprat=100 loasc=160 lodes=154 dides=102))
((Linux\ Biolinum\ Outline Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=202 lvw=2 lhw=1 uvw=2 uhw=1 fillp=11 vcnt=10 lasprat=106 pasprat=86 loasc=160 lodes=154 dides=102))
((Linux\ Biolinum\ Shadow Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=226 lvw=2 lhw=16 uvw=2 uhw=16 fillp=28 vcnt=31 lasprat=132 pasprat=114 loasc=160 lodes=167 dides=116))
((Linux\ Biolinum\ Shadow Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=73 em=202 lvw=2 lhw=16 uvw=2 uhw=16 fillp=29 vcnt=33 lasprat=114 pasprat=113 loasc=160 lodes=167 dides=115))
((Linux\ Biolinum\ Shadow Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=215 lvw=2 lhw=16 uvw=2 uhw=16 fillp=31 vcnt=34 lasprat=119 pasprat=99 loasc=160 lodes=167 dides=115))
((Linux\ Biolinum\ Slanted Bold\ Slanted) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=73 em=212 lvw=32 lhw=10 uvw=36 uhw=10 fillp=40 vcnt=41 lasprat=120 pasprat=117 loasc=160 lodes=154 dides=102))
((Linux\ Biolinum\ Slanted Slanted) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=73 em=202 lvw=20 lhw=8 uvw=24 uhw=9 fillp=30 vcnt=30 lasprat=106 pasprat=102 loasc=160 lodes=153 dides=102))
((Linux\ Libertine Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=205 lvw=31 lhw=9 uvw=31 uhw=9 fillp=42 vcnt=42 lasprat=119 pasprat=110 loasc=160 lodes=153 dides=102))
((Linux\ Libertine Bold\ Italic) (Ascii Latin Greek MathSymbols mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=74 em=194 lvw=29 lhw=10 uvw=32 uhw=10 fillp=38 vcnt=39 lasprat=113 pasprat=110 loasc=158 lodes=152 dides=102))
((Linux\ Libertine Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=74 em=181 lvw=17 lhw=9 uvw=20 uhw=8 fillp=29 vcnt=29 lasprat=101 pasprat=96 loasc=158 lodes=154 dides=102))
((Linux\ Libertine Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=191 lvw=19 lhw=8 uvw=21 uhw=8 fillp=32 vcnt=32 lasprat=106 pasprat=97 loasc=160 lodes=154 dides=102))
((Linux\ Libertine Semibold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=194 lvw=27 lhw=9 uvw=30 uhw=9 fillp=40 vcnt=40 lasprat=110 pasprat=101 loasc=160 lodes=152 dides=104))
((Linux\ Libertine Semibold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=22 italic=yes case=mixed regular=yes ex=75 em=186 lvw=28 lhw=10 uvw=29 uhw=9 fillp=37 vcnt=38 lasprat=111 pasprat=105 loasc=156 lodes=153 dides=102))
((Linux\ Libertine\ Capitals Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=78 em=192 lvw=29 lhw=8 uvw=29 uhw=8 fillp=42 vcnt=40 lasprat=123 pasprat=112 loasc=102 lodes=144 dides=102))
((Linux\ Libertine\ Capitals Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=no case=smallcaps regular=yes ex=78 em=171 lvw=16 lhw=6 uvw=19 uhw=7 fillp=27 vcnt=26 lasprat=107 pasprat=108 loasc=102 lodes=142 dides=102))
((Linux\ Libertine\ Capitals Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=78 em=179 lvw=17 lhw=7 uvw=20 uhw=7 fillp=32 vcnt=31 lasprat=110 pasprat=98 loasc=103 lodes=137 dides=102))
((Linux\ Libertine\ Capitals Semibold\ Italic) (Latin Greek Cyrillic MathSymbols mono=no sans=no slant=25 italic=no case=smallcaps regular=yes ex=79 em=177 lvw=25 lhw=8 uvw=27 uhw=8 fillp=37 vcnt=36 lasprat=107 pasprat=115 loasc=102 lodes=140 dides=102))
((Linux\ Libertine\ Display Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=198 lvw=18 lhw=5 uvw=21 uhw=5 fillp=29 vcnt=29 lasprat=109 pasprat=100 loasc=169 lodes=157 dides=102))
((Linux\ Libertine\ Display\ Capitals Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=198 lvw=18 lhw=5 uvw=21 uhw=5 fillp=29 vcnt=29 lasprat=109 pasprat=100 loasc=169 lodes=157 dides=102))
((Linux\ Libertine\ Display\ O Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=198 lvw=18 lhw=5 uvw=21 uhw=5 fillp=29 vcnt=27 lasprat=109 pasprat=99 loasc=168 lodes=159 dides=102))
((Linux\ Libertine\ Initials Initials) (sans=no))
((Linux\ Libertine\ Initials\ O Initials) (sans=no))
((Linux\ Libertine\ Mono\ O Mono) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=133 lvw=20 lhw=8 uvw=20 uhw=8 fillp=32 vcnt=28 lasprat=133 pasprat=112 loasc=147 lodes=150 dides=103))
((Linux\ Libertine\ Mono\ O\  Mono) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=133 lvw=31 lhw=18 uvw=31 uhw=18 fillp=48 vcnt=52 lasprat=133 pasprat=137 loasc=147 lodes=150 dides=103))
((Linux\ Libertine\ O Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=205 lvw=32 lhw=9 uvw=34 uhw=9 fillp=42 vcnt=40 lasprat=119 pasprat=111 loasc=158 lodes=154 dides=102))
((Linux\ Libertine\ O Bold\ Italic) (Ascii Latin Greek MathSymbols mono=no sans=no slant=22 italic=yes case=mixed regular=yes ex=74 em=194 lvw=29 lhw=12 uvw=32 uhw=10 fillp=39 vcnt=40 lasprat=114 pasprat=109 loasc=156 lodes=154 dides=108))
((Linux\ Libertine\ O Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=74 em=181 lvw=18 lhw=9 uvw=20 uhw=8 fillp=29 vcnt=29 lasprat=101 pasprat=95 loasc=156 lodes=154 dides=104))
((Linux\ Libertine\ O Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=194 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=108 pasprat=99 loasc=161 lodes=155 dides=102))
((Linux\ Libertine\ O Semibold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=194 lvw=27 lhw=10 uvw=30 uhw=9 fillp=40 vcnt=38 lasprat=110 pasprat=101 loasc=158 lodes=154 dides=102))
((Linux\ Libertine\ O Semibold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=73 em=191 lvw=28 lhw=12 uvw=31 uhw=9 fillp=38 vcnt=38 lasprat=114 pasprat=108 loasc=158 lodes=154 dides=104))
((Linux\ Libertine\ Slanted Bold\ Slanted) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=205 lvw=32 lhw=9 uvw=34 uhw=9 fillp=37 vcnt=38 lasprat=119 pasprat=122 loasc=160 lodes=153 dides=102))
((Linux\ Libertine\ Slanted Semibold\ Slanted) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=194 lvw=27 lhw=10 uvw=30 uhw=9 fillp=35 vcnt=36 lasprat=110 pasprat=113 loasc=160 lodes=152 dides=104))
((Linux\ Libertine\ Slanted Slanted) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=191 lvw=19 lhw=8 uvw=21 uhw=8 fillp=28 vcnt=28 lasprat=106 pasprat=109 loasc=160 lodes=154 dides=102))
((LiSong\ Pro Light) (Ascii CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=160 lvw=12 lhw=6 uvw=12 uhw=6 fillp=23 vcnt=24 lasprat=99 pasprat=90 loasc=147 lodes=128 dides=100))
((LiSu Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=109 lvw=13 lhw=5 uvw=15 uhw=5 fillp=26 vcnt=27 lasprat=109 pasprat=88 loasc=156 lodes=127 dides=100))
((Litos\ Script Italic) (mono=no sans=no slant=20 italic=no case=mixed regular=yes ex=71 em=194 lvw=12 lhw=7 uvw=15 uhw=7 fillp=23 vcnt=25 lasprat=71 pasprat=77 loasc=190 lodes=170 dides=107))
((Litos\ Script Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=197 lvw=11 lhw=7 uvw=15 uhw=7 fillp=25 vcnt=28 lasprat=74 pasprat=75 loasc=188 lodes=172 dides=115))
((Litos\ Script SemiBold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=172 lvw=15 lhw=11 uvw=18 uhw=10 fillp=32 vcnt=34 lasprat=73 pasprat=74 loasc=185 lodes=168 dides=107))
((Litos\ Script SemiBold\ Italic) (mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=71 em=194 lvw=14 lhw=9 uvw=16 uhw=9 fillp=29 vcnt=31 lasprat=71 pasprat=76 loasc=183 lodes=169 dides=108))
((Livia Medium) (sans=no))
((LMTypewriter10\ Regular Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=120 lvw=16 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=36 lasprat=120 pasprat=103 loasc=141 lodes=152 dides=102))
((Lobster\ Two Bold) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=94 em=139 lvw=25 lhw=19 uvw=15 uhw=15 fillp=47 vcnt=55 lasprat=78 pasprat=83 loasc=132 lodes=144 dides=102))
((Lobster\ Two Bold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=no ex=93 em=141 lvw=26 lhw=22 uvw=16 uhw=17 fillp=45 vcnt=55 lasprat=79 pasprat=89 loasc=134 lodes=145 dides=102))
((Lobster\ Two Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=no ex=93 em=134 lvw=19 lhw=15 uvw=13 uhw=13 fillp=37 vcnt=45 lasprat=73 pasprat=82 loasc=134 lodes=145 dides=102))
((Lobster\ Two Regular) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=94 em=134 lvw=19 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=46 lasprat=72 pasprat=77 loasc=132 lodes=144 dides=102))
((Logix Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=167 lvw=16 lhw=13 uvw=20 uhw=16 fillp=43 vcnt=34 lasprat=102 pasprat=80 loasc=146 lodes=150 dides=103))
((Lohit\ Bengali Regular) (slant=0))
((Lohit\ Gujarati Regular) (slant=0))
((Lohit\ Hindi Regular) (slant=0))
((Lohit\ Punjabi Regular) (slant=0))
((Lohit\ Tamil Regular) (slant=0))
((Loma Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=22 lhw=20 uvw=22 uhw=21 fillp=52 vcnt=56 lasprat=93 pasprat=80 loasc=142 lodes=140 dides=101))
((Loma BoldOblique) (Ascii mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=87 em=159 lvw=22 lhw=20 uvw=22 uhw=21 fillp=42 vcnt=48 lasprat=93 pasprat=95 loasc=142 lodes=140 dides=101))
((Loma Book) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=17 uhw=17 fillp=43 vcnt=45 lasprat=93 pasprat=79 loasc=143 lodes=140 dides=101))
((Loma Oblique) (Ascii mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=18 uhw=17 fillp=35 vcnt=39 lasprat=93 pasprat=94 loasc=143 lodes=140 dides=101))
((Loma Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=13 uvw=17 uhw=16 fillp=42 vcnt=39 lasprat=93 pasprat=79 loasc=142 lodes=140 dides=101))
((Lucida\ Console Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=113 lvw=19 lhw=13 uvw=19 uhw=13 fillp=41 vcnt=43 lasprat=113 pasprat=86 loasc=147 lodes=138 dides=103))
((Lucida\ Grande Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=168 lvw=28 lhw=16 uvw=28 uhw=18 fillp=54 vcnt=60 lasprat=109 pasprat=88 loasc=145 lodes=137 dides=103))
((Lucida\ Grande Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=161 lvw=19 lhw=13 uvw=20 uhw=14 fillp=43 vcnt=47 lasprat=103 pasprat=81 loasc=147 lodes=138 dides=103))
((Lucida\ Sans Demibold\ Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=90 em=166 lvw=27 lhw=18 uvw=30 uhw=20 fillp=44 vcnt=52 lasprat=107 pasprat=102 loasc=145 lodes=137 dides=103))
((Lucida\ Sans Demibold\ Roman) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=168 lvw=28 lhw=16 uvw=30 uhw=18 fillp=54 vcnt=60 lasprat=109 pasprat=88 loasc=145 lodes=137 dides=103))
((Lucida\ Sans Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=89 em=155 lvw=19 lhw=13 uvw=20 uhw=13 fillp=34 vcnt=40 lasprat=102 pasprat=94 loasc=147 lodes=138 dides=103))
((Lucida\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=159 lvw=17 lhw=13 uvw=20 uhw=13 fillp=43 vcnt=46 lasprat=103 pasprat=81 loasc=147 lodes=138 dides=103))
((Lucida\ Sans\ Unicode Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=161 lvw=19 lhw=13 uvw=20 uhw=14 fillp=43 vcnt=47 lasprat=103 pasprat=81 loasc=147 lodes=138 dides=103))
((Luminari Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=84 em=219 lvw=23 lhw=19 uvw=29 uhw=7 fillp=32 vcnt=42 lasprat=103 pasprat=111 loasc=153 lodes=163 dides=110))
((Luxi\ Mono Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=28 lhw=15 uvw=28 uhw=15 fillp=51 vcnt=59 lasprat=112 pasprat=101 loasc=147 lodes=138 dides=103))
((Luxi\ Mono Bold\ Oblique) (Ascii Latin mono=yes sans=no slant=21 italic=no case=mixed regular=yes ex=89 em=112 lvw=28 lhw=15 uvw=26 uhw=16 fillp=45 vcnt=52 lasprat=112 pasprat=111 loasc=147 lodes=138 dides=103))
((Luxi\ Mono Oblique) (Ascii Latin mono=yes sans=no slant=21 italic=no case=mixed regular=yes ex=89 em=112 lvw=19 lhw=11 uvw=19 uhw=11 fillp=34 vcnt=39 lasprat=112 pasprat=103 loasc=147 lodes=138 dides=103))
((Luxi\ Mono Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=19 lhw=11 uvw=19 uhw=11 fillp=39 vcnt=45 lasprat=112 pasprat=94 loasc=147 lodes=138 dides=103))
((Luxi\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=27 lhw=16 uvw=28 uhw=18 fillp=54 vcnt=60 lasprat=99 pasprat=83 loasc=145 lodes=137 dides=103))
((Luxi\ Sans Bold\ Oblique) (Ascii Latin mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=90 em=154 lvw=28 lhw=16 uvw=30 uhw=18 fillp=45 vcnt=52 lasprat=99 pasprat=97 loasc=145 lodes=137 dides=103))
((Luxi\ Sans Oblique) (Ascii Latin mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=89 em=156 lvw=20 lhw=13 uvw=20 uhw=14 fillp=35 vcnt=40 lasprat=92 pasprat=90 loasc=147 lodes=138 dides=103))
((Luxi\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=156 lvw=19 lhw=13 uvw=20 uhw=14 fillp=44 vcnt=47 lasprat=92 pasprat=76 loasc=147 lodes=138 dides=103))
((Luxi\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=175 lvw=27 lhw=10 uvw=30 uhw=8 fillp=46 vcnt=52 lasprat=90 pasprat=86 loasc=145 lodes=137 dides=103))
((Luxi\ Serif Bold\ Oblique) (Ascii Latin mono=no sans=no slant=21 italic=no case=mixed regular=yes ex=90 em=175 lvw=26 lhw=10 uvw=28 uhw=8 fillp=40 vcnt=46 lasprat=90 pasprat=97 loasc=145 lodes=137 dides=103))
((Luxi\ Serif Oblique) (Ascii Latin mono=no sans=no slant=21 italic=no case=mixed regular=yes ex=89 em=166 lvw=19 lhw=6 uvw=20 uhw=6 fillp=30 vcnt=34 lasprat=86 pasprat=91 loasc=147 lodes=138 dides=103))
((Luxi\ Serif Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=89 em=166 lvw=19 lhw=6 uvw=21 uhw=6 fillp=35 vcnt=39 lasprat=86 pasprat=80 loasc=147 lodes=138 dides=103))
((Maassslicer Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=25 italic=no case=mixed regular=yes ex=102 em=150 lvw=81 lhw=22 uvw=80 uhw=22 fillp=45 vcnt=59 lasprat=96 pasprat=99 loasc=142 lodes=115 dides=100))
((Making\ a\ List\ Checking\ it\ Twice Regular) (mono=no sans=no italic=no case=caps regular=no ex=137 em=121 lvw=0 lhw=2 uvw=0 uhw=2 fillp=16 vcnt=21 lasprat=102 pasprat=93 loasc=105 lodes=128 dides=100))
((Malayalam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Malayalam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=21 lhw=6 uvw=25 uhw=6 fillp=38 vcnt=35 lasprat=99 pasprat=88 loasc=150 lodes=146 dides=103))
((Malayalam\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=20 lhw=16 uvw=20 uhw=16 fillp=49 vcnt=43 lasprat=94 pasprat=80 loasc=142 lodes=142 dides=101))
((Malayalam\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=32 lasprat=94 pasprat=77 loasc=144 lodes=144 dides=102))
((Malgun\ Gothic Bold) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=187 lvw=26 lhw=20 uvw=27 uhw=23 fillp=54 vcnt=51 lasprat=104 pasprat=89 loasc=150 lodes=147 dides=102))
((Malgun\ Gothic Regular) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=177 lvw=15 lhw=12 uvw=16 uhw=13 fillp=38 vcnt=33 lasprat=97 pasprat=79 loasc=150 lodes=147 dides=102))
((Malgun\ Gothic SemiLight) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=170 lvw=11 lhw=10 uvw=12 uhw=10 fillp=32 vcnt=27 lasprat=94 pasprat=76 loasc=148 lodes=146 dides=102))
((Malgun\ Gothic\ Boot Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=179 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=99 pasprat=81 loasc=150 lodes=146 dides=102))
((Mallige Bold) ())
((Mallige Normal) ())
((Mangal Regular) (slant=0))
((Marcellus Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=202 lvw=19 lhw=7 uvw=20 uhw=9 fillp=34 vcnt=31 lasprat=99 pasprat=84 loasc=147 lodes=154 dides=130))
((MarcellusSmallCaps Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=88 em=193 lvw=18 lhw=5 uvw=19 uhw=9 fillp=34 vcnt=29 lasprat=98 pasprat=86 loasc=102 lodes=144 dides=129))
((Marion Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=238 lvw=35 lhw=11 uvw=42 uhw=11 fillp=46 vcnt=44 lasprat=120 pasprat=113 loasc=167 lodes=144 dides=102))
((Marion Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=71 em=188 lvw=18 lhw=9 uvw=23 uhw=9 fillp=32 vcnt=32 lasprat=86 pasprat=83 loasc=161 lodes=142 dides=104))
((Marion Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=219 lvw=23 lhw=8 uvw=27 uhw=10 fillp=35 vcnt=33 lasprat=110 pasprat=103 loasc=169 lodes=145 dides=104))
((Marker\ Felt Thin) (Ascii Greek Cyrillic mono=no sans=yes slant=-5 italic=no case=mixed regular=yes ex=96 em=161 lvw=20 lhw=16 uvw=22 uhw=28 fillp=54 vcnt=69 lasprat=72 pasprat=69 loasc=144 lodes=137 dides=109))
((Marker\ Felt Wide) (Ascii Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=101 em=155 lvw=25 lhw=39 uvw=29 uhw=28 fillp=60 vcnt=80 lasprat=78 pasprat=74 loasc=139 lodes=139 dides=111))
((Marlett Regular) ())
((MarVoSym Regular) (slant=75))
((MdSymbol Bold) (MathSymbols slant=0))
((MdSymbol Light) (MathSymbols slant=0))
((MdSymbol Regular) (MathSymbols slant=0))
((MdSymbol Semibold) (MathSymbols slant=0))
((Meera Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=62 em=148 lvw=14 lhw=12 uvw=16 uhw=12 fillp=38 vcnt=29 lasprat=92 pasprat=78 loasc=140 lodes=141 dides=103))
((Meiryo\ Boot Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=179 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=99 pasprat=81 loasc=150 lodes=146 dides=102))
((Menaion\ Unicode Regular) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=8 uvw=25 uhw=8 fillp=32 vcnt=30 lasprat=102 pasprat=96 loasc=154 lodes=148 dides=102))
((Menaion\ Unicode\ TT Regular) (Ascii Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=8 uvw=25 uhw=8 fillp=32 vcnt=30 lasprat=102 pasprat=96 loasc=154 lodes=148 dides=102))
((Menlo Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=24 fillp=56 vcnt=65 lasprat=110 pasprat=88 loasc=149 lodes=138 dides=102))
((Menlo Bold\ Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=110 lvw=26 lhw=20 uvw=27 uhw=23 fillp=48 vcnt=56 lasprat=110 pasprat=99 loasc=149 lodes=138 dides=102))
((Menlo Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=22 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=35 vcnt=41 lasprat=110 pasprat=93 loasc=139 lodes=138 dides=104))
((Menlo Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=110 lvw=17 lhw=14 uvw=18 uhw=14 fillp=41 vcnt=47 lasprat=110 pasprat=82 loasc=140 lodes=138 dides=102))
((Merriweather Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=181 lvw=28 lhw=12 uvw=29 uhw=11 fillp=49 vcnt=54 lasprat=104 pasprat=94 loasc=148 lodes=147 dides=132))
((Merriweather Bold\ Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=95 em=167 lvw=25 lhw=11 uvw=25 uhw=10 fillp=43 vcnt=50 lasprat=92 pasprat=85 loasc=144 lodes=145 dides=136))
((Merriweather Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=95 em=161 lvw=17 lhw=11 uvw=17 uhw=10 fillp=36 vcnt=41 lasprat=91 pasprat=82 loasc=143 lodes=145 dides=137))
((Merriweather Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=93 em=177 lvw=13 lhw=9 uvw=13 uhw=7 fillp=29 vcnt=30 lasprat=101 pasprat=87 loasc=148 lodes=148 dides=133))
((Merriweather Light\ Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=95 em=161 lvw=12 lhw=8 uvw=12 uhw=8 fillp=28 vcnt=31 lasprat=91 pasprat=78 loasc=143 lodes=145 dides=137))
((Merriweather Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=93 em=179 lvw=21 lhw=10 uvw=22 uhw=10 fillp=40 vcnt=43 lasprat=102 pasprat=92 loasc=148 lodes=148 dides=133))
((Merriweather\ UltraBold Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=95 em=172 lvw=30 lhw=11 uvw=32 uhw=11 fillp=48 vcnt=59 lasprat=94 pasprat=92 loasc=146 lodes=145 dides=136))
((Merriweather\ UltraBold Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=94 em=186 lvw=37 lhw=13 uvw=38 uhw=13 fillp=57 vcnt=66 lasprat=106 pasprat=101 loasc=150 lodes=147 dides=134))
((MerriweatherSans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=164 lvw=27 lhw=19 uvw=29 uhw=20 fillp=56 vcnt=56 lasprat=104 pasprat=87 loasc=147 lodes=145 dides=135))
((MerriweatherSans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=93 em=165 lvw=24 lhw=16 uvw=24 uhw=18 fillp=47 vcnt=53 lasprat=94 pasprat=87 loasc=147 lodes=146 dides=140))
((MerriweatherSans ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=173 lvw=33 lhw=21 uvw=34 uhw=24 fillp=62 vcnt=63 lasprat=106 pasprat=91 loasc=147 lodes=146 dides=136))
((MerriweatherSans ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=93 em=174 lvw=31 lhw=19 uvw=32 uhw=23 fillp=55 vcnt=63 lasprat=99 pasprat=93 loasc=147 lodes=147 dides=143))
((MerriweatherSans Italic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=93 em=156 lvw=18 lhw=12 uvw=18 uhw=12 fillp=37 vcnt=40 lasprat=90 pasprat=81 loasc=147 lodes=145 dides=137))
((MerriweatherSans Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=168 lvw=13 lhw=9 uvw=15 uhw=10 fillp=37 vcnt=33 lasprat=97 pasprat=77 loasc=147 lodes=145 dides=133))
((MerriweatherSans LightItalic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=93 em=156 lvw=13 lhw=9 uvw=13 uhw=9 fillp=30 vcnt=32 lasprat=89 pasprat=79 loasc=147 lodes=146 dides=137))
((MerriweatherSans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=168 lvw=19 lhw=13 uvw=19 uhw=15 fillp=45 vcnt=42 lasprat=97 pasprat=79 loasc=147 lodes=145 dides=134))
((Meyne\ Textur Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=95 em=122 lvw=29 lhw=94 uvw=16 uhw=16 fillp=38 vcnt=47 lasprat=58 pasprat=60 loasc=128 lodes=158 dides=155))
((Miama\ Nueva Medium) (Ascii Latin mono=no sans=no slant=51 italic=no case=mixed regular=no ex=79 em=253 lvw=17 lhw=6 uvw=21 uhw=10 fillp=15 vcnt=29 lasprat=113 pasprat=167 loasc=244 lodes=300 dides=105))
((Microsoft\ Himalaya Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=50 em=198 lvw=20 lhw=8 uvw=24 uhw=8 fillp=32 vcnt=20 lasprat=102 pasprat=96 loasc=156 lodes=148 dides=104))
((Microsoft\ JhengHei Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=184 lvw=22 lhw=16 uvw=23 uhw=18 fillp=48 vcnt=46 lasprat=101 pasprat=85 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=167 lvw=10 lhw=8 uvw=10 uhw=8 fillp=28 vcnt=24 lasprat=93 pasprat=75 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=178 lvw=15 lhw=13 uvw=16 uhw=14 fillp=38 vcnt=35 lasprat=98 pasprat=80 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei\ Boot Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=179 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=99 pasprat=81 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei\ UI Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=184 lvw=22 lhw=16 uvw=23 uhw=18 fillp=48 vcnt=46 lasprat=101 pasprat=85 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei\ UI Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=167 lvw=10 lhw=8 uvw=10 uhw=8 fillp=28 vcnt=24 lasprat=93 pasprat=75 loasc=150 lodes=146 dides=102))
((Microsoft\ JhengHei\ UI Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=178 lvw=15 lhw=13 uvw=16 uhw=14 fillp=38 vcnt=35 lasprat=98 pasprat=80 loasc=150 lodes=146 dides=102))
((Microsoft\ New\ Tai\ Lue Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Microsoft\ New\ Tai\ Lue Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Microsoft\ PhagsPa Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=103))
((Microsoft\ PhagsPa Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Microsoft\ Sans\ Serif Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=13 uvw=18 uhw=16 fillp=43 vcnt=46 lasprat=94 pasprat=79 loasc=140 lodes=140 dides=102))
((Microsoft\ Tai\ Le Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Microsoft\ Tai\ Le Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Microsoft\ YaHei Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=191 lvw=30 lhw=22 uvw=31 uhw=25 fillp=57 vcnt=58 lasprat=106 pasprat=91 loasc=150 lodes=147 dides=102))
((Microsoft\ YaHei Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=166 lvw=8 lhw=7 uvw=10 uhw=8 fillp=27 vcnt=23 lasprat=92 pasprat=75 loasc=150 lodes=146 dides=102))
((Microsoft\ YaHei Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=181 lvw=18 lhw=14 uvw=18 uhw=16 fillp=42 vcnt=40 lasprat=99 pasprat=82 loasc=150 lodes=146 dides=102))
((Microsoft\ YaHei\ Boot Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=179 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=99 pasprat=81 loasc=150 lodes=146 dides=102))
((Microsoft\ YaHei\ UI Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=191 lvw=30 lhw=22 uvw=31 uhw=25 fillp=57 vcnt=58 lasprat=106 pasprat=91 loasc=150 lodes=147 dides=103))
((Microsoft\ YaHei\ UI Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=166 lvw=8 lhw=7 uvw=10 uhw=8 fillp=27 vcnt=23 lasprat=92 pasprat=75 loasc=150 lodes=146 dides=102))
((Microsoft\ YaHei\ UI Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=181 lvw=18 lhw=14 uvw=18 uhw=16 fillp=42 vcnt=40 lasprat=99 pasprat=82 loasc=150 lodes=146 dides=102))
((Microsoft\ Yi\ Baiti Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=63 em=168 lvw=9 lhw=11 uvw=11 uhw=11 fillp=31 vcnt=18 lasprat=96 pasprat=74 loasc=142 lodes=138 dides=103))
((Mikodacs Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=152 lvw=37 lhw=22 uvw=37 uhw=22 fillp=78 vcnt=87 lasprat=89 pasprat=83 loasc=140 lodes=139 dides=102))
((MikodacsPCS Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=87 em=152 lvw=37 lhw=22 uvw=37 uhw=22 fillp=78 vcnt=81 lasprat=95 pasprat=89 loasc=101 lodes=140 dides=102))
((MingLiU Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=115 lvw=15 lhw=6 uvw=15 uhw=6 fillp=26 vcnt=29 lasprat=115 pasprat=89 loasc=158 lodes=145 dides=119))
((MingLiU-ExtB Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=115 lvw=15 lhw=6 uvw=15 uhw=6 fillp=26 vcnt=25 lasprat=115 pasprat=88 loasc=158 lodes=147 dides=119))
((MingLiU_HKSCS-ExtB Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=115 lvw=15 lhw=6 uvw=15 uhw=6 fillp=26 vcnt=25 lasprat=115 pasprat=88 loasc=158 lodes=147 dides=119))
((Mint\ Spirit Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=210 lvw=22 lhw=21 uvw=22 uhw=21 fillp=50 vcnt=43 lasprat=108 pasprat=86 loasc=150 lodes=146 dides=110))
((Mint\ Spirit Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=79 em=210 lvw=24 lhw=22 uvw=22 uhw=21 fillp=41 vcnt=43 lasprat=108 pasprat=102 loasc=150 lodes=146 dides=110))
((Mint\ Spirit Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=79 em=208 lvw=16 lhw=13 uvw=15 uhw=12 fillp=31 vcnt=32 lasprat=104 pasprat=99 loasc=150 lodes=146 dides=102))
((Mint\ Spirit Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=208 lvw=16 lhw=13 uvw=15 uhw=12 fillp=39 vcnt=32 lasprat=103 pasprat=83 loasc=150 lodes=146 dides=102))
((Mint\ Spirit\ No2 Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=148 lvw=22 lhw=21 uvw=22 uhw=21 fillp=50 vcnt=43 lasprat=108 pasprat=87 loasc=150 lodes=146 dides=110))
((Mint\ Spirit\ No2 Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=79 em=148 lvw=24 lhw=22 uvw=22 uhw=21 fillp=41 vcnt=43 lasprat=108 pasprat=102 loasc=150 lodes=146 dides=110))
((Mint\ Spirit\ No2 Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=79 em=143 lvw=16 lhw=13 uvw=15 uhw=12 fillp=31 vcnt=32 lasprat=102 pasprat=98 loasc=150 lodes=146 dides=102))
((Mint\ Spirit\ No2 Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=143 lvw=16 lhw=13 uvw=15 uhw=12 fillp=38 vcnt=32 lasprat=101 pasprat=82 loasc=150 lodes=146 dides=102))
((Mishafi Regular) (slant=0))
((Mishafi\ Gold Regular) (slant=0))
((Missaali Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=91 em=194 lvw=62 lhw=20 uvw=13 uhw=18 fillp=47 vcnt=52 lasprat=76 pasprat=69 loasc=131 lodes=130 dides=131))
((Mona\ Lisa\ Solid\ ITC\ TT Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=48 em=270 lvw=31 lhw=6 uvw=41 uhw=6 fillp=35 vcnt=33 lasprat=125 pasprat=116 loasc=277 lodes=152 dides=112))
((Mongolian\ Baiti Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=8 uvw=25 uhw=8 fillp=32 vcnt=30 lasprat=102 pasprat=96 loasc=154 lodes=148 dides=102))
((Monomakh\ Unicode Medium) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=200 lvw=26 lhw=12 uvw=33 uhw=12 fillp=41 vcnt=40 lasprat=118 pasprat=107 loasc=162 lodes=161 dides=103))
((Monomakh\ Unicode\ TT Medium) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=200 lvw=26 lhw=12 uvw=33 uhw=12 fillp=41 vcnt=40 lasprat=118 pasprat=107 loasc=162 lodes=161 dides=103))
((Monteiro\ Lobato Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=81 em=156 lvw=17 lhw=8 uvw=32 uhw=16 fillp=36 vcnt=39 lasprat=110 pasprat=94 loasc=151 lodes=143 dides=111))
((Montserrat Black) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=40 lhw=31 uvw=42 uhw=35 fillp=69 vcnt=71 lasprat=115 pasprat=105 loasc=150 lodes=137 dides=103))
((Montserrat Black\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=174 lvw=40 lhw=31 uvw=42 uhw=35 fillp=61 vcnt=71 lasprat=115 pasprat=118 loasc=150 lodes=137 dides=103))
((Montserrat Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=176 lvw=30 lhw=23 uvw=30 uhw=25 fillp=57 vcnt=55 lasprat=111 pasprat=98 loasc=145 lodes=137 dides=102))
((Montserrat Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=176 lvw=28 lhw=23 uvw=30 uhw=25 fillp=49 vcnt=55 lasprat=112 pasprat=112 loasc=145 lodes=137 dides=102))
((Montserrat ExtraBold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=176 lvw=34 lhw=27 uvw=35 uhw=31 fillp=63 vcnt=62 lasprat=113 pasprat=101 loasc=148 lodes=137 dides=102))
((Montserrat ExtraBold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=176 lvw=34 lhw=27 uvw=36 uhw=31 fillp=55 vcnt=62 lasprat=114 pasprat=114 loasc=148 lodes=137 dides=102))
((Montserrat ExtraLight) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=182 lvw=6 lhw=5 uvw=6 uhw=5 fillp=20 vcnt=14 lasprat=107 pasprat=84 loasc=142 lodes=137 dides=101))
((Montserrat ExtraLight\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=87 em=182 lvw=6 lhw=5 uvw=6 uhw=5 fillp=14 vcnt=14 lasprat=108 pasprat=98 loasc=142 lodes=137 dides=101))
((Montserrat Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=180 lvw=13 lhw=12 uvw=13 uhw=12 fillp=27 vcnt=28 lasprat=109 pasprat=102 loasc=142 lodes=137 dides=101))
((Montserrat Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=182 lvw=9 lhw=9 uvw=9 uhw=9 fillp=26 vcnt=20 lasprat=108 pasprat=86 loasc=142 lodes=137 dides=101))
((Montserrat Light\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=87 em=182 lvw=9 lhw=9 uvw=9 uhw=9 fillp=20 vcnt=20 lasprat=109 pasprat=100 loasc=142 lodes=137 dides=101))
((Montserrat Medium) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=180 lvw=18 lhw=15 uvw=18 uhw=17 fillp=42 vcnt=36 lasprat=110 pasprat=90 loasc=143 lodes=137 dides=101))
((Montserrat Medium\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=180 lvw=18 lhw=15 uvw=18 uhw=17 fillp=35 vcnt=36 lasprat=111 pasprat=104 loasc=143 lodes=137 dides=101))
((Montserrat Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=180 lvw=13 lhw=12 uvw=13 uhw=12 fillp=34 vcnt=28 lasprat=108 pasprat=88 loasc=142 lodes=137 dides=101))
((Montserrat SemiBold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=178 lvw=23 lhw=20 uvw=24 uhw=21 fillp=50 vcnt=46 lasprat=111 pasprat=95 loasc=144 lodes=137 dides=102))
((Montserrat SemiBold\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=89 em=178 lvw=23 lhw=20 uvw=24 uhw=21 fillp=42 vcnt=46 lasprat=111 pasprat=109 loasc=144 lodes=137 dides=102))
((Montserrat Thin) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=184 lvw=3 lhw=3 uvw=3 uhw=3 fillp=13 vcnt=8 lasprat=107 pasprat=81 loasc=144 lodes=138 dides=100))
((Montserrat Thin\ Italic) (Ascii Latin Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=184 lvw=3 lhw=3 uvw=3 uhw=3 fillp=8 vcnt=8 lasprat=108 pasprat=95 loasc=144 lodes=138 dides=100))
((Montserrat\ Alternates Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=212 lvw=40 lhw=31 uvw=42 uhw=35 fillp=71 vcnt=73 lasprat=112 pasprat=100 loasc=149 lodes=137 dides=102))
((Montserrat\ Alternates Black\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=212 lvw=40 lhw=31 uvw=42 uhw=35 fillp=62 vcnt=72 lasprat=114 pasprat=115 loasc=149 lodes=137 dides=102))
((Montserrat\ Alternates Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=217 lvw=32 lhw=25 uvw=34 uhw=28 fillp=62 vcnt=61 lasprat=111 pasprat=95 loasc=146 lodes=136 dides=101))
((Montserrat\ Alternates Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=217 lvw=32 lhw=25 uvw=34 uhw=28 fillp=54 vcnt=61 lasprat=113 pasprat=110 loasc=146 lodes=136 dides=101))
((Montserrat\ Alternates ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=214 lvw=37 lhw=28 uvw=39 uhw=31 fillp=67 vcnt=69 lasprat=111 pasprat=100 loasc=147 lodes=137 dides=101))
((Montserrat\ Alternates ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=214 lvw=37 lhw=28 uvw=39 uhw=31 fillp=58 vcnt=68 lasprat=113 pasprat=114 loasc=147 lodes=137 dides=101))
((Montserrat\ Alternates ExtraLight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=233 lvw=8 lhw=8 uvw=8 uhw=6 fillp=21 vcnt=18 lasprat=107 pasprat=83 loasc=143 lodes=136 dides=100))
((Montserrat\ Alternates ExtraLight\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=87 em=233 lvw=8 lhw=8 uvw=8 uhw=6 fillp=17 vcnt=17 lasprat=108 pasprat=98 loasc=143 lodes=136 dides=100))
((Montserrat\ Alternates Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=227 lvw=17 lhw=14 uvw=18 uhw=17 fillp=35 vcnt=36 lasprat=110 pasprat=102 loasc=142 lodes=137 dides=101))
((Montserrat\ Alternates Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=232 lvw=12 lhw=11 uvw=12 uhw=11 fillp=31 vcnt=26 lasprat=108 pasprat=84 loasc=142 lodes=136 dides=101))
((Montserrat\ Alternates Light\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=87 em=232 lvw=12 lhw=11 uvw=12 uhw=12 fillp=27 vcnt=27 lasprat=110 pasprat=99 loasc=143 lodes=136 dides=101))
((Montserrat\ Alternates Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=222 lvw=23 lhw=20 uvw=24 uhw=22 fillp=52 vcnt=48 lasprat=109 pasprat=90 loasc=143 lodes=137 dides=101))
((Montserrat\ Alternates Medium\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=89 em=222 lvw=23 lhw=20 uvw=24 uhw=22 fillp=45 vcnt=48 lasprat=111 pasprat=105 loasc=143 lodes=137 dides=101))
((Montserrat\ Alternates Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=227 lvw=17 lhw=14 uvw=17 uhw=17 fillp=41 vcnt=36 lasprat=108 pasprat=86 loasc=142 lodes=137 dides=101))
((Montserrat\ Alternates SemiBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=218 lvw=28 lhw=23 uvw=30 uhw=25 fillp=57 vcnt=56 lasprat=109 pasprat=94 loasc=144 lodes=136 dides=101))
((Montserrat\ Alternates SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=218 lvw=28 lhw=23 uvw=30 uhw=25 fillp=50 vcnt=56 lasprat=111 pasprat=109 loasc=144 lodes=136 dides=101))
((Montserrat\ Alternates Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=238 lvw=3 lhw=3 uvw=3 uhw=3 fillp=10 vcnt=8 lasprat=107 pasprat=79 loasc=146 lodes=137 dides=100))
((Montserrat\ Alternates Thin\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=86 em=238 lvw=3 lhw=3 uvw=3 uhw=3 fillp=9 vcnt=8 lasprat=108 pasprat=94 loasc=146 lodes=137 dides=100))
((MPH\ 2B\ Damase Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=177 lvw=18 lhw=11 uvw=22 uhw=12 fillp=37 vcnt=39 lasprat=97 pasprat=86 loasc=146 lodes=144 dides=102))
((MS\ Gothic Regular) (Ascii Latin CJK MathSymbols mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=92 lvw=15 lhw=13 uvw=16 uhw=14 fillp=46 vcnt=52 lasprat=92 pasprat=68 loasc=141 lodes=124 dides=100))
((MS\ Mincho Regular) (Ascii Latin CJK MathSymbols mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=110 lvw=14 lhw=6 uvw=15 uhw=6 fillp=28 vcnt=29 lasprat=110 pasprat=88 loasc=157 lodes=128 dides=100))
((Mshtakan Bold) (slant=0))
((Mshtakan BoldOblique) (slant=0))
((Mshtakan Oblique) (slant=0))
((Mshtakan Regular) (slant=0))
((Mukti Bold\ Narrow) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=152 lvw=25 lhw=20 uvw=27 uhw=24 fillp=57 vcnt=64 lasprat=98 pasprat=84 loasc=134 lodes=139 dides=104))
((Mukti Narrow) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=15 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=93 pasprat=77 loasc=139 lodes=140 dides=103))
((Mukti Narrow\ Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=152 lvw=25 lhw=20 uvw=27 uhw=24 fillp=57 vcnt=55 lasprat=98 pasprat=84 loasc=134 lodes=139 dides=104))
((Muna Black) ())
((Muna Bold) ())
((Muna Regular) ())
((Muna\ PUA Black) ())
((Muna\ PUA Bold) ())
((Muna\ PUA Regular) ())
((MV\ Boli Regular) (slant=28))
((Myanmar\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Myanmar\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=21 lhw=6 uvw=25 uhw=6 fillp=38 vcnt=35 lasprat=99 pasprat=88 loasc=150 lodes=146 dides=103))
((Myanmar\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=22 lhw=20 uvw=22 uhw=21 fillp=54 vcnt=48 lasprat=94 pasprat=80 loasc=139 lodes=140 dides=102))
((Myanmar\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=32 lasprat=94 pasprat=77 loasc=143 lodes=144 dides=102))
((Myanmar\ Text Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=57 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Myanmar\ Text Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=39 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Nadeem Regular) (slant=0))
((Nadeem\ PUA Regular) (slant=0))
((Nanum\ Brush\ Script Regular) (Ascii Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=83 em=115 lvw=9 lhw=4 uvw=9 uhw=16 fillp=32 vcnt=22 lasprat=70 pasprat=62 loasc=148 lodes=122 dides=100))
((Nanum\ Pen\ Script Regular) (Ascii Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=81 em=124 lvw=13 lhw=14 uvw=13 uhw=14 fillp=39 vcnt=25 lasprat=79 pasprat=68 loasc=141 lodes=129 dides=100))
((NanumGothic Bold) (Ascii Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=192 lvw=21 lhw=19 uvw=23 uhw=21 fillp=49 vcnt=47 lasprat=103 pasprat=85 loasc=154 lodes=141 dides=111))
((NanumGothic ExtraBold) (Ascii Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=190 lvw=25 lhw=23 uvw=28 uhw=24 fillp=55 vcnt=55 lasprat=102 pasprat=86 loasc=154 lodes=143 dides=116))
((NanumGothic Regular) (Ascii Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=195 lvw=14 lhw=12 uvw=15 uhw=13 fillp=35 vcnt=30 lasprat=104 pasprat=82 loasc=154 lodes=139 dides=110))
((NanumMyeongjo Bold) (Ascii Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=212 lvw=20 lhw=7 uvw=21 uhw=10 fillp=32 vcnt=33 lasprat=103 pasprat=93 loasc=167 lodes=148 dides=102))
((NanumMyeongjo ExtraBold) (Ascii Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=215 lvw=25 lhw=10 uvw=25 uhw=11 fillp=38 vcnt=40 lasprat=104 pasprat=98 loasc=168 lodes=150 dides=105))
((NanumMyeongjo Regular) (Ascii Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=215 lvw=16 lhw=6 uvw=16 uhw=7 fillp=25 vcnt=24 lasprat=104 pasprat=91 loasc=169 lodes=149 dides=102))
((New\ Peninim\ MT Bold) (slant=0))
((New\ Peninim\ MT Bold\ Inclined) (slant=24))
((New\ Peninim\ MT Inclined) (slant=24))
((New\ Peninim\ MT Regular) (slant=0))
((NimbusSanL Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=25 lhw=21 uvw=27 uhw=23 fillp=57 vcnt=55 lasprat=99 pasprat=84 loasc=135 lodes=141 dides=104))
((NimbusSanL Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=154 lvw=26 lhw=21 uvw=27 uhw=23 fillp=48 vcnt=55 lasprat=99 pasprat=100 loasc=135 lodes=141 dides=104))
((NimbusSanL Italic) (Ascii Latin mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=18 uhw=16 fillp=34 vcnt=38 lasprat=93 pasprat=92 loasc=140 lodes=141 dides=104))
((NimbusSanL Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=14 uvw=17 uhw=16 fillp=43 vcnt=38 lasprat=93 pasprat=76 loasc=140 lodes=142 dides=104))
((Ninoshandwriting Medium) (mono=no sans=yes italic=no case=mixed regular=no ex=91 em=125 lvw=16 lhw=15 uvw=13 uhw=17 fillp=39 vcnt=39 lasprat=74 pasprat=72 loasc=145 lodes=124 dides=100))
((Nirmala\ UI Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=56 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Nirmala\ UI Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Nirmala\ UI SemiLight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=11 lhw=10 uvw=14 uhw=11 fillp=34 vcnt=28 lasprat=95 pasprat=77 loasc=148 lodes=146 dides=102))
((Nisan Regular) (slant=0))
((Nisan\ PUA Regular) ())
((NKD04\ Playing\ Card\'s\ Index Regular) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=98 em=112 lvw=19 lhw=18 uvw=19 uhw=18 fillp=45 vcnt=63 lasprat=112 pasprat=103 loasc=155 lodes=165 dides=122))
((Norasi Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=31 lhw=6 uvw=35 uhw=7 fillp=45 vcnt=47 lasprat=105 pasprat=97 loasc=150 lodes=145 dides=102))
((Norasi BoldItalic) (Ascii Latin mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=7 uvw=33 uhw=6 fillp=38 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=145 dides=102))
((Norasi BoldOblique) (Ascii Latin mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=77 em=203 lvw=29 lhw=6 uvw=37 uhw=7 fillp=40 vcnt=42 lasprat=105 pasprat=109 loasc=150 lodes=145 dides=102))
((Norasi Italic) (Ascii Latin mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=187 lvw=21 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=29 lasprat=100 pasprat=98 loasc=154 lodes=147 dides=104))
((Norasi Oblique) (Ascii Latin mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=75 em=197 lvw=21 lhw=6 uvw=25 uhw=6 fillp=29 vcnt=30 lasprat=101 pasprat=104 loasc=152 lodes=148 dides=104))
((Norasi Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=5 uvw=25 uhw=6 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=152 lodes=148 dides=104))
((Noteworthy Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=89 em=164 lvw=21 lhw=17 uvw=21 uhw=17 fillp=46 vcnt=53 lasprat=88 pasprat=78 loasc=167 lodes=166 dides=108))
((Noteworthy Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=89 em=151 lvw=12 lhw=8 uvw=11 uhw=11 fillp=31 vcnt=36 lasprat=78 pasprat=69 loasc=161 lodes=166 dides=108))
((Noto\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=172 lvw=27 lhw=21 uvw=28 uhw=24 fillp=57 vcnt=55 lasprat=104 pasprat=88 loasc=140 lodes=143 dides=102))
((Noto\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=91 em=161 lvw=27 lhw=23 uvw=27 uhw=24 fillp=48 vcnt=56 lasprat=97 pasprat=97 loasc=140 lodes=143 dides=102))
((Noto\ Sans Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=90 em=155 lvw=15 lhw=13 uvw=16 uhw=15 fillp=34 vcnt=37 lasprat=92 pasprat=87 loasc=142 lodes=144 dides=102))
((Noto\ Sans Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=162 lvw=10 lhw=10 uvw=12 uhw=10 fillp=29 vcnt=25 lasprat=94 pasprat=75 loasc=143 lodes=146 dides=102))
((Noto\ Sans Light\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=89 em=153 lvw=10 lhw=8 uvw=11 uhw=10 fillp=23 vcnt=26 lasprat=90 pasprat=87 loasc=143 lodes=146 dides=102))
((Noto\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=167 lvw=16 lhw=14 uvw=17 uhw=14 fillp=40 vcnt=36 lasprat=98 pasprat=78 loasc=142 lodes=144 dides=102))
((Noto\ Sans\ Blk Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=92 em=165 lvw=33 lhw=28 uvw=34 uhw=29 fillp=57 vcnt=65 lasprat=100 pasprat=99 loasc=141 lodes=143 dides=102))
((Noto\ Sans\ Blk Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=175 lvw=34 lhw=26 uvw=36 uhw=29 fillp=65 vcnt=64 lasprat=107 pasprat=91 loasc=141 lodes=143 dides=102))
((Noto\ Sans\ Cond Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=150 lvw=25 lhw=20 uvw=26 uhw=23 fillp=59 vcnt=57 lasprat=87 pasprat=73 loasc=140 lodes=143 dides=102))
((Noto\ Sans\ Cond Bold\ Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=91 em=137 lvw=23 lhw=20 uvw=25 uhw=21 fillp=48 vcnt=59 lasprat=80 pasprat=84 loasc=140 lodes=143 dides=102))
((Noto\ Sans\ Cond Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=90 em=131 lvw=14 lhw=12 uvw=15 uhw=14 fillp=35 vcnt=41 lasprat=74 pasprat=75 loasc=142 lodes=145 dides=102))
((Noto\ Sans\ Cond Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=139 lvw=10 lhw=8 uvw=11 uhw=10 fillp=33 vcnt=28 lasprat=76 pasprat=60 loasc=143 lodes=146 dides=102))
((Noto\ Sans\ Cond Light\ Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=89 em=126 lvw=10 lhw=8 uvw=10 uhw=10 fillp=25 vcnt=29 lasprat=70 pasprat=72 loasc=143 lodes=146 dides=102))
((Noto\ Sans\ Cond Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=143 lvw=15 lhw=13 uvw=16 uhw=14 fillp=44 vcnt=40 lasprat=80 pasprat=64 loasc=142 lodes=144 dides=102))
((Noto\ Sans\ Mono Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=109 lvw=26 lhw=21 uvw=27 uhw=23 fillp=55 vcnt=54 lasprat=109 pasprat=92 loasc=141 lodes=146 dides=102))
((Noto\ Sans\ Mono Light) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=11 lhw=10 uvw=11 uhw=10 fillp=27 vcnt=23 lasprat=112 pasprat=83 loasc=143 lodes=147 dides=102))
((Noto\ Sans\ Mono Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=111 lvw=16 lhw=14 uvw=16 uhw=15 fillp=39 vcnt=34 lasprat=111 pasprat=84 loasc=142 lodes=145 dides=102))
((Noto\ Sans\ Mono\ Cond Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=96 lvw=24 lhw=20 uvw=25 uhw=21 fillp=56 vcnt=56 lasprat=96 pasprat=82 loasc=141 lodes=146 dides=102))
((Noto\ Sans\ Mono\ Cond Light) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=98 lvw=10 lhw=8 uvw=10 uhw=10 fillp=29 vcnt=25 lasprat=98 pasprat=73 loasc=143 lodes=147 dides=102))
((Noto\ Sans\ Mono\ Cond Regular) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=97 lvw=15 lhw=13 uvw=15 uhw=14 fillp=40 vcnt=36 lasprat=97 pasprat=75 loasc=142 lodes=145 dides=102))
((Noto\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=176 lvw=27 lhw=12 uvw=30 uhw=12 fillp=47 vcnt=49 lasprat=108 pasprat=98 loasc=143 lodes=144 dides=102))
((Noto\ Serif Bold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=90 em=176 lvw=27 lhw=14 uvw=30 uhw=12 fillp=43 vcnt=49 lasprat=108 pasprat=103 loasc=143 lodes=144 dides=102))
((Noto\ Serif Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=90 em=173 lvw=18 lhw=10 uvw=20 uhw=10 fillp=33 vcnt=37 lasprat=97 pasprat=92 loasc=143 lodes=144 dides=102))
((Noto\ Serif Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=171 lvw=11 lhw=7 uvw=13 uhw=7 fillp=27 vcnt=27 lasprat=98 pasprat=85 loasc=143 lodes=144 dides=102))
((Noto\ Serif Light\ Italic) (Ascii Latin mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=90 em=172 lvw=13 lhw=7 uvw=13 uhw=7 fillp=25 vcnt=27 lasprat=91 pasprat=85 loasc=143 lodes=144 dides=102))
((Noto\ Serif Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=173 lvw=17 lhw=10 uvw=20 uhw=10 fillp=36 vcnt=36 lasprat=101 pasprat=90 loasc=143 lodes=144 dides=102))
((NovelDeco Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=163 lvw=19 lhw=8 uvw=22 uhw=8 fillp=34 vcnt=29 lasprat=108 pasprat=99 loasc=150 lodes=147 dides=102))
((NSimSun Regular) (Ascii Latin CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=110 lvw=13 lhw=5 uvw=15 uhw=5 fillp=26 vcnt=22 lasprat=110 pasprat=89 loasc=156 lodes=128 dides=100))
((NTS\ Akkhara Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=59 em=150 lvw=13 lhw=13 uvw=13 uhw=13 fillp=36 vcnt=27 lasprat=93 pasprat=81 loasc=140 lodes=145 dides=103))
((NTS\ Akkhara BoldItalic) (Ascii mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=59 em=149 lvw=15 lhw=15 uvw=15 uhw=13 fillp=32 vcnt=25 lasprat=93 pasprat=92 loasc=140 lodes=145 dides=103))
((NTS\ Akkhara Book) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=59 em=149 lvw=8 lhw=8 uvw=8 uhw=8 fillp=25 vcnt=17 lasprat=94 pasprat=76 loasc=137 lodes=142 dides=103))
((NTS\ Akkhara Italic) (Ascii mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=59 em=149 lvw=8 lhw=8 uvw=8 uhw=8 fillp=20 vcnt=15 lasprat=93 pasprat=88 loasc=137 lodes=142 dides=103))
((Ntxsups Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=130 lvw=21 lhw=6 uvw=26 uhw=6 fillp=52 vcnt=30 lasprat=66 pasprat=62 loasc=128 lodes=100 dides=100))
((Ntxsups BoldItalic) (Ascii mono=no sans=no slant=29 italic=no case=mixed regular=yes ex=92 em=118 lvw=17 lhw=5 uvw=22 uhw=6 fillp=44 vcnt=28 lasprat=62 pasprat=62 loasc=128 lodes=100 dides=100))
((Ntxsups Italic) (Ascii mono=no sans=no slant=30 italic=no case=mixed regular=yes ex=90 em=111 lvw=13 lhw=4 uvw=15 uhw=5 fillp=34 vcnt=21 lasprat=60 pasprat=58 loasc=126 lodes=100 dides=100))
((Ntxsups Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=90 em=122 lvw=13 lhw=5 uvw=17 uhw=6 fillp=40 vcnt=23 lasprat=60 pasprat=57 loasc=127 lodes=100 dides=100))
((Odstemplik Bold) (Ascii Latin mono=no sans=no slant=63 italic=yes case=mixed regular=yes ex=52 em=238 lvw=25 lhw=7 uvw=25 uhw=7 fillp=28 vcnt=25 lasprat=119 pasprat=136 loasc=196 lodes=198 dides=140))
((Odstemplik Regular) (Ascii Latin mono=no sans=no slant=102 italic=yes case=mixed regular=yes ex=51 em=237 lvw=17 lhw=5 uvw=19 uhw=5 fillp=22 vcnt=19 lasprat=114 pasprat=130 loasc=198 lodes=200 dides=139))
((Old\ Standard Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=187 lvw=26 lhw=5 uvw=35 uhw=6 fillp=41 vcnt=40 lasprat=105 pasprat=92 loasc=153 lodes=150 dides=103))
((Old\ Standard BoldItalic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=76 em=197 lvw=23 lhw=11 uvw=27 uhw=13 fillp=37 vcnt=39 lasprat=110 pasprat=105 loasc=157 lodes=153 dides=106))
((Old\ Standard Italic) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=76 em=196 lvw=17 lhw=5 uvw=21 uhw=6 fillp=26 vcnt=28 lasprat=104 pasprat=97 loasc=157 lodes=153 dides=103))
((Old\ Standard Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=184 lvw=19 lhw=5 uvw=23 uhw=6 fillp=31 vcnt=28 lasprat=106 pasprat=92 loasc=157 lodes=152 dides=103))
((Oldprint Normal) ())
((OMGWilliamsSerifs Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=77 em=192 lvw=7 lhw=7 uvw=7 uhw=7 fillp=19 vcnt=21 lasprat=101 pasprat=103 loasc=170 lodes=154 dides=144))
((OMGWriteLikeWilliam Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=91 em=152 lvw=10 lhw=10 uvw=10 uhw=10 fillp=28 vcnt=27 lasprat=96 pasprat=82 loasc=146 lodes=151 dides=116))
((Open\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=172 lvw=28 lhw=21 uvw=28 uhw=24 fillp=57 vcnt=55 lasprat=103 pasprat=88 loasc=140 lodes=143 dides=102))
((Open\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=91 em=161 lvw=27 lhw=23 uvw=27 uhw=24 fillp=48 vcnt=56 lasprat=97 pasprat=97 loasc=140 lodes=143 dides=102))
((Open\ Sans Condensed\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=143 lvw=24 lhw=20 uvw=24 uhw=21 fillp=60 vcnt=59 lasprat=80 pasprat=69 loasc=140 lodes=143 dides=102))
((Open\ Sans ExtraBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=173 lvw=34 lhw=25 uvw=36 uhw=29 fillp=66 vcnt=64 lasprat=106 pasprat=90 loasc=139 lodes=143 dides=102))
((Open\ Sans ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=93 em=163 lvw=33 lhw=26 uvw=34 uhw=29 fillp=57 vcnt=65 lasprat=99 pasprat=99 loasc=139 lodes=143 dides=102))
((Open\ Sans Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=90 em=154 lvw=15 lhw=12 uvw=16 uhw=14 fillp=32 vcnt=35 lasprat=90 pasprat=87 loasc=142 lodes=144 dides=102))
((Open\ Sans Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=161 lvw=10 lhw=8 uvw=10 uhw=8 fillp=27 vcnt=22 lasprat=93 pasprat=73 loasc=143 lodes=144 dides=102))
((Open\ Sans Light\ Condensed) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=128 lvw=7 lhw=8 uvw=8 uhw=8 fillp=33 vcnt=26 lasprat=66 pasprat=50 loasc=143 lodes=144 dides=102))
((Open\ Sans Light\ Condensed\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=89 em=114 lvw=8 lhw=7 uvw=8 uhw=8 fillp=24 vcnt=29 lasprat=60 pasprat=64 loasc=143 lodes=144 dides=102))
((Open\ Sans Light\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=89 em=152 lvw=8 lhw=8 uvw=8 uhw=8 fillp=21 vcnt=23 lasprat=88 pasprat=84 loasc=143 lodes=144 dides=102))
((Open\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=168 lvw=15 lhw=13 uvw=15 uhw=14 fillp=39 vcnt=34 lasprat=97 pasprat=78 loasc=143 lodes=144 dides=102))
((Open\ Sans SemiBold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=171 lvw=21 lhw=17 uvw=22 uhw=18 fillp=49 vcnt=44 lasprat=100 pasprat=82 loasc=142 lodes=144 dides=102))
((Open\ Sans SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=90 em=158 lvw=21 lhw=16 uvw=22 uhw=18 fillp=41 vcnt=46 lasprat=94 pasprat=91 loasc=142 lodes=144 dides=102))
((OpenSymbol Regular) (slant=0))
((Optima Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=185 lvw=31 lhw=10 uvw=33 uhw=12 fillp=50 vcnt=53 lasprat=103 pasprat=88 loasc=157 lodes=156 dides=102))
((Optima Bold\ Italic) (Ascii Latin mono=no sans=yes slant=21 italic=no case=mixed regular=yes ex=79 em=187 lvw=29 lhw=7 uvw=31 uhw=11 fillp=41 vcnt=44 lasprat=103 pasprat=104 loasc=160 lodes=155 dides=102))
((Optima ExtraBlack) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=186 lvw=43 lhw=12 uvw=45 uhw=14 fillp=61 vcnt=68 lasprat=106 pasprat=97 loasc=147 lodes=150 dides=101))
((Optima Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=78 em=189 lvw=16 lhw=6 uvw=17 uhw=6 fillp=26 vcnt=28 lasprat=103 pasprat=96 loasc=158 lodes=156 dides=103))
((Optima Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=187 lvw=18 lhw=6 uvw=20 uhw=6 fillp=34 vcnt=34 lasprat=103 pasprat=84 loasc=159 lodes=156 dides=102))
((Oriya\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Oriya\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=21 lhw=6 uvw=25 uhw=6 fillp=38 vcnt=35 lasprat=99 pasprat=88 loasc=150 lodes=146 dides=103))
((Oriya\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=147 lvw=19 lhw=17 uvw=19 uhw=17 fillp=49 vcnt=39 lasprat=93 pasprat=79 loasc=140 lodes=142 dides=101))
((Oriya\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=148 lvw=12 lhw=13 uvw=12 uhw=13 fillp=36 vcnt=26 lasprat=94 pasprat=74 loasc=144 lodes=144 dides=101))
((Osaka Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=143 lvw=17 lhw=13 uvw=18 uhw=14 fillp=42 vcnt=47 lasprat=98 pasprat=81 loasc=145 lodes=141 dides=104))
((Osaka Regular-Mono) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=110 lvw=18 lhw=13 uvw=18 uhw=13 fillp=40 vcnt=40 lasprat=111 pasprat=88 loasc=148 lodes=142 dides=104))
((Overhaul Regular) (mono=no sans=no italic=no case=caps regular=yes ex=125 em=111 lvw=3 lhw=12 uvw=3 uhw=12 fillp=40 vcnt=49 lasprat=81 pasprat=73 loasc=100 lodes=116 dides=100))
((Overlock Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=169 lvw=30 lhw=19 uvw=34 uhw=20 fillp=56 vcnt=54 lasprat=102 pasprat=93 loasc=154 lodes=151 dides=102))
((Overlock Black\ Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=81 em=170 lvw=33 lhw=20 uvw=35 uhw=22 fillp=54 vcnt=55 lasprat=100 pasprat=95 loasc=153 lodes=151 dides=102))
((Overlock Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=162 lvw=23 lhw=16 uvw=23 uhw=17 fillp=46 vcnt=42 lasprat=98 pasprat=85 loasc=153 lodes=151 dides=102))
((Overlock Bold\ Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=81 em=159 lvw=24 lhw=14 uvw=23 uhw=16 fillp=45 vcnt=45 lasprat=91 pasprat=85 loasc=155 lodes=151 dides=102))
((Overlock Italic) (Ascii Latin mono=no sans=yes slant=13 italic=yes case=mixed regular=yes ex=79 em=160 lvw=16 lhw=11 uvw=17 uhw=12 fillp=35 vcnt=33 lasprat=88 pasprat=81 loasc=156 lodes=153 dides=102))
((Overlock Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=168 lvw=15 lhw=12 uvw=17 uhw=13 fillp=37 vcnt=31 lasprat=95 pasprat=78 loasc=158 lodes=153 dides=102))
((Overlock\ SC Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=88 em=151 lvw=14 lhw=10 uvw=15 uhw=12 fillp=38 vcnt=30 lasprat=94 pasprat=75 loasc=100 lodes=123 dides=130))
((OxfordCP Regular) (mono=no sans=no slant=0 italic=no case=caps regular=yes ex=91 em=129 lvw=0 lhw=4 uvw=0 uhw=4 fillp=37 vcnt=38 lasprat=77 pasprat=76 loasc=140 lodes=137 dides=100))
((Pacifico Regular) (Ascii Latin mono=no sans=no slant=16 italic=yes case=mixed regular=no ex=73 em=243 lvw=24 lhw=21 uvw=28 uhw=27 fillp=43 vcnt=57 lasprat=99 pasprat=118 loasc=213 lodes=202 dides=119))
((Padauk Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=182 lvw=23 lhw=16 uvw=27 uhw=21 fillp=51 vcnt=41 lasprat=106 pasprat=88 loasc=146 lodes=141 dides=101))
((Padauk Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=178 lvw=19 lhw=12 uvw=21 uhw=17 fillp=44 vcnt=33 lasprat=103 pasprat=84 loasc=146 lodes=141 dides=101))
((Padauk\ Book Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=184 lvw=26 lhw=17 uvw=30 uhw=23 fillp=55 vcnt=45 lasprat=107 pasprat=91 loasc=146 lodes=141 dides=101))
((Padauk\ Book Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=180 lvw=21 lhw=13 uvw=24 uhw=19 fillp=48 vcnt=37 lasprat=104 pasprat=86 loasc=146 lodes=141 dides=101))
((Palatino Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=29 lhw=11 uvw=31 uhw=11 fillp=43 vcnt=41 lasprat=112 pasprat=100 loasc=151 lodes=155 dides=103))
((Palatino Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=79 em=200 lvw=24 lhw=12 uvw=29 uhw=10 fillp=36 vcnt=38 lasprat=107 pasprat=100 loasc=153 lodes=158 dides=103))
((Palatino Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=80 em=197 lvw=15 lhw=8 uvw=18 uhw=8 fillp=27 vcnt=28 lasprat=95 pasprat=89 loasc=152 lodes=157 dides=102))
((Palatino Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=200 lvw=20 lhw=8 uvw=22 uhw=8 fillp=31 vcnt=31 lasprat=108 pasprat=99 loasc=164 lodes=159 dides=103))
((Palatino\ Linotype Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=80 em=208 lvw=28 lhw=11 uvw=31 uhw=11 fillp=42 vcnt=46 lasprat=111 pasprat=99 loasc=152 lodes=155 dides=105))
((Palatino\ Linotype Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=80 em=197 lvw=23 lhw=12 uvw=28 uhw=10 fillp=35 vcnt=40 lasprat=106 pasprat=99 loasc=153 lodes=158 dides=103))
((Palatino\ Linotype Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=79 em=200 lvw=16 lhw=8 uvw=18 uhw=8 fillp=27 vcnt=30 lasprat=96 pasprat=89 loasc=151 lodes=158 dides=103))
((Palatino\ Linotype Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=20 lhw=6 uvw=21 uhw=8 fillp=31 vcnt=34 lasprat=109 pasprat=100 loasc=155 lodes=160 dides=103))
((Paper\ Cuts\ 2 Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=73 em=171 lvw=83 lhw=97 uvw=113 uhw=32 fillp=53 vcnt=63 lasprat=98 pasprat=90 loasc=189 lodes=212 dides=116))
((Papyrus Condensed) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=133 lvw=10 lhw=10 uvw=12 uhw=9 fillp=26 vcnt=27 lasprat=77 pasprat=70 loasc=213 lodes=236 dides=144))
((Papyrus Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=195 lvw=17 lhw=10 uvw=18 uhw=8 fillp=26 vcnt=27 lasprat=111 pasprat=102 loasc=213 lodes=236 dides=144))
((Party\ LET Plain) (mono=no sans=no slant=0 italic=no case=mixed regular=no ex=45 em=335 lvw=13 lhw=4 uvw=26 uhw=15 fillp=24 vcnt=23 lasprat=100 pasprat=107 loasc=217 lodes=253 dides=133))
((PCMyungjo Regular) (Ascii CJK Hangul mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=107 lvw=18 lhw=6 uvw=18 uhw=7 fillp=33 vcnt=35 lasprat=107 pasprat=73 loasc=155 lodes=144 dides=102))
((Penguin\ Attack Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=no ex=62 em=225 lvw=19 lhw=11 uvw=20 uhw=11 fillp=34 vcnt=33 lasprat=120 pasprat=101 loasc=169 lodes=196 dides=103))
((Perfect\ Dark\ Zero Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=57 em=121 lvw=28 lhw=17 uvw=91 uhw=17 fillp=60 vcnt=37 lasprat=87 pasprat=80 loasc=100 lodes=100 dides=100))
((Phaistos Regular) ())
((Phetsarath\ OT Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=46 lasprat=92 pasprat=77 loasc=139 lodes=142 dides=100))
((Philokalia Regular) (Greek slant=0))
((Phosphate Inline) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=112 em=114 lvw=14 lhw=14 uvw=14 uhw=14 fillp=64 vcnt=67 lasprat=87 pasprat=83 loasc=102 lodes=101 dides=101))
((Phosphate Solid) (Ascii Latin mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=112 em=114 lvw=31 lhw=31 uvw=31 uhw=31 fillp=72 vcnt=76 lasprat=87 pasprat=83 loasc=102 lodes=101 dides=101))
((PilGi Regular) (Ascii Hangul mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=65 em=196 lvw=21 lhw=16 uvw=21 uhw=16 fillp=38 vcnt=38 lasprat=116 pasprat=113 loasc=172 lodes=150 dides=103))
((PingFang\ HK Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=166 lvw=11 lhw=9 uvw=11 uhw=10 fillp=31 vcnt=27 lasprat=96 pasprat=80 loasc=140 lodes=140 dides=102))
((PingFang\ HK Medium) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=172 lvw=20 lhw=16 uvw=20 uhw=18 fillp=46 vcnt=43 lasprat=100 pasprat=86 loasc=140 lodes=140 dides=102))
((PingFang\ HK Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=16 lhw=12 uvw=16 uhw=13 fillp=38 vcnt=34 lasprat=98 pasprat=83 loasc=140 lodes=140 dides=102))
((PingFang\ HK Semibold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=173 lvw=21 lhw=17 uvw=21 uhw=19 fillp=49 vcnt=46 lasprat=101 pasprat=87 loasc=140 lodes=140 dides=102))
((PingFang\ HK Thin) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=164 lvw=8 lhw=6 uvw=8 uhw=6 fillp=23 vcnt=18 lasprat=94 pasprat=78 loasc=140 lodes=140 dides=102))
((PingFang\ HK Ultralight) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=162 lvw=4 lhw=4 uvw=4 uhw=4 fillp=16 vcnt=12 lasprat=92 pasprat=76 loasc=140 lodes=140 dides=102))
((PingFang\ SC Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=166 lvw=11 lhw=9 uvw=11 uhw=10 fillp=31 vcnt=27 lasprat=96 pasprat=80 loasc=140 lodes=140 dides=102))
((PingFang\ SC Medium) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=172 lvw=20 lhw=16 uvw=20 uhw=18 fillp=46 vcnt=43 lasprat=100 pasprat=86 loasc=140 lodes=140 dides=102))
((PingFang\ SC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=16 lhw=12 uvw=16 uhw=13 fillp=38 vcnt=34 lasprat=98 pasprat=83 loasc=140 lodes=140 dides=102))
((PingFang\ SC Semibold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=173 lvw=21 lhw=17 uvw=21 uhw=19 fillp=49 vcnt=46 lasprat=101 pasprat=87 loasc=140 lodes=140 dides=102))
((PingFang\ SC Thin) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=164 lvw=8 lhw=6 uvw=8 uhw=6 fillp=23 vcnt=18 lasprat=94 pasprat=78 loasc=140 lodes=140 dides=102))
((PingFang\ SC Ultralight) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=162 lvw=4 lhw=4 uvw=4 uhw=4 fillp=16 vcnt=12 lasprat=92 pasprat=76 loasc=140 lodes=140 dides=102))
((PingFang\ SC }0) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=166 lvw=11 lhw=9 uvw=11 uhw=10 fillp=31 vcnt=27 lasprat=96 pasprat=80 loasc=140 lodes=140 dides=102))
((PingFang\ TC Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=166 lvw=11 lhw=9 uvw=11 uhw=10 fillp=31 vcnt=27 lasprat=96 pasprat=80 loasc=140 lodes=140 dides=102))
((PingFang\ TC Medium) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=172 lvw=20 lhw=16 uvw=20 uhw=18 fillp=46 vcnt=43 lasprat=100 pasprat=86 loasc=140 lodes=140 dides=102))
((PingFang\ TC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=16 lhw=12 uvw=16 uhw=13 fillp=38 vcnt=34 lasprat=98 pasprat=83 loasc=140 lodes=140 dides=102))
((PingFang\ TC Semibold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=173 lvw=21 lhw=17 uvw=21 uhw=19 fillp=49 vcnt=46 lasprat=101 pasprat=87 loasc=140 lodes=140 dides=102))
((PingFang\ TC Thin) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=164 lvw=8 lhw=6 uvw=8 uhw=6 fillp=23 vcnt=18 lasprat=94 pasprat=78 loasc=140 lodes=140 dides=102))
((PingFang\ TC Ultralight) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=162 lvw=4 lhw=4 uvw=4 uhw=4 fillp=16 vcnt=12 lasprat=92 pasprat=76 loasc=140 lodes=140 dides=102))
((PipeSquare\ Rounded Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=47 em=165 lvw=6 lhw=6 uvw=6 uhw=6 fillp=29 vcnt=20 lasprat=156 pasprat=145 loasc=161 lodes=155 dides=155))
((Plantagenet\ Cherokee Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=201 lvw=24 lhw=8 uvw=28 uhw=9 fillp=35 vcnt=37 lasprat=111 pasprat=105 loasc=156 lodes=170 dides=144))
((Playfair\ Display Black) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=185 lvw=35 lhw=3 uvw=40 uhw=3 fillp=50 vcnt=54 lasprat=103 pasprat=99 loasc=150 lodes=135 dides=129))
((Playfair\ Display Black\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=89 em=177 lvw=32 lhw=3 uvw=40 uhw=4 fillp=43 vcnt=54 lasprat=98 pasprat=106 loasc=148 lodes=135 dides=134))
((Playfair\ Display Bold) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=180 lvw=29 lhw=3 uvw=31 uhw=3 fillp=43 vcnt=44 lasprat=102 pasprat=94 loasc=152 lodes=136 dides=130))
((Playfair\ Display Bold\ Italic) (Ascii Latin Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=88 em=173 lvw=26 lhw=3 uvw=31 uhw=3 fillp=36 vcnt=44 lasprat=95 pasprat=99 loasc=150 lodes=136 dides=135))
((Playfair\ Display Italic) (Ascii Latin Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=88 em=164 lvw=15 lhw=3 uvw=20 uhw=3 fillp=26 vcnt=30 lasprat=90 pasprat=90 loasc=150 lodes=136 dides=135))
((Playfair\ Display Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=168 lvw=18 lhw=3 uvw=19 uhw=3 fillp=30 vcnt=31 lasprat=98 pasprat=90 loasc=152 lodes=136 dides=129))
((PMingLiU-ExtB Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=193 lvw=13 lhw=6 uvw=16 uhw=6 fillp=25 vcnt=25 lasprat=99 pasprat=92 loasc=158 lodes=147 dides=119))
((Pointfree Regular) (Ascii mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=109 lvw=17 lhw=18 uvw=17 uhw=17 fillp=42 vcnt=50 lasprat=109 pasprat=86 loasc=140 lodes=154 dides=106))
((Poiret\ One Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=213 lvw=12 lhw=10 uvw=10 uhw=10 fillp=28 vcnt=23 lasprat=109 pasprat=92 loasc=166 lodes=146 dides=104))
((Poiret\ One Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=204 lvw=6 lhw=6 uvw=6 uhw=6 fillp=19 vcnt=15 lasprat=102 pasprat=83 loasc=166 lodes=146 dides=104))
((Pomorsky\ Unicode Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=177 lvw=19 lhw=5 uvw=22 uhw=7 fillp=33 vcnt=28 lasprat=96 pasprat=92 loasc=153 lodes=155 dides=102))
((Pomorsky\ Unicode\ TT Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=177 lvw=19 lhw=5 uvw=22 uhw=7 fillp=33 vcnt=28 lasprat=96 pasprat=92 loasc=153 lodes=155 dides=102))
((Ponomar\ Unicode Regular) (Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=194 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=109 pasprat=99 loasc=163 lodes=152 dides=102))
((Ponomar\ Unicode\ TT Regular) (Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=194 lvw=19 lhw=8 uvw=22 uhw=8 fillp=32 vcnt=30 lasprat=109 pasprat=99 loasc=163 lodes=152 dides=102))
((PortagoITC\ TT Regular) (mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=102 em=102 lvw=0 lhw=0 uvw=21 uhw=0 fillp=61 vcnt=60 lasprat=60 pasprat=54 loasc=100 lodes=114 dides=101))
((Portmanteau Regular) (mono=no sans=no slant=0 italic=yes case=caps regular=yes ex=129 em=149 lvw=13 lhw=5 uvw=13 uhw=5 fillp=27 vcnt=41 lasprat=116 pasprat=104 loasc=101 lodes=146 dides=119))
((Pothana2000 Regular) (slant=0))
((Pretzel Regular) (Ascii mono=no sans=no slant=0 italic=yes case=caps regular=yes ex=112 em=166 lvw=27 lhw=7 uvw=27 uhw=7 fillp=39 vcnt=55 lasprat=119 pasprat=118 loasc=100 lodes=160 dides=125))
((PreussischeIV44Ausgabe3 Regular) (Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=100 lvw=19 lhw=20 uvw=19 uhw=20 fillp=63 vcnt=69 lasprat=77 pasprat=56 loasc=140 lodes=140 dides=100))
((Princetown\ LET Regular) (mono=no sans=no slant=0 italic=no case=caps regular=yes ex=112 em=112 lvw=8 lhw=8 uvw=8 uhw=8 fillp=48 vcnt=50 lasprat=89 pasprat=83 loasc=100 lodes=108 dides=100))
((Prociono Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=180 lvw=18 lhw=14 uvw=19 uhw=12 fillp=36 vcnt=41 lasprat=92 pasprat=85 loasc=151 lodes=138 dides=139))
((Promocyja Regular) (Ascii Latin mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=44 em=536 lvw=15 lhw=4 uvw=15 uhw=6 fillp=18 vcnt=14 lasprat=127 pasprat=135 loasc=175 lodes=247 dides=100))
((Psicopatologia\ de\ la\ Vida\ Cotidiana Regular) (mono=no sans=no italic=no case=mixed regular=no ex=93 em=164 lvw=23 lhw=7 uvw=24 uhw=10 fillp=41 vcnt=45 lasprat=93 pasprat=79 loasc=127 lodes=143 dides=104))
((PT\ Mono Bold) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=119 lvw=26 lhw=21 uvw=28 uhw=23 fillp=54 vcnt=51 lasprat=119 pasprat=103 loasc=141 lodes=141 dides=102))
((PT\ Mono Regular) (Ascii Latin Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=119 lvw=15 lhw=14 uvw=17 uhw=14 fillp=37 vcnt=33 lasprat=119 pasprat=96 loasc=140 lodes=141 dides=102))
((PT\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=158 lvw=26 lhw=21 uvw=28 uhw=23 fillp=56 vcnt=60 lasprat=95 pasprat=82 loasc=141 lodes=140 dides=102))
((PT\ Sans Bold\ Caption) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=164 lvw=27 lhw=21 uvw=29 uhw=23 fillp=55 vcnt=61 lasprat=105 pasprat=90 loasc=138 lodes=142 dides=102))
((PT\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=152 lvw=23 lhw=20 uvw=27 uhw=23 fillp=46 vcnt=51 lasprat=90 pasprat=92 loasc=141 lodes=141 dides=102))
((PT\ Sans Bold\ Narrow) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=132 lvw=23 lhw=21 uvw=25 uhw=22 fillp=58 vcnt=63 lasprat=79 pasprat=69 loasc=141 lodes=140 dides=102))
((PT\ Sans Caption) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=164 lvw=18 lhw=14 uvw=19 uhw=15 fillp=41 vcnt=45 lasprat=105 pasprat=85 loasc=135 lodes=138 dides=102))
((PT\ Sans Caption\ Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=164 lvw=27 lhw=22 uvw=29 uhw=25 fillp=55 vcnt=54 lasprat=105 pasprat=91 loasc=135 lodes=142 dides=102))
((PT\ Sans Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=150 lvw=15 lhw=13 uvw=15 uhw=14 fillp=32 vcnt=35 lasprat=89 pasprat=85 loasc=141 lodes=141 dides=102))
((PT\ Sans Narrow) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=126 lvw=14 lhw=13 uvw=15 uhw=14 fillp=42 vcnt=44 lasprat=76 pasprat=61 loasc=140 lodes=142 dides=102))
((PT\ Sans Narrow\ Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=132 lvw=25 lhw=21 uvw=26 uhw=22 fillp=58 vcnt=57 lasprat=79 pasprat=71 loasc=141 lodes=141 dides=102))
((PT\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=157 lvw=16 lhw=14 uvw=17 uhw=14 fillp=40 vcnt=42 lasprat=95 pasprat=75 loasc=140 lodes=141 dides=102))
((PT\ Serif Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=184 lvw=29 lhw=11 uvw=33 uhw=13 fillp=47 vcnt=52 lasprat=107 pasprat=99 loasc=148 lodes=141 dides=102))
((PT\ Serif Bold\ Italic) (Ascii Latin mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=85 em=181 lvw=28 lhw=11 uvw=32 uhw=12 fillp=43 vcnt=48 lasprat=98 pasprat=98 loasc=148 lodes=142 dides=102))
((PT\ Serif Caption) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=186 lvw=20 lhw=9 uvw=22 uhw=10 fillp=38 vcnt=42 lasprat=107 pasprat=97 loasc=142 lodes=138 dides=102))
((PT\ Serif Caption\ Italic) (Ascii Latin mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=88 em=184 lvw=20 lhw=10 uvw=23 uhw=10 fillp=35 vcnt=39 lasprat=98 pasprat=91 loasc=142 lodes=139 dides=102))
((PT\ Serif Italic) (Ascii Latin mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=85 em=168 lvw=17 lhw=9 uvw=21 uhw=10 fillp=33 vcnt=36 lasprat=92 pasprat=87 loasc=148 lodes=142 dides=102))
((PT\ Serif Italic\ Caption) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=88 em=184 lvw=19 lhw=9 uvw=22 uhw=10 fillp=35 vcnt=38 lasprat=98 pasprat=89 loasc=142 lodes=139 dides=102))
((PT\ Serif Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=17 lhw=9 uvw=20 uhw=10 fillp=36 vcnt=39 lasprat=99 pasprat=88 loasc=148 lodes=141 dides=102))
((Punk\ Nova Bold) (mono=no sans=yes slant=0 italic=yes case=mixed regular=no ex=88 em=104 lvw=19 lhw=14 uvw=19 uhw=14 fillp=47 vcnt=53 lasprat=85 pasprat=78 loasc=113 lodes=134 dides=128))
((Punk\ Nova BoldSlanted) (mono=no sans=yes slant=25 italic=no case=mixed regular=no ex=85 em=140 lvw=20 lhw=16 uvw=20 uhw=16 fillp=41 vcnt=47 lasprat=97 pasprat=91 loasc=118 lodes=125 dides=125))
((Punk\ Nova Regular) (mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=84 em=101 lvw=11 lhw=9 uvw=11 uhw=10 fillp=36 vcnt=37 lasprat=79 pasprat=72 loasc=110 lodes=135 dides=122))
((Punk\ Nova Slanted) (mono=no sans=yes slant=33 italic=no case=mixed regular=no ex=89 em=114 lvw=11 lhw=8 uvw=12 uhw=10 fillp=30 vcnt=33 lasprat=84 pasprat=78 loasc=113 lodes=124 dides=122))
((Purisa Bold) (Ascii Latin mono=no sans=yes slant=-7 italic=no case=mixed regular=no ex=88 em=147 lvw=18 lhw=15 uvw=18 uhw=18 fillp=37 vcnt=46 lasprat=120 pasprat=93 loasc=190 lodes=147 dides=105))
((Purisa BoldOblique) (Ascii Latin mono=no sans=yes slant=15 italic=no case=mixed regular=no ex=88 em=147 lvw=20 lhw=15 uvw=18 uhw=19 fillp=34 vcnt=43 lasprat=120 pasprat=101 loasc=190 lodes=147 dides=105))
((Purisa Medium) (Ascii Latin mono=no sans=yes slant=-7 italic=no case=mixed regular=no ex=88 em=138 lvw=13 lhw=11 uvw=13 uhw=13 fillp=29 vcnt=36 lasprat=109 pasprat=83 loasc=189 lodes=147 dides=106))
((Purisa Oblique) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=no ex=88 em=137 lvw=13 lhw=11 uvw=13 uhw=13 fillp=26 vcnt=34 lasprat=109 pasprat=91 loasc=189 lodes=147 dides=106))
((Purisa Regular) (Ascii Latin mono=no sans=yes slant=-6 italic=no case=mixed regular=no ex=88 em=137 lvw=14 lhw=11 uvw=14 uhw=13 fillp=29 vcnt=28 lasprat=109 pasprat=83 loasc=189 lodes=147 dides=106))
((QTAbbie Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=64 em=146 lvw=28 lhw=17 uvw=32 uhw=18 fillp=51 vcnt=42 lasprat=106 pasprat=94 loasc=168 lodes=167 dides=150))
((QTAgateType Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=166 lvw=21 lhw=2 uvw=25 uhw=3 fillp=31 vcnt=29 lasprat=111 pasprat=104 loasc=139 lodes=138 dides=102))
((QTAgateType Italic) (Ascii Latin mono=no sans=no slant=14 italic=yes case=mixed regular=yes ex=84 em=175 lvw=16 lhw=2 uvw=19 uhw=2 fillp=23 vcnt=23 lasprat=107 pasprat=104 loasc=138 lodes=139 dides=102))
((QTAgateType Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=164 lvw=16 lhw=2 uvw=18 uhw=3 fillp=26 vcnt=25 lasprat=106 pasprat=99 loasc=138 lodes=137 dides=102))
((QTAncientOlive Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=137 lvw=25 lhw=21 uvw=25 uhw=24 fillp=60 vcnt=58 lasprat=95 pasprat=86 loasc=129 lodes=125 dides=103))
((QTAncientOlive Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=131 lvw=19 lhw=17 uvw=19 uhw=19 fillp=51 vcnt=48 lasprat=89 pasprat=81 loasc=131 lodes=125 dides=102))
((QTAntiquePost Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=206 lvw=21 lhw=16 uvw=20 uhw=10 fillp=36 vcnt=32 lasprat=95 pasprat=86 loasc=158 lodes=142 dides=104))
((QTArabian Medium) (Ascii Latin mono=no sans=yes slant=9 italic=no case=mixed regular=yes ex=48 em=672 lvw=41 lhw=29 uvw=25 uhw=45 fillp=35 vcnt=31 lasprat=182 pasprat=165 loasc=216 lodes=181 dides=104))
((QTArnieB Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=21 lhw=0 uvw=19 uhw=0 fillp=48 vcnt=47 lasprat=101 pasprat=95 loasc=140 lodes=137 dides=101))
((QTArtiston Medium) (Ascii Latin mono=no sans=no slant=36 italic=yes case=mixed regular=yes ex=66 em=237 lvw=36 lhw=10 uvw=40 uhw=4 fillp=38 vcnt=40 lasprat=129 pasprat=133 loasc=172 lodes=150 dides=110))
((QTAtchen Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=146 lvw=37 lhw=23 uvw=43 uhw=29 fillp=77 vcnt=70 lasprat=99 pasprat=87 loasc=137 lodes=141 dides=102))
((QTAvanti Italic) (Ascii Latin mono=no sans=yes slant=19 italic=no case=mixed regular=yes ex=92 em=166 lvw=13 lhw=13 uvw=14 uhw=13 fillp=28 vcnt=33 lasprat=98 pasprat=98 loasc=134 lodes=139 dides=102))
((QTAvanti Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=169 lvw=13 lhw=13 uvw=14 uhw=13 fillp=37 vcnt=33 lasprat=100 pasprat=85 loasc=136 lodes=138 dides=102))
((QTBasker Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=213 lvw=34 lhw=9 uvw=41 uhw=10 fillp=44 vcnt=43 lasprat=119 pasprat=110 loasc=161 lodes=164 dides=115))
((QTBasker Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=74 em=214 lvw=16 lhw=4 uvw=25 uhw=5 fillp=26 vcnt=28 lasprat=100 pasprat=97 loasc=160 lodes=164 dides=106))
((QTBasker Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=217 lvw=23 lhw=4 uvw=28 uhw=5 fillp=30 vcnt=28 lasprat=118 pasprat=104 loasc=163 lodes=164 dides=113))
((QTBeckman Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=232 lvw=18 lhw=27 uvw=16 uhw=34 fillp=50 vcnt=49 lasprat=105 pasprat=97 loasc=149 lodes=135 dides=105))
((QTBengal Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=167 lvw=40 lhw=17 uvw=44 uhw=17 fillp=55 vcnt=55 lasprat=121 pasprat=116 loasc=149 lodes=148 dides=104))
((QTBengal Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=152 lvw=21 lhw=10 uvw=25 uhw=10 fillp=38 vcnt=38 lasprat=105 pasprat=101 loasc=143 lodes=143 dides=104))
((QTBlackForest BlackForest) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=72 em=240 lvw=22 lhw=13 uvw=29 uhw=8 fillp=32 vcnt=37 lasprat=103 pasprat=96 loasc=154 lodes=177 dides=120))
((QTBlimpo Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=169 lvw=37 lhw=37 uvw=39 uhw=40 fillp=72 vcnt=65 lasprat=104 pasprat=88 loasc=142 lodes=150 dides=103))
((QTBodini Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=208 lvw=36 lhw=6 uvw=40 uhw=6 fillp=43 vcnt=40 lasprat=121 pasprat=110 loasc=161 lodes=158 dides=102))
((QTBodini Italic) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=70 em=204 lvw=21 lhw=7 uvw=27 uhw=7 fillp=29 vcnt=30 lasprat=113 pasprat=113 loasc=168 lodes=164 dides=102))
((QTBodini Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=66 em=219 lvw=25 lhw=7 uvw=30 uhw=7 fillp=33 vcnt=31 lasprat=124 pasprat=113 loasc=177 lodes=166 dides=106))
((QTBodiniPoster Italic) (Ascii Latin mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=75 em=193 lvw=52 lhw=4 uvw=62 uhw=4 fillp=56 vcnt=55 lasprat=126 pasprat=123 loasc=144 lodes=145 dides=108))
((QTBodiniPoster Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=55 lhw=4 uvw=66 uhw=4 fillp=58 vcnt=55 lasprat=131 pasprat=126 loasc=150 lodes=148 dides=108))
((QTBookmann Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=188 lvw=35 lhw=20 uvw=38 uhw=20 fillp=55 vcnt=58 lasprat=116 pasprat=110 loasc=147 lodes=148 dides=103))
((QTBookmann BoldItalic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=86 em=167 lvw=33 lhw=17 uvw=36 uhw=19 fillp=50 vcnt=57 lasprat=116 pasprat=115 loasc=146 lodes=141 dides=103))
((QTBookmann Bookmann) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=191 lvw=22 lhw=8 uvw=24 uhw=11 fillp=34 vcnt=35 lasprat=113 pasprat=108 loasc=150 lodes=151 dides=103))
((QTBookmann Italic) (Ascii Latin mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=83 em=173 lvw=20 lhw=9 uvw=24 uhw=9 fillp=32 vcnt=35 lasprat=109 pasprat=108 loasc=145 lodes=144 dides=103))
((QTBoulevard Medium) (Ascii Latin mono=no sans=no slant=22 italic=yes case=mixed regular=no ex=48 em=418 lvw=18 lhw=16 uvw=18 uhw=16 fillp=21 vcnt=20 lasprat=125 pasprat=121 loasc=247 lodes=225 dides=172))
((QTBrushStroke Medium) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=65 em=293 lvw=21 lhw=18 uvw=29 uhw=20 fillp=40 vcnt=47 lasprat=109 pasprat=120 loasc=175 lodes=169 dides=109))
((QTCaligulatype Medium) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=71 em=229 lvw=29 lhw=9 uvw=29 uhw=11 fillp=42 vcnt=38 lasprat=109 pasprat=102 loasc=174 lodes=150 dides=121))
((QTCanaithtype Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=135 lvw=16 lhw=16 uvw=19 uhw=19 fillp=41 vcnt=39 lasprat=93 pasprat=82 loasc=151 lodes=144 dides=101))
((QTCascadetype Medium) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=no ex=71 em=169 lvw=28 lhw=87 uvw=30 uhw=19 fillp=43 vcnt=43 lasprat=92 pasprat=90 loasc=157 lodes=147 dides=121))
((QTCaslan Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=225 lvw=28 lhw=5 uvw=35 uhw=6 fillp=37 vcnt=36 lasprat=119 pasprat=109 loasc=166 lodes=145 dides=102))
((QTCaslan BoldItalic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=77 em=216 lvw=23 lhw=5 uvw=31 uhw=6 fillp=34 vcnt=36 lasprat=106 pasprat=101 loasc=161 lodes=141 dides=102))
((QTCaslan Italic) (Ascii Latin mono=no sans=no slant=33 italic=yes case=mixed regular=yes ex=74 em=202 lvw=16 lhw=5 uvw=18 uhw=5 fillp=25 vcnt=28 lasprat=96 pasprat=102 loasc=158 lodes=148 dides=101))
((QTCaslan Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=217 lvw=20 lhw=4 uvw=24 uhw=5 fillp=31 vcnt=28 lasprat=112 pasprat=96 loasc=160 lodes=150 dides=112))
((QTCaslanOpen Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=51 em=325 lvw=3 lhw=3 uvw=3 uhw=3 fillp=20 vcnt=16 lasprat=143 pasprat=123 loasc=227 lodes=160 dides=101))
((QTCasual Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=78 em=139 lvw=21 lhw=26 uvw=25 uhw=25 fillp=58 vcnt=48 lasprat=78 pasprat=57 loasc=151 lodes=156 dides=114))
((QTChanceryType Bold) (Ascii Latin mono=no sans=no slant=6 italic=yes case=mixed regular=no ex=75 em=198 lvw=32 lhw=41 uvw=34 uhw=8 fillp=39 vcnt=42 lasprat=104 pasprat=112 loasc=160 lodes=170 dides=109))
((QTChanceryType Italic) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=no ex=73 em=193 lvw=17 lhw=19 uvw=19 uhw=10 fillp=26 vcnt=31 lasprat=90 pasprat=103 loasc=164 lodes=172 dides=108))
((QTChanceryType Medium) (Ascii Latin mono=no sans=no slant=6 italic=yes case=mixed regular=no ex=74 em=189 lvw=16 lhw=16 uvw=20 uhw=9 fillp=28 vcnt=29 lasprat=86 pasprat=92 loasc=162 lodes=171 dides=106))
((QTChicagoland Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=151 lvw=28 lhw=14 uvw=28 uhw=14 fillp=63 vcnt=55 lasprat=92 pasprat=81 loasc=134 lodes=145 dides=101))
((QTClaytablet Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=97 em=92 lvw=13 lhw=22 uvw=15 uhw=15 fillp=22 vcnt=24 lasprat=83 pasprat=81 loasc=125 lodes=135 dides=101))
((QTCloisteredMonk Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=182 lvw=43 lhw=21 uvw=20 uhw=20 fillp=43 vcnt=46 lasprat=75 pasprat=69 loasc=135 lodes=130 dides=102))
((QTCoronation Medium) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=38 em=376 lvw=28 lhw=5 uvw=31 uhw=10 fillp=26 vcnt=26 lasprat=112 pasprat=127 loasc=315 lodes=202 dides=115))
((QTDeuce Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=101 lvw=21 lhw=15 uvw=26 uhw=19 fillp=74 vcnt=73 lasprat=60 pasprat=52 loasc=100 lodes=102 dides=101))
((QTDingBits Medium) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=140 em=111 lvw=4 lhw=20 uvw=44 uhw=0 fillp=41 vcnt=52 lasprat=95 pasprat=90 loasc=102 lodes=103 dides=111))
((QTDoghaus Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=72 em=173 lvw=19 lhw=18 uvw=20 uhw=18 fillp=46 vcnt=38 lasprat=94 pasprat=83 loasc=145 lodes=150 dides=102))
((QTDoghausHeavy Heavy) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=171 lvw=40 lhw=41 uvw=47 uhw=45 fillp=75 vcnt=67 lasprat=107 pasprat=95 loasc=158 lodes=144 dides=102))
((QTDoghausLight Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=71 em=194 lvw=9 lhw=8 uvw=11 uhw=8 fillp=25 vcnt=17 lasprat=100 pasprat=79 loasc=150 lodes=147 dides=101))
((QTDublinIrish Medium) (Ascii Latin mono=no sans=no slant=15 italic=no case=mixed regular=no ex=81 em=213 lvw=19 lhw=13 uvw=23 uhw=18 fillp=41 vcnt=40 lasprat=86 pasprat=81 loasc=145 lodes=148 dides=101))
((QTEraType Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=153 lvw=15 lhw=11 uvw=18 uhw=11 fillp=41 vcnt=32 lasprat=99 pasprat=86 loasc=138 lodes=147 dides=103))
((QTEraType Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=150 lvw=10 lhw=9 uvw=13 uhw=11 fillp=32 vcnt=25 lasprat=94 pasprat=82 loasc=136 lodes=148 dides=103))
((QTEurotype Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=192 lvw=24 lhw=17 uvw=28 uhw=23 fillp=55 vcnt=48 lasprat=101 pasprat=87 loasc=143 lodes=144 dides=101))
((QTEurotype Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=185 lvw=15 lhw=12 uvw=16 uhw=14 fillp=40 vcnt=32 lasprat=96 pasprat=80 loasc=144 lodes=146 dides=101))
((QTFloraline Bold) (Ascii Latin mono=no sans=yes slant=5 italic=yes case=mixed regular=yes ex=94 em=146 lvw=27 lhw=19 uvw=27 uhw=19 fillp=55 vcnt=57 lasprat=93 pasprat=86 loasc=136 lodes=142 dides=103))
((QTFloraline Medium) (Ascii Latin mono=no sans=yes slant=6 italic=yes case=mixed regular=yes ex=94 em=136 lvw=15 lhw=11 uvw=17 uhw=11 fillp=39 vcnt=40 lasprat=83 pasprat=76 loasc=140 lodes=143 dides=103))
((QTFlorencia Medium) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=59 em=262 lvw=15 lhw=11 uvw=15 uhw=10 fillp=19 vcnt=14 lasprat=131 pasprat=131 loasc=186 lodes=216 dides=113))
((QTFraktur Medium) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=83 em=202 lvw=49 lhw=31 uvw=2 uhw=31 fillp=47 vcnt=53 lasprat=89 pasprat=84 loasc=137 lodes=146 dides=104))
((QTFrank Medium) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=144 lvw=16 lhw=14 uvw=17 uhw=14 fillp=42 vcnt=41 lasprat=86 pasprat=78 loasc=136 lodes=138 dides=104))
((QTFrankHeavy Heavy) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=171 lvw=35 lhw=22 uvw=42 uhw=28 fillp=65 vcnt=70 lasprat=101 pasprat=94 loasc=144 lodes=132 dides=102))
((QTFrizQuad Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=192 lvw=35 lhw=20 uvw=41 uhw=22 fillp=56 vcnt=55 lasprat=113 pasprat=105 loasc=144 lodes=146 dides=105))
((QTFrizQuad Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=207 lvw=21 lhw=14 uvw=24 uhw=15 fillp=38 vcnt=36 lasprat=112 pasprat=100 loasc=147 lodes=151 dides=105))
((QTFuture Italic) (Ascii Latin mono=no sans=yes slant=13 italic=no case=mixed regular=yes ex=75 em=196 lvw=20 lhw=16 uvw=22 uhw=17 fillp=37 vcnt=38 lasprat=102 pasprat=95 loasc=172 lodes=152 dides=108))
((QTFuture Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=190 lvw=17 lhw=17 uvw=22 uhw=22 fillp=44 vcnt=41 lasprat=99 pasprat=87 loasc=169 lodes=152 dides=106))
((QTFuturePoster Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=164 lvw=43 lhw=0 uvw=55 uhw=0 fillp=69 vcnt=73 lasprat=95 pasprat=88 loasc=142 lodes=142 dides=103))
((QTGaromand Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=214 lvw=30 lhw=10 uvw=32 uhw=12 fillp=41 vcnt=39 lasprat=112 pasprat=101 loasc=170 lodes=155 dides=108))
((QTGaromand BoldItalic) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=71 em=225 lvw=25 lhw=9 uvw=28 uhw=9 fillp=35 vcnt=36 lasprat=108 pasprat=108 loasc=163 lodes=153 dides=102))
((QTGaromand Italic) (Ascii Latin mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=70 em=201 lvw=17 lhw=7 uvw=20 uhw=8 fillp=27 vcnt=29 lasprat=94 pasprat=101 loasc=164 lodes=155 dides=104))
((QTGaromand Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=208 lvw=19 lhw=8 uvw=21 uhw=8 fillp=32 vcnt=29 lasprat=105 pasprat=92 loasc=167 lodes=153 dides=104))
((QTGhoulFace Medium) (Ascii Latin mono=no sans=no slant=-7 italic=no case=mixed regular=yes ex=105 em=139 lvw=16 lhw=19 uvw=19 uhw=21 fillp=47 vcnt=53 lasprat=93 pasprat=85 loasc=102 lodes=115 dides=117))
((QTGraphLite Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=54 em=283 lvw=31 lhw=5 uvw=40 uhw=9 fillp=38 vcnt=33 lasprat=131 pasprat=121 loasc=242 lodes=170 dides=101))
((QTGraveure Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=92 em=168 lvw=23 lhw=18 uvw=27 uhw=20 fillp=48 vcnt=44 lasprat=123 pasprat=109 loasc=104 lodes=120 dides=107))
((QTGraveure Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=91 em=168 lvw=13 lhw=10 uvw=14 uhw=12 fillp=30 vcnt=27 lasprat=116 pasprat=102 loasc=105 lodes=117 dides=106))
((QTGreece Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=122 em=146 lvw=25 lhw=18 uvw=25 uhw=18 fillp=52 vcnt=52 lasprat=100 pasprat=85 loasc=101 lodes=114 dides=104))
((QTHandwriting Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=39 em=294 lvw=10 lhw=10 uvw=15 uhw=12 fillp=13 vcnt=9 lasprat=170 pasprat=172 loasc=220 lodes=264 dides=100))
((QTHeidelbergType Medium) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=72 em=211 lvw=23 lhw=23 uvw=27 uhw=22 fillp=38 vcnt=40 lasprat=95 pasprat=90 loasc=155 lodes=179 dides=122))
((QTHelvet-Black Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=182 lvw=38 lhw=27 uvw=41 uhw=34 fillp=68 vcnt=64 lasprat=111 pasprat=101 loasc=139 lodes=134 dides=102))
((QTHelvet-BoldOutline BoldOutline) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=95 em=146 lvw=3 lhw=3 uvw=2 uhw=3 fillp=15 vcnt=16 lasprat=94 pasprat=87 loasc=133 lodes=138 dides=103))
((QTHelvetCnd Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=129 lvw=16 lhw=11 uvw=16 uhw=12 fillp=46 vcnt=39 lasprat=76 pasprat=63 loasc=131 lodes=134 dides=102))
((QTHelvetCnd-Black Black) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=142 lvw=33 lhw=21 uvw=35 uhw=22 fillp=71 vcnt=67 lasprat=88 pasprat=80 loasc=135 lodes=134 dides=102))
((QTHelvetCnd-Light Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=127 lvw=10 lhw=9 uvw=12 uhw=9 fillp=37 vcnt=30 lasprat=73 pasprat=60 loasc=134 lodes=136 dides=103))
((QTHoboken Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=136 lvw=19 lhw=25 uvw=25 uhw=27 fillp=57 vcnt=52 lasprat=78 pasprat=68 loasc=133 lodes=102 dides=102))
((QTHowardType Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=144 lvw=5 lhw=6 uvw=6 uhw=7 fillp=22 vcnt=18 lasprat=88 pasprat=75 loasc=157 lodes=161 dides=102))
((QTHowardTypeFat Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=154 lvw=27 lhw=29 uvw=32 uhw=32 fillp=62 vcnt=60 lasprat=96 pasprat=85 loasc=155 lodes=155 dides=102))
((QTImpromptu Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=79 em=188 lvw=39 lhw=31 uvw=48 uhw=36 fillp=64 vcnt=65 lasprat=120 pasprat=108 loasc=162 lodes=151 dides=105))
((QTJupiter Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=125 em=89 lvw=23 lhw=2 uvw=23 uhw=2 fillp=51 vcnt=58 lasprat=74 pasprat=66 loasc=100 lodes=101 dides=100))
((QTKooper Italic) (Ascii Latin mono=no sans=yes slant=10 italic=yes case=mixed regular=yes ex=82 em=196 lvw=46 lhw=98 uvw=52 uhw=25 fillp=62 vcnt=62 lasprat=116 pasprat=106 loasc=146 lodes=137 dides=124))
((QTKooper Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=187 lvw=48 lhw=32 uvw=52 uhw=32 fillp=62 vcnt=65 lasprat=129 pasprat=118 loasc=138 lodes=140 dides=127))
((QTKorrin Italic) (Ascii Latin mono=no sans=no slant=21 italic=no case=mixed regular=yes ex=81 em=175 lvw=14 lhw=9 uvw=17 uhw=9 fillp=29 vcnt=28 lasprat=107 pasprat=98 loasc=144 lodes=145 dides=102))
((QTKorrin Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=170 lvw=18 lhw=13 uvw=21 uhw=14 fillp=37 vcnt=33 lasprat=107 pasprat=94 loasc=152 lodes=148 dides=105))
((QTKung-Fu Fu) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=67 em=171 lvw=20 lhw=19 uvw=25 uhw=23 fillp=37 vcnt=33 lasprat=127 pasprat=111 loasc=149 lodes=152 dides=102))
((QTLautrecType Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=147 lvw=11 lhw=14 uvw=10 uhw=14 fillp=32 vcnt=30 lasprat=76 pasprat=68 loasc=147 lodes=168 dides=136))
((QTLetterGoth Bold) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=13 lhw=11 uvw=13 uhw=12 fillp=36 vcnt=28 lasprat=112 pasprat=78 loasc=139 lodes=140 dides=102))
((QTLetterGoth BoldItalic) (Ascii Latin mono=yes sans=yes slant=27 italic=no case=mixed regular=yes ex=89 em=112 lvw=14 lhw=12 uvw=13 uhw=12 fillp=28 vcnt=28 lasprat=112 pasprat=97 loasc=139 lodes=140 dides=102))
((QTLetterGoth Italic) (Ascii Latin mono=yes sans=yes slant=27 italic=no case=mixed regular=yes ex=87 em=114 lvw=9 lhw=8 uvw=10 uhw=8 fillp=19 vcnt=19 lasprat=114 pasprat=94 loasc=142 lodes=141 dides=102))
((QTLetterGoth Medium) (Ascii Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=112 lvw=8 lhw=7 uvw=8 uhw=7 fillp=25 vcnt=19 lasprat=112 pasprat=72 loasc=139 lodes=140 dides=102))
((QTLinoscroll Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=63 em=204 lvw=9 lhw=87 uvw=26 uhw=6 fillp=35 vcnt=39 lasprat=94 pasprat=88 loasc=174 lodes=165 dides=104))
((QTLinostroke Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=36 em=436 lvw=27 lhw=13 uvw=27 uhw=19 fillp=24 vcnt=22 lasprat=152 pasprat=174 loasc=272 lodes=247 dides=102))
((QTLondonScroll Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=80 em=171 lvw=16 lhw=22 uvw=17 uhw=18 fillp=44 vcnt=48 lasprat=77 pasprat=70 loasc=136 lodes=140 dides=112))
((QTMagicMarker Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=20 lhw=17 uvw=22 uhw=21 fillp=54 vcnt=59 lasprat=74 pasprat=69 loasc=144 lodes=139 dides=110))
((QTMerryScript Medium) (Ascii Latin mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=64 em=257 lvw=15 lhw=6 uvw=18 uhw=7 fillp=29 vcnt=27 lasprat=80 pasprat=69 loasc=168 lodes=165 dides=117))
((QTMilitary Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=111 em=118 lvw=35 lhw=0 uvw=35 uhw=0 fillp=58 vcnt=59 lasprat=95 pasprat=86 loasc=101 lodes=106 dides=100))
((QTOKCorral Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=98 lvw=9 lhw=23 uvw=12 uhw=34 fillp=59 vcnt=55 lasprat=56 pasprat=48 loasc=128 lodes=126 dides=101))
((QTOKCorral-Cnd Cnd) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=84 lvw=7 lhw=23 uvw=10 uhw=34 fillp=60 vcnt=55 lasprat=48 pasprat=41 loasc=128 lodes=127 dides=101))
((QTOKCorral-Ext Ext) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=11 lhw=23 uvw=13 uhw=34 fillp=60 vcnt=56 lasprat=65 pasprat=55 loasc=128 lodes=126 dides=101))
((QTOldGoudy Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=69 em=218 lvw=24 lhw=7 uvw=30 uhw=10 fillp=35 vcnt=35 lasprat=112 pasprat=105 loasc=178 lodes=143 dides=114))
((QTOldGoudy Italic) (Ascii Latin mono=no sans=no slant=12 italic=yes case=mixed regular=yes ex=67 em=214 lvw=16 lhw=7 uvw=19 uhw=7 fillp=27 vcnt=24 lasprat=100 pasprat=87 loasc=173 lodes=143 dides=117))
((QTOldGoudy Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=67 em=222 lvw=16 lhw=5 uvw=19 uhw=7 fillp=28 vcnt=26 lasprat=108 pasprat=100 loasc=182 lodes=149 dides=117))
((QTOptimum Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=198 lvw=30 lhw=8 uvw=34 uhw=12 fillp=50 vcnt=44 lasprat=104 pasprat=89 loasc=158 lodes=146 dides=103))
((QTOptimum BoldItalic) (Ascii Latin mono=no sans=no slant=21 italic=no case=mixed regular=yes ex=78 em=189 lvw=29 lhw=8 uvw=32 uhw=11 fillp=40 vcnt=43 lasprat=103 pasprat=103 loasc=158 lodes=146 dides=103))
((QTOptimum Italic) (Ascii Latin mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=77 em=185 lvw=16 lhw=6 uvw=18 uhw=6 fillp=26 vcnt=26 lasprat=100 pasprat=93 loasc=158 lodes=145 dides=103))
((QTOptimum Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=197 lvw=18 lhw=6 uvw=20 uhw=6 fillp=34 vcnt=27 lasprat=103 pasprat=85 loasc=158 lodes=145 dides=103))
((QTPalatine Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=27 lhw=10 uvw=31 uhw=11 fillp=43 vcnt=41 lasprat=112 pasprat=100 loasc=151 lodes=156 dides=105))
((QTPalatine Italic) (Ascii Latin mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=81 em=196 lvw=16 lhw=9 uvw=18 uhw=8 fillp=28 vcnt=28 lasprat=95 pasprat=88 loasc=151 lodes=158 dides=102))
((QTPalatine Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=203 lvw=20 lhw=8 uvw=23 uhw=8 fillp=31 vcnt=31 lasprat=111 pasprat=101 loasc=155 lodes=161 dides=103))
((QTPandora Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=45 em=231 lvw=13 lhw=13 uvw=17 uhw=13 fillp=24 vcnt=16 lasprat=106 pasprat=93 loasc=204 lodes=208 dides=160))
((QTParisFrance Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=44 em=254 lvw=27 lhw=4 uvw=36 uhw=4 fillp=32 vcnt=22 lasprat=105 pasprat=90 loasc=263 lodes=170 dides=104))
((QTPeignoir Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=73 em=157 lvw=23 lhw=8 uvw=30 uhw=9 fillp=43 vcnt=38 lasprat=88 pasprat=78 loasc=164 lodes=147 dides=102))
((QTPeignoir-Lite Lite) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=76 em=160 lvw=15 lhw=5 uvw=18 uhw=6 fillp=32 vcnt=26 lasprat=83 pasprat=73 loasc=161 lodes=146 dides=105))
((QTPiltdown Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=100 em=118 lvw=13 lhw=20 uvw=20 uhw=34 fillp=36 vcnt=37 lasprat=76 pasprat=69 loasc=100 lodes=109 dides=101))
((QTPristine Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=128 lvw=28 lhw=19 uvw=28 uhw=19 fillp=47 vcnt=45 lasprat=128 pasprat=112 loasc=153 lodes=148 dides=110))
((QTPristine BoldItalic) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=78 em=128 lvw=28 lhw=19 uvw=26 uhw=20 fillp=43 vcnt=45 lasprat=128 pasprat=118 loasc=153 lodes=148 dides=110))
((QTPristine Italic) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=79 em=126 lvw=18 lhw=15 uvw=18 uhw=16 fillp=35 vcnt=35 lasprat=126 pasprat=113 loasc=150 lodes=148 dides=110))
((QTPristine Medium) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=126 lvw=17 lhw=15 uvw=20 uhw=16 fillp=38 vcnt=35 lasprat=126 pasprat=108 loasc=150 lodes=148 dides=110))
((QTRobotic2000 Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=59 em=277 lvw=16 lhw=16 uvw=16 uhw=16 fillp=38 vcnt=29 lasprat=108 pasprat=95 loasc=184 lodes=172 dides=101))
((QTSanDiego Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=59 em=167 lvw=15 lhw=16 uvw=23 uhw=15 fillp=39 vcnt=31 lasprat=107 pasprat=97 loasc=155 lodes=164 dides=103))
((QTSchoolCentury Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=207 lvw=36 lhw=11 uvw=41 uhw=11 fillp=48 vcnt=50 lasprat=125 pasprat=116 loasc=155 lodes=143 dides=103))
((QTSchoolCentury BoldItalic) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=80 em=198 lvw=33 lhw=10 uvw=38 uhw=11 fillp=43 vcnt=49 lasprat=122 pasprat=117 loasc=155 lodes=143 dides=103))
((QTSchoolCentury Italic) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=78 em=203 lvw=19 lhw=7 uvw=25 uhw=8 fillp=32 vcnt=34 lasprat=112 pasprat=104 loasc=157 lodes=144 dides=103))
((QTSchoolCentury Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=203 lvw=21 lhw=8 uvw=26 uhw=10 fillp=36 vcnt=37 lasprat=113 pasprat=103 loasc=158 lodes=144 dides=103))
((QTSlogantype Medium) (Ascii Latin mono=no sans=yes slant=33 italic=yes case=mixed regular=no ex=48 em=408 lvw=52 lhw=41 uvw=39 uhw=29 fillp=28 vcnt=26 lasprat=132 pasprat=133 loasc=193 lodes=195 dides=104))
((QTSnowCaps Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=135 em=85 lvw=26 lhw=11 uvw=26 uhw=11 fillp=58 vcnt=73 lasprat=69 pasprat=64 loasc=100 lodes=111 dides=102))
((QTStoryTimeCaps Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=150 lvw=20 lhw=8 uvw=5 uhw=4 fillp=46 vcnt=53 lasprat=101 pasprat=96 loasc=154 lodes=149 dides=102))
((QTTechtone Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=140 lvw=8 lhw=8 uvw=10 uhw=8 fillp=29 vcnt=25 lasprat=82 pasprat=73 loasc=139 lodes=149 dides=103))
((QTTechtone BoldItalic) (Ascii Latin mono=no sans=yes slant=26 italic=no case=mixed regular=yes ex=79 em=167 lvw=10 lhw=8 uvw=8 uhw=8 fillp=22 vcnt=23 lasprat=90 pasprat=93 loasc=140 lodes=148 dides=102))
((QTTechtone Italic) (Ascii Latin mono=no sans=yes slant=27 italic=no case=mixed regular=yes ex=78 em=152 lvw=5 lhw=3 uvw=3 uhw=3 fillp=11 vcnt=11 lasprat=88 pasprat=89 loasc=142 lodes=148 dides=102))
((QTTechtone Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=78 em=133 lvw=5 lhw=3 uvw=5 uhw=3 fillp=17 vcnt=12 lasprat=80 pasprat=70 loasc=142 lodes=150 dides=102))
((QTTheatre Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=48 lhw=6 uvw=57 uhw=5 fillp=54 vcnt=52 lasprat=118 pasprat=108 loasc=129 lodes=106 dides=104))
((QTTimeOutline Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=3 lhw=3 uvw=3 uhw=3 fillp=16 vcnt=17 lasprat=99 pasprat=97 loasc=145 lodes=145 dides=102))
((QTTumbleweed Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=caps regular=yes ex=131 em=109 lvw=0 lhw=31 uvw=0 uhw=31 fillp=42 vcnt=55 lasprat=83 pasprat=83 loasc=100 lodes=116 dides=100))
((QTUSA-Uncial Uncial) (Ascii Latin mono=no sans=yes slant=0 italic=yes case=caps regular=yes ex=82 em=234 lvw=24 lhw=6 uvw=24 uhw=4 fillp=39 vcnt=35 lasprat=140 pasprat=134 loasc=139 lodes=150 dides=135))
((QTVagaRound Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=163 lvw=29 lhw=26 uvw=32 uhw=26 fillp=61 vcnt=55 lasprat=102 pasprat=85 loasc=143 lodes=141 dides=103))
((QTVagaRound Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=154 lvw=14 lhw=11 uvw=14 uhw=13 fillp=39 vcnt=30 lasprat=87 pasprat=70 loasc=141 lodes=140 dides=102))
((QTWeise Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=66 em=215 lvw=27 lhw=7 uvw=34 uhw=9 fillp=39 vcnt=36 lasprat=105 pasprat=99 loasc=174 lodes=151 dides=104))
((QTWeise Italic) (Ascii Latin mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=66 em=204 lvw=15 lhw=13 uvw=19 uhw=4 fillp=27 vcnt=26 lasprat=81 pasprat=83 loasc=180 lodes=151 dides=103))
((QTWeise Medium) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=68 em=210 lvw=19 lhw=5 uvw=25 uhw=5 fillp=30 vcnt=29 lasprat=102 pasprat=98 loasc=176 lodes=147 dides=102))
((QTWestEnd Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=79 em=183 lvw=15 lhw=7 uvw=20 uhw=10 fillp=36 vcnt=30 lasprat=92 pasprat=79 loasc=100 lodes=124 dides=102))
((Quadrata\ Preciosa Extended\ Medium) (mono=no sans=no slant=10 italic=no case=mixed regular=no ex=37 em=216 lvw=27 lhw=45 uvw=18 uhw=24 fillp=43 vcnt=20 lasprat=108 pasprat=76 loasc=175 lodes=175 dides=102))
((Quadrata\ preciosa Medium) (mono=no sans=no italic=no case=mixed regular=no ex=75 em=120 lvw=10 lhw=18 uvw=9 uhw=13 fillp=41 vcnt=28 lasprat=59 pasprat=43 loasc=144 lodes=100))
((Quattrocento Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=205 lvw=25 lhw=15 uvw=25 uhw=18 fillp=42 vcnt=40 lasprat=116 pasprat=108 loasc=161 lodes=157 dides=102))
((Quattrocento BoldItalic) (Ascii Latin mono=no sans=no slant=24 italic=no case=mixed regular=yes ex=77 em=205 lvw=25 lhw=15 uvw=25 uhw=18 fillp=36 vcnt=40 lasprat=116 pasprat=120 loasc=161 lodes=157 dides=102))
((Quattrocento Italic) (Ascii Latin mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=77 em=194 lvw=16 lhw=9 uvw=16 uhw=11 fillp=25 vcnt=27 lasprat=112 pasprat=114 loasc=161 lodes=155 dides=102))
((Quattrocento Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=194 lvw=15 lhw=9 uvw=16 uhw=11 fillp=29 vcnt=27 lasprat=112 pasprat=101 loasc=161 lodes=157 dides=103))
((Quattrocento\ Sans Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=190 lvw=25 lhw=18 uvw=27 uhw=20 fillp=50 vcnt=42 lasprat=106 pasprat=89 loasc=162 lodes=157 dides=102))
((Quattrocento\ Sans Bold\ Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=77 em=190 lvw=25 lhw=18 uvw=25 uhw=22 fillp=41 vcnt=42 lasprat=107 pasprat=106 loasc=161 lodes=157 dides=103))
((Quattrocento\ Sans Italic) (Ascii Latin mono=no sans=yes slant=21 italic=yes case=mixed regular=yes ex=77 em=183 lvw=15 lhw=11 uvw=16 uhw=14 fillp=29 vcnt=30 lasprat=107 pasprat=103 loasc=162 lodes=157 dides=102))
((Quattrocento\ Sans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=183 lvw=15 lhw=11 uvw=18 uhw=14 fillp=37 vcnt=30 lasprat=106 pasprat=86 loasc=162 lodes=157 dides=102))
((QumpellkaNo12 Regular) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=81 em=234 lvw=30 lhw=4 uvw=32 uhw=6 fillp=33 vcnt=39 lasprat=130 pasprat=125 loasc=164 lodes=148 dides=113))
((Raanana Bold) (slant=0))
((Raanana Regular) (slant=0))
((Raavi Regular) (slant=0))
((Rabanera Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=141 lvw=4 lhw=0 uvw=3 uhw=0 fillp=22 vcnt=25 lasprat=93 pasprat=85 loasc=145 lodes=141 dides=108))
((Rachana Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=194 lvw=19 lhw=6 uvw=25 uhw=7 fillp=33 vcnt=34 lasprat=100 pasprat=93 loasc=151 lodes=147 dides=105))
((Raleway Black) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=161 lvw=37 lhw=30 uvw=37 uhw=32 fillp=65 vcnt=67 lasprat=107 pasprat=100 loasc=140 lodes=144 dides=129))
((Raleway Black\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=88 em=155 lvw=38 lhw=32 uvw=37 uhw=34 fillp=57 vcnt=68 lasprat=104 pasprat=109 loasc=139 lodes=144 dides=129))
((Raleway Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=165 lvw=26 lhw=21 uvw=26 uhw=22 fillp=52 vcnt=50 lasprat=105 pasprat=92 loasc=142 lodes=143 dides=129))
((Raleway Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=158 lvw=26 lhw=22 uvw=27 uhw=24 fillp=45 vcnt=52 lasprat=101 pasprat=103 loasc=141 lodes=143 dides=129))
((Raleway ExtraBold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=162 lvw=30 lhw=26 uvw=31 uhw=27 fillp=59 vcnt=58 lasprat=105 pasprat=96 loasc=140 lodes=143 dides=129))
((Raleway ExtraBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=88 em=156 lvw=31 lhw=26 uvw=31 uhw=28 fillp=51 vcnt=60 lasprat=102 pasprat=105 loasc=139 lodes=144 dides=129))
((Raleway ExtraLight) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=6 lhw=5 uvw=6 uhw=5 fillp=19 vcnt=15 lasprat=98 pasprat=81 loasc=141 lodes=142 dides=129))
((Raleway ExtraLight\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=162 lvw=6 lhw=5 uvw=6 uhw=6 fillp=15 vcnt=15 lasprat=93 pasprat=90 loasc=141 lodes=142 dides=129))
((Raleway Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=160 lvw=13 lhw=11 uvw=13 uhw=12 fillp=27 vcnt=29 lasprat=96 pasprat=94 loasc=141 lodes=142 dides=129))
((Raleway Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=9 lhw=9 uvw=9 uhw=9 fillp=25 vcnt=21 lasprat=99 pasprat=83 loasc=142 lodes=142 dides=129))
((Raleway Light\ Italic) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=87 em=160 lvw=10 lhw=9 uvw=10 uhw=9 fillp=21 vcnt=22 lasprat=95 pasprat=92 loasc=141 lodes=142 dides=129))
((Raleway Medium) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=167 lvw=17 lhw=14 uvw=17 uhw=16 fillp=39 vcnt=36 lasprat=102 pasprat=88 loasc=142 lodes=142 dides=129))
((Raleway Medium\ Italic) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=87 em=160 lvw=17 lhw=14 uvw=18 uhw=16 fillp=33 vcnt=36 lasprat=98 pasprat=97 loasc=141 lodes=142 dides=129))
((Raleway Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=167 lvw=12 lhw=11 uvw=12 uhw=11 fillp=32 vcnt=27 lasprat=100 pasprat=85 loasc=142 lodes=142 dides=129))
((Raleway SemiBold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=166 lvw=20 lhw=18 uvw=21 uhw=19 fillp=46 vcnt=42 lasprat=103 pasprat=89 loasc=142 lodes=143 dides=129))
((Raleway SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=159 lvw=21 lhw=18 uvw=21 uhw=19 fillp=39 vcnt=44 lasprat=100 pasprat=100 loasc=141 lodes=143 dides=129))
((Raleway Thin) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=168 lvw=3 lhw=3 uvw=3 uhw=3 fillp=13 vcnt=8 lasprat=97 pasprat=79 loasc=142 lodes=142 dides=129))
((Raleway Thin\ Italic) (Ascii Latin mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=87 em=162 lvw=3 lhw=3 uvw=3 uhw=3 fillp=9 vcnt=9 lasprat=92 pasprat=88 loasc=141 lodes=142 dides=129))
((Rawengulk Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=201 lvw=15 lhw=15 uvw=15 uhw=15 fillp=36 vcnt=36 lasprat=105 pasprat=92 loasc=145 lodes=145 dides=103))
((Rawengulk Demibold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=198 lvw=11 lhw=11 uvw=11 uhw=11 fillp=29 vcnt=28 lasprat=103 pasprat=91 loasc=143 lodes=144 dides=103))
((Rawengulk Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=186 lvw=3 lhw=3 uvw=3 uhw=3 fillp=12 vcnt=10 lasprat=101 pasprat=87 loasc=143 lodes=145 dides=101))
((Rawengulk Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=201 lvw=7 lhw=6 uvw=7 uhw=6 fillp=21 vcnt=19 lasprat=104 pasprat=90 loasc=143 lodes=145 dides=101))
((Rawengulk Ultralight) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=187 lvw=1 lhw=1 uvw=1 uhw=1 fillp=6 vcnt=4 lasprat=100 pasprat=86 loasc=144 lodes=145 dides=100))
((RawengulkPcs Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=smallcaps regular=yes ex=80 em=201 lvw=7 lhw=7 uvw=7 uhw=7 fillp=23 vcnt=19 lasprat=98 pasprat=81 loasc=101 lodes=137 dides=103))
((RawengulkSans Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=186 lvw=7 lhw=7 uvw=7 uhw=7 fillp=22 vcnt=19 lasprat=96 pasprat=85 loasc=143 lodes=145 dides=101))
((Raya Regular) (slant=0))
((Raya\ PUA Regular) ())
((Rekha Medium) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=no ex=74 em=195 lvw=20 lhw=6 uvw=24 uhw=8 fillp=34 vcnt=34 lasprat=101 pasprat=93 loasc=151 lodes=147 dides=104))
((Resagnicto Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=97 em=164 lvw=21 lhw=6 uvw=21 uhw=6 fillp=40 vcnt=47 lasprat=109 pasprat=88 loasc=136 lodes=136 dides=101))
((Resagnicto Italic) (Ascii Latin mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=97 em=157 lvw=14 lhw=7 uvw=14 uhw=7 fillp=26 vcnt=32 lasprat=103 pasprat=94 loasc=136 lodes=136 dides=101))
((Resagnicto Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=97 em=157 lvw=14 lhw=6 uvw=14 uhw=6 fillp=32 vcnt=37 lasprat=103 pasprat=82 loasc=136 lodes=136 dides=102))
((Resagokr Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=169 lvw=25 lhw=10 uvw=25 uhw=10 fillp=46 vcnt=43 lasprat=108 pasprat=91 loasc=136 lodes=136 dides=101))
((Resagokr Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=154 lvw=10 lhw=5 uvw=11 uhw=5 fillp=26 vcnt=23 lasprat=94 pasprat=77 loasc=135 lodes=135 dides=101))
((Resagokr Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=159 lvw=18 lhw=7 uvw=18 uhw=7 fillp=37 vcnt=34 lasprat=101 pasprat=84 loasc=137 lodes=135 dides=101))
((Reswysokr Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=101 em=92 lvw=8 lhw=3 uvw=9 uhw=3 fillp=29 vcnt=33 lasprat=62 pasprat=48 loasc=131 lodes=120 dides=100))
((Ringling Regular) (mono=no sans=no italic=no case=caps regular=yes ex=167 em=119 lvw=24 lhw=12 uvw=24 uhw=12 fillp=41 vcnt=67 lasprat=98 pasprat=78 loasc=100 lodes=112 dides=100))
((Roboto Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=31 lhw=25 uvw=32 uhw=26 fillp=63 vcnt=62 lasprat=96 pasprat=87 loasc=144 lodes=140 dides=102))
((Roboto Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=161 lvw=30 lhw=23 uvw=31 uhw=26 fillp=54 vcnt=62 lasprat=94 pasprat=95 loasc=144 lodes=142 dides=102))
((Roboto Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=27 lhw=21 uvw=28 uhw=22 fillp=58 vcnt=55 lasprat=96 pasprat=83 loasc=144 lodes=140 dides=102))
((Roboto Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=161 lvw=27 lhw=21 uvw=27 uhw=22 fillp=49 vcnt=55 lasprat=94 pasprat=92 loasc=144 lodes=142 dides=102))
((Roboto Condensed) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=143 lvw=15 lhw=14 uvw=17 uhw=15 fillp=46 vcnt=40 lasprat=83 pasprat=65 loasc=144 lodes=140 dides=102))
((Roboto Condensed\ Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=143 lvw=26 lhw=22 uvw=26 uhw=22 fillp=62 vcnt=59 lasprat=85 pasprat=72 loasc=144 lodes=140 dides=102))
((Roboto Condensed\ Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=139 lvw=26 lhw=21 uvw=26 uhw=22 fillp=52 vcnt=58 lasprat=83 pasprat=82 loasc=144 lodes=140 dides=103))
((Roboto Condensed\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=139 lvw=15 lhw=14 uvw=15 uhw=15 fillp=37 vcnt=39 lasprat=81 pasprat=76 loasc=144 lodes=142 dides=103))
((Roboto Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=161 lvw=17 lhw=14 uvw=17 uhw=15 fillp=36 vcnt=38 lasprat=92 pasprat=86 loasc=144 lodes=142 dides=103))
((Roboto Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=163 lvw=11 lhw=10 uvw=11 uhw=10 fillp=31 vcnt=26 lasprat=93 pasprat=74 loasc=144 lodes=140 dides=102))
((Roboto Light\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=33 vcnt=27 lasprat=82 pasprat=62 loasc=144 lodes=140 dides=102))
((Roboto Light\ Condensed\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=138 lvw=10 lhw=10 uvw=10 uhw=10 fillp=26 vcnt=27 lasprat=80 pasprat=73 loasc=145 lodes=142 dides=102))
((Roboto Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=160 lvw=10 lhw=10 uvw=11 uhw=10 fillp=25 vcnt=26 lasprat=91 pasprat=84 loasc=144 lodes=142 dides=102))
((Roboto Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=21 lhw=18 uvw=23 uhw=19 fillp=52 vcnt=48 lasprat=95 pasprat=80 loasc=144 lodes=140 dides=102))
((Roboto\ Mono Bold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=26 lhw=21 uvw=26 uhw=21 fillp=54 vcnt=50 lasprat=113 pasprat=91 loasc=146 lodes=140 dides=102))
((Roboto\ Mono Bold\ Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=111 lvw=25 lhw=20 uvw=26 uhw=21 fillp=48 vcnt=50 lasprat=111 pasprat=97 loasc=146 lodes=140 dides=102))
((Roboto\ Mono Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=111 lvw=17 lhw=13 uvw=17 uhw=14 fillp=35 vcnt=35 lasprat=111 pasprat=93 loasc=146 lodes=140 dides=103))
((Roboto\ Mono Light) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=11 lhw=10 uvw=11 uhw=10 fillp=28 vcnt=24 lasprat=113 pasprat=83 loasc=145 lodes=140 dides=102))
((Roboto\ Mono Light\ Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=111 lvw=11 lhw=10 uvw=10 uhw=10 fillp=25 vcnt=24 lasprat=111 pasprat=90 loasc=145 lodes=140 dides=102))
((Roboto\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=22 lhw=18 uvw=22 uhw=19 fillp=48 vcnt=44 lasprat=113 pasprat=89 loasc=146 lodes=140 dides=102))
((Roboto\ Mono\ Thin Italic) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=111 lvw=5 lhw=5 uvw=4 uhw=5 fillp=13 vcnt=12 lasprat=111 pasprat=88 loasc=144 lodes=140 dides=102))
((Roboto\ Mono\ Thin Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=113 lvw=4 lhw=5 uvw=4 uhw=5 fillp=14 vcnt=12 lasprat=113 pasprat=80 loasc=144 lodes=140 dides=102))
((Roboto\ Slab Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=178 lvw=27 lhw=21 uvw=26 uhw=21 fillp=54 vcnt=56 lasprat=103 pasprat=94 loasc=146 lodes=140 dides=102))
((Roboto\ Slab Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=171 lvw=11 lhw=10 uvw=10 uhw=10 fillp=27 vcnt=27 lasprat=102 pasprat=87 loasc=146 lodes=140 dides=102))
((Roboto\ Slab Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=18 lhw=14 uvw=18 uhw=14 fillp=41 vcnt=40 lasprat=103 pasprat=90 loasc=146 lodes=140 dides=102))
((Roboto\ Slab Thin) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=168 lvw=4 lhw=5 uvw=4 uhw=5 fillp=14 vcnt=13 lasprat=101 pasprat=85 loasc=146 lodes=140 dides=102))
((Roboto\ Thin Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=16 italic=no case=mixed regular=yes ex=88 em=157 lvw=4 lhw=5 uvw=4 uhw=5 fillp=13 vcnt=13 lasprat=89 pasprat=81 loasc=144 lodes=140 dides=102))
((Roboto\ Thin Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=162 lvw=5 lhw=5 uvw=4 uhw=5 fillp=18 vcnt=13 lasprat=91 pasprat=71 loasc=144 lodes=140 dides=102))
((Rockwell Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=219 lvw=32 lhw=24 uvw=39 uhw=25 fillp=59 vcnt=63 lasprat=118 pasprat=109 loasc=145 lodes=146 dides=102))
((Rockwell Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=86 em=210 lvw=31 lhw=22 uvw=38 uhw=25 fillp=50 vcnt=61 lasprat=113 pasprat=115 loasc=146 lodes=146 dides=102))
((Rockwell Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=86 em=175 lvw=19 lhw=17 uvw=20 uhw=17 fillp=37 vcnt=45 lasprat=105 pasprat=107 loasc=145 lodes=146 dides=102))
((Rockwell Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=186 lvw=20 lhw=18 uvw=24 uhw=18 fillp=44 vcnt=47 lasprat=111 pasprat=102 loasc=145 lodes=146 dides=102))
((Rosario Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=168 lvw=26 lhw=16 uvw=30 uhw=19 fillp=51 vcnt=52 lasprat=94 pasprat=86 loasc=156 lodes=145 dides=143))
((Rosario Bold\ Italic) (Ascii Latin mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=83 em=166 lvw=24 lhw=16 uvw=27 uhw=19 fillp=46 vcnt=54 lasprat=89 pasprat=90 loasc=156 lodes=153 dides=143))
((Rosario Italic) (Ascii Latin mono=no sans=yes slant=14 italic=yes case=mixed regular=yes ex=82 em=160 lvw=17 lhw=12 uvw=19 uhw=14 fillp=35 vcnt=38 lasprat=88 pasprat=84 loasc=156 lodes=151 dides=145))
((Rosario Light) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=168 lvw=13 lhw=10 uvw=14 uhw=10 fillp=34 vcnt=29 lasprat=94 pasprat=76 loasc=154 lodes=145 dides=143))
((Rosario Light\ Italic) (Ascii Latin mono=no sans=yes slant=15 italic=yes case=mixed regular=yes ex=82 em=156 lvw=12 lhw=9 uvw=14 uhw=9 fillp=28 vcnt=29 lasprat=87 pasprat=79 loasc=154 lodes=150 dides=143))
((Rosario Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=168 lvw=18 lhw=13 uvw=20 uhw=13 fillp=40 vcnt=37 lasprat=94 pasprat=79 loasc=155 lodes=145 dides=143))
((Rosario SemiBold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=83 em=168 lvw=21 lhw=14 uvw=24 uhw=15 fillp=45 vcnt=44 lasprat=94 pasprat=82 loasc=155 lodes=145 dides=143))
((Rosario SemiBold\ Italic) (Ascii Latin mono=no sans=no slant=13 italic=yes case=mixed regular=yes ex=82 em=164 lvw=19 lhw=14 uvw=23 uhw=17 fillp=40 vcnt=44 lasprat=89 pasprat=85 loasc=157 lodes=152 dides=143))
((Saab Regular) (slant=0))
((Sana Regular) ())
((Sana\ PUA Regular) ())
((Santa\ Fe\ LET Plain) (mono=no sans=no slant=47 italic=yes case=mixed regular=yes ex=60 em=223 lvw=25 lhw=21 uvw=103 uhw=21 fillp=38 vcnt=41 lasprat=92 pasprat=117 loasc=155 lodes=156 dides=101))
((Sathu Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=142 lvw=17 lhw=14 uvw=18 uhw=14 fillp=42 vcnt=47 lasprat=97 pasprat=80 loasc=143 lodes=141 dides=104))
((Savoye\ LET Plain) (Greek Cyrillic mono=no sans=no slant=21 italic=yes case=mixed regular=yes ex=48 em=241 lvw=14 lhw=4 uvw=18 uhw=6 fillp=20 vcnt=18 lasprat=93 pasprat=93 loasc=239 lodes=166 dides=106))
((Savoye\ LET\ CC. Plain) (Greek Cyrillic mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=75 em=242 lvw=16 lhw=4 uvw=20 uhw=5 fillp=20 vcnt=28 lasprat=93 pasprat=94 loasc=241 lodes=168 dides=108))
((Sawasdee Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=172 lvw=15 lhw=14 uvw=15 uhw=14 fillp=38 vcnt=38 lasprat=99 pasprat=84 loasc=146 lodes=148 dides=101))
((Sawasdee BoldOblique) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=83 em=172 lvw=15 lhw=15 uvw=15 uhw=15 fillp=30 vcnt=33 lasprat=99 pasprat=96 loasc=146 lodes=148 dides=101))
((Sawasdee Oblique) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=83 em=169 lvw=9 lhw=8 uvw=9 uhw=8 fillp=18 vcnt=20 lasprat=96 pasprat=90 loasc=148 lodes=151 dides=101))
((Sawasdee Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=169 lvw=8 lhw=8 uvw=8 uhw=8 fillp=25 vcnt=24 lasprat=96 pasprat=76 loasc=148 lodes=151 dides=101))
((Sazanami\ Gothic Gothic-Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=96 lvw=17 lhw=14 uvw=17 uhw=14 fillp=46 vcnt=50 lasprat=95 pasprat=73 loasc=142 lodes=129 dides=102))
((Sazanami\ Mincho Mincho-Regular) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=106 lvw=15 lhw=7 uvw=15 uhw=7 fillp=29 vcnt=31 lasprat=107 pasprat=94 loasc=164 lodes=124 dides=100))
((SchoolHouse\ Cursive\ B Regular) (mono=no sans=no slant=33 italic=yes case=mixed regular=yes ex=54 em=335 lvw=0 lhw=0 uvw=12 uhw=11 fillp=21 vcnt=18 lasprat=191 pasprat=172 loasc=200 lodes=201 dides=103))
((SchoolHouse\ Printed\ A Regular) (Ascii mono=no sans=no slant=-27 italic=no case=caps regular=yes ex=107 em=120 lvw=0 lhw=3 uvw=0 uhw=3 fillp=20 vcnt=34 lasprat=50 pasprat=55 loasc=100 lodes=153 dides=153))
((Schwaben\ Alt Bold) (mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=73 em=219 lvw=23 lhw=30 uvw=26 uhw=26 fillp=37 vcnt=41 lasprat=86 pasprat=83 loasc=154 lodes=143 dides=101))
((Seattle\ Avenue Regular) (mono=no sans=yes slant=11 italic=no case=mixed regular=no ex=79 em=191 lvw=20 lhw=24 uvw=26 uhw=17 fillp=39 vcnt=52 lasprat=99 pasprat=83 loasc=158 lodes=153 dides=144))
((Segoe\ Boot SemiLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=11 lhw=10 uvw=14 uhw=11 fillp=34 vcnt=28 lasprat=95 pasprat=77 loasc=150 lodes=147 dides=103))
((Segoe\ Mono\ Boot Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=120 lvw=16 lhw=13 uvw=16 uhw=14 fillp=37 vcnt=32 lasprat=120 pasprat=88 loasc=150 lodes=148 dides=102))
((Segoe\ Print Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=92 em=171 lvw=21 lhw=18 uvw=22 uhw=19 fillp=41 vcnt=45 lasprat=100 pasprat=95 loasc=156 lodes=163 dides=108))
((Segoe\ Print Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=91 em=173 lvw=15 lhw=14 uvw=16 uhw=15 fillp=32 vcnt=34 lasprat=102 pasprat=93 loasc=157 lodes=161 dides=108))
((Segoe\ Script Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=76 em=221 lvw=25 lhw=23 uvw=27 uhw=23 fillp=36 vcnt=42 lasprat=133 pasprat=151 loasc=169 lodes=156 dides=110))
((Segoe\ Script Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=74 em=227 lvw=17 lhw=18 uvw=20 uhw=18 fillp=27 vcnt=32 lasprat=137 pasprat=154 loasc=175 lodes=158 dides=110))
((Segoe\ UI Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=196 lvw=41 lhw=29 uvw=44 uhw=35 fillp=69 vcnt=68 lasprat=112 pasprat=101 loasc=150 lodes=146 dides=102))
((Segoe\ UI Black\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=196 lvw=41 lhw=29 uvw=44 uhw=35 fillp=60 vcnt=69 lasprat=111 pasprat=116 loasc=150 lodes=146 dides=102))
((Segoe\ UI Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=190 lvw=30 lhw=23 uvw=33 uhw=27 fillp=59 vcnt=56 lasprat=106 pasprat=92 loasc=150 lodes=147 dides=102))
((Segoe\ UI Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=yes case=mixed regular=yes ex=84 em=172 lvw=30 lhw=23 uvw=33 uhw=27 fillp=50 vcnt=56 lasprat=105 pasprat=106 loasc=150 lodes=147 dides=102))
((Segoe\ UI Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=163 lvw=16 lhw=13 uvw=17 uhw=14 fillp=32 vcnt=34 lasprat=95 pasprat=92 loasc=150 lodes=147 dides=102))
((Segoe\ UI Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=165 lvw=9 lhw=8 uvw=9 uhw=8 fillp=27 vcnt=21 lasprat=92 pasprat=74 loasc=148 lodes=146 dides=102))
((Segoe\ UI Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=165 lvw=9 lhw=8 uvw=10 uhw=8 fillp=20 vcnt=21 lasprat=90 pasprat=87 loasc=150 lodes=146 dides=102))
((Segoe\ UI Regular) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Segoe\ UI SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=183 lvw=22 lhw=17 uvw=23 uhw=20 fillp=49 vcnt=45 lasprat=102 pasprat=85 loasc=150 lodes=147 dides=102))
((Segoe\ UI SemiBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=167 lvw=22 lhw=19 uvw=25 uhw=21 fillp=42 vcnt=46 lasprat=100 pasprat=99 loasc=150 lodes=146 dides=102))
((Segoe\ UI SemiLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=11 lhw=10 uvw=14 uhw=11 fillp=34 vcnt=28 lasprat=95 pasprat=77 loasc=148 lodes=146 dides=102))
((Segoe\ UI SemiLight\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=164 lvw=11 lhw=10 uvw=13 uhw=11 fillp=26 vcnt=28 lasprat=92 pasprat=90 loasc=150 lodes=146 dides=102))
((Segoe\ UI\ Emoji Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Segoe\ UI\ Historic Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Segoe\ UI\ Soundlines Regular) ())
((Segoe\ UI\ Symbol Regular) (Ascii Latin Greek MathSymbols MathExtra MathLetters mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=178 lvw=16 lhw=13 uvw=16 uhw=14 fillp=40 vcnt=34 lasprat=98 pasprat=80 loasc=150 lodes=147 dides=102))
((Seravek Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=175 lvw=32 lhw=24 uvw=32 uhw=26 fillp=61 vcnt=56 lasprat=105 pasprat=93 loasc=147 lodes=143 dides=102))
((Seravek Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=82 em=171 lvw=31 lhw=24 uvw=32 uhw=25 fillp=53 vcnt=57 lasprat=102 pasprat=101 loasc=147 lodes=143 dides=102))
((Seravek Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=80 em=170 lvw=18 lhw=13 uvw=18 uhw=15 fillp=36 vcnt=36 lasprat=97 pasprat=92 loasc=150 lodes=145 dides=102))
((Seravek Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=175 lvw=13 lhw=11 uvw=13 uhw=11 fillp=34 vcnt=27 lasprat=98 pasprat=79 loasc=150 lodes=145 dides=102))
((Seravek Light\ Italic) (Ascii Latin mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=80 em=170 lvw=13 lhw=11 uvw=13 uhw=11 fillp=28 vcnt=27 lasprat=95 pasprat=88 loasc=150 lodes=145 dides=102))
((Seravek Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=176 lvw=18 lhw=15 uvw=18 uhw=15 fillp=42 vcnt=35 lasprat=100 pasprat=83 loasc=150 lodes=145 dides=102))
((Seravek\ ExtraLight Italic) (Ascii Latin mono=no sans=yes slant=18 italic=yes case=mixed regular=yes ex=79 em=170 lvw=8 lhw=7 uvw=8 uhw=7 fillp=19 vcnt=18 lasprat=93 pasprat=85 loasc=151 lodes=145 dides=102))
((Seravek\ ExtraLight Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=8 lhw=7 uvw=8 uhw=7 fillp=24 vcnt=18 lasprat=96 pasprat=76 loasc=151 lodes=145 dides=102))
((Sertig Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=139 lvw=10 lhw=6 uvw=12 uhw=8 fillp=37 vcnt=37 lasprat=75 pasprat=57 loasc=141 lodes=140 dides=101))
((SF\ NS\ Display Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=163 lvw=37 lhw=26 uvw=38 uhw=30 fillp=68 vcnt=69 lasprat=105 pasprat=96 loasc=140 lodes=137 dides=103))
((SF\ NS\ Display Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=160 lvw=26 lhw=20 uvw=27 uhw=23 fillp=57 vcnt=54 lasprat=98 pasprat=86 loasc=138 lodes=136 dides=103))
((SF\ NS\ Display Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=161 lvw=32 lhw=23 uvw=32 uhw=26 fillp=63 vcnt=62 lasprat=101 pasprat=92 loasc=139 lodes=137 dides=103))
((SF\ NS\ Display Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=153 lvw=12 lhw=11 uvw=13 uhw=11 fillp=34 vcnt=30 lasprat=89 pasprat=76 loasc=139 lodes=135 dides=102))
((SF\ NS\ Display Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=159 lvw=20 lhw=17 uvw=20 uhw=18 fillp=48 vcnt=44 lasprat=95 pasprat=82 loasc=139 lodes=136 dides=102))
((SF\ NS\ Display Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=17 uhw=15 fillp=42 vcnt=37 lasprat=92 pasprat=78 loasc=140 lodes=136 dides=102))
((SF\ NS\ Display Semibold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=159 lvw=22 lhw=17 uvw=24 uhw=20 fillp=52 vcnt=49 lasprat=96 pasprat=84 loasc=138 lodes=135 dides=102))
((SF\ NS\ Display Thin) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=148 lvw=7 lhw=6 uvw=7 uhw=6 fillp=23 vcnt=19 lasprat=86 pasprat=73 loasc=139 lodes=134 dides=102))
((SF\ NS\ Display Ultralight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=145 lvw=4 lhw=4 uvw=4 uhw=4 fillp=17 vcnt=12 lasprat=84 pasprat=72 loasc=139 lodes=134 dides=102))
((SF\ NS\ Rounded Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=160 lvw=16 lhw=13 uvw=17 uhw=16 fillp=42 vcnt=37 lasprat=91 pasprat=77 loasc=138 lodes=137 dides=102))
((SF\ NS\ Text Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=26 lhw=21 uvw=27 uhw=24 fillp=57 vcnt=51 lasprat=106 pasprat=87 loasc=140 lodes=137 dides=103))
((SF\ NS\ Text Bold\ G1) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=28 lhw=22 uvw=28 uhw=25 fillp=59 vcnt=54 lasprat=106 pasprat=89 loasc=141 lodes=137 dides=103))
((SF\ NS\ Text Bold\ G2) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=28 lhw=23 uvw=31 uhw=25 fillp=60 vcnt=56 lasprat=106 pasprat=90 loasc=140 lodes=137 dides=103))
((SF\ NS\ Text Bold\ G3) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=170 lvw=31 lhw=23 uvw=32 uhw=26 fillp=61 vcnt=57 lasprat=106 pasprat=91 loasc=141 lodes=137 dides=103))
((SF\ NS\ Text Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=90 em=170 lvw=27 lhw=22 uvw=27 uhw=24 fillp=48 vcnt=51 lasprat=106 pasprat=102 loasc=140 lodes=137 dides=103))
((SF\ NS\ Text Bold\ Italic\ G1) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=170 lvw=28 lhw=23 uvw=30 uhw=25 fillp=49 vcnt=53 lasprat=106 pasprat=103 loasc=141 lodes=137 dides=103))
((SF\ NS\ Text Bold\ Italic\ G2) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=90 em=170 lvw=30 lhw=23 uvw=31 uhw=26 fillp=50 vcnt=55 lasprat=106 pasprat=104 loasc=140 lodes=137 dides=103))
((SF\ NS\ Text Bold\ Italic\ G3) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=90 em=170 lvw=31 lhw=23 uvw=31 uhw=26 fillp=52 vcnt=57 lasprat=106 pasprat=105 loasc=141 lodes=137 dides=103))
((SF\ NS\ Text Heavy) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=172 lvw=31 lhw=24 uvw=34 uhw=27 fillp=63 vcnt=58 lasprat=109 pasprat=92 loasc=139 lodes=137 dides=103))
((SF\ NS\ Text Heavy\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=91 em=172 lvw=32 lhw=24 uvw=32 uhw=27 fillp=53 vcnt=58 lasprat=109 pasprat=106 loasc=139 lodes=137 dides=103))
((SF\ NS\ Text Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=165 lvw=17 lhw=14 uvw=18 uhw=15 fillp=33 vcnt=35 lasprat=100 pasprat=93 loasc=143 lodes=138 dides=103))
((SF\ NS\ Text Italic\ G1) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=88 em=165 lvw=18 lhw=14 uvw=18 uhw=15 fillp=35 vcnt=36 lasprat=100 pasprat=94 loasc=142 lodes=138 dides=103))
((SF\ NS\ Text Italic\ G2) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=165 lvw=18 lhw=15 uvw=19 uhw=17 fillp=36 vcnt=38 lasprat=100 pasprat=95 loasc=143 lodes=138 dides=103))
((SF\ NS\ Text Italic\ G3) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=165 lvw=18 lhw=15 uvw=19 uhw=17 fillp=36 vcnt=39 lasprat=100 pasprat=95 loasc=142 lodes=138 dides=103))
((SF\ NS\ Text Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=162 lvw=12 lhw=11 uvw=13 uhw=11 fillp=34 vcnt=27 lasprat=99 pasprat=76 loasc=140 lodes=137 dides=102))
((SF\ NS\ Text Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=162 lvw=12 lhw=11 uvw=13 uhw=11 fillp=27 vcnt=27 lasprat=99 pasprat=91 loasc=140 lodes=137 dides=102))
((SF\ NS\ Text Medium) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=166 lvw=20 lhw=17 uvw=21 uhw=19 fillp=48 vcnt=41 lasprat=102 pasprat=82 loasc=141 lodes=138 dides=103))
((SF\ NS\ Text Medium\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=89 em=166 lvw=20 lhw=17 uvw=21 uhw=19 fillp=39 vcnt=41 lasprat=102 pasprat=96 loasc=141 lodes=138 dides=103))
((SF\ NS\ Text Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=15 lhw=14 uvw=17 uhw=15 fillp=41 vcnt=35 lasprat=100 pasprat=79 loasc=143 lodes=138 dides=103))
((SF\ NS\ Text Regular\ G1) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=17 lhw=14 uvw=18 uhw=15 fillp=42 vcnt=36 lasprat=100 pasprat=79 loasc=142 lodes=138 dides=103))
((SF\ NS\ Text Regular\ G2) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=18 lhw=15 uvw=19 uhw=17 fillp=44 vcnt=38 lasprat=100 pasprat=80 loasc=143 lodes=138 dides=103))
((SF\ NS\ Text Regular\ G3) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=165 lvw=18 lhw=15 uvw=19 uhw=17 fillp=45 vcnt=39 lasprat=100 pasprat=81 loasc=142 lodes=138 dides=103))
((SF\ NS\ Text Semibold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=168 lvw=23 lhw=19 uvw=23 uhw=21 fillp=52 vcnt=46 lasprat=104 pasprat=85 loasc=141 lodes=138 dides=103))
((SF\ NS\ Text Semibold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=89 em=168 lvw=23 lhw=19 uvw=24 uhw=21 fillp=43 vcnt=45 lasprat=104 pasprat=99 loasc=141 lodes=138 dides=103))
((Shobhika Bold) (Latin mono=no sans=no slant=0 italic=no case=mixed regular=no ex=83 em=116 lvw=0 lhw=0 uvw=50 uhw=143 fillp=47 vcnt=49 lasprat=107 pasprat=101 loasc=155 lodes=143 dides=126))
((Shobhika\ Regular Regular) (Latin mono=no sans=no slant=-34 italic=no case=mixed regular=no ex=83 em=130 lvw=0 lhw=96 uvw=0 uhw=0 fillp=37 vcnt=35 lasprat=98 pasprat=89 loasc=155 lodes=142 dides=126))
((Shree\ Devanagari\ 714 Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=150 lvw=15 lhw=13 uvw=17 uhw=15 fillp=43 vcnt=41 lasprat=89 pasprat=76 loasc=135 lodes=134 dides=101))
((Shree\ Devanagari\ 714 Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=93 em=150 lvw=15 lhw=13 uvw=17 uhw=15 fillp=34 vcnt=41 lasprat=89 pasprat=91 loasc=135 lodes=134 dides=101))
((Shree\ Devanagari\ 714 Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=89 em=160 lvw=10 lhw=6 uvw=10 uhw=7 fillp=21 vcnt=24 lasprat=91 pasprat=90 loasc=139 lodes=135 dides=101))
((Shree\ Devanagari\ 714 Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=160 lvw=8 lhw=6 uvw=8 uhw=7 fillp=28 vcnt=24 lasprat=91 pasprat=75 loasc=139 lodes=135 dides=101))
((Shruti Regular) (slant=0))
((SignPainter-HouseScript Regular) (Latin Greek Cyrillic mono=no sans=yes slant=50 italic=yes case=mixed regular=yes ex=67 em=143 lvw=14 lhw=11 uvw=17 uhw=11 fillp=29 vcnt=37 lasprat=86 pasprat=110 loasc=165 lodes=198 dides=113))
((SignPainter-HouseScript Semibold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=50 italic=yes case=mixed regular=yes ex=68 em=141 lvw=20 lhw=13 uvw=23 uhw=14 fillp=37 vcnt=46 lasprat=84 pasprat=107 loasc=164 lodes=197 dides=110))
((Silom Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=97 em=172 lvw=28 lhw=14 uvw=28 uhw=14 fillp=62 vcnt=72 lasprat=109 pasprat=82 loasc=128 lodes=143 dides=100))
((SimHei Regular) (Ascii CJK mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=109 lvw=18 lhw=15 uvw=19 uhw=15 fillp=46 vcnt=45 lasprat=109 pasprat=80 loasc=151 lodes=127 dides=101))
((SimSun Regular) (Ascii Latin CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=110 lvw=13 lhw=5 uvw=15 uhw=5 fillp=26 vcnt=27 lasprat=110 pasprat=88 loasc=157 lodes=128 dides=100))
((SimSun-ExtB Regular) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=109 lvw=14 lhw=5 uvw=16 uhw=5 fillp=26 vcnt=23 lasprat=109 pasprat=87 loasc=157 lodes=128 dides=100))
((Sinhala\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=62 em=183 lvw=32 lhw=12 uvw=35 uhw=9 fillp=51 vcnt=34 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Sinhala\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=61 em=178 lvw=22 lhw=8 uvw=26 uhw=6 fillp=38 vcnt=24 lasprat=100 pasprat=89 loasc=152 lodes=147 dides=103))
((Sinhala\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=36 lasprat=92 pasprat=76 loasc=143 lodes=143 dides=102))
((Sinhala\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=148 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=36 lasprat=92 pasprat=76 loasc=143 lodes=143 dides=102))
((Sitka\ Banner Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=186 lvw=29 lhw=11 uvw=31 uhw=11 fillp=43 vcnt=41 lasprat=107 pasprat=104 loasc=156 lodes=148 dides=143))
((Sitka\ Banner Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=73 em=184 lvw=28 lhw=10 uvw=31 uhw=10 fillp=40 vcnt=41 lasprat=105 pasprat=108 loasc=154 lodes=147 dides=142))
((Sitka\ Banner Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=73 em=172 lvw=17 lhw=6 uvw=19 uhw=6 fillp=29 vcnt=29 lasprat=98 pasprat=99 loasc=154 lodes=147 dides=142))
((Sitka\ Banner Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=175 lvw=19 lhw=6 uvw=19 uhw=6 fillp=32 vcnt=29 lasprat=99 pasprat=96 loasc=156 lodes=148 dides=143))
((Sitka\ Display Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=189 lvw=30 lhw=10 uvw=31 uhw=12 fillp=44 vcnt=42 lasprat=109 pasprat=106 loasc=156 lodes=147 dides=141))
((Sitka\ Display Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=75 em=185 lvw=28 lhw=10 uvw=30 uhw=12 fillp=41 vcnt=42 lasprat=106 pasprat=107 loasc=152 lodes=146 dides=140))
((Sitka\ Display Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=75 em=173 lvw=18 lhw=8 uvw=20 uhw=8 fillp=29 vcnt=30 lasprat=99 pasprat=98 loasc=152 lodes=146 dides=140))
((Sitka\ Display Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=178 lvw=19 lhw=8 uvw=20 uhw=8 fillp=32 vcnt=30 lasprat=102 pasprat=97 loasc=156 lodes=147 dides=141))
((Sitka\ Heading Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=190 lvw=30 lhw=12 uvw=33 uhw=13 fillp=45 vcnt=43 lasprat=111 pasprat=106 loasc=152 lodes=148 dides=140))
((Sitka\ Heading Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=77 em=187 lvw=29 lhw=11 uvw=31 uhw=12 fillp=42 vcnt=43 lasprat=107 pasprat=107 loasc=148 lodes=146 dides=138))
((Sitka\ Heading Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=77 em=176 lvw=18 lhw=7 uvw=20 uhw=9 fillp=30 vcnt=31 lasprat=101 pasprat=98 loasc=148 lodes=146 dides=138))
((Sitka\ Heading Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=181 lvw=20 lhw=8 uvw=21 uhw=9 fillp=33 vcnt=31 lasprat=104 pasprat=97 loasc=152 lodes=148 dides=140))
((Sitka\ Small Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=202 lvw=32 lhw=14 uvw=34 uhw=16 fillp=49 vcnt=48 lasprat=120 pasprat=110 loasc=142 lodes=145 dides=133))
((Sitka\ Small Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=86 em=197 lvw=30 lhw=13 uvw=32 uhw=16 fillp=45 vcnt=48 lasprat=116 pasprat=109 loasc=139 lodes=144 dides=132))
((Sitka\ Small Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=86 em=188 lvw=19 lhw=10 uvw=20 uhw=11 fillp=34 vcnt=35 lasprat=109 pasprat=99 loasc=139 lodes=144 dides=132))
((Sitka\ Small Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=192 lvw=20 lhw=10 uvw=21 uhw=11 fillp=38 vcnt=35 lasprat=114 pasprat=99 loasc=142 lodes=145 dides=133))
((Sitka\ Subheading Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=194 lvw=31 lhw=12 uvw=32 uhw=14 fillp=46 vcnt=44 lasprat=114 pasprat=107 loasc=149 lodes=146 dides=137))
((Sitka\ Subheading Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=79 em=191 lvw=29 lhw=12 uvw=31 uhw=13 fillp=43 vcnt=44 lasprat=110 pasprat=108 loasc=145 lodes=145 dides=136))
((Sitka\ Subheading Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=79 em=179 lvw=18 lhw=8 uvw=20 uhw=10 fillp=32 vcnt=32 lasprat=103 pasprat=98 loasc=145 lodes=145 dides=136))
((Sitka\ Subheading Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=184 lvw=20 lhw=9 uvw=20 uhw=10 fillp=35 vcnt=32 lasprat=107 pasprat=98 loasc=149 lodes=146 dides=137))
((Sitka\ Text Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=198 lvw=31 lhw=13 uvw=33 uhw=15 fillp=48 vcnt=46 lasprat=117 pasprat=109 loasc=145 lodes=146 dides=135))
((Sitka\ Text Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=no case=mixed regular=yes ex=81 em=196 lvw=29 lhw=13 uvw=32 uhw=14 fillp=44 vcnt=46 lasprat=114 pasprat=109 loasc=143 lodes=145 dides=134))
((Sitka\ Text Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=81 em=186 lvw=19 lhw=9 uvw=19 uhw=11 fillp=33 vcnt=33 lasprat=107 pasprat=99 loasc=143 lodes=145 dides=134))
((Sitka\ Text Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=188 lvw=20 lhw=10 uvw=21 uhw=11 fillp=36 vcnt=33 lasprat=110 pasprat=98 loasc=145 lodes=146 dides=135))
((SkakNew-Diagram Regular) ())
((SkakNew-Figurine Regular) ())
((SkakNewFigurine Bold) ())
((Skia Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=188 lvw=15 lhw=11 uvw=16 uhw=13 fillp=38 vcnt=36 lasprat=100 pasprat=79 loasc=142 lodes=144 dides=135))
((Snell\ Roundhand Black) (Ascii Latin Greek Cyrillic mono=no sans=no slant=58 italic=no case=mixed regular=yes ex=62 em=269 lvw=32 lhw=4 uvw=37 uhw=14 fillp=26 vcnt=38 lasprat=132 pasprat=197 loasc=190 lodes=187 dides=162))
((Snell\ Roundhand Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=66 italic=no case=mixed regular=yes ex=61 em=273 lvw=24 lhw=3 uvw=27 uhw=6 fillp=21 vcnt=30 lasprat=124 pasprat=190 loasc=191 lodes=188 dides=160))
((Snell\ Roundhand Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=64 italic=no case=mixed regular=yes ex=60 em=278 lvw=15 lhw=3 uvw=18 uhw=5 fillp=14 vcnt=20 lasprat=112 pasprat=179 loasc=193 lodes=190 dides=160))
((Somer Regular) (slant=0))
((Somer\ PUA Regular) ())
((Songti\ SC Black) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=212 lvw=28 lhw=9 uvw=32 uhw=8 fillp=40 vcnt=37 lasprat=101 pasprat=95 loasc=161 lodes=133 dides=100))
((Songti\ SC Bold) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=201 lvw=24 lhw=6 uvw=28 uhw=6 fillp=35 vcnt=32 lasprat=101 pasprat=93 loasc=161 lodes=137 dides=100))
((Songti\ SC Light) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=185 lvw=16 lhw=4 uvw=20 uhw=4 fillp=27 vcnt=24 lasprat=101 pasprat=90 loasc=162 lodes=140 dides=100))
((Songti\ SC Regular) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=188 lvw=17 lhw=5 uvw=21 uhw=5 fillp=28 vcnt=25 lasprat=101 pasprat=91 loasc=162 lodes=140 dides=100))
((Songti\ TC Bold) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=201 lvw=24 lhw=6 uvw=28 uhw=6 fillp=35 vcnt=32 lasprat=101 pasprat=93 loasc=161 lodes=137 dides=100))
((Songti\ TC Light) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=185 lvw=16 lhw=4 uvw=20 uhw=4 fillp=27 vcnt=24 lasprat=101 pasprat=90 loasc=162 lodes=140 dides=100))
((Songti\ TC Regular) (Ascii Latin Greek Cyrillic CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=188 lvw=17 lhw=5 uvw=21 uhw=5 fillp=28 vcnt=25 lasprat=101 pasprat=91 loasc=162 lodes=140 dides=100))
((Source\ Code\ Pro Black) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=120 lvw=34 lhw=27 uvw=34 uhw=30 fillp=63 vcnt=55 lasprat=120 pasprat=98 loasc=155 lodes=140 dides=102))
((Source\ Code\ Pro Black\ Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=120 lvw=31 lhw=26 uvw=32 uhw=27 fillp=54 vcnt=52 lasprat=120 pasprat=107 loasc=153 lodes=137 dides=102))
((Source\ Code\ Pro Bold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=120 lvw=30 lhw=24 uvw=30 uhw=25 fillp=57 vcnt=50 lasprat=120 pasprat=98 loasc=151 lodes=142 dides=102))
((Source\ Code\ Pro Bold\ Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=120 lvw=27 lhw=22 uvw=28 uhw=22 fillp=48 vcnt=47 lasprat=120 pasprat=107 loasc=150 lodes=139 dides=102))
((Source\ Code\ Pro Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=81 em=123 lvw=19 lhw=16 uvw=19 uhw=16 fillp=36 vcnt=33 lasprat=123 pasprat=104 loasc=148 lodes=143 dides=102))
((Source\ Code\ Pro Light) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=125 lvw=10 lhw=8 uvw=10 uhw=8 fillp=23 vcnt=18 lasprat=125 pasprat=91 loasc=153 lodes=147 dides=102))
((Source\ Code\ Pro Light\ Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=80 em=125 lvw=8 lhw=8 uvw=8 uhw=8 fillp=19 vcnt=16 lasprat=125 pasprat=99 loasc=153 lodes=147 dides=102))
((Source\ Code\ Pro Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=123 lvw=20 lhw=16 uvw=20 uhw=18 fillp=43 vcnt=36 lasprat=123 pasprat=95 loasc=149 lodes=145 dides=102))
((Source\ Code\ Pro SemiBold) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=123 lvw=24 lhw=18 uvw=24 uhw=20 fillp=48 vcnt=41 lasprat=123 pasprat=97 loasc=151 lodes=144 dides=102))
((Source\ Code\ Pro SemiBold\ Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=81 em=123 lvw=22 lhw=18 uvw=22 uhw=18 fillp=40 vcnt=38 lasprat=123 pasprat=106 loasc=150 lodes=141 dides=102))
((Source\ Code\ Pro\ ExtraLight Italic) (Ascii Latin mono=yes sans=yes slant=20 italic=no case=mixed regular=yes ex=80 em=125 lvw=6 lhw=6 uvw=6 uhw=6 fillp=14 vcnt=12 lasprat=125 pasprat=98 loasc=153 lodes=148 dides=102))
((Source\ Code\ Pro\ ExtraLight Regular) (Ascii Latin Greek Cyrillic mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=125 lvw=7 lhw=6 uvw=7 uhw=6 fillp=17 vcnt=13 lasprat=125 pasprat=89 loasc=153 lodes=148 dides=102))
((Source\ Han\ Sans\ SC Bold) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=93 em=152 lvw=26 lhw=21 uvw=26 uhw=22 fillp=55 vcnt=55 lasprat=101 pasprat=86 loasc=146 lodes=144 dides=102))
((Source\ Han\ Sans\ SC ExtraLight) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=145 lvw=6 lhw=6 uvw=7 uhw=6 fillp=21 vcnt=17 lasprat=93 pasprat=72 loasc=153 lodes=148 dides=102))
((Source\ Han\ Sans\ SC Heavy) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=95 em=153 lvw=31 lhw=25 uvw=31 uhw=27 fillp=61 vcnt=63 lasprat=102 pasprat=89 loasc=146 lodes=142 dides=102))
((Source\ Han\ Sans\ SC Light) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=147 lvw=12 lhw=8 uvw=12 uhw=10 fillp=29 vcnt=25 lasprat=95 pasprat=75 loasc=151 lodes=147 dides=102))
((Source\ Han\ Sans\ SC Medium) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=150 lvw=21 lhw=17 uvw=20 uhw=18 fillp=47 vcnt=45 lasprat=98 pasprat=81 loasc=147 lodes=144 dides=102))
((Source\ Han\ Sans\ SC Normal) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=148 lvw=15 lhw=12 uvw=15 uhw=13 fillp=37 vcnt=34 lasprat=97 pasprat=78 loasc=150 lodes=146 dides=102))
((Source\ Han\ Sans\ SC Regular) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=148 lvw=16 lhw=14 uvw=17 uhw=15 fillp=41 vcnt=37 lasprat=97 pasprat=79 loasc=149 lodes=146 dides=102))
((Source\ Han\ Sans\ SC\ ExtraLight Regular) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=145 lvw=6 lhw=6 uvw=7 uhw=6 fillp=21 vcnt=17 lasprat=93 pasprat=72 loasc=153 lodes=148 dides=102))
((Source\ Han\ Sans\ SC\ Normal Regular) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=148 lvw=15 lhw=12 uvw=15 uhw=13 fillp=37 vcnt=34 lasprat=97 pasprat=78 loasc=150 lodes=146 dides=102))
((Source\ Han\ Sans\ SC\ Regular Regular) (Ascii Latin Greek CJK Hangul MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=148 lvw=16 lhw=14 uvw=17 uhw=15 fillp=41 vcnt=37 lasprat=97 pasprat=79 loasc=149 lodes=146 dides=102))
((Source\ Sans\ Pro Black) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=155 lvw=34 lhw=27 uvw=34 uhw=30 fillp=65 vcnt=58 lasprat=104 pasprat=89 loasc=148 lodes=140 dides=102))
((Source\ Sans\ Pro Black\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=151 lvw=31 lhw=26 uvw=32 uhw=27 fillp=54 vcnt=55 lasprat=100 pasprat=98 loasc=145 lodes=142 dides=102))
((Source\ Sans\ Pro Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=153 lvw=30 lhw=24 uvw=30 uhw=25 fillp=60 vcnt=53 lasprat=102 pasprat=87 loasc=145 lodes=142 dides=102))
((Source\ Sans\ Pro Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=83 em=148 lvw=27 lhw=21 uvw=27 uhw=22 fillp=49 vcnt=50 lasprat=98 pasprat=97 loasc=144 lodes=142 dides=102))
((Source\ Sans\ Pro Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=81 em=145 lvw=14 lhw=13 uvw=16 uhw=13 fillp=32 vcnt=32 lasprat=95 pasprat=90 loasc=149 lodes=146 dides=102))
((Source\ Sans\ Pro Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=147 lvw=10 lhw=8 uvw=10 uhw=8 fillp=27 vcnt=21 lasprat=94 pasprat=74 loasc=153 lodes=147 dides=102))
((Source\ Sans\ Pro Light\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=80 em=142 lvw=8 lhw=8 uvw=10 uhw=8 fillp=20 vcnt=19 lasprat=92 pasprat=85 loasc=153 lodes=147 dides=102))
((Source\ Sans\ Pro Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=149 lvw=17 lhw=13 uvw=17 uhw=14 fillp=41 vcnt=33 lasprat=97 pasprat=79 loasc=149 lodes=145 dides=102))
((Source\ Sans\ Pro SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=153 lvw=23 lhw=18 uvw=23 uhw=20 fillp=51 vcnt=43 lasprat=101 pasprat=84 loasc=148 lodes=144 dides=102))
((Source\ Sans\ Pro SemiBold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=81 em=149 lvw=22 lhw=18 uvw=23 uhw=18 fillp=41 vcnt=42 lasprat=98 pasprat=95 loasc=146 lodes=144 dides=102))
((Source\ Sans\ Pro\ ExtraLight Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=80 em=141 lvw=6 lhw=6 uvw=6 uhw=6 fillp=14 vcnt=14 lasprat=91 pasprat=83 loasc=153 lodes=148 dides=102))
((Source\ Sans\ Pro\ ExtraLight Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=80 em=145 lvw=6 lhw=6 uvw=6 uhw=6 fillp=20 vcnt=14 lasprat=93 pasprat=71 loasc=153 lodes=148 dides=102))
((Source\ Serif\ Pro Black) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=183 lvw=40 lhw=11 uvw=40 uhw=12 fillp=56 vcnt=56 lasprat=111 pasprat=105 loasc=151 lodes=148 dides=104))
((Source\ Serif\ Pro Black\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=84 em=178 lvw=33 lhw=13 uvw=34 uhw=11 fillp=48 vcnt=53 lasprat=105 pasprat=105 loasc=148 lodes=146 dides=104))
((Source\ Serif\ Pro Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=183 lvw=34 lhw=11 uvw=37 uhw=12 fillp=51 vcnt=51 lasprat=109 pasprat=104 loasc=151 lodes=148 dides=104))
((Source\ Serif\ Pro Bold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=83 em=181 lvw=28 lhw=10 uvw=31 uhw=12 fillp=44 vcnt=48 lasprat=103 pasprat=104 loasc=150 lodes=148 dides=104))
((Source\ Serif\ Pro Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=81 em=191 lvw=17 lhw=8 uvw=18 uhw=11 fillp=30 vcnt=32 lasprat=96 pasprat=96 loasc=154 lodes=151 dides=104))
((Source\ Serif\ Pro Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=189 lvw=11 lhw=6 uvw=12 uhw=7 fillp=23 vcnt=21 lasprat=107 pasprat=94 loasc=159 lodes=153 dides=103))
((Source\ Serif\ Pro Light\ Italic) (Ascii Latin mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=81 em=188 lvw=9 lhw=6 uvw=11 uhw=7 fillp=20 vcnt=21 lasprat=95 pasprat=92 loasc=155 lodes=153 dides=104))
((Source\ Serif\ Pro Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=189 lvw=20 lhw=10 uvw=22 uhw=10 fillp=35 vcnt=33 lasprat=107 pasprat=96 loasc=158 lodes=151 dides=103))
((Source\ Serif\ Pro SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=189 lvw=27 lhw=10 uvw=30 uhw=11 fillp=43 vcnt=42 lasprat=110 pasprat=102 loasc=156 lodes=150 dides=103))
((Source\ Serif\ Pro SemiBold\ Italic) (Ascii Latin mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=82 em=186 lvw=23 lhw=9 uvw=24 uhw=10 fillp=37 vcnt=40 lasprat=99 pasprat=99 loasc=151 lodes=150 dides=103))
((Source\ Serif\ Pro\ ExtraLight Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=80 em=188 lvw=6 lhw=3 uvw=6 uhw=5 fillp=13 vcnt=13 lasprat=96 pasprat=90 loasc=157 lodes=155 dides=105))
((Source\ Serif\ Pro\ ExtraLight Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=189 lvw=6 lhw=3 uvw=6 uhw=5 fillp=15 vcnt=13 lasprat=106 pasprat=91 loasc=159 lodes=153 dides=102))
((Step Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=7 fillp=45 vcnt=44 lasprat=105 pasprat=97 loasc=149 lodes=144 dides=102))
((Step Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=192 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=144 dides=102))
((Step Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=73 em=190 lvw=19 lhw=5 uvw=24 uhw=6 fillp=29 vcnt=30 lasprat=101 pasprat=99 loasc=157 lodes=147 dides=104))
((Step Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((STEP\ Math Bold) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=7 fillp=45 vcnt=44 lasprat=105 pasprat=98 loasc=149 lodes=145 dides=102))
((STEP\ Math Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((STFangsong Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=187 lvw=17 lhw=4 uvw=20 uhw=4 fillp=26 vcnt=25 lasprat=99 pasprat=91 loasc=163 lodes=131 dides=100))
((STHeiti Light) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=11 lhw=11 uvw=12 uhw=11 fillp=35 vcnt=36 lasprat=91 pasprat=75 loasc=134 lodes=122 dides=100))
((STHeiti Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=99 em=154 lvw=11 lhw=11 uvw=12 uhw=11 fillp=35 vcnt=36 lasprat=91 pasprat=75 loasc=134 lodes=122 dides=100))
((Stix Bold) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=7 fillp=45 vcnt=47 lasprat=105 pasprat=97 loasc=149 lodes=144 dides=102))
((Stix Bold\ Italic) (Ascii Latin Greek Cyrillic MathLetters mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=192 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=144 dides=102))
((Stix Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=73 em=190 lvw=19 lhw=5 uvw=24 uhw=6 fillp=29 vcnt=30 lasprat=101 pasprat=99 loasc=157 lodes=147 dides=104))
((Stix Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=153 lodes=148 dides=104))
((Stix\ Math Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=153 lodes=148 dides=104))
((STKaiti Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=187 lvw=17 lhw=4 uvw=20 uhw=4 fillp=26 vcnt=25 lasprat=99 pasprat=91 loasc=163 lodes=131 dides=100))
((Stone\ Sans\ ITC\ TT Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=185 lvw=40 lhw=17 uvw=44 uhw=28 fillp=64 vcnt=61 lasprat=116 pasprat=101 loasc=148 lodes=150 dides=101))
((Stone\ Sans\ Sem\ ITC\ TT Semi) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=183 lvw=27 lhw=15 uvw=29 uhw=20 fillp=51 vcnt=47 lasprat=107 pasprat=90 loasc=145 lodes=150 dides=101))
((Stone\ Sans\ Sem\ ITC\ TT SemiIta) (Ascii Latin mono=no sans=yes slant=19 italic=no case=mixed regular=yes ex=85 em=176 lvw=24 lhw=12 uvw=27 uhw=20 fillp=42 vcnt=45 lasprat=98 pasprat=94 loasc=144 lodes=149 dides=101))
((STSong Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=187 lvw=17 lhw=4 uvw=20 uhw=4 fillp=26 vcnt=25 lasprat=99 pasprat=91 loasc=163 lodes=131 dides=100))
((Sukhumvit\ Set Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=167 lvw=25 lhw=19 uvw=27 uhw=22 fillp=55 vcnt=48 lasprat=103 pasprat=86 loasc=141 lodes=141 dides=102))
((Sukhumvit\ Set Light) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=160 lvw=13 lhw=11 uvw=13 uhw=11 fillp=36 vcnt=28 lasprat=99 pasprat=78 loasc=141 lodes=141 dides=102))
((Sukhumvit\ Set Medium) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=162 lvw=17 lhw=14 uvw=17 uhw=14 fillp=42 vcnt=34 lasprat=100 pasprat=80 loasc=141 lodes=141 dides=102))
((Sukhumvit\ Set Semi\ Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=166 lvw=22 lhw=16 uvw=22 uhw=18 fillp=49 vcnt=42 lasprat=101 pasprat=83 loasc=140 lodes=141 dides=102))
((Sukhumvit\ Set Text) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=162 lvw=14 lhw=12 uvw=16 uhw=13 fillp=39 vcnt=31 lasprat=99 pasprat=78 loasc=140 lodes=141 dides=102))
((Sukhumvit\ Set Thin) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=159 lvw=9 lhw=7 uvw=9 uhw=8 fillp=27 vcnt=20 lasprat=97 pasprat=75 loasc=140 lodes=140 dides=101))
((Superclarendon Black) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=221 lvw=44 lhw=21 uvw=49 uhw=24 fillp=62 vcnt=66 lasprat=141 pasprat=127 loasc=152 lodes=147 dides=103))
((Superclarendon Black\ Italic) (Ascii Latin mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=85 em=224 lvw=44 lhw=21 uvw=50 uhw=24 fillp=58 vcnt=66 lasprat=144 pasprat=138 loasc=152 lodes=147 dides=103))
((Superclarendon Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=212 lvw=36 lhw=16 uvw=41 uhw=20 fillp=54 vcnt=57 lasprat=135 pasprat=121 loasc=154 lodes=147 dides=103))
((Superclarendon Bold\ Italic) (Ascii Latin mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=85 em=217 lvw=35 lhw=16 uvw=40 uhw=20 fillp=50 vcnt=57 lasprat=138 pasprat=131 loasc=152 lodes=147 dides=103))
((Superclarendon Italic) (Ascii Latin mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=85 em=210 lvw=27 lhw=12 uvw=30 uhw=16 fillp=41 vcnt=46 lasprat=131 pasprat=125 loasc=152 lodes=147 dides=103))
((Superclarendon Light) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=200 lvw=17 lhw=8 uvw=22 uhw=11 fillp=33 vcnt=34 lasprat=122 pasprat=109 loasc=152 lodes=145 dides=103))
((Superclarendon Light\ Italic) (Ascii Latin mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=85 em=203 lvw=18 lhw=8 uvw=22 uhw=11 fillp=30 vcnt=34 lasprat=125 pasprat=118 loasc=152 lodes=145 dides=103))
((Superclarendon Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=207 lvw=27 lhw=12 uvw=30 uhw=16 fillp=44 vcnt=47 lasprat=129 pasprat=115 loasc=152 lodes=147 dides=103))
((SVRsymbols Regular) (italic=no regular=no))
((Sylfaen Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=209 lvw=20 lhw=9 uvw=22 uhw=11 fillp=34 vcnt=35 lasprat=110 pasprat=102 loasc=163 lodes=159 dides=104))
((Symbol Regular) ())
((Synchro\ LET Regular) (mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=112 em=94 lvw=17 lhw=14 uvw=17 uhw=14 fillp=43 vcnt=40 lasprat=86 pasprat=72 loasc=100 lodes=100 dides=100))
((Tabaquera Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=145 lvw=3 lhw=0 uvw=3 uhw=0 fillp=66 vcnt=76 lasprat=93 pasprat=77 loasc=151 lodes=132 dides=101))
((Tahoma Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=161 lvw=31 lhw=21 uvw=33 uhw=25 fillp=62 vcnt=71 lasprat=103 pasprat=92 loasc=139 lodes=138 dides=103))
((Tahoma Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=141 lvw=17 lhw=14 uvw=18 uhw=15 fillp=43 vcnt=48 lasprat=89 pasprat=77 loasc=140 lodes=138 dides=103))
((TakaoExGothic Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=177 lvw=17 lhw=14 uvw=18 uhw=15 fillp=41 vcnt=42 lasprat=102 pasprat=82 loasc=148 lodes=138 dides=101))
((TakaoExMincho Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=193 lvw=15 lhw=7 uvw=17 uhw=7 fillp=27 vcnt=29 lasprat=107 pasprat=97 loasc=150 lodes=141 dides=103))
((TakaoGothic Regular) (Ascii Latin CJK mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=95 lvw=14 lhw=13 uvw=15 uhw=13 fillp=43 vcnt=46 lasprat=95 pasprat=65 loasc=142 lodes=118 dides=100))
((TakaoMincho Regular) (Ascii Latin CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=95 lvw=11 lhw=5 uvw=13 uhw=5 fillp=28 vcnt=31 lasprat=95 pasprat=72 loasc=147 lodes=118 dides=100))
((TakaoPGothic Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=177 lvw=17 lhw=14 uvw=18 uhw=14 fillp=40 vcnt=42 lasprat=102 pasprat=82 loasc=149 lodes=138 dides=101))
((TakaoPMincho Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=193 lvw=14 lhw=7 uvw=17 uhw=7 fillp=27 vcnt=29 lasprat=107 pasprat=97 loasc=148 lodes=141 dides=103))
((Tamil\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=183 lvw=32 lhw=12 uvw=35 uhw=11 fillp=51 vcnt=49 lasprat=106 pasprat=95 loasc=148 lodes=141 dides=103))
((Tamil\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=176 lvw=21 lhw=6 uvw=25 uhw=6 fillp=38 vcnt=35 lasprat=99 pasprat=88 loasc=150 lodes=146 dides=103))
((Tamil\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=150 lvw=22 lhw=19 uvw=24 uhw=19 fillp=53 vcnt=49 lasprat=94 pasprat=81 loasc=140 lodes=140 dides=102))
((Tamil\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=83 em=149 lvw=14 lhw=12 uvw=14 uhw=12 fillp=38 vcnt=32 lasprat=93 pasprat=77 loasc=142 lodes=144 dides=102))
((Tangerine Bold) (Ascii Latin mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=43 em=495 lvw=20 lhw=16 uvw=23 uhw=16 fillp=20 vcnt=16 lasprat=105 pasprat=142 loasc=295 lodes=195 dides=162))
((Tangerine Regular) (Ascii Latin mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=43 em=474 lvw=11 lhw=13 uvw=16 uhw=13 fillp=16 vcnt=13 lasprat=94 pasprat=133 loasc=293 lodes=195 dides=162))
((Telugu\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=182 lvw=32 lhw=11 uvw=35 uhw=10 fillp=51 vcnt=46 lasprat=105 pasprat=94 loasc=146 lodes=140 dides=102))
((Telugu\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=82 em=178 lvw=21 lhw=7 uvw=25 uhw=6 fillp=38 vcnt=33 lasprat=100 pasprat=88 loasc=152 lodes=146 dides=103))
((Telugu\ Sangam\ MN Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=150 lvw=21 lhw=16 uvw=22 uhw=17 fillp=50 vcnt=48 lasprat=95 pasprat=81 loasc=142 lodes=142 dides=102))
((Telugu\ Sangam\ MN Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=149 lvw=14 lhw=13 uvw=14 uhw=13 fillp=39 vcnt=35 lasprat=95 pasprat=77 loasc=144 lodes=144 dides=102))
((Tempora Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=38 uhw=7 fillp=45 vcnt=44 lasprat=105 pasprat=97 loasc=149 lodes=144 dides=103))
((Tempora Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=193 lvw=27 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=153 lodes=144 dides=102))
((Tempora Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=73 em=189 lvw=19 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=29 lasprat=101 pasprat=97 loasc=157 lodes=147 dides=104))
((Tempora Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=196 lvw=21 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=31 lasprat=101 pasprat=94 loasc=153 lodes=148 dides=105))
((TeX\ AMS\ Blackboard\ Bold Regular) (sans=no slant=391))
((TeX\ Blackboard\ Bold Bold) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=270 lvw=14 lhw=9 uvw=17 uhw=9 fillp=36 vcnt=38 lasprat=151 pasprat=137 loasc=158 lodes=145))
((TeX\ Blackboard\ Bold Bold Oblique) (mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=74 em=270 lvw=14 lhw=9 uvw=17 uhw=9 fillp=35 vcnt=36 lasprat=151 pasprat=144 loasc=158 lodes=145))
((TeX\ Blackboard\ Bold Oblique) (mono=no sans=no slant=16 italic=no case=mixed regular=yes ex=72 em=236 lvw=9 lhw=6 uvw=12 uhw=6 fillp=26 vcnt=27 lasprat=137 pasprat=131 loasc=163 lodes=147))
((TeX\ Blackboard\ Bold Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=236 lvw=9 lhw=6 uvw=12 uhw=6 fillp=27 vcnt=28 lasprat=137 pasprat=124 loasc=163 lodes=147))
((TeX\ Blackboard\ Bold\ Sans Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=217 lvw=9 lhw=14 uvw=10 uhw=14 fillp=35 vcnt=36 lasprat=123 pasprat=104 loasc=159 lodes=145))
((TeX\ Blackboard\ Bold\ Variant Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=166 lvw=9 lhw=9 uvw=9 uhw=9 fillp=29 vcnt=30 lasprat=114 pasprat=97 loasc=166 lodes=150 dides=105))
((TeX\ Calligraphic Regular) (mono=no sans=no slant=92 italic=yes case=mixed regular=yes ex=33 em=403 lvw=15 lhw=6 uvw=18 uhw=6 fillp=15 vcnt=16 lasprat=140 pasprat=212 loasc=269 lodes=215 dides=103))
((TeX\ Calligraphic\ Capitals Bold) (mono=no sans=no slant=-17 italic=no case=mixed regular=no ex=117 em=196 lvw=0 lhw=6 uvw=18 uhw=15 fillp=31 vcnt=40 lasprat=88 pasprat=66 loasc=109 lodes=234))
((TeX\ Calligraphic\ Capitals Regular) (mono=no sans=no slant=-16 italic=no case=mixed regular=no ex=118 em=169 lvw=0 lhw=4 uvw=11 uhw=9 fillp=23 vcnt=28 lasprat=75 pasprat=56 loasc=108 lodes=235))
((TeX\ Double\ Stroke Regular) (sans=no))
((TeX\ Double\ Stroke\ Sans Regular) (sans=no))
((TeX\ Euler\ Calligraphic Regular) (sans=no))
((TeX\ Gothic Regular) (mono=no sans=no slant=17 italic=no case=mixed regular=no ex=83 em=187 lvw=27 lhw=19 uvw=15 uhw=144 fillp=40 vcnt=47 lasprat=66 pasprat=65 loasc=134 lodes=139 dides=104))
((TeX\ Gyre\ Adventor Bold) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=163 lvw=23 lhw=21 uvw=25 uhw=23 fillp=56 vcnt=62 lasprat=99 pasprat=85 loasc=139 lodes=140 dides=102))
((TeX\ Gyre\ Adventor Bold\ Italic) (Ascii Latin Greek mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=92 em=163 lvw=23 lhw=21 uvw=23 uhw=23 fillp=48 vcnt=56 lasprat=99 pasprat=97 loasc=139 lodes=140 dides=102))
((TeX\ Gyre\ Adventor Italic) (Ascii Latin Greek mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=168 lvw=14 lhw=12 uvw=14 uhw=12 fillp=30 vcnt=35 lasprat=99 pasprat=95 loasc=135 lodes=139 dides=102))
((TeX\ Gyre\ Adventor Regular) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=168 lvw=13 lhw=12 uvw=13 uhw=12 fillp=36 vcnt=38 lasprat=99 pasprat=83 loasc=135 lodes=139 dides=102))
((TeX\ Gyre\ Bonum Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=186 lvw=35 lhw=19 uvw=38 uhw=20 fillp=55 vcnt=60 lasprat=115 pasprat=110 loasc=152 lodes=148 dides=102))
((TeX\ Gyre\ Bonum Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=87 em=164 lvw=33 lhw=17 uvw=35 uhw=18 fillp=50 vcnt=55 lasprat=113 pasprat=114 loasc=144 lodes=140 dides=102))
((TeX\ Gyre\ Bonum Italic) (Ascii Latin Greek mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=84 em=170 lvw=19 lhw=8 uvw=21 uhw=9 fillp=32 vcnt=35 lasprat=107 pasprat=107 loasc=145 lodes=144 dides=102))
((TeX\ Gyre\ Bonum Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=20 lhw=8 uvw=24 uhw=9 fillp=34 vcnt=37 lasprat=112 pasprat=108 loasc=151 lodes=149 dides=102))
((TeX\ Gyre\ Bonum\ Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=20 lhw=8 uvw=24 uhw=9 fillp=34 vcnt=35 lasprat=112 pasprat=108 loasc=150 lodes=149 dides=102))
((TeX\ Gyre\ Chorus Regular) (Ascii Latin mono=no sans=no slant=27 italic=yes case=mixed regular=no ex=68 em=205 lvw=19 lhw=22 uvw=20 uhw=13 fillp=26 vcnt=26 lasprat=97 pasprat=106 loasc=167 lodes=160 dides=105))
((TeX\ Gyre\ Cursor Bold) (Ascii Latin Greek mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=51 vcnt=48 lasprat=136 pasprat=122 loasc=146 lodes=146 dides=102))
((TeX\ Gyre\ Cursor Bold\ Italic) (Ascii Latin Greek mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=47 vcnt=44 lasprat=136 pasprat=128 loasc=147 lodes=146 dides=102))
((TeX\ Gyre\ Cursor Italic) (Ascii Latin Greek mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=23 vcnt=21 lasprat=142 pasprat=119 loasc=145 lodes=144 dides=102))
((TeX\ Gyre\ Cursor Regular) (Ascii Latin Greek mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=25 vcnt=23 lasprat=142 pasprat=112 loasc=145 lodes=144 dides=102))
((TeX\ Gyre\ Heros Bold) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=25 lhw=21 uvw=27 uhw=23 fillp=58 vcnt=64 lasprat=99 pasprat=84 loasc=137 lodes=140 dides=101))
((TeX\ Gyre\ Heros Bold\ Italic) (Ascii Latin Greek mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=90 em=154 lvw=26 lhw=21 uvw=27 uhw=23 fillp=49 vcnt=56 lasprat=99 pasprat=99 loasc=137 lodes=140 dides=101))
((TeX\ Gyre\ Heros Italic) (Ascii Latin Greek mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=14 uvw=18 uhw=16 fillp=34 vcnt=39 lasprat=93 pasprat=91 loasc=140 lodes=141 dides=102))
((TeX\ Gyre\ Heros Regular) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=14 uvw=17 uhw=16 fillp=43 vcnt=46 lasprat=93 pasprat=77 loasc=140 lodes=142 dides=102))
((TeX\ Gyre\ Heros\ Cn Bold) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=128 lvw=22 lhw=21 uvw=23 uhw=23 fillp=58 vcnt=64 lasprat=82 pasprat=70 loasc=137 lodes=140 dides=103))
((TeX\ Gyre\ Heros\ Cn Bold\ Italic) (Ascii Latin Greek mono=no sans=yes slant=17 italic=no case=mixed regular=yes ex=89 em=128 lvw=22 lhw=22 uvw=23 uhw=23 fillp=48 vcnt=55 lasprat=82 pasprat=82 loasc=137 lodes=140 dides=103))
((TeX\ Gyre\ Heros\ Cn Italic) (Ascii Latin Greek mono=no sans=yes slant=19 italic=no case=mixed regular=yes ex=87 em=131 lvw=13 lhw=14 uvw=16 uhw=16 fillp=36 vcnt=41 lasprat=76 pasprat=75 loasc=139 lodes=142 dides=103))
((TeX\ Gyre\ Heros\ Cn Regular) (Ascii Latin Greek mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=131 lvw=13 lhw=14 uvw=14 uhw=17 fillp=44 vcnt=47 lasprat=76 pasprat=63 loasc=139 lodes=142 dides=103))
((TeX\ Gyre\ Pagella Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=211 lvw=29 lhw=10 uvw=31 uhw=11 fillp=42 vcnt=45 lasprat=112 pasprat=100 loasc=151 lodes=155 dides=103))
((TeX\ Gyre\ Pagella Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=79 em=198 lvw=24 lhw=12 uvw=29 uhw=8 fillp=36 vcnt=40 lasprat=107 pasprat=101 loasc=153 lodes=156 dides=103))
((TeX\ Gyre\ Pagella Italic) (Ascii Latin Greek mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=81 em=193 lvw=14 lhw=9 uvw=17 uhw=8 fillp=28 vcnt=30 lasprat=93 pasprat=86 loasc=150 lodes=156 dides=102))
((TeX\ Gyre\ Pagella Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=200 lvw=20 lhw=8 uvw=22 uhw=8 fillp=31 vcnt=34 lasprat=108 pasprat=99 loasc=153 lodes=159 dides=103))
((TeX\ Gyre\ Pagella\ Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=20 lhw=8 uvw=21 uhw=10 fillp=32 vcnt=34 lasprat=109 pasprat=99 loasc=155 lodes=160 dides=103))
((TeX\ Gyre\ Schola Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=207 lvw=36 lhw=11 uvw=41 uhw=11 fillp=48 vcnt=54 lasprat=125 pasprat=117 loasc=155 lodes=143 dides=102))
((TeX\ Gyre\ Schola Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=80 em=196 lvw=32 lhw=8 uvw=38 uhw=11 fillp=45 vcnt=50 lasprat=120 pasprat=115 loasc=153 lodes=142 dides=102))
((TeX\ Gyre\ Schola Italic) (Ascii Latin Greek mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=78 em=201 lvw=20 lhw=7 uvw=26 uhw=8 fillp=33 vcnt=37 lasprat=110 pasprat=104 loasc=157 lodes=143 dides=102))
((TeX\ Gyre\ Schola Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=201 lvw=23 lhw=8 uvw=28 uhw=10 fillp=37 vcnt=41 lasprat=111 pasprat=103 loasc=157 lodes=143 dides=102))
((TeX\ Gyre\ Schola\ Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=201 lvw=23 lhw=8 uvw=28 uhw=10 fillp=37 vcnt=38 lasprat=111 pasprat=103 loasc=157 lodes=143 dides=102))
((TeX\ Gyre\ Termes Bold) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=38 uhw=7 fillp=45 vcnt=47 lasprat=105 pasprat=98 loasc=149 lodes=144 dides=102))
((TeX\ Gyre\ Termes Bold\ Italic) (Ascii Latin Greek mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=144 dides=102))
((TeX\ Gyre\ Termes Italic) (Ascii Latin Greek mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=73 em=190 lvw=19 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=101 pasprat=99 loasc=156 lodes=146 dides=104))
((TeX\ Gyre\ Termes Regular) (Ascii Latin Greek mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=152 lodes=148 dides=105))
((TeX\ Gyre\ Termes\ Math Regular) (Ascii Latin Greek MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=152 lodes=148 dides=105))
((TeX\ Pandora Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=214 lvw=27 lhw=13 uvw=27 uhw=16 fillp=45 vcnt=51 lasprat=99 pasprat=93 loasc=147 lodes=140 dides=111))
((TeX\ Pandora Oblique) (Ascii mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=85 em=207 lvw=18 lhw=11 uvw=21 uhw=12 fillp=33 vcnt=36 lasprat=102 pasprat=97 loasc=150 lodes=142 dides=107))
((TeX\ Pandora Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=85 em=205 lvw=20 lhw=10 uvw=21 uhw=11 fillp=35 vcnt=39 lasprat=102 pasprat=91 loasc=151 lodes=140 dides=105))
((TeX\ Pandora\ Mono Regular) (Ascii mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=109 lvw=20 lhw=12 uvw=20 uhw=11 fillp=43 vcnt=45 lasprat=109 pasprat=80 loasc=149 lodes=139 dides=102))
((TeX\ Pandora\ Sans Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=86 em=217 lvw=27 lhw=13 uvw=29 uhw=15 fillp=48 vcnt=52 lasprat=96 pasprat=90 loasc=148 lodes=141 dides=106))
((TeX\ Pandora\ Sans Italic) (Ascii mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=84 em=209 lvw=19 lhw=10 uvw=21 uhw=14 fillp=34 vcnt=38 lasprat=102 pasprat=93 loasc=152 lodes=142 dides=107))
((TeX\ Pandora\ Sans Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=208 lvw=20 lhw=10 uvw=20 uhw=13 fillp=38 vcnt=41 lasprat=102 pasprat=84 loasc=152 lodes=141 dides=109))
((TeX\ Ralph\ Smith Regular) (sans=no slant=50 italic=yes))
((TeX\ Swab Regular) (mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=80 em=211 lvw=17 lhw=23 uvw=21 uhw=22 fillp=38 vcnt=44 lasprat=84 pasprat=80 loasc=147 lodes=141 dides=102))
((TeXmacs\ Avant\ Garde Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=163 lvw=23 lhw=22 uvw=25 uhw=23 fillp=56 vcnt=62 lasprat=99 pasprat=85 loasc=133 lodes=140 dides=102))
((TeXmacs\ Avant\ Garde Bold\ Italic) (Ascii mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=92 em=163 lvw=25 lhw=23 uvw=25 uhw=23 fillp=48 vcnt=56 lasprat=99 pasprat=97 loasc=133 lodes=140 dides=102))
((TeXmacs\ Avant\ Garde Italic) (Ascii mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=168 lvw=14 lhw=12 uvw=14 uhw=12 fillp=30 vcnt=35 lasprat=99 pasprat=95 loasc=135 lodes=139 dides=102))
((TeXmacs\ Avant\ Garde Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=168 lvw=13 lhw=12 uvw=13 uhw=12 fillp=36 vcnt=38 lasprat=99 pasprat=83 loasc=135 lodes=139 dides=102))
((TeXmacs\ Bookman Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=84 em=186 lvw=35 lhw=19 uvw=38 uhw=20 fillp=55 vcnt=60 lasprat=115 pasprat=110 loasc=146 lodes=148 dides=102))
((TeXmacs\ Bookman Bold\ Italic) (Ascii mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=87 em=164 lvw=32 lhw=17 uvw=35 uhw=18 fillp=50 vcnt=55 lasprat=113 pasprat=112 loasc=145 lodes=140 dides=102))
((TeXmacs\ Bookman Italic) (Ascii mono=no sans=no slant=20 italic=yes case=mixed regular=yes ex=83 em=172 lvw=19 lhw=8 uvw=21 uhw=9 fillp=32 vcnt=35 lasprat=108 pasprat=109 loasc=146 lodes=144 dides=102))
((TeXmacs\ Bookman Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=81 em=188 lvw=20 lhw=8 uvw=24 uhw=9 fillp=34 vcnt=37 lasprat=112 pasprat=108 loasc=150 lodes=149 dides=102))
((TeXmacs\ Computer\ Modern Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=245 lvw=29 lhw=9 uvw=33 uhw=9 fillp=39 vcnt=40 lasprat=126 pasprat=114 loasc=158 lodes=147 dides=102))
((TeXmacs\ Computer\ Modern Bold\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=213 lvw=28 lhw=9 uvw=35 uhw=9 fillp=42 vcnt=44 lasprat=110 pasprat=102 loasc=158 lodes=145 dides=105))
((TeXmacs\ Computer\ Modern Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=232 lvw=24 lhw=9 uvw=29 uhw=10 fillp=36 vcnt=38 lasprat=117 pasprat=108 loasc=154 lodes=145 dides=142))
((TeXmacs\ Computer\ Modern Bold\ Oblique) (Ascii Latin Greek Cyrillic mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=74 em=245 lvw=28 lhw=9 uvw=33 uhw=10 fillp=36 vcnt=38 lasprat=126 pasprat=121 loasc=158 lodes=145 dides=104))
((TeXmacs\ Computer\ Modern Bold\ Oblique\ SmallCaps) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=no case=smallcaps regular=yes ex=87 em=222 lvw=24 lhw=8 uvw=29 uhw=9 fillp=35 vcnt=36 lasprat=127 pasprat=118 loasc=103 lodes=126 dides=103))
((TeXmacs\ Computer\ Modern Bold\ SmallCaps) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=87 em=222 lvw=25 lhw=8 uvw=28 uhw=8 fillp=37 vcnt=38 lasprat=127 pasprat=110 loasc=104 lodes=126 dides=103))
((TeXmacs\ Computer\ Modern Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=75 em=198 lvw=17 lhw=5 uvw=20 uhw=6 fillp=26 vcnt=27 lasprat=103 pasprat=93 loasc=157 lodes=148 dides=142))
((TeXmacs\ Computer\ Modern LeftOblique) (Ascii Latin Greek Cyrillic mono=no sans=no slant=-10 italic=no case=mixed regular=yes ex=88 em=123 lvw=10 lhw=7 uvw=13 uhw=6 fillp=29 vcnt=29 lasprat=74 pasprat=63 loasc=120 lodes=156 dides=104))
((TeXmacs\ Computer\ Modern Long) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=6 uvw=25 uhw=6 fillp=27 vcnt=36 lasprat=113 pasprat=102 loasc=229 lodes=148 dides=105))
((TeXmacs\ Computer\ Modern Oblique) (Ascii Latin Greek Cyrillic mono=no sans=no slant=16 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=6 uvw=23 uhw=6 fillp=26 vcnt=28 lasprat=113 pasprat=108 loasc=165 lodes=150 dides=112))
((TeXmacs\ Computer\ Modern Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=212 lvw=19 lhw=6 uvw=25 uhw=6 fillp=29 vcnt=30 lasprat=113 pasprat=102 loasc=163 lodes=148 dides=108))
((TeXmacs\ Computer\ Modern SmallCaps) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=86 em=191 lvw=16 lhw=4 uvw=19 uhw=5 fillp=28 vcnt=28 lasprat=113 pasprat=98 loasc=103 lodes=126 dides=108))
((TeXmacs\ Computer\ Modern\ Mono Italic\ Proportional) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=76 em=222 lvw=14 lhw=13 uvw=17 uhw=14 fillp=32 vcnt=30 lasprat=121 pasprat=106 loasc=136 lodes=150 dides=147))
((TeXmacs\ Computer\ Modern\ Mono Oblique) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=17 italic=no case=mixed regular=yes ex=72 em=122 lvw=16 lhw=15 uvw=16 uhw=15 fillp=35 vcnt=33 lasprat=122 pasprat=109 loasc=143 lodes=154 dides=105))
((TeXmacs\ Computer\ Modern\ Mono Proportional) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=216 lvw=16 lhw=13 uvw=15 uhw=15 fillp=34 vcnt=32 lasprat=118 pasprat=107 loasc=144 lodes=155 dides=106))
((TeXmacs\ Computer\ Modern\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=15 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=35 lasprat=122 pasprat=104 loasc=144 lodes=152 dides=105))
((TeXmacs\ Computer\ Modern\ Mono SmallCaps) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=smallcaps regular=yes ex=79 em=111 lvw=15 lhw=12 uvw=15 uhw=12 fillp=39 vcnt=36 lasprat=111 pasprat=91 loasc=102 lodes=122 dides=106))
((TeXmacs\ Computer\ Modern\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=211 lvw=29 lhw=16 uvw=31 uhw=18 fillp=52 vcnt=55 lasprat=108 pasprat=92 loasc=159 lodes=145 dides=105))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=24 lhw=15 uvw=25 uhw=15 fillp=50 vcnt=52 lasprat=91 pasprat=76 loasc=149 lodes=140 dides=106))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Oblique) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=22 italic=no case=mixed regular=yes ex=77 em=211 lvw=28 lhw=18 uvw=31 uhw=18 fillp=44 vcnt=48 lasprat=108 pasprat=107 loasc=159 lodes=145 dides=105))
((TeXmacs\ Computer\ Modern\ Sans Oblique) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=14 uvw=20 uhw=16 fillp=31 vcnt=33 lasprat=103 pasprat=100 loasc=166 lodes=147 dides=108))
((TeXmacs\ Computer\ Modern\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=14 uvw=20 uhw=14 fillp=39 vcnt=38 lasprat=103 pasprat=85 loasc=166 lodes=147 dides=106))
((TeXmacs\ Concrete Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=245 lvw=29 lhw=9 uvw=33 uhw=9 fillp=39 vcnt=40 lasprat=126 pasprat=114 loasc=158 lodes=147 dides=102))
((TeXmacs\ Concrete Bold\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=213 lvw=28 lhw=9 uvw=35 uhw=9 fillp=42 vcnt=44 lasprat=110 pasprat=102 loasc=158 lodes=145 dides=105))
((TeXmacs\ Concrete Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=232 lvw=24 lhw=9 uvw=29 uhw=10 fillp=36 vcnt=38 lasprat=117 pasprat=108 loasc=154 lodes=145 dides=142))
((TeXmacs\ Concrete Bold\ Oblique) (Ascii Latin Greek Cyrillic mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=74 em=245 lvw=28 lhw=9 uvw=33 uhw=10 fillp=36 vcnt=38 lasprat=126 pasprat=121 loasc=158 lodes=145 dides=104))
((TeXmacs\ Concrete Italic) (Ascii Latin mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=80 em=198 lvw=15 lhw=12 uvw=17 uhw=13 fillp=30 vcnt=32 lasprat=103 pasprat=95 loasc=147 lodes=142 dides=141))
((TeXmacs\ Concrete Oblique) (Ascii Latin mono=no sans=no slant=16 italic=no case=mixed regular=yes ex=77 em=196 lvw=16 lhw=14 uvw=16 uhw=14 fillp=32 vcnt=33 lasprat=106 pasprat=102 loasc=153 lodes=145 dides=102))
((TeXmacs\ Concrete Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=196 lvw=16 lhw=12 uvw=16 uhw=14 fillp=34 vcnt=36 lasprat=106 pasprat=95 loasc=151 lodes=144 dides=103))
((TeXmacs\ Concrete SmallCaps) (Ascii Latin mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=86 em=189 lvw=13 lhw=11 uvw=15 uhw=12 fillp=34 vcnt=34 lasprat=112 pasprat=96 loasc=104 lodes=127 dides=103))
((TeXmacs\ Concrete\ Mono Oblique) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=17 italic=no case=mixed regular=yes ex=72 em=122 lvw=16 lhw=15 uvw=16 uhw=15 fillp=34 vcnt=31 lasprat=122 pasprat=109 loasc=143 lodes=154 dides=105))
((TeXmacs\ Concrete\ Mono Proportional) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=216 lvw=16 lhw=13 uvw=15 uhw=15 fillp=34 vcnt=32 lasprat=118 pasprat=107 loasc=144 lodes=155 dides=106))
((TeXmacs\ Concrete\ Mono Regular) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=15 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=35 lasprat=122 pasprat=104 loasc=144 lodes=152 dides=105))
((TeXmacs\ Concrete\ Mono SmallCaps) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=smallcaps regular=yes ex=79 em=111 lvw=15 lhw=12 uvw=15 uhw=12 fillp=39 vcnt=36 lasprat=111 pasprat=91 loasc=102 lodes=122 dides=106))
((TeXmacs\ Concrete\ Sans Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=211 lvw=29 lhw=16 uvw=31 uhw=18 fillp=52 vcnt=55 lasprat=108 pasprat=92 loasc=159 lodes=145 dides=105))
((TeXmacs\ Concrete\ Sans Bold\ Condensed) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=175 lvw=24 lhw=15 uvw=25 uhw=15 fillp=50 vcnt=52 lasprat=91 pasprat=76 loasc=149 lodes=140 dides=106))
((TeXmacs\ Concrete\ Sans Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=197 lvw=17 lhw=14 uvw=20 uhw=14 fillp=39 vcnt=38 lasprat=103 pasprat=85 loasc=166 lodes=147 dides=106))
((TeXmacs\ Courier Bold) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=21 uhw=21 fillp=50 vcnt=47 lasprat=136 pasprat=121 loasc=142 lodes=145 dides=102))
((TeXmacs\ Courier Bold\ Italic) (Ascii mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=47 vcnt=44 lasprat=136 pasprat=128 loasc=142 lodes=145 dides=102))
((TeXmacs\ Courier Italic) (Ascii mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=23 vcnt=21 lasprat=142 pasprat=119 loasc=148 lodes=144 dides=104))
((TeXmacs\ Courier Regular) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=8 uhw=10 fillp=25 vcnt=22 lasprat=142 pasprat=112 loasc=148 lodes=144 dides=104))
((TeXmacs\ Euler Bold) (mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=79 em=262 lvw=25 lhw=30 uvw=10 uhw=21 fillp=38 vcnt=44 lasprat=114 pasprat=93 loasc=145 lodes=150 dides=141))
((TeXmacs\ Euler Regular) (mono=no sans=no slant=0 italic=yes case=mixed regular=no ex=79 em=221 lvw=17 lhw=29 uvw=6 uhw=15 fillp=32 vcnt=36 lasprat=96 pasprat=80 loasc=145 lodes=149 dides=140))
((TeXmacs\ Euler\ New\ Roman Bold) (mono=no sans=no italic=no case=mixed regular=yes ex=82 em=235 lvw=25 lhw=8 uvw=28 uhw=12 fillp=36 vcnt=40 lasprat=122 pasprat=105 loasc=143 lodes=150 dides=103))
((TeXmacs\ Euler\ New\ Roman Regular) (mono=no sans=no italic=no case=mixed regular=yes ex=78 em=223 lvw=17 lhw=10 uvw=20 uhw=10 fillp=30 vcnt=32 lasprat=116 pasprat=103 loasc=147 lodes=151 dides=103))
((TeXmacs\ Helvetica Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=25 lhw=21 uvw=27 uhw=24 fillp=57 vcnt=64 lasprat=99 pasprat=84 loasc=135 lodes=141 dides=104))
((TeXmacs\ Helvetica Bold\ Italic) (Ascii mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=90 em=154 lvw=26 lhw=21 uvw=27 uhw=24 fillp=48 vcnt=56 lasprat=99 pasprat=99 loasc=135 lodes=141 dides=104))
((TeXmacs\ Helvetica Italic) (Ascii mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=88 em=157 lvw=17 lhw=14 uvw=18 uhw=15 fillp=34 vcnt=39 lasprat=92 pasprat=90 loasc=138 lodes=140 dides=104))
((TeXmacs\ Helvetica Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=157 lvw=15 lhw=14 uvw=17 uhw=15 fillp=43 vcnt=46 lasprat=92 pasprat=75 loasc=138 lodes=140 dides=104))
((TeXmacs\ New\ Century\ Schoolbook Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=207 lvw=36 lhw=11 uvw=41 uhw=11 fillp=48 vcnt=54 lasprat=125 pasprat=117 loasc=155 lodes=143 dides=102))
((TeXmacs\ New\ Century\ Schoolbook Bold\ Italic) (Ascii mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=80 em=196 lvw=32 lhw=8 uvw=38 uhw=11 fillp=45 vcnt=50 lasprat=120 pasprat=115 loasc=153 lodes=142 dides=102))
((TeXmacs\ New\ Century\ Schoolbook Italic) (Ascii mono=no sans=no slant=27 italic=yes case=mixed regular=yes ex=79 em=198 lvw=20 lhw=8 uvw=26 uhw=8 fillp=33 vcnt=37 lasprat=108 pasprat=102 loasc=155 lodes=143 dides=102))
((TeXmacs\ New\ Century\ Schoolbook Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=201 lvw=23 lhw=10 uvw=28 uhw=10 fillp=37 vcnt=41 lasprat=111 pasprat=103 loasc=157 lodes=143 dides=102))
((TeXmacs\ Palatino Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=214 lvw=28 lhw=10 uvw=32 uhw=11 fillp=43 vcnt=45 lasprat=113 pasprat=99 loasc=155 lodes=156 dides=103))
((TeXmacs\ Palatino Bold\ Italic) (Ascii mono=no sans=no slant=15 italic=yes case=mixed regular=yes ex=79 em=198 lvw=24 lhw=12 uvw=29 uhw=8 fillp=36 vcnt=40 lasprat=107 pasprat=98 loasc=153 lodes=156 dides=103))
((TeXmacs\ Palatino Bold\ Oblique) (Ascii mono=no sans=no slant=16 italic=no case=mixed regular=yes ex=78 em=214 lvw=28 lhw=11 uvw=32 uhw=11 fillp=39 vcnt=41 lasprat=113 pasprat=109 loasc=155 lodes=156 dides=103))
((TeXmacs\ Palatino Bold\ SmallCaps) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=78 em=214 lvw=28 lhw=10 uvw=32 uhw=11 fillp=43 vcnt=42 lasprat=118 pasprat=102 loasc=102 lodes=130 dides=103))
((TeXmacs\ Palatino Italic) (Ascii mono=no sans=no slant=16 italic=yes case=mixed regular=yes ex=81 em=193 lvw=16 lhw=9 uvw=18 uhw=8 fillp=28 vcnt=30 lasprat=93 pasprat=88 loasc=151 lodes=156 dides=102))
((TeXmacs\ Palatino Oblique) (Ascii mono=no sans=no slant=17 italic=no case=mixed regular=yes ex=79 em=200 lvw=20 lhw=8 uvw=24 uhw=10 fillp=29 vcnt=31 lasprat=108 pasprat=106 loasc=153 lodes=159 dides=103))
((TeXmacs\ Palatino Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=19 lhw=8 uvw=21 uhw=10 fillp=32 vcnt=34 lasprat=109 pasprat=99 loasc=156 lodes=160 dides=103))
((TeXmacs\ Palatino SmallCaps) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=76 em=207 lvw=19 lhw=7 uvw=22 uhw=10 fillp=32 vcnt=31 lasprat=113 pasprat=98 loasc=102 lodes=131 dides=103))
((TeXmacs\ Times Bold) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=6 fillp=45 vcnt=47 lasprat=105 pasprat=98 loasc=149 lodes=144 dides=102))
((TeXmacs\ Times Bold\ Italic) (Ascii mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=193 lvw=25 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=144 dides=102))
((TeXmacs\ Times Bold\ Oblique) (Ascii mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=77 em=203 lvw=31 lhw=6 uvw=37 uhw=6 fillp=41 vcnt=43 lasprat=105 pasprat=108 loasc=149 lodes=144 dides=102))
((TeXmacs\ Times Bold\ SmallCaps) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=77 em=203 lvw=27 lhw=7 uvw=37 uhw=6 fillp=43 vcnt=43 lasprat=100 pasprat=94 loasc=102 lodes=125 dides=102))
((TeXmacs\ Times Italic) (Ascii mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=186 lvw=18 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=100 pasprat=98 loasc=155 lodes=147 dides=104))
((TeXmacs\ Times Oblique) (Ascii mono=no sans=no slant=18 italic=no case=mixed regular=yes ex=75 em=197 lvw=21 lhw=6 uvw=25 uhw=8 fillp=30 vcnt=31 lasprat=101 pasprat=102 loasc=153 lodes=149 dides=105))
((TeXmacs\ Times Regular) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=34 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((TeXmacs\ Times SmallCaps) (Ascii mono=no sans=no slant=0 italic=no case=smallcaps regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=103 pasprat=96 loasc=102 lodes=126 dides=105))
((Theano\ Didot Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=216 lvw=26 lhw=11 uvw=31 uhw=11 fillp=40 vcnt=37 lasprat=126 pasprat=110 loasc=170 lodes=172 dides=102))
((Theano\ Didot Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=205 lvw=20 lhw=5 uvw=26 uhw=5 fillp=31 vcnt=29 lasprat=115 pasprat=100 loasc=170 lodes=172 dides=102))
((Theano\ Modern Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=225 lvw=22 lhw=10 uvw=31 uhw=12 fillp=39 vcnt=37 lasprat=123 pasprat=108 loasc=166 lodes=160 dides=104))
((Theano\ Modern Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=217 lvw=17 lhw=5 uvw=24 uhw=6 fillp=30 vcnt=28 lasprat=114 pasprat=100 loasc=165 lodes=163 dides=104))
((Theano\ Old\ Style Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=225 lvw=22 lhw=12 uvw=31 uhw=12 fillp=39 vcnt=37 lasprat=122 pasprat=108 loasc=163 lodes=156 dides=104))
((Theano\ Old\ Style Regular) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=74 em=214 lvw=17 lhw=5 uvw=24 uhw=6 fillp=29 vcnt=28 lasprat=112 pasprat=98 loasc=163 lodes=156 dides=104))
((Thickhead Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=no ex=97 em=196 lvw=19 lhw=26 uvw=29 uhw=21 fillp=51 vcnt=69 lasprat=94 pasprat=93 loasc=142 lodes=152 dides=110))
((Thonburi Bold) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=143 lvw=20 lhw=17 uvw=21 uhw=17 fillp=49 vcnt=56 lasprat=97 pasprat=81 loasc=142 lodes=140 dides=104))
((Thonburi Light) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=145 lvw=16 lhw=14 uvw=18 uhw=14 fillp=42 vcnt=40 lasprat=98 pasprat=81 loasc=145 lodes=141 dides=104))
((Thonburi Regular) (Ascii Latin Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=143 lvw=17 lhw=14 uvw=18 uhw=14 fillp=42 vcnt=47 lasprat=98 pasprat=81 loasc=145 lodes=141 dides=104))
((Times Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=31 lhw=6 uvw=38 uhw=6 fillp=45 vcnt=44 lasprat=105 pasprat=98 loasc=149 lodes=144 dides=102))
((Times Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=144 dides=102))
((Times Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=187 lvw=20 lhw=4 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=100 pasprat=98 loasc=155 lodes=145 dides=104))
((Times Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=21 lhw=6 uvw=25 uhw=8 fillp=32 vcnt=31 lasprat=101 pasprat=94 loasc=152 lodes=148 dides=105))
((Times\ New\ Roman Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=210 lvw=32 lhw=8 uvw=38 uhw=8 fillp=44 vcnt=45 lasprat=109 pasprat=98 loasc=150 lodes=148 dides=102))
((Times\ New\ Roman Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=29 italic=yes case=mixed regular=yes ex=76 em=194 lvw=27 lhw=6 uvw=35 uhw=9 fillp=37 vcnt=39 lasprat=101 pasprat=104 loasc=148 lodes=147 dides=102))
((Times\ New\ Roman Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=31 italic=yes case=mixed regular=yes ex=74 em=187 lvw=17 lhw=5 uvw=21 uhw=6 fillp=27 vcnt=28 lasprat=100 pasprat=102 loasc=156 lodes=148 dides=102))
((Times\ New\ Roman Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=6 fillp=32 vcnt=33 lasprat=102 pasprat=96 loasc=154 lodes=148 dides=102))
((Tinos Bold) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=31 lhw=11 uvw=35 uhw=11 fillp=46 vcnt=43 lasprat=105 pasprat=97 loasc=153 lodes=148 dides=102))
((Tinos Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=17 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=11 uvw=32 uhw=11 fillp=43 vcnt=43 lasprat=99 pasprat=97 loasc=153 lodes=148 dides=102))
((Tinos Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=77 em=180 lvw=18 lhw=9 uvw=22 uhw=9 fillp=32 vcnt=32 lasprat=96 pasprat=90 loasc=153 lodes=148 dides=102))
((Tinos Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=192 lvw=19 lhw=7 uvw=22 uhw=7 fillp=34 vcnt=31 lasprat=99 pasprat=90 loasc=153 lodes=146 dides=102))
((Tlwg\ Typist Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=50 vcnt=48 lasprat=136 pasprat=121 loasc=143 lodes=146 dides=102))
((Tlwg\ Typist BoldOblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=46 vcnt=43 lasprat=136 pasprat=128 loasc=143 lodes=146 dides=102))
((Tlwg\ Typist Medium) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=25 vcnt=23 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((Tlwg\ Typist Oblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=22 vcnt=20 lasprat=142 pasprat=120 loasc=150 lodes=144 dides=102))
((Tlwg\ Typist Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=8 uhw=9 fillp=25 vcnt=18 lasprat=140 pasprat=110 loasc=149 lodes=145 dides=104))
((Tlwg\ Typo Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=50 vcnt=48 lasprat=136 pasprat=121 loasc=143 lodes=146 dides=102))
((Tlwg\ Typo BoldOblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=23 fillp=46 vcnt=43 lasprat=136 pasprat=128 loasc=143 lodes=146 dides=102))
((Tlwg\ Typo Medium) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=25 vcnt=23 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((Tlwg\ Typo Oblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=22 vcnt=20 lasprat=142 pasprat=120 loasc=150 lodes=144 dides=102))
((Tlwg\ Typo Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=8 uhw=9 fillp=25 vcnt=18 lasprat=140 pasprat=110 loasc=149 lodes=145 dides=104))
((TlwgMono Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=51 vcnt=48 lasprat=136 pasprat=121 loasc=142 lodes=146 dides=102))
((TlwgMono BoldOblique) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=47 vcnt=44 lasprat=136 pasprat=128 loasc=142 lodes=146 dides=102))
((TlwgMono Medium) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=25 vcnt=22 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((TlwgMono Oblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=22 vcnt=20 lasprat=142 pasprat=120 loasc=150 lodes=144 dides=102))
((TlwgMono Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=8 uhw=9 fillp=25 vcnt=18 lasprat=140 pasprat=110 loasc=149 lodes=145 dides=104))
((TlwgTypewriter Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=51 vcnt=48 lasprat=136 pasprat=121 loasc=142 lodes=146 dides=102))
((TlwgTypewriter BoldOblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=21 uvw=23 uhw=21 fillp=47 vcnt=44 lasprat=136 pasprat=128 loasc=142 lodes=146 dides=102))
((TlwgTypewriter Medium) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=25 vcnt=22 lasprat=142 pasprat=112 loasc=150 lodes=144 dides=102))
((TlwgTypewriter Oblique) (Ascii Latin mono=yes sans=no slant=23 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=8 uvw=10 uhw=8 fillp=22 vcnt=20 lasprat=142 pasprat=120 loasc=150 lodes=144 dides=102))
((TlwgTypewriter Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=71 em=140 lvw=9 lhw=9 uvw=8 uhw=9 fillp=25 vcnt=18 lasprat=140 pasprat=110 loasc=149 lodes=145 dides=104))
((Trattatello Regular) (Ascii Latin Greek Cyrillic mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=79 em=174 lvw=15 lhw=34 uvw=25 uhw=15 fillp=40 vcnt=46 lasprat=78 pasprat=95 loasc=191 lodes=207 dides=111))
((Trebuchet\ MS Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=142 lvw=24 lhw=19 uvw=25 uhw=21 fillp=50 vcnt=55 lasprat=101 pasprat=87 loasc=143 lodes=139 dides=102))
((Trebuchet\ MS Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=87 em=150 lvw=24 lhw=19 uvw=25 uhw=21 fillp=44 vcnt=50 lasprat=103 pasprat=97 loasc=145 lodes=139 dides=102))
((Trebuchet\ MS Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=17 italic=yes case=mixed regular=yes ex=87 em=145 lvw=18 lhw=14 uvw=19 uhw=17 fillp=37 vcnt=42 lasprat=96 pasprat=90 loasc=141 lodes=139 dides=102))
((Trebuchet\ MS Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=135 lvw=18 lhw=14 uvw=19 uhw=17 fillp=42 vcnt=46 lasprat=96 pasprat=81 loasc=141 lodes=139 dides=102))
((TriangleETcircle\ Shadow Regular) (mono=no sans=no italic=no case=mixed regular=no ex=95 em=157 lvw=2 lhw=6 uvw=2 uhw=6 fillp=28 vcnt=36 lasprat=96 pasprat=100 loasc=143 lodes=145 dides=110))
((TriangleETcircle\ Shadowed Regular) (mono=no sans=no italic=no case=mixed regular=no ex=94 em=159 lvw=2 lhw=9 uvw=2 uhw=8 fillp=30 vcnt=39 lasprat=97 pasprat=99 loasc=144 lodes=143 dides=108))
((Tsukushi\ A\ Round\ Gothic Bold) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=81 em=192 lvw=20 lhw=19 uvw=24 uhw=22 fillp=46 vcnt=43 lasprat=105 pasprat=87 loasc=155 lodes=154 dides=103))
((Tsukushi\ A\ Round\ Gothic Regular) (Ascii Latin CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=79 em=189 lvw=12 lhw=11 uvw=13 uhw=12 fillp=31 vcnt=25 lasprat=105 pasprat=82 loasc=156 lodes=154 dides=101))
((Tsukushi\ B\ Round\ Gothic Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=200 lvw=20 lhw=19 uvw=23 uhw=20 fillp=44 vcnt=47 lasprat=109 pasprat=99 loasc=153 lodes=153 dides=103))
((Tsukushi\ B\ Round\ Gothic Regular) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=202 lvw=12 lhw=11 uvw=14 uhw=11 fillp=28 vcnt=27 lasprat=112 pasprat=98 loasc=158 lodes=155 dides=100))
((Tt-Kp Medium) (Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=120 lvw=22 lhw=9 uvw=25 uhw=13 fillp=44 vcnt=45 lasprat=120 pasprat=89 loasc=144 lodes=141 dides=104))
((Tt-Kp Regular) (Latin mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=74 em=120 lvw=20 lhw=6 uvw=21 uhw=10 fillp=38 vcnt=39 lasprat=120 pasprat=89 loasc=140 lodes=141 dides=104))
((Tuffy Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=143 lvw=22 lhw=21 uvw=26 uhw=22 fillp=55 vcnt=61 lasprat=94 pasprat=80 loasc=138 lodes=143 dides=102))
((Tuffy Bold-Italic) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=88 em=143 lvw=23 lhw=22 uvw=26 uhw=22 fillp=45 vcnt=51 lasprat=94 pasprat=94 loasc=138 lodes=143 dides=102))
((Tuffy Italic) (Ascii Latin mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=88 em=144 lvw=14 lhw=12 uvw=15 uhw=12 fillp=30 vcnt=33 lasprat=87 pasprat=85 loasc=136 lodes=142 dides=102))
((Tuffy Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=147 lvw=14 lhw=12 uvw=16 uhw=12 fillp=39 vcnt=41 lasprat=88 pasprat=72 loasc=137 lodes=142 dides=102))
((Tunga Regular) (slant=0))
((Tw\ Cen\ MT Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=70 em=188 lvw=30 lhw=28 uvw=34 uhw=31 fillp=60 vcnt=48 lasprat=113 pasprat=94 loasc=155 lodes=144 dides=104))
((Tw\ Cen\ MT Bold\ Italic) (Ascii Latin mono=no sans=yes slant=15 italic=no case=mixed regular=yes ex=69 em=179 lvw=30 lhw=26 uvw=33 uhw=27 fillp=51 vcnt=48 lasprat=103 pasprat=99 loasc=166 lodes=144 dides=114))
((Tw\ Cen\ MT Italic) (Ascii Latin mono=no sans=yes slant=14 italic=no case=mixed regular=yes ex=65 em=198 lvw=21 lhw=21 uvw=23 uhw=23 fillp=39 vcnt=33 lasprat=110 pasprat=99 loasc=166 lodes=149 dides=109))
((Tw\ Cen\ MT Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=67 em=192 lvw=20 lhw=20 uvw=20 uhw=22 fillp=45 vcnt=33 lasprat=111 pasprat=90 loasc=161 lodes=147 dides=108))
((Twemoji\ Mozilla Regular) ())
((Type\ Embellishments\ One\ LET Embellishments\ One\ LET\ Plain) (Ascii mono=no sans=no slant=0 italic=no case=mixed regular=no ex=114 em=85 lvw=8 lhw=4 uvw=3 uhw=1 fillp=29 vcnt=24 lasprat=161 pasprat=147 loasc=107 lodes=119 dides=127))
((Typicons Book) ())
((Ubuntu Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=170 lvw=28 lhw=23 uvw=30 uhw=26 fillp=58 vcnt=64 lasprat=102 pasprat=86 loasc=147 lodes=135 dides=103))
((Ubuntu Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=25 italic=yes case=mixed regular=yes ex=88 em=167 lvw=28 lhw=23 uvw=30 uhw=25 fillp=48 vcnt=55 lasprat=100 pasprat=102 loasc=147 lodes=136 dides=102))
((Ubuntu Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=25 italic=yes case=mixed regular=yes ex=87 em=163 lvw=18 lhw=14 uvw=19 uhw=16 fillp=35 vcnt=39 lasprat=95 pasprat=94 loasc=149 lodes=136 dides=103))
((Ubuntu Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=170 lvw=18 lhw=16 uvw=19 uhw=16 fillp=43 vcnt=46 lasprat=99 pasprat=79 loasc=149 lodes=135 dides=103))
((Ubuntu-Title Title) (mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=80 em=130 lvw=21 lhw=21 uvw=21 uhw=21 fillp=55 vcnt=50 lasprat=91 pasprat=76 loasc=140 lodes=140 dides=103))
((Ubuntu-Title-fr Title-fr) (mono=no sans=yes slant=0 italic=no case=caps regular=yes ex=80 em=130 lvw=21 lhw=21 uvw=21 uhw=21 fillp=55 vcnt=50 lasprat=91 pasprat=76 loasc=140 lodes=140 dides=103))
((UM\ Typewriter Bold) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=19 lhw=18 uvw=20 uhw=18 fillp=45 vcnt=37 lasprat=122 pasprat=104 loasc=141 lodes=151 dides=102))
((UM\ Typewriter Bold\ Italic) (Latin Greek Cyrillic mono=yes sans=no slant=17 italic=no case=mixed regular=yes ex=72 em=122 lvw=19 lhw=18 uvw=20 uhw=18 fillp=41 vcnt=37 lasprat=122 pasprat=111 loasc=141 lodes=151 dides=102))
((UM\ Typewriter Italic) (Latin Greek Cyrillic mono=yes sans=no slant=16 italic=no case=mixed regular=yes ex=72 em=122 lvw=16 lhw=13 uvw=16 uhw=13 fillp=33 vcnt=30 lasprat=122 pasprat=112 loasc=143 lodes=154 dides=102))
((UM\ Typewriter Regular) (Ascii Latin Greek Cyrillic mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=122 lvw=15 lhw=13 uvw=16 uhw=13 fillp=37 vcnt=31 lasprat=122 pasprat=104 loasc=143 lodes=154 dides=102))
((Umpush Bold) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=22 lhw=20 uvw=22 uhw=21 fillp=52 vcnt=56 lasprat=93 pasprat=80 loasc=142 lodes=140 dides=101))
((Umpush BoldOblique) (Ascii mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=87 em=159 lvw=22 lhw=20 uvw=22 uhw=21 fillp=44 vcnt=49 lasprat=93 pasprat=91 loasc=142 lodes=140 dides=101))
((Umpush Book) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=18 uhw=17 fillp=43 vcnt=45 lasprat=93 pasprat=79 loasc=143 lodes=140 dides=101))
((Umpush Light) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=86 em=161 lvw=11 lhw=11 uvw=13 uhw=11 fillp=34 vcnt=34 lasprat=97 pasprat=79 loasc=145 lodes=141 dides=101))
((Umpush LightOblique) (Ascii mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=86 em=161 lvw=12 lhw=11 uvw=12 uhw=11 fillp=27 vcnt=30 lasprat=97 pasprat=91 loasc=145 lodes=141 dides=101))
((Umpush Oblique) (Ascii mono=no sans=yes slant=18 italic=no case=mixed regular=yes ex=87 em=159 lvw=17 lhw=14 uvw=19 uhw=17 fillp=36 vcnt=40 lasprat=93 pasprat=91 loasc=143 lodes=140 dides=101))
((Umpush Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=159 lvw=16 lhw=13 uvw=17 uhw=16 fillp=42 vcnt=39 lasprat=93 pasprat=79 loasc=142 lodes=140 dides=101))
((UnBatang Bold) (Ascii Latin Greek Cyrillic CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=189 lvw=28 lhw=8 uvw=31 uhw=8 fillp=43 vcnt=47 lasprat=107 pasprat=101 loasc=152 lodes=148 dides=102))
((UnBatang Regular) (Ascii Latin Greek Cyrillic CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=20 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=37 lasprat=104 pasprat=97 loasc=152 lodes=148 dides=102))
((UnDinaru Bold) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=21 lhw=17 uvw=22 uhw=17 fillp=49 vcnt=50 lasprat=86 pasprat=78 loasc=144 lodes=141 dides=101))
((UnDinaru Light) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=156 lvw=13 lhw=11 uvw=14 uhw=11 fillp=36 vcnt=32 lasprat=86 pasprat=73 loasc=146 lodes=142 dides=101))
((UnDinaru Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=90 em=154 lvw=16 lhw=14 uvw=17 uhw=14 fillp=43 vcnt=40 lasprat=86 pasprat=73 loasc=143 lodes=141 dides=101))
((UnDotum Bold) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=173 lvw=32 lhw=19 uvw=34 uhw=26 fillp=62 vcnt=65 lasprat=98 pasprat=86 loasc=138 lodes=135 dides=102))
((UnDotum Regular) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=160 lvw=17 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=42 lasprat=92 pasprat=77 loasc=136 lodes=138 dides=102))
((UnGraphic Bold) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=173 lvw=32 lhw=19 uvw=34 uhw=26 fillp=62 vcnt=65 lasprat=98 pasprat=86 loasc=138 lodes=135 dides=102))
((UnGraphic Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=160 lvw=17 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=42 lasprat=92 pasprat=77 loasc=136 lodes=138 dides=102))
((UnGungseo Regular) (Ascii Latin Greek Cyrillic CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=191 lvw=20 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=37 lasprat=104 pasprat=97 loasc=152 lodes=148 dides=102))
((Universalis\ ADF\ Std Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=184 lvw=28 lhw=22 uvw=29 uhw=25 fillp=53 vcnt=45 lasprat=111 pasprat=89 loasc=168 lodes=150 dides=102))
((Universalis\ ADF\ Std Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=184 lvw=28 lhw=24 uvw=29 uhw=25 fillp=43 vcnt=45 lasprat=111 pasprat=105 loasc=166 lodes=150 dides=102))
((Universalis\ ADF\ Std Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=172 lvw=18 lhw=14 uvw=16 uhw=14 fillp=31 vcnt=33 lasprat=103 pasprat=98 loasc=168 lodes=149 dides=102))
((Universalis\ ADF\ Std Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=172 lvw=17 lhw=14 uvw=16 uhw=14 fillp=41 vcnt=33 lasprat=103 pasprat=82 loasc=168 lodes=149 dides=102))
((Universalis\ ADF\ Std\ Cond Bold\ Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=161 lvw=26 lhw=24 uvw=29 uhw=25 fillp=43 vcnt=46 lasprat=98 pasprat=93 loasc=168 lodes=150 dides=102))
((Universalis\ ADF\ Std\ Cond Italic) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=75 em=148 lvw=18 lhw=16 uvw=16 uhw=14 fillp=33 vcnt=34 lasprat=92 pasprat=87 loasc=168 lodes=149 dides=102))
((Universalis\ ADF\ Std\ Cond Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=148 lvw=18 lhw=14 uvw=17 uhw=14 fillp=44 vcnt=35 lasprat=92 pasprat=71 loasc=168 lodes=149 dides=102))
((Universalis\ ADF\ Std\ cond Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=75 em=161 lvw=26 lhw=22 uvw=28 uhw=24 fillp=55 vcnt=46 lasprat=98 pasprat=76 loasc=168 lodes=150 dides=102))
((UnJamoBatang Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=180 lvw=15 lhw=7 uvw=17 uhw=7 fillp=29 vcnt=29 lasprat=98 pasprat=91 loasc=152 lodes=150 dides=102))
((UnJamoDotum Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=161 lvw=16 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=35 lasprat=92 pasprat=77 loasc=136 lodes=137 dides=102))
((UnJamoNovel Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=161 lvw=16 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=35 lasprat=92 pasprat=77 loasc=136 lodes=137 dides=102))
((UnJamoSora Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=161 lvw=16 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=35 lasprat=92 pasprat=77 loasc=136 lodes=137 dides=102))
((UnPen Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=192 lvw=21 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=34 lasprat=104 pasprat=97 loasc=152 lodes=150 dides=102))
((UnPenheulim Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=192 lvw=21 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=34 lasprat=104 pasprat=97 loasc=152 lodes=150 dides=102))
((UnPilgi Bold) (Ascii Hangul mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=54 em=231 lvw=18 lhw=20 uvw=25 uhw=20 fillp=33 vcnt=37 lasprat=149 pasprat=176 loasc=224 lodes=231 dides=107))
((UnPilgi Regular) (Ascii Hangul mono=no sans=no slant=0 italic=yes case=mixed regular=yes ex=53 em=237 lvw=9 lhw=13 uvw=16 uhw=11 fillp=21 vcnt=23 lasprat=152 pasprat=172 loasc=226 lodes=232 dides=105))
((UnPilgia Regular) (Ascii Latin Hangul mono=yes sans=yes slant=0 italic=yes case=mixed regular=yes ex=77 em=81 lvw=14 lhw=14 uvw=14 uhw=16 fillp=34 vcnt=31 lasprat=81 pasprat=73 loasc=153 lodes=149 dides=109))
((UnShinmun Regular) (Ascii Latin Greek Cyrillic CJK Hangul mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=192 lvw=21 lhw=7 uvw=23 uhw=7 fillp=34 vcnt=34 lasprat=104 pasprat=97 loasc=152 lodes=150 dides=102))
((UnTaza Regular) (Ascii Latin Hangul mono=yes sans=yes slant=0 italic=no case=mixed regular=yes ex=77 em=109 lvw=19 lhw=12 uvw=19 uhw=12 fillp=43 vcnt=31 lasprat=109 pasprat=83 loasc=148 lodes=138 dides=102))
((UnVada Regular) (Ascii Latin Greek Cyrillic Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=161 lvw=16 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=35 lasprat=92 pasprat=77 loasc=136 lodes=137 dides=102))
((UnYetgul Bold) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=172 lvw=30 lhw=18 uvw=32 uhw=25 fillp=61 vcnt=58 lasprat=96 pasprat=85 loasc=136 lodes=135 dides=102))
((Utkal Medium) ())
((Verdana Bold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=92 em=171 lvw=32 lhw=21 uvw=35 uhw=25 fillp=60 vcnt=70 lasprat=115 pasprat=98 loasc=139 lodes=138 dides=103))
((Verdana Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=25 italic=no case=mixed regular=yes ex=91 em=173 lvw=34 lhw=21 uvw=36 uhw=24 fillp=51 vcnt=60 lasprat=117 pasprat=115 loasc=140 lodes=138 dides=103))
((Verdana Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=25 italic=no case=mixed regular=yes ex=91 em=154 lvw=17 lhw=14 uvw=18 uhw=14 fillp=33 vcnt=39 lasprat=103 pasprat=98 loasc=140 lodes=138 dides=103))
((Verdana Regular) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=154 lvw=17 lhw=14 uvw=18 uhw=15 fillp=41 vcnt=46 lasprat=103 pasprat=82 loasc=140 lodes=138 dides=103))
((Verily\ Serif\ Mono Book) (Ascii mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=114 lvw=19 lhw=9 uvw=21 uhw=10 fillp=37 vcnt=43 lasprat=114 pasprat=93 loasc=145 lodes=142 dides=102))
((Vermi\ di\ Rouge Regular) (mono=no sans=no italic=no case=mixed regular=yes ex=84 em=173 lvw=2 lhw=2 uvw=4 uhw=4 fillp=15 vcnt=17 lasprat=90 pasprat=85 loasc=101 lodes=109 dides=100))
((Victor Regular) (mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=98 em=112 lvw=24 lhw=17 uvw=24 uhw=22 fillp=74 vcnt=80 lasprat=65 pasprat=55 loasc=117 lodes=112 dides=102))
((Vipond\ Angular Regular) (Ascii mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=63 em=200 lvw=33 lhw=17 uvw=33 uhw=17 fillp=58 vcnt=45 lasprat=130 pasprat=97 loasc=133 lodes=133 dides=100))
((Vipond\ Octic Regular) (Cyrillic mono=no sans=yes italic=no case=caps regular=yes ex=104 em=140 lvw=40 lhw=100 uvw=40 uhw=100 fillp=71 vcnt=74 lasprat=101 pasprat=81 loasc=100 lodes=100 dides=100))
((Vrinda Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=57 em=161 lvw=19 lhw=14 uvw=19 uhw=14 fillp=44 vcnt=30 lasprat=94 pasprat=80 loasc=140 lodes=140 dides=103))
((Waree Bold) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=182 lvw=32 lhw=21 uvw=35 uhw=24 fillp=61 vcnt=69 lasprat=116 pasprat=97 loasc=139 lodes=139 dides=102))
((Waree BoldOblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=182 lvw=34 lhw=23 uvw=36 uhw=25 fillp=52 vcnt=61 lasprat=116 pasprat=111 loasc=139 lodes=139 dides=102))
((Waree Book) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=158 lvw=18 lhw=13 uvw=18 uhw=14 fillp=43 vcnt=47 lasprat=103 pasprat=81 loasc=139 lodes=138 dides=102))
((Waree Oblique) (Ascii Latin mono=no sans=yes slant=20 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=13 uvw=19 uhw=14 fillp=34 vcnt=40 lasprat=103 pasprat=95 loasc=139 lodes=138 dides=102))
((Waree Regular) (Ascii Latin mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=158 lvw=17 lhw=14 uvw=19 uhw=14 fillp=43 vcnt=38 lasprat=103 pasprat=81 loasc=139 lodes=138 dides=102))
((Waseem Light) (slant=7))
((Waseem Regular) (slant=7))
((Wawati\ SC Regular) (Ascii Latin Greek Cyrillic CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=71 em=177 lvw=16 lhw=14 uvw=18 uhw=16 fillp=34 vcnt=28 lasprat=107 pasprat=91 loasc=159 lodes=145 dides=101))
((Wawati\ TC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=71 em=177 lvw=16 lhw=14 uvw=18 uhw=16 fillp=34 vcnt=28 lasprat=107 pasprat=91 loasc=159 lodes=145 dides=101))
((Webdings Regular) ())
((WeblySleek\ UI Light) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=165 lvw=9 lhw=8 uvw=9 uhw=8 fillp=27 vcnt=21 lasprat=92 pasprat=74 loasc=148 lodes=146 dides=102))
((WeblySleek\ UI Light\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=165 lvw=9 lhw=8 uvw=10 uhw=8 fillp=20 vcnt=21 lasprat=90 pasprat=87 loasc=150 lodes=146 dides=102))
((WeblySleek\ UI SemiBold) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=183 lvw=22 lhw=17 uvw=23 uhw=20 fillp=49 vcnt=45 lasprat=102 pasprat=86 loasc=150 lodes=147 dides=102))
((WeblySleek\ UI SemiBold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=167 lvw=22 lhw=19 uvw=25 uhw=21 fillp=42 vcnt=46 lasprat=100 pasprat=99 loasc=150 lodes=146 dides=102))
((WeblySleek\ UI SemiLight) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=84 em=172 lvw=13 lhw=10 uvw=13 uhw=11 fillp=34 vcnt=28 lasprat=95 pasprat=77 loasc=148 lodes=146 dides=102))
((WeblySleek\ UI SemiLight\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=yes slant=20 italic=yes case=mixed regular=yes ex=84 em=164 lvw=11 lhw=10 uvw=13 uhw=11 fillp=26 vcnt=28 lasprat=92 pasprat=90 loasc=150 lodes=146 dides=102))
((Weibei\ SC Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=175 lvw=23 lhw=8 uvw=24 uhw=10 fillp=39 vcnt=35 lasprat=107 pasprat=92 loasc=148 lodes=144 dides=103))
((Weibei\ TC Bold) (Ascii Latin CJK mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=78 em=175 lvw=23 lhw=8 uvw=24 uhw=10 fillp=39 vcnt=35 lasprat=107 pasprat=92 loasc=148 lodes=144 dides=103))
((WenQuanYi\ Zen\ Hei Medium) (Ascii Latin Greek CJK Hangul mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=85 em=161 lvw=16 lhw=12 uvw=17 uhw=14 fillp=41 vcnt=42 lasprat=92 pasprat=77 loasc=137 lodes=136 dides=101))
((Wingdings Regular) ())
((Wingdings\ 2 Regular) ())
((Wingdings\ 3 Regular) ())
((Wolgast\ Two Bold) (Ascii Latin Cyrillic mono=no sans=no slant=48 italic=no case=mixed regular=yes ex=96 em=183 lvw=25 lhw=82 uvw=23 uhw=37 fillp=37 vcnt=62 lasprat=98 pasprat=127 loasc=164 lodes=186 dides=123))
((Wolgast\ Two Normal) (Cyrillic mono=no sans=no slant=50 italic=yes case=mixed regular=yes ex=95 em=176 lvw=15 lhw=22 uvw=15 uhw=22 fillp=22 vcnt=29 lasprat=96 pasprat=119 loasc=165 lodes=188 dides=108))
((XCharter Bold) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=82 em=179 lvw=28 lhw=10 uvw=30 uhw=12 fillp=44 vcnt=45 lasprat=106 pasprat=100 loasc=151 lodes=143 dides=110))
((XCharter Bold\ Italic) (Ascii Latin mono=no sans=no slant=18 italic=yes case=mixed regular=yes ex=82 em=181 lvw=26 lhw=10 uvw=28 uhw=12 fillp=40 vcnt=43 lasprat=103 pasprat=101 loasc=150 lodes=145 dides=112))
((XCharter Bold\ Slanted) (Ascii Latin mono=no sans=no slant=20 italic=no case=mixed regular=yes ex=82 em=187 lvw=28 lhw=10 uvw=30 uhw=12 fillp=40 vcnt=43 lasprat=110 pasprat=109 loasc=151 lodes=143 dides=110))
((XCharter Italic) (Ascii Latin mono=no sans=no slant=19 italic=yes case=mixed regular=yes ex=81 em=172 lvw=16 lhw=8 uvw=19 uhw=9 fillp=31 vcnt=32 lasprat=96 pasprat=90 loasc=151 lodes=144 dides=111))
((XCharter Roman) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=180 lvw=18 lhw=8 uvw=21 uhw=11 fillp=35 vcnt=33 lasprat=102 pasprat=92 loasc=155 lodes=145 dides=111))
((XCharter Slanted) (Ascii Latin mono=no sans=no slant=20 italic=no case=mixed regular=yes ex=80 em=185 lvw=18 lhw=8 uvw=21 uhw=11 fillp=31 vcnt=32 lasprat=103 pasprat=101 loasc=155 lodes=145 dides=111))
((Xingkai\ SC Bold) (Ascii CJK mono=no sans=no slant=56 italic=yes case=mixed regular=no ex=63 em=220 lvw=15 lhw=17 uvw=22 uhw=12 fillp=37 vcnt=42 lasprat=90 pasprat=98 loasc=171 lodes=168 dides=104))
((Xingkai\ SC Light) (Ascii CJK mono=no sans=no slant=56 italic=yes case=mixed regular=yes ex=61 em=262 lvw=8 lhw=11 uvw=11 uhw=9 fillp=23 vcnt=21 lasprat=107 pasprat=101 loasc=178 lodes=177 dides=106))
((Xits Bold) (Ascii Latin Greek Cyrillic MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=7 fillp=45 vcnt=44 lasprat=105 pasprat=98 loasc=149 lodes=145 dides=102))
((Xits Bold\ Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=25 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=41 lasprat=99 pasprat=100 loasc=151 lodes=145 dides=103))
((Xits Italic) (Ascii Latin Greek Cyrillic mono=no sans=no slant=24 italic=yes case=mixed regular=yes ex=74 em=187 lvw=18 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=30 lasprat=100 pasprat=98 loasc=155 lodes=148 dides=104))
((Xits Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((XITS\ Math Bold) (Ascii Latin Greek Cyrillic MathSymbols MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=77 em=203 lvw=32 lhw=6 uvw=37 uhw=7 fillp=45 vcnt=44 lasprat=105 pasprat=98 loasc=149 lodes=145 dides=102))
((XITS\ Math Regular) (Ascii Latin Greek Cyrillic MathSymbols MathExtra MathLetters mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=32 lasprat=101 pasprat=94 loasc=153 lodes=149 dides=105))
((Yaziji Regular) (slant=0))
((Yaziji\ PUA Regular) ())
((Yiggivoo\ Unicode Regular) (Latin Greek Cyrillic mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=179 lvw=24 lhw=4 uvw=24 uhw=4 fillp=40 vcnt=44 lasprat=122 pasprat=110 loasc=141 lodes=148 dides=103))
((Yiggivoo\ Unicode\  Italic) (Latin Greek Cyrillic mono=no sans=yes slant=23 italic=no case=mixed regular=yes ex=89 em=179 lvw=24 lhw=4 uvw=23 uhw=4 fillp=32 vcnt=37 lasprat=122 pasprat=127 loasc=141 lodes=148 dides=103))
((Yiggivoo\ Unicode\ 3D Italic) (Latin Greek Cyrillic mono=no sans=no slant=22 italic=no case=mixed regular=yes ex=92 em=173 lvw=3 lhw=7 uvw=2 uhw=7 fillp=17 vcnt=22 lasprat=118 pasprat=131 loasc=140 lodes=153 dides=110))
((Yiggivoo\ Unicode\ 3D Regular) (Latin Greek Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=91 em=175 lvw=1 lhw=7 uvw=1 uhw=7 fillp=19 vcnt=24 lasprat=120 pasprat=117 loasc=140 lodes=154 dides=110))
((Yinit Regular) (sans=no))
((Yokawerad Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=87 em=252 lvw=54 lhw=8 uvw=60 uhw=9 fillp=52 vcnt=60 lasprat=166 pasprat=158 loasc=156 lodes=145 dides=102))
((YouYuan Regular) (Ascii CJK mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=109 lvw=13 lhw=5 uvw=15 uhw=5 fillp=26 vcnt=27 lasprat=109 pasprat=88 loasc=156 lodes=127 dides=100))
((Yuanti\ SC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=150 lvw=23 lhw=21 uvw=23 uhw=21 fillp=54 vcnt=52 lasprat=94 pasprat=83 loasc=140 lodes=134 dides=103))
((Yuanti\ SC Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=154 lvw=9 lhw=8 uvw=9 uhw=9 fillp=27 vcnt=21 lasprat=96 pasprat=76 loasc=140 lodes=134 dides=102))
((Yuanti\ SC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=152 lvw=14 lhw=12 uvw=14 uhw=13 fillp=39 vcnt=33 lasprat=95 pasprat=78 loasc=140 lodes=134 dides=102))
((Yuanti\ TC Bold) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=89 em=150 lvw=23 lhw=21 uvw=23 uhw=21 fillp=54 vcnt=52 lasprat=94 pasprat=83 loasc=140 lodes=134 dides=103))
((Yuanti\ TC Light) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=154 lvw=9 lhw=8 uvw=9 uhw=9 fillp=27 vcnt=21 lasprat=96 pasprat=76 loasc=140 lodes=134 dides=102))
((Yuanti\ TC Regular) (Ascii Latin Greek CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=152 lvw=14 lhw=12 uvw=14 uhw=13 fillp=39 vcnt=33 lasprat=95 pasprat=78 loasc=140 lodes=134 dides=102))
((YuGothic Bold) (Ascii Latin CJK MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=91 em=174 lvw=24 lhw=16 uvw=26 uhw=18 fillp=52 vcnt=50 lasprat=99 pasprat=81 loasc=143 lodes=136 dides=103))
((YuGothic Medium) (Ascii Latin CJK MathSymbols mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=88 em=173 lvw=15 lhw=12 uvw=18 uhw=13 fillp=40 vcnt=34 lasprat=96 pasprat=74 loasc=145 lodes=130 dides=100))
((YuMincho Demibold) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=210 lvw=23 lhw=6 uvw=28 uhw=7 fillp=35 vcnt=37 lasprat=103 pasprat=97 loasc=166 lodes=146 dides=100))
((YuMincho Medium) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=205 lvw=20 lhw=6 uvw=24 uhw=7 fillp=31 vcnt=31 lasprat=102 pasprat=94 loasc=167 lodes=144 dides=100))
((YuMincho\ +36p\ Kana Demibold) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=80 em=210 lvw=23 lhw=6 uvw=28 uhw=7 fillp=35 vcnt=37 lasprat=103 pasprat=97 loasc=166 lodes=146 dides=100))
((YuMincho\ +36p\ Kana Medium) (Ascii Latin CJK MathSymbols mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=79 em=205 lvw=20 lhw=6 uvw=24 uhw=7 fillp=31 vcnt=31 lasprat=102 pasprat=94 loasc=167 lodes=144 dides=100))
((Yuppy\ SC Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=150 lvw=13 lhw=12 uvw=13 uhw=13 fillp=35 vcnt=32 lasprat=93 pasprat=81 loasc=140 lodes=141 dides=103))
((Yuppy\ TC Regular) (Ascii CJK mono=no sans=yes slant=0 italic=no case=mixed regular=yes ex=87 em=150 lvw=13 lhw=12 uvw=13 uhw=13 fillp=35 vcnt=32 lasprat=93 pasprat=81 loasc=140 lodes=141 dides=103))
((Zantroke Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=100 em=173 lvw=33 lhw=20 uvw=33 uhw=20 fillp=58 vcnt=70 lasprat=118 pasprat=112 loasc=139 lodes=140 dides=102))
((Zapf\ Dingbats Regular) ())
((Zapfino Regular) (Ascii Latin mono=no sans=no slant=55 italic=no case=mixed regular=no ex=92 em=340 lvw=18 lhw=56 uvw=21 uhw=4 fillp=13 vcnt=24 lasprat=109 pasprat=215 loasc=339 lodes=375 dides=126))
((Zawra Bold) ())
((Zawra Heavy) ())
((Zawra\ PUA Bold) ())
((Zawra\ PUA Heavy) ())
((Zco Bold) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=51 vcnt=43 lasprat=136 pasprat=122 loasc=142 lodes=146 dides=102))
((Zco Bold\ Italic) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=73 em=136 lvw=23 lhw=23 uvw=23 uhw=23 fillp=47 vcnt=43 lasprat=136 pasprat=128 loasc=142 lodes=146 dides=102))
((Zco Italic) (Ascii Latin mono=yes sans=no slant=22 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=23 vcnt=18 lasprat=142 pasprat=119 loasc=148 lodes=145 dides=102))
((Zco Light) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=70 em=142 lvw=10 lhw=10 uvw=10 uhw=10 fillp=25 vcnt=18 lasprat=142 pasprat=112 loasc=148 lodes=145 dides=102))
((Zco Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=138 lvw=15 lhw=15 uvw=15 uhw=15 fillp=36 vcnt=29 lasprat=138 pasprat=114 loasc=147 lodes=147 dides=102))
((ZcoN Oblique) (Ascii Latin mono=yes sans=no slant=20 italic=no case=mixed regular=yes ex=72 em=115 lvw=15 lhw=15 uvw=15 uhw=15 fillp=34 vcnt=32 lasprat=115 pasprat=110 loasc=148 lodes=147 dides=102))
((ZcoN Regular) (Ascii Latin mono=yes sans=no slant=0 italic=no case=mixed regular=yes ex=72 em=115 lvw=15 lhw=15 uvw=15 uhw=15 fillp=39 vcnt=32 lasprat=115 pasprat=99 loasc=148 lodes=147 dides=102))
((Znikomit Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=88 em=178 lvw=2 lhw=2 uvw=2 uhw=2 fillp=6 vcnt=7 lasprat=101 pasprat=94 loasc=144 lodes=145 dides=100))
((ZnikomitNo24 Regular) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=112 em=138 lvw=1 lhw=1 uvw=1 uhw=1 fillp=9 vcnt=11 lasprat=79 pasprat=81 loasc=113 lodes=135 dides=121))
((ZnikomitNo24 Thin) (Ascii Latin Cyrillic mono=no sans=no slant=0 italic=no case=mixed regular=no ex=112 em=138 lvw=1 lhw=1 uvw=1 uhw=1 fillp=6 vcnt=7 lasprat=79 pasprat=81 loasc=113 lodes=135 dides=121))
((Ztm Med) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=76 em=206 lvw=31 lhw=6 uvw=38 uhw=6 fillp=45 vcnt=42 lasprat=107 pasprat=97 loasc=148 lodes=144 dides=102))
((Ztm MedIta) (Ascii Latin mono=no sans=no slant=23 italic=yes case=mixed regular=yes ex=77 em=192 lvw=27 lhw=6 uvw=32 uhw=7 fillp=39 vcnt=40 lasprat=99 pasprat=99 loasc=150 lodes=144 dides=102))
((Ztm MedObl) (Ascii Latin mono=no sans=no slant=27 italic=no case=mixed regular=yes ex=76 em=206 lvw=30 lhw=6 uvw=35 uhw=6 fillp=37 vcnt=42 lasprat=107 pasprat=117 loasc=148 lodes=144 dides=102))
((Ztm Reg) (Ascii Latin mono=no sans=no slant=0 italic=no case=mixed regular=yes ex=75 em=197 lvw=20 lhw=6 uvw=25 uhw=8 fillp=33 vcnt=31 lasprat=101 pasprat=94 loasc=152 lodes=149 dides=105))
((Ztm RegIta) (Ascii Latin mono=no sans=no slant=28 italic=yes case=mixed regular=yes ex=75 em=185 lvw=18 lhw=5 uvw=24 uhw=8 fillp=29 vcnt=31 lasprat=98 pasprat=98 loasc=154 lodes=146 dides=104))
((Ztm RegObl) (Ascii Latin mono=no sans=no slant=28 italic=no case=mixed regular=yes ex=75 em=202 lvw=21 lhw=6 uvw=25 uhw=8 fillp=28 vcnt=31 lasprat=102 pasprat=112 loasc=152 lodes=149 dides=105))
