((Academicons Regular) ((academicons.ttf 0 47500)))
((Academy\ Engraved\ LET Plain) ((Academy\ Engraved\ LET\ Fonts.ttf 0 109124) (Academy\ Engraved\ LET\ Fonts.ttf 0 108612)))
((Accanthis\ ADF\ Std\ No3 Bold) ((AccanthisADFStdNo3-Bold.otf 0 52400)))
((Accanthis\ ADF\ Std\ No3 Bold\ Italic) ((AccanthisADFStdNo3-BoldItalic.otf 0 53312)))
((Accanthis\ ADF\ Std\ No3 Italic) ((AccanthisADFStdNo3-Italic.otf 0 53096)))
((Accanthis\ ADF\ Std\ No3 Regular) ((AccanthisADFStdNo3-Regular.otf 0 52204)))
((Al\ Bayan Bold) ((AlBayanBold.ttf 0 81852) (AlBayan.ttc 2 178720) (AlBayanBold.ttf 0 82200) (AlBayan.ttc 2 188132)))
((Al\ Bayan Plain) ((AlBayan.ttf 0 82080) (AlBayan.ttc 0 178720) (AlBayan.ttf 0 82432) (AlBayan.ttc 0 188132)))
((Al\ Bayan\ PUA Bold) ((AlBayan.ttc 3 178720) (AlBayan.ttc 3 188132)))
((Al\ Bayan\ PUA Plain) ((AlBayan.ttc 1 178720) (AlBayan.ttc 1 188132)))
((Al\ Firat Regular) ((AlFirat.ttc 0 61544)))
((Al\ Khalil Bold) ((AlKhalil.ttc 1 116672)))
((Al\ Khalil Regular) ((AlKhalil.ttc 0 116672)))
((Al\ Nile Bold) ((Al\ Nile.ttc 1 124996) (Al\ Nile.ttc 2 131264)))
((Al\ Nile Regular) ((Al\ Nile.ttc 0 124996) (Al\ Nile.ttc 0 131264)))
((Al\ Nile\ PUA Bold) ((Al\ Nile.ttc 3 124996) (Al\ Nile.ttc 3 131264)))
((Al\ Nile\ PUA Regular) ((Al\ Nile.ttc 2 124996) (Al\ Nile.ttc 1 131264)))
((Al\ Rafidain Regular) ((AlRafidain.ttc 0 53076)))
((Al\ Rafidain\ Al\ Fanni Regular) ((AlRafidainAlFanni.ttc 0 55824)))
((Al\ Rafidain\ PUA Regular) ((AlRafidain.ttc 1 53076)))
((Al\ Tarikh Regular) ((Al\ Tarikh.ttc 0 76572) (Al\ Tarikh.ttc 0 79748)))
((Al\ Tarikh\ PUA Regular) ((Al\ Tarikh.ttc 1 76572) (Al\ Tarikh.ttc 1 79748)))
((Alegreya Black) ((Alegreya-Black.otf 0 470368)))
((Alegreya Black\ Italic) ((Alegreya-BlackItalic.otf 0 475640)))
((Alegreya Bold) ((Alegreya-Bold.otf 0 468020)))
((Alegreya Bold\ Italic) ((Alegreya-BoldItalic.otf 0 477240)))
((Alegreya ExtraBold) ((Alegreya-ExtraBold.otf 0 470648)))
((Alegreya ExtraBold\ Italic) ((Alegreya-ExtraBoldItalic.otf 0 479276)))
((Alegreya Italic) ((Alegreya-Italic.otf 0 479412)))
((Alegreya Medium) ((Alegreya-Medium.otf 0 469332)))
((Alegreya Medium\ Italic) ((Alegreya-MediumItalic.otf 0 480996)))
((Alegreya Regular) ((Alegreya-Regular.otf 0 468048)))
((Alegreya\ Sans Black) ((AlegreyaSans-Black.otf 0 235092)))
((Alegreya\ Sans Black\ Italic) ((AlegreyaSans-BlackItalic.otf 0 240688)))
((Alegreya\ Sans Bold) ((AlegreyaSans-Bold.otf 0 236208)))
((Alegreya\ Sans Bold\ Italic) ((AlegreyaSans-BoldItalic.otf 0 239328)))
((Alegreya\ Sans ExtraBold) ((AlegreyaSans-ExtraBold.otf 0 235508)))
((Alegreya\ Sans ExtraBold\ Italic) ((AlegreyaSans-ExtraBoldItalic.otf 0 243000)))
((Alegreya\ Sans Italic) ((AlegreyaSans-Italic.otf 0 236812)))
((Alegreya\ Sans Light) ((AlegreyaSans-Light.otf 0 229920)))
((Alegreya\ Sans Light\ Italic) ((AlegreyaSans-LightItalic.otf 0 237308)))
((Alegreya\ Sans Medium) ((AlegreyaSans-Medium.otf 0 233608)))
((Alegreya\ Sans Medium\ Italic) ((AlegreyaSans-MediumItalic.otf 0 237272)))
((Alegreya\ Sans Regular) ((AlegreyaSans-Regular.otf 0 230620)))
((Alegreya\ Sans Thin) ((AlegreyaSans-Thin.otf 0 224064)))
((Alegreya\ Sans Thin\ Italic) ((AlegreyaSans-ThinItalic.otf 0 236064)))
((Alegreya\ Sans\ SC Black) ((AlegreyaSansSC-Black.otf 0 170980)))
((Alegreya\ Sans\ SC Black\ Italic) ((AlegreyaSansSC-BlackItalic.otf 0 174272)))
((Alegreya\ Sans\ SC Bold) ((AlegreyaSansSC-Bold.otf 0 170716)))
((Alegreya\ Sans\ SC Bold\ Italic) ((AlegreyaSansSC-BoldItalic.otf 0 173244)))
((Alegreya\ Sans\ SC ExtraBold) ((AlegreyaSansSC-ExtraBold.otf 0 169812)))
((Alegreya\ Sans\ SC ExtraBold\ Italic) ((AlegreyaSansSC-ExtraBoldItalic.otf 0 176012)))
((Alegreya\ Sans\ SC Italic) ((AlegreyaSansSC-Italic.otf 0 169428)))
((Alegreya\ Sans\ SC Light) ((AlegreyaSansSC-Light.otf 0 163460)))
((Alegreya\ Sans\ SC Light\ Italic) ((AlegreyaSansSC-LightItalic.otf 0 170196)))
((Alegreya\ Sans\ SC Medium) ((AlegreyaSansSC-Medium.otf 0 168348)))
((Alegreya\ Sans\ SC Medium\ Italic) ((AlegreyaSansSC-MediumItalic.otf 0 169284)))
((Alegreya\ Sans\ SC Regular) ((AlegreyaSansSC-Regular.otf 0 164580)))
((Alegreya\ Sans\ SC Thin) ((AlegreyaSansSC-Thin.otf 0 160036)))
((Alegreya\ Sans\ SC Thin\ Italic) ((AlegreyaSansSC-ThinItalic.otf 0 167696)))
((Alegreya\ SC Black) ((AlegreyaSC-Black.otf 0 342752)))
((Alegreya\ SC Black\ Italic) ((AlegreyaSC-BlackItalic.otf 0 347508)))
((Alegreya\ SC Bold) ((AlegreyaSC-Bold.otf 0 338556)))
((Alegreya\ SC Bold\ Italic) ((AlegreyaSC-BoldItalic.otf 0 347400)))
((Alegreya\ SC ExtraBold) ((AlegreyaSC-ExtraBold.otf 0 341296)))
((Alegreya\ SC ExtraBold\ Italic) ((AlegreyaSC-ExtraBoldItalic.otf 0 348256)))
((Alegreya\ SC Italic) ((AlegreyaSC-Italic.otf 0 349552)))
((Alegreya\ SC Medium) ((AlegreyaSC-Medium.otf 0 341888)))
((Alegreya\ SC Medium\ Italic) ((AlegreyaSC-MediumItalic.otf 0 351644)))
((Alegreya\ SC Regular) ((AlegreyaSC-Regular.otf 0 339672)))
((Alex\ Toth Regular) ((alex-toth.ttf 0 72096)))
((AlFirat\ PUA Regular) ((AlFirat.ttc 1 61544)))
((Algiers Regular) ((Algiers.ttc 0 99524)))
((Algiers\ PUA Regular) ((Algiers.ttc 1 99524)))
((AlgolRevived Medium) ((AlgolRevived-Medium.otf 0 219212)))
((AlgolRevived MediumSlanted) ((AlgolRevived-MediumSlanted.otf 0 218324)))
((AlgolRevived Regular) ((AlgolRevived.otf 0 44512)))
((AlgolRevived Slanted) ((AlgolRevived-Slanted.otf 0 36488)))
((Alkalami Light) ((Alkalami-Light.ttf 0 145788)))
((Alkalami Regular) ((Alkalami-Regular.ttf 0 152068)))
((AlKhalil\ PUA Bold) ((AlKhalil.ttc 3 116672)))
((AlKhalil\ PUA Regular) ((AlKhalil.ttc 2 116672)))
((ALM\ Fixed Regular) ((almfixed.otf 0 304376) (almfixed.ttf 0 599924)))
((Almendra Bold) ((Almendra-Bold.ttf 0 34224)))
((Almendra Bold\ Italic) ((Almendra-BoldItalic.ttf 0 32988)))
((Almendra Italic) ((Almendra-Italic.ttf 0 32876)))
((Almendra Regular) ((Almendra-Regular.ttf 0 57324)))
((AlmendraSmallCaps Regular) ((AlmendraSmallCaps.ttf 0 34576)))
((Alpenkreuzer Regular) ((Alpenkreuzer.ttf 0 9780)))
((AlRafidain\ AlFanni\ PUA Regular) ((AlRafidainAlFanni.ttc 1 55824)))
((American\ Typewriter Bold) ((AmericanTypewriter.ttc 1 917120) (AmericanTypewriter.ttc 2 2906024) (AmericanTypewriter.ttc 1 1001208) (AmericanTypewriter.ttc 2 2440176) (AmericanTypewriter.ttc 2 2440184)))
((American\ Typewriter Condensed) ((AmericanTypewriter.ttc 4 917120) (AmericanTypewriter.ttc 3 2906024) (AmericanTypewriter.ttc 4 1001208) (AmericanTypewriter.ttc 4 2440176) (AmericanTypewriter.ttc 4 2440184)))
((American\ Typewriter Condensed\ Bold) ((AmericanTypewriter.ttc 2 917120) (AmericanTypewriter.ttc 4 2906024) (AmericanTypewriter.ttc 2 1001208) (AmericanTypewriter.ttc 5 2440176) (AmericanTypewriter.ttc 5 2440184)))
((American\ Typewriter Condensed\ Light) ((AmericanTypewriter.ttc 5 917120) (AmericanTypewriter.ttc 5 2906024) (AmericanTypewriter.ttc 5 1001208) (AmericanTypewriter.ttc 6 2440176) (AmericanTypewriter.ttc 6 2440184)))
((American\ Typewriter Light) ((AmericanTypewriter.ttc 3 917120) (AmericanTypewriter.ttc 1 2906024) (AmericanTypewriter.ttc 3 1001208) (AmericanTypewriter.ttc 1 2440176) (AmericanTypewriter.ttc 1 2440184)))
((American\ Typewriter Regular) ((AmericanTypewriter.ttc 0 917120) (AmericanTypewriter.ttc 0 2906024) (AmericanTypewriter.ttc 0 1001208) (AmericanTypewriter.ttc 0 2440176) (AmericanTypewriter.ttc 0 2440184)))
((American\ Typewriter Semibold) ((AmericanTypewriter.ttc 3 2440176) (AmericanTypewriter.ttc 3 2440184)))
((Amiri Bold) ((Amiri-Bold.ttf 0 529580)))
((Amiri Bold\ Slanted) ((Amiri-BoldSlanted.ttf 0 529936)))
((Amiri Regular) ((Amiri-Regular.ttf 0 551132)))
((Amiri Slanted) ((Amiri-Slanted.ttf 0 534596)))
((Amiri\ Quran Regular) ((AmiriQuran.ttf 0 136896)))
((Amiri\ Quran\ Colored Regular) ((AmiriQuranColored.ttf 0 172944)))
((Andale\ Mono Regular) ((Andale\ Mono.ttf 0 109700) (andalemo.ttf 0 105548)))
((Andika\ Basic Regular) ((AndBasR.ttf 0 250908)))
((Anonymous\ Pro Bold) ((AnonymousPro-Bold.ttf 0 153708)))
((Anonymous\ Pro Bold\ Italic) ((AnonymousPro-BoldItalic.ttf 0 142016)))
((Anonymous\ Pro Italic) ((AnonymousPro-Italic.ttf 0 144516)))
((Anonymous\ Pro Regular) ((AnonymousPro-Regular.ttf 0 158080)))
((Antykwa\ Poltawskiego Bold) ((antpolt-bold.otf 0 132908)))
((Antykwa\ Poltawskiego Bold\ Italic) ((antpolt-bolditalic.otf 0 135556)))
((Antykwa\ Poltawskiego Cond\ Bold) ((antpoltcond-bold.otf 0 133248)))
((Antykwa\ Poltawskiego Cond\ Bold\ Italic) ((antpoltcond-bolditalic.otf 0 135816)))
((Antykwa\ Poltawskiego Cond\ Italic) ((antpoltcond-italic.otf 0 134568)))
((Antykwa\ Poltawskiego Cond\ Regular) ((antpoltcond-regular.otf 0 131504)))
((Antykwa\ Poltawskiego Expd\ Bold) ((antpoltexpd-bold.otf 0 133904)))
((Antykwa\ Poltawskiego Expd\ Bold\ Italic) ((antpoltexpd-bolditalic.otf 0 136164)))
((Antykwa\ Poltawskiego Expd\ Italic) ((antpoltexpd-italic.otf 0 134736)))
((Antykwa\ Poltawskiego Expd\ Regular) ((antpoltexpd-regular.otf 0 133144)))
((Antykwa\ Poltawskiego Italic) ((antpolt-italic.otf 0 134332)))
((Antykwa\ Poltawskiego Light) ((antpoltlt-regular.otf 0 129436)))
((Antykwa\ Poltawskiego Light\ Bold) ((antpoltlt-bold.otf 0 132888)))
((Antykwa\ Poltawskiego Light\ Bold\ Italic) ((antpoltlt-bolditalic.otf 0 135868)))
((Antykwa\ Poltawskiego Light\ Cond\ Bold) ((antpoltltcond-bold.otf 0 133012)))
((Antykwa\ Poltawskiego Light\ Cond\ Bold\ Italic) ((antpoltltcond-bolditalic.otf 0 135096)))
((Antykwa\ Poltawskiego Light\ Cond\ Italic) ((antpoltltcond-italic.otf 0 133796)))
((Antykwa\ Poltawskiego Light\ Cond\ Regular) ((antpoltltcond-regular.otf 0 130496)))
((Antykwa\ Poltawskiego Light\ Expd\ Bold) ((antpoltltexpd-bold.otf 0 133436)))
((Antykwa\ Poltawskiego Light\ Expd\ Bold\ Italic) ((antpoltltexpd-bolditalic.otf 0 136296)))
((Antykwa\ Poltawskiego Light\ Expd\ Italic) ((antpoltltexpd-italic.otf 0 133800)))
((Antykwa\ Poltawskiego Light\ Expd\ Regular) ((antpoltltexpd-regular.otf 0 130664)))
((Antykwa\ Poltawskiego Light\ Italic) ((antpoltlt-italic.otf 0 133556)))
((Antykwa\ Poltawskiego Light\ SemiCond\ Bold) ((antpoltltsemicond-bold.otf 0 133292)))
((Antykwa\ Poltawskiego Light\ SemiCond\ Bold\ Italic) ((antpoltltsemicond-bolditalic.otf 0 135920)))
((Antykwa\ Poltawskiego Light\ SemiCond\ Italic) ((antpoltltsemicond-italic.otf 0 133616)))
((Antykwa\ Poltawskiego Light\ SemiCond\ Regular) ((antpoltltsemicond-regular.otf 0 130268)))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Bold) ((antpoltltsemiexpd-bold.otf 0 133276)))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Bold\ Italic) ((antpoltltsemiexpd-bolditalic.otf 0 135732)))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Italic) ((antpoltltsemiexpd-italic.otf 0 133976)))
((Antykwa\ Poltawskiego Light\ SemiExpd\ Regular) ((antpoltltsemiexpd-regular.otf 0 130108)))
((Antykwa\ Poltawskiego Regular) ((antpolt-regular.otf 0 131876)))
((Antykwa\ Poltawskiego SemiCond\ Bold) ((antpoltsemicond-bold.otf 0 132848)))
((Antykwa\ Poltawskiego SemiCond\ Bold\ Italic) ((antpoltsemicond-bolditalic.otf 0 136328)))
((Antykwa\ Poltawskiego SemiCond\ Italic) ((antpoltsemicond-italic.otf 0 133600)))
((Antykwa\ Poltawskiego SemiCond\ Regular) ((antpoltsemicond-regular.otf 0 132816)))
((Antykwa\ Poltawskiego SemiExpd\ Bold) ((antpoltsemiexpd-bold.otf 0 135316)))
((Antykwa\ Poltawskiego SemiExpd\ Bold\ Italic) ((antpoltsemiexpd-bolditalic.otf 0 136000)))
((Antykwa\ Poltawskiego SemiExpd\ Italic) ((antpoltsemiexpd-italic.otf 0 134568)))
((Antykwa\ Poltawskiego SemiExpd\ Regular) ((antpoltsemiexpd-regular.otf 0 132000)))
((Antykwa\ Torunska Bold) ((AntykwaTorunska-Bold.otf 0 172216)))
((Antykwa\ Torunska Bold\ Italic) ((AntykwaTorunska-BoldItalic.otf 0 171248)))
((Antykwa\ Torunska Condensed) ((AntykwaTorunskaCond-Regular.otf 0 173268)))
((Antykwa\ Torunska Condensed\ Bold) ((AntykwaTorunskaCond-Bold.otf 0 172432)))
((Antykwa\ Torunska Condensed\ Bold\ Italic) ((AntykwaTorunskaCond-BoldItalic.otf 0 170912)))
((Antykwa\ Torunska Condensed\ Italic) ((AntykwaTorunskaCond-Italic.otf 0 172388)))
((Antykwa\ Torunska Condensed\ Light) ((AntykwaTorunskaCondLight-Regular.otf 0 173000)))
((Antykwa\ Torunska Condensed\ Light\ Italic) ((AntykwaTorunskaCondLight-Italic.otf 0 171800)))
((Antykwa\ Torunska Condensed\ Medium) ((AntykwaTorunskaCondMed-Regular.otf 0 171616)))
((Antykwa\ Torunska Condensed\ Medium\ Italic) ((AntykwaTorunskaCondMed-Italic.otf 0 171760)))
((Antykwa\ Torunska Italic) ((AntykwaTorunska-Italic.otf 0 172912)))
((Antykwa\ Torunska Light) ((AntykwaTorunskaLight-Regular.otf 0 171008)))
((Antykwa\ Torunska Light\ Italic) ((AntykwaTorunskaLight-Italic.otf 0 171716)))
((Antykwa\ Torunska Medium) ((AntykwaTorunskaMed-Regular.otf 0 171092)))
((Antykwa\ Torunska Medium\ Italic) ((AntykwaTorunskaMed-Italic.otf 0 171756)))
((Antykwa\ Torunska Regular) ((AntykwaTorunska-Regular.otf 0 173960)))
((Apex\ Lake Regular) ((Apex\ Lake\ Regular.ttf 0 381496) (ApexLake-Regular.otf 0 188600)))
((Apple\ Braille Outline\ 6\ Dot) ((Apple\ Braille\ Outline\ 6\ Dot.ttf 0 263912) (Apple\ Braille\ Outline\ 6\ Dot.ttf 0 266008)))
((Apple\ Braille Outline\ 8\ Dot) ((Apple\ Braille\ Outline\ 8\ Dot.ttf 0 280980) (Apple\ Braille\ Outline\ 8\ Dot.ttf 0 283076)))
((Apple\ Braille Pinpoint\ 6\ Dot) ((Apple\ Braille\ Pinpoint\ 6\ Dot.ttf 0 183080) (Apple\ Braille\ Pinpoint\ 6\ Dot.ttf 0 185180)))
((Apple\ Braille Pinpoint\ 8\ Dot) ((Apple\ Braille\ Pinpoint\ 8\ Dot.ttf 0 189668) (Apple\ Braille\ Pinpoint\ 8\ Dot.ttf 0 191768)))
((Apple\ Braille Regular) ((Apple\ Braille.ttf 0 135960) (Apple\ Braille.ttf 0 138012)))
((Apple\ Chancery Chancery) ((Apple\ Chancery.ttf 0 336776) (Apple\ Chancery.ttf 0 335572) (Apple\ Chancery.ttf 0 336452)))
((Apple\ Color\ Emoji Regular) ((Apple\ Color\ Emoji.ttf 0 69122784) (Apple\ Color\ Emoji.ttf 0 35944652) (Apple\ Color\ Emoji.ttc 0 211880520) (Apple\ Color\ Emoji.ttc 0 159972324)))
((Apple\ Color\ Emoji\ UI Regular) ((Apple\ Color\ Emoji.ttc 1 211880520) (Apple\ Color\ Emoji.ttc 1 159972324)))
((Apple\ LiGothic Medium) ((Apple\ LiGothic\ Medium.ttf 0 5802828)))
((Apple\ LiSung Light) ((Apple\ LiSung\ Light.ttf 0 8881092)))
((Apple\ SD\ Gothic\ Neo Bold) ((AppleSDGothicNeo.ttc 6 28386056) (AppleSDGothicNeo-Bold.otf 0 2379684) (AppleSDGothicNeo.ttc 6 28429272)))
((Apple\ SD\ Gothic\ Neo ExtraBold) ((AppleSDGothicNeo.ttc 14 28386056) (AppleSDGothicNeo-ExtraBold.otf 0 2376488) (AppleSDGothicNeo.ttc 14 28429272)))
((Apple\ SD\ Gothic\ Neo Heavy) ((AppleSDGothicNeo.ttc 16 28386056) (AppleSDGothicNeo-Heavy.otf 0 2489128) (AppleSDGothicNeo.ttc 16 28429272)))
((Apple\ SD\ Gothic\ Neo Light) ((AppleSDGothicNeo.ttc 8 28386056) (AppleSDGothicNeo-Light.otf 0 2344104) (AppleSDGothicNeo.ttc 8 28429272)))
((Apple\ SD\ Gothic\ Neo Medium) ((AppleSDGothicNeo.ttc 2 28386056) (AppleSDGothicNeo-Medium.otf 0 2335688) (AppleSDGothicNeo.ttc 2 28429272)))
((Apple\ SD\ Gothic\ Neo Regular) ((AppleSDGothicNeo.ttc 0 28386056) (AppleSDGothicNeo-Regular.otf 0 2352564) (AppleSDGothicNeo.ttc 0 28429272)))
((Apple\ SD\ Gothic\ Neo SemiBold) ((AppleSDGothicNeo.ttc 4 28386056) (AppleSDGothicNeo-SemiBold.otf 0 2322500) (AppleSDGothicNeo.ttc 4 28429272)))
((Apple\ SD\ Gothic\ Neo Thin) ((AppleSDGothicNeo.ttc 10 28386056) (AppleSDGothicNeo-Thin.otf 0 2413980) (AppleSDGothicNeo.ttc 10 28429272)))
((Apple\ SD\ Gothic\ Neo UltraLight) ((AppleSDGothicNeo.ttc 12 28386056) (AppleSDGothicNeo-UltraLight.otf 0 2350084) (AppleSDGothicNeo.ttc 12 28429272)))
((Apple\ SD\ Gothic\ NeoI Bold) ((AppleSDGothicNeo.ttc 7 28386056) (AppleSDGothicNeo.ttc 7 28429272)))
((Apple\ SD\ Gothic\ NeoI ExtraBold) ((AppleSDGothicNeo.ttc 15 28386056) (AppleSDGothicNeo.ttc 15 28429272)))
((Apple\ SD\ Gothic\ NeoI Heavy) ((AppleSDGothicNeo.ttc 17 28386056) (AppleSDGothicNeo.ttc 17 28429272)))
((Apple\ SD\ Gothic\ NeoI Light) ((AppleSDGothicNeo.ttc 9 28386056) (AppleSDGothicNeo.ttc 9 28429272)))
((Apple\ SD\ Gothic\ NeoI Medium) ((AppleSDGothicNeo.ttc 3 28386056) (AppleSDGothicNeo.ttc 3 28429272)))
((Apple\ SD\ Gothic\ NeoI Regular) ((AppleSDGothicNeo.ttc 1 28386056) (AppleSDGothicNeo.ttc 1 28429272)))
((Apple\ SD\ Gothic\ NeoI SemiBold) ((AppleSDGothicNeo.ttc 5 28386056) (AppleSDGothicNeo.ttc 5 28429272)))
((Apple\ SD\ Gothic\ NeoI Thin) ((AppleSDGothicNeo.ttc 11 28386056) (AppleSDGothicNeo.ttc 11 28429272)))
((Apple\ SD\ Gothic\ NeoI UltraLight) ((AppleSDGothicNeo.ttc 13 28386056) (AppleSDGothicNeo.ttc 13 28429272)))
((Apple\ Symbols Regular) ((Apple\ Symbols.ttf 0 1506200) (Apple\ Symbols.ttc 0 1681044) (Apple\ Symbols.ttf 0 3751668) (Apple\ Symbols.ttf 0 976688) (Apple\ Symbols.ttf 0 965188)))
((AppleGothic Regular) ((AppleGothic.ttf 0 15394584) (AppleGothic.ttf 0 15292988) (AppleGothic.ttf 0 15600596) (AppleGothic.ttf 0 15255648)))
((Aqua\ Kana Bold) ((AquaKana.ttc 1 36497832) (AquaKana.ttc 1 18487164) (AquaKana.ttc 1 18487652) (AquaKana.ttc 1 18494124)))
((Aqua\ Kana Regular) ((AquaKana.ttc 0 36497832) (AquaKana.ttc 0 18487164) (AquaKana.ttc 0 18487652) (AquaKana.ttc 0 18494124)))
((AR\ PL\ KaitiM\ Big5 Regular) ((bkai00mp.ttf 0 10579132)))
((AR\ PL\ KaitiM\ GB Regular) ((gkai00mp.ttf 0 4633128)))
((AR\ PL\ Mingti2L\ Big5 Reguler) ((bsmi00lp.ttf 0 12804736)))
((AR\ PL\ New\ Sung Regular) ((fireflysung.ttf 0 15443432)))
((AR\ PL\ SungtiL\ GB Regular) ((gbsn00lp.ttf 0 5192076)))
((AR\ PL\ UMing\ CN Light) ((uming.ttc 0 21053592)))
((AR\ PL\ UMing\ HK Light) ((uming.ttc 1 21053592)))
((AR\ PL\ UMing\ TW Light) ((uming.ttc 2 21053592)))
((AR\ PL\ UMing\ TW\ MBE Light) ((uming.ttc 3 21053592)))
((AR\ PL\ ZenKai\ Uni Regular) ((ukai.ttf 0 16480888)))
((Arabic\ UI\ Display Black) ((ArabicUIDisplay.ttc 0 1296220) (ArabicUIDisplay.ttc 0 983632)))
((Arabic\ UI\ Display Bold) ((ArabicUIDisplay.ttc 1 1296220) (ArabicUIDisplay.ttc 1 983632)))
((Arabic\ UI\ Display Heavy) ((ArabicUIDisplay.ttc 2 1296220) (ArabicUIDisplay.ttc 2 983632)))
((Arabic\ UI\ Display Light) ((ArabicUIDisplay.ttc 3 1296220) (ArabicUIDisplay.ttc 3 983632)))
((Arabic\ UI\ Display Medium) ((ArabicUIDisplay.ttc 4 1296220) (ArabicUIDisplay.ttc 4 983632)))
((Arabic\ UI\ Display Regular) ((ArabicUIDisplay.ttc 5 1296220) (ArabicUIDisplay.ttc 5 983632)))
((Arabic\ UI\ Display Semibold) ((ArabicUIDisplay.ttc 6 1296220) (ArabicUIDisplay.ttc 6 983632)))
((Arabic\ UI\ Display Thin) ((ArabicUIDisplay.ttc 7 1296220) (ArabicUIDisplay.ttc 7 983632)))
((Arabic\ UI\ Display Ultralight) ((ArabicUIDisplay.ttc 8 1296220) (ArabicUIDisplay.ttc 8 983632)))
((Arabic\ UI\ Text Bold) ((ArabicUIText.ttc 3 880672) (ArabicUIText.ttc 3 665860)))
((Arabic\ UI\ Text Heavy) ((ArabicUIText.ttc 4 880672) (ArabicUIText.ttc 4 665860)))
((Arabic\ UI\ Text Light) ((ArabicUIText.ttc 5 880672) (ArabicUIText.ttc 5 665860)))
((Arabic\ UI\ Text Medium) ((ArabicUIText.ttc 1 880672) (ArabicUIText.ttc 1 665860)))
((Arabic\ UI\ Text Regular) ((ArabicUIText.ttc 0 880672) (ArabicUIText.ttc 0 665860)))
((Arabic\ UI\ Text Semibold) ((ArabicUIText.ttc 2 880672) (ArabicUIText.ttc 2 665860)))
((Architext Regular) ((architxt.ttf 0 40728)))
((Arial Black) ((Arial\ Black.ttf 0 122556) (ariblk.ttf 0 118832) (ariblk.ttf 0 167592)))
((Arial Bold) ((Arial\ Bold.ttf 0 750984) (arialbd.ttf 0 352224) (arialbd.ttf 0 980756)))
((Arial Bold\ Italic) ((Arial\ Bold\ Italic.ttf 0 558672) (arialbi.ttf 0 226748) (arialbi.ttf 0 721144)))
((Arial Italic) ((Arial\ Italic.ttf 0 553284) (ariali.ttf 0 207808) (ariali.ttf 0 717428)))
((Arial Narrow) ((Arial\ Narrow.ttf 0 179492)))
((Arial Narrow\ Bold) ((Arial\ Narrow\ Bold.ttf 0 184420)))
((Arial Narrow\ Bold\ Italic) ((Arial\ Narrow\ Bold\ Italic.ttf 0 183932)))
((Arial Narrow\ Italic) ((Arial\ Narrow\ Italic.ttf 0 184944)))
((Arial Regular) ((arial.ttf 0 367112) (Arial.ttf 0 773236) (arial.ttf 0 1036584)))
((Arial\ Hebrew Bold) ((ArialHBBold.ttf 0 35548) (ArialHB.ttc 1 192088) (ArialHB.ttc 1 459376)))
((Arial\ Hebrew Light) ((ArialHB.ttc 2 192088) (ArialHB.ttc 2 459376)))
((Arial\ Hebrew Regular) ((ArialHB.ttf 0 36216) (ArialHB.ttc 0 192088) (ArialHB.ttc 0 459376)))
((Arial\ Hebrew\ Desk\ Interface Bold) ((ArialHB.ttc 4 192088) (ArialHB.ttc 4 459376)))
((Arial\ Hebrew\ Desk\ Interface Light) ((ArialHB.ttc 5 192088) (ArialHB.ttc 5 459376)))
((Arial\ Hebrew\ Desk\ Interface Regular) ((ArialHB.ttc 3 192088) (ArialHB.ttc 3 459376)))
((Arial\ Hebrew\ Scholar Bold) ((ArialHB.ttc 7 192088) (ArialHB.ttc 7 459376)))
((Arial\ Hebrew\ Scholar Light) ((ArialHB.ttc 8 192088) (ArialHB.ttc 8 459376)))
((Arial\ Hebrew\ Scholar Regular) ((ArialHB.ttc 6 192088) (ArialHB.ttc 6 459376)))
((Arial\ Rounded\ MT Bold) ((Arial\ Rounded\ Bold.ttf 0 49296)))
((Arial\ Unicode\ MS Regular) ((Arial\ Unicode.ttf 0 23278008)))
((Arimo Bold) ((Arimo-Bold.ttf 0 439272)))
((Arimo Bold\ Italic) ((Arimo-BoldItalic.ttf 0 435744)))
((Arimo Italic) ((Arimo-Italic.ttf 0 441484)))
((Arimo Regular) ((Arimo-Regular.ttf 0 436876)))
((Asana\ Math Regular) ((Asana-Math.ttf 0 497852) (Asana-Math.ttf 0 483532) (Asana-Math.otf 0 429452) (Asana-Math.otf 0 433528)))
((Asap Symbol) ((Asap-Symbol.otf 0 65224)))
((Astroneo ASTRONEO) ((ASTRONEO.ttf 0 196208)))
((Athelas Bold) ((Athelas.ttc 3 2310148) (Athelas.ttc 3 2325812)))
((Athelas Bold\ Italic) ((Athelas.ttc 2 2310148) (Athelas.ttc 2 2325812)))
((Athelas Italic) ((Athelas.ttc 1 2310148) (Athelas.ttc 1 2325812)))
((Athelas Regular) ((Athelas.ttc 0 2310148) (Athelas.ttc 0 2325812)))
((Aurulent\ Sans Bold) ((AurulentSans-Bold.otf 0 37392)))
((Aurulent\ Sans BoldItalic) ((AurulentSans-BoldItalic.otf 0 53436)))
((Aurulent\ Sans Italic) ((AurulentSans-Italic.otf 0 52732)))
((Aurulent\ Sans Regular) ((AurulentSans-Regular.otf 0 37316)))
((Aurulent\ Sans\ Mono Regular) ((AurulentSansMono-Regular.otf 0 36492)))
((Avenir Black) ((Avenir.ttc 2 1593228) (Avenir.ttc 2 1540324) (Avenir.ttc 2 1639536)))
((Avenir Heavy) ((Avenir.ttc 4 1593228) (Avenir.ttc 4 1540324) (Avenir.ttc 4 1639536)))
((Avenir Heavy\ Oblique) ((Avenir.ttc 5 1593228) (Avenir.ttc 5 1540324) (Avenir.ttc 5 1639536)))
((Avenir Light) ((Avenir.ttc 6 1593228) (Avenir.ttc 6 1540324) (Avenir.ttc 6 1639536)))
((Avenir Light\ Oblique) ((Avenir.ttc 7 1593228) (Avenir.ttc 7 1540324) (Avenir.ttc 7 1639536)))
((Avenir Oblique) ((Avenir.ttc 9 1593228) (Avenir.ttc 10 1593228) (Avenir.ttc 9 1540324) (Avenir.ttc 10 1540324) (Avenir.ttc 9 1639536) (Avenir.ttc 10 1639536)))
((Avenir Oblique\ Black) ((Avenir.ttc 3 1593228) (Avenir.ttc 3 1540324) (Avenir.ttc 3 1639536)))
((Avenir Regular) ((Avenir.ttc 8 1593228) (Avenir.ttc 8 1540324) (Avenir.ttc 8 1639536)))
((Avenir Roman) ((Avenir.ttc 11 1593228) (Avenir.ttc 11 1540324) (Avenir.ttc 11 1639536)))
((Avenir\ Book Oblique) ((Avenir.ttc 1 1593228) (Avenir.ttc 1 1540324) (Avenir.ttc 1 1639536)))
((Avenir\ Book Regular) ((Avenir.ttc 0 1593228) (Avenir.ttc 0 1540324) (Avenir.ttc 0 1639536)))
((Avenir\ Next Bold) ((Avenir\ Next.ttc 0 5195904) (Avenir\ Next.ttc 0 2838512) (Avenir\ Next.ttc 0 4988788)))
((Avenir\ Next Bold\ Italic) ((Avenir\ Next.ttc 1 5195904) (Avenir\ Next.ttc 1 2838512) (Avenir\ Next.ttc 1 4988788)))
((Avenir\ Next Condensed) ((Avenir\ Next\ Condensed.ttc 5 3157212) (Avenir\ Next\ Condensed.ttc 7 3157212) (Avenir\ Next\ Condensed.ttc 5 2794276) (Avenir\ Next\ Condensed.ttc 7 2794276) (Avenir\ Next\ Condensed.ttc 5 3284564) (Avenir\ Next\ Condensed.ttc 7 3284564)))
((Avenir\ Next Condensed\ Bold) ((Avenir\ Next\ Condensed.ttc 0 3157212) (Avenir\ Next\ Condensed.ttc 0 2794276) (Avenir\ Next\ Condensed.ttc 0 3284564)))
((Avenir\ Next Condensed\ Bold\ Italic) ((Avenir\ Next\ Condensed.ttc 1 3157212) (Avenir\ Next\ Condensed.ttc 1 2794276) (Avenir\ Next\ Condensed.ttc 1 3284564)))
((Avenir\ Next Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 4 3157212) (Avenir\ Next\ Condensed.ttc 6 3157212) (Avenir\ Next\ Condensed.ttc 4 2794276) (Avenir\ Next\ Condensed.ttc 6 2794276) (Avenir\ Next\ Condensed.ttc 4 3284564) (Avenir\ Next\ Condensed.ttc 6 3284564)))
((Avenir\ Next DemiBold) ((Avenir\ Next.ttc 2 5195904) (Avenir\ Next.ttc 2 2838512) (Avenir\ Next.ttc 2 4988788)))
((Avenir\ Next DemiBold\ Condensed) ((Avenir\ Next\ Condensed.ttc 2 3157212) (Avenir\ Next\ Condensed.ttc 2 2794276) (Avenir\ Next\ Condensed.ttc 2 3284564)))
((Avenir\ Next DemiBold\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 3 3157212) (Avenir\ Next\ Condensed.ttc 3 2794276) (Avenir\ Next\ Condensed.ttc 3 3284564)))
((Avenir\ Next DemiBold\ Italic) ((Avenir\ Next.ttc 3 5195904) (Avenir\ Next.ttc 3 2838512) (Avenir\ Next.ttc 3 4988788)))
((Avenir\ Next Heavy) ((Avenir\ Next.ttc 8 5195904) (Avenir\ Next.ttc 8 2838512) (Avenir\ Next.ttc 8 4988788)))
((Avenir\ Next Heavy\ Condensed) ((Avenir\ Next\ Condensed.ttc 8 3157212) (Avenir\ Next\ Condensed.ttc 8 2794276) (Avenir\ Next\ Condensed.ttc 8 3284564)))
((Avenir\ Next Heavy\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 9 3157212) (Avenir\ Next\ Condensed.ttc 9 2794276) (Avenir\ Next\ Condensed.ttc 9 3284564)))
((Avenir\ Next Heavy\ Italic) ((Avenir\ Next.ttc 9 5195904) (Avenir\ Next.ttc 9 2838512) (Avenir\ Next.ttc 9 4988788)))
((Avenir\ Next Italic) ((Avenir\ Next.ttc 4 5195904) (Avenir\ Next.ttc 6 5195904) (Avenir\ Next.ttc 4 2838512) (Avenir\ Next.ttc 6 2838512) (Avenir\ Next.ttc 4 4988788) (Avenir\ Next.ttc 6 4988788)))
((Avenir\ Next Regular) ((Avenir\ Next.ttc 5 5195904) (Avenir\ Next.ttc 7 5195904) (Avenir\ Next.ttc 5 2838512) (Avenir\ Next.ttc 7 2838512) (Avenir\ Next.ttc 5 4988788) (Avenir\ Next.ttc 7 4988788)))
((Avenir\ Next Thin) ((Avenir\ Next.ttc 10 5195904) (Avenir\ Next.ttc 10 2838512) (Avenir\ Next.ttc 10 4988788)))
((Avenir\ Next Thin\ Condensed) ((Avenir\ Next\ Condensed.ttc 10 3157212) (Avenir\ Next\ Condensed.ttc 10 2794276) (Avenir\ Next\ Condensed.ttc 10 3284564)))
((Avenir\ Next Thin\ Condensed\ Italic) ((Avenir\ Next\ Condensed.ttc 11 3157212) (Avenir\ Next\ Condensed.ttc 11 2794276) (Avenir\ Next\ Condensed.ttc 11 3284564)))
((Avenir\ Next Thin\ Italic) ((Avenir\ Next.ttc 11 5195904) (Avenir\ Next.ttc 11 2838512) (Avenir\ Next.ttc 11 4988788)))
((Avocado Regular) ((avocado_.ttf 0 67056)))
((Ayuthaya Regular) ((Ayuthaya.ttf 0 297876) (Ayuthaya.ttf 0 304592) (Ayuthaya.ttf 0 305352) (Ayuthaya.ttf 0 307268)))
((Baekmuk\ Batang Regular) ((batang.ttf 0 13939436)))
((Baekmuk\ Dotum Regular) ((dotum.ttf 0 3066060)))
((Baekmuk\ Gulim Regular) ((gulim.ttf 0 10385096)))
((Baekmuk\ Headline Regular) ((hline.ttf 0 1203464)))
((Baghdad Regular) ((Baghdad.ttf 0 99132) (Baghdad.ttc 0 106220) (Baghdad.ttf 0 99492) (Baghdad.ttc 0 109492)))
((Baghdad\ PUA Regular) ((Baghdad.ttc 1 106220) (Baghdad.ttc 1 109492)))
((Bahnschrift Regular) ((bahnschrift.ttf 0 355600)))
((Balham Regular) ((Balham.otf 0 23908)))
((Bangla\ MN Bold) ((Bangla\ MN.ttc 1 830804) (Bangla\ MN.ttc 1 832052) (Bangla\ MN.ttc 1 316524)))
((Bangla\ MN Regular) ((Bangla\ MN.ttc 0 830804) (Bangla\ MN.ttc 0 832052) (Bangla\ MN.ttc 0 316524)))
((Bangla\ Sangam\ MN Bold) ((Bangla\ Sangam\ MN.ttc 1 762944) (Bangla\ Sangam\ MN.ttc 1 698648) (Bangla\ Sangam\ MN.ttc 1 439724)))
((Bangla\ Sangam\ MN Regular) ((Bangla\ Sangam\ MN.ttc 0 762944) (Bangla\ Sangam\ MN.ttc 0 698648) (Bangla\ Sangam\ MN.ttc 0 439724)))
((Bank\ Gothic Light) ((BankGothic.ttc 0 227400)))
((Bank\ Gothic Medium) ((BankGothic.ttc 1 227400)))
((Baoli\ SC Regular) ((Baoli.ttc 0 8474944)))
((Baskervaldx Bol) ((Baskervaldx-Bol.otf 0 66408)))
((Baskervaldx Bold\ Italic) ((Baskervaldx-BolIta.otf 0 64744)))
((Baskervaldx Ita) ((Baskervaldx-Ita.otf 0 61860)))
((Baskervaldx Reg) ((Baskervaldx-Reg.otf 0 63368)))
((Baskerville Bold) ((Baskerville.ttc 1 449004) (Baskerville.ttc 0 1277484) (Baskerville.ttc 1 1123736) (Baskerville.ttc 1 1371312)))
((Baskerville Bold\ Italic) ((Baskerville.ttc 4 449004) (Baskerville.ttc 1 1277484) (Baskerville.ttc 4 1123736) (Baskerville.ttc 3 1371312)))
((Baskerville Italic) ((Baskerville.ttc 2 449004) (Baskerville.ttc 2 1277484) (Baskerville.ttc 2 1123736) (Baskerville.ttc 2 1371312)))
((Baskerville Regular) ((Baskerville.ttc 0 449004) (Baskerville.ttc 3 1277484) (Baskerville.ttc 0 1123736) (Baskerville.ttc 0 1371312)))
((Baskerville SemiBold) ((Baskerville.ttc 5 449004) (Baskerville.ttc 4 1277484) (Baskerville.ttc 5 1123736) (Baskerville.ttc 4 1371312)))
((Baskerville SemiBold\ Italic) ((Baskerville.ttc 3 449004) (Baskerville.ttc 5 1277484) (Baskerville.ttc 3 1123736) (Baskerville.ttc 5 1371312)))
((BaskervilleF Bold) ((BaskervilleF-Bold.otf 0 105608) (BaskervilleF-Bold.otf 0 105604)))
((BaskervilleF Bold\ Italic) ((BaskervilleF-BoldItalic.otf 0 167616) (BaskervilleF-BoldItalic.otf 0 167624)))
((BaskervilleF Italic) ((BaskervilleF-Italic.otf 0 157564) (BaskervilleF-Italic.otf 0 157568)))
((BaskervilleF Regular) ((BaskervilleF-Regular.otf 0 104040) (BaskervilleF-Regular.otf 0 104044)))
((Basra Bold) ((Basra.ttc 2 139448)))
((Basra Regular) ((Basra.ttc 0 139448)))
((Basra\ PUA Bold) ((Basra.ttc 3 139448)))
((Basra\ PUA Regular) ((Basra.ttc 1 139448)))
((Batang Regular) ((batang.ttf 0 15519828)))
((BB\ Petie\ Boy Destroyed) ((BB_Petie_Boy_Destroyed.ttf 0 350196)))
((BB\ Petie\ Boy Heavy) ((BB_Petie_Boy_Heavy.ttf 0 199800)))
((BB\ Petie\ Boy Light) ((BB_Petie_Boy_Light.ttf 0 126260)))
((BB\ Petie\ Boy Medium) ((BB_Petie_Boy_Medium.ttf 0 375376)))
((Beirut Regular) ((Beirut.ttc 0 78976) (Beirut.ttc 0 81672)))
((Beirut\ PUA Regular) ((Beirut.ttc 1 78976) (Beirut.ttc 1 81672)))
((Berenis\ ADF\ Pro Bold) ((BerenisADFPro-Bold.otf 0 124844)))
((Berenis\ ADF\ Pro Bold\ Italic) ((BerenisADFPro-BoldItalic.otf 0 151352)))
((Berenis\ ADF\ Pro Italic) ((BerenisADFPro-Italic.otf 0 193328)))
((Berenis\ ADF\ Pro Regular) ((BerenisADFPro-Regular.otf 0 136852)))
((Berenis\ ADF\ Pro\ SC Bold) ((BerenisADFProSC-Bold.otf 0 136296)))
((Berenis\ ADF\ Pro\ SC Bold\ Italic) ((BerenisADFProSC-BoldItalic.otf 0 147408)))
((Berenis\ ADF\ Pro\ SC Italic) ((BerenisADFProSC-Italic.otf 0 159028)))
((Berenis\ ADF\ Pro\ SC Regular) ((BerenisADFProSC-Regular.otf 0 120380)))
((Beroga Regular) ((Beroga.ttf 0 91868)))
((Beuron Condensed) ((BeuronCondensed-Regular.otf 0 8420)))
((Beuron Extended) ((BeuronExtended-Regular.otf 0 8412)))
((Beuron Regular) ((Beuron-Regular.otf 0 8108)))
((BiauKai Regular) ((BiauKai.ttf 0 13911192)))
((Big\ Caslon Medium) ((BigCaslon.ttf 0 140976) (BigCaslon.ttf 0 213512) (BigCaslon.ttf 0 223272)))
((Bimbo\ JVE Regular) ((Bimbo_JVE.ttf 0 18700)))
((Bitstream\ Vera\ Sans Bold) ((VeraBd.ttf 0 58716)))
((Bitstream\ Vera\ Sans Bold\ Oblique) ((VeraBI.ttf 0 63208)))
((Bitstream\ Vera\ Sans Oblique) ((VeraIt.ttf 0 63684)))
((Bitstream\ Vera\ Sans Roman) ((Vera.ttf 0 65932)))
((Bitstream\ Vera\ Sans\ Mono Bold) ((VeraMoBd.ttf 0 49052)))
((Bitstream\ Vera\ Sans\ Mono Bold\ Oblique) ((VeraMoBI.ttf 0 55032)))
((Bitstream\ Vera\ Sans\ Mono Oblique) ((VeraMoIt.ttf 0 54508)))
((Bitstream\ Vera\ Sans\ Mono Roman) ((VeraMono.ttf 0 49224)))
((Bitstream\ Vera\ Serif Bold) ((VeraSeBd.ttf 0 58736)))
((Bitstream\ Vera\ Serif Roman) ((VeraSe.ttf 0 60280)))
((Bitter Bold) ((Bitter-Bold.ttf 0 23636)))
((Bitter Italic) ((Bitter-Italic.ttf 0 35828)))
((Bitter Regular) ((Bitter-Regular.ttf 0 87128)))
((BlackChancery Regular) ((BLKCHCRY.ttf 0 56732)))
((Blackmoor\ LET Plain) ((Blackmoor\ LET\ Fonts.ttf 0 241960) (Blackmoor\ LET\ Fonts.ttf 0 263464)))
((BlairMdITC\ TT Medium) ((Blair\ Medium.ttf 0 144024)))
((BloomingGrove Medium) ((bgrove.otf 0 32292) (bgrove.ttf 0 18744)))
((BloomingGroveAltBold Bold) ((bgrovealtb.otf 0 49912) (bgrovealtb.ttf 0 17648)))
((BloomingGroveAlternate Alternate) ((bgrovealt.otf 0 29944) (bgrovealt.ttf 0 18872)))
((BloomingGroveBold Bold) ((bgroveb.otf 0 54344) (bgroveb.ttf 0 17732)))
((Bodoni\ 72 Bold) ((Bodoni\ 72.ttc 2 416692) (Bodoni\ 72.ttc 2 427652)))
((Bodoni\ 72 Book) ((Bodoni\ 72.ttc 0 416692) (Bodoni\ 72.ttc 0 427652)))
((Bodoni\ 72 Book\ Italic) ((Bodoni\ 72.ttc 1 416692) (Bodoni\ 72.ttc 1 427652)))
((Bodoni\ 72\ Oldstyle Bold) ((Bodoni\ 72\ OS.ttc 2 230216) (Bodoni\ 72\ OS.ttc 2 238724)))
((Bodoni\ 72\ Oldstyle Book) ((Bodoni\ 72\ OS.ttc 0 230216) (Bodoni\ 72\ OS.ttc 0 238724)))
((Bodoni\ 72\ Oldstyle Book\ Italic) ((Bodoni\ 72\ OS.ttc 1 230216) (Bodoni\ 72\ OS.ttc 1 238724)))
((Bodoni\ 72\ Smallcaps Book) ((Bodoni\ 72\ Smallcaps\ Book.ttf 0 79956) (Bodoni\ 72\ Smallcaps\ Book.ttf 0 82788)))
((Bodoni\ Ornaments Regular) ((Bodoni\ Ornaments.ttf 0 72492) (Bodoni\ Ornaments.ttf 0 73972)))
((Bodoni\ Ornaments\ ITC\ TT Regular) ((Bodoni\ Ornaments.ttf 0 57296)))
((Bodoni\ SvtyTwo\ ITC\ TT Bold) ((Bodoni\ SvtyTwo.ttc 2 534504)))
((Bodoni\ SvtyTwo\ ITC\ TT Book) ((Bodoni\ SvtyTwo.ttc 0 534504)))
((Bodoni\ SvtyTwo\ ITC\ TT BookIta) ((Bodoni\ SvtyTwo.ttc 1 534504)))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT Bold) ((Bodoni\ SvtyTwo\ OS.ttc 2 259616)))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT Book) ((Bodoni\ SvtyTwo\ OS.ttc 0 259616)))
((Bodoni\ SvtyTwo\ OS\ ITC\ TT BookIt) ((Bodoni\ SvtyTwo\ OS.ttc 1 259616)))
((Bodoni\ SvtyTwo\ SC\ ITC\ TT Book) ((Bodoni\ SvtyTwo\ SC\ Book.ttf 0 93556)))
((Book\ Antiqua Bold) ((BookAntiqua.ttc 1 581996)))
((Book\ Antiqua Bold\ Italic) ((BookAntiqua.ttc 3 581996)))
((Book\ Antiqua Italic) ((BookAntiqua.ttc 2 581996)))
((Book\ Antiqua Regular) ((BookAntiqua.ttc 0 581996)))
((Bookman\ Old\ Style Bold) ((BookmanOldStyle.ttc 1 608764)))
((Bookman\ Old\ Style Bold\ Italic) ((BookmanOldStyle.ttc 3 608764)))
((Bookman\ Old\ Style Italic) ((BookmanOldStyle.ttc 2 608764)))
((Bookman\ Old\ Style Regular) ((BookmanOldStyle.ttc 0 608764)))
((Bordeaux\ Roman\ LET Bold\ Plain) ((Bordeaux\ Roman\ Bold\ LET\ Fonts.ttf 0 113852)))
((BPreplay Bold) ((BPreplayBold.otf 0 31480)))
((BPreplay Bold\ Italic) ((BPreplayBoldItalics.otf 0 33204)))
((BPreplay Italic) ((BPreplayItalics.otf 0 33248)))
((BPreplay Regular) ((BPreplay.otf 0 30672)))
((Bradley\ Hand Bold) ((Bradley\ Hand\ Bold.ttf 0 592324) (Bradley\ Hand\ Bold.ttf 0 596236) (Bradley\ Hand\ Bold.ttf 0 596216)))
((Braganza Regular) ((Braganza.ttf 0 202944)))
((Brewsky Regular) ((Brewsky.ttf 0 51836)))
((Brush\ Script\ MT Italic) ((Brush\ Script.ttf 0 56844) (Brush\ Script.ttf 0 222640)))
((Cabin Bold) ((Cabin-Bold.otf 0 73128)))
((Cabin Bold\ Italic) ((Cabin-BoldItalic.otf 0 64940)))
((Cabin Condensed) ((CabinCondensed-Medium.otf 0 73852) (CabinCondensed-MediumItalic.otf 0 125892) (CabinCondensed-Regular.otf 0 72932)))
((Cabin Condensed\ Bold) ((CabinCondensed-Bold.otf 0 70628)))
((Cabin Condensed\ BoldItalic) ((CabinCondensed-BoldItalic.otf 0 120024)))
((Cabin Condensed\ Italic) ((CabinCondensed-Italic.otf 0 123508)))
((Cabin Italic) ((Cabin-Italic.otf 0 64404) (Cabin-MediumItalic.otf 0 69852)))
((Cabin Regular) ((Cabin-Medium.otf 0 77304) (Cabin-Regular.otf 0 73056)))
((Cabin SemiBold) ((Cabin-SemiBold.otf 0 77908)))
((Cabin SemiBold\ Condensed) ((CabinCondensed-SemiBold.otf 0 74092) (CabinCondensed-SemiBoldItalic.otf 0 127036)))
((Cabin SemiBold\ Italic) ((Cabin-SemiBoldItalic.otf 0 70080)))
((Cake\ Frosting Decorative) ((CakeFrostingDecorative.ttf 0 297484)))
((Caladea Bold) ((Caladea-Bold.ttf 0 58892)))
((Caladea Italic) ((Caladea-BoldItalic.ttf 0 61828) (Caladea-Italic.ttf 0 61860)))
((Caladea Regular) ((Caladea-Regular.ttf 0 58964)))
((Calibri Bold) ((calibrib.ttf 0 1613668)))
((Calibri Bold\ Italic) ((calibriz.ttf 0 1159032)))
((Calibri Italic) ((calibrii.ttf 0 1196672)))
((Calibri Light) ((calibril.ttf 0 1438808)))
((Calibri Light\ Italic) ((calibrili.ttf 0 1061248)))
((Calibri Regular) ((calibri.ttf 0 1648120)))
((Cambria Bold) ((cambriab.ttf 0 841440)))
((Cambria Bold\ Italic) ((cambriaz.ttf 0 856672)))
((Cambria Italic) ((cambriai.ttf 0 892620)))
((Cambria Regular) ((cambria.ttc 0 1792664)))
((Candara Bold) ((Candarab.ttf 0 227604)))
((Candara Bold\ Italic) ((Candaraz.ttf 0 229364)))
((Candara Italic) ((Candarai.ttf 0 227648)))
((Candara Light) ((Candaral.ttf 0 122132)))
((Candara Light\ Italic) ((Candarali.ttf 0 120996)))
((Candara Regular) ((Candara.ttf 0 219532) (Candara.ttf 0 162584)))
((Cantarell Bold) ((Cantarell-Bold.otf 0 143192)))
((Cantarell Light) ((Cantarell-Light.otf 0 141608)))
((Cantarell Regular) ((Cantarell-Regular.otf 0 137812)))
((Cantarell\ Extra Bold) ((Cantarell-ExtraBold.otf 0 145140)))
((Cantarell\ Thin Regular) ((Cantarell-Thin.otf 0 140512)))
((Capitals Regular) ((Capitals.ttf 0 79692)))
((Carlito Bold) ((Carlito-Bold.ttf 0 690516) (Carlito.ttc 3 2745296)))
((Carlito Bold\ Italic) ((Carlito-BoldItalic.ttf 0 816716) (Carlito.ttc 2 2745296)))
((Carlito Italic) ((Carlito-Italic.ttf 0 623416) (Carlito.ttc 1 2745296)))
((Carlito Regular) ((Carlito-Regular.ttf 0 635996) (Carlito.ttc 0 2745296)))
((Casa\ Sans Regular) ((casa_sans.ttf 0 50256)))
((Catenary\ Stamp Regular) ((Catenary-Stamp.ttf 0 455376)))
((CCIcons Medium) ((ccicons.otf 0 4960)))
((Century\ Gothic Bold) ((CenturyGothic.ttc 1 530864)))
((Century\ Gothic Bold\ Italic) ((CenturyGothic.ttc 3 530864)))
((Century\ Gothic Italic) ((CenturyGothic.ttc 2 530864)))
((Century\ Gothic Regular) ((CenturyGothic.ttc 0 530864)))
((Century\ Schoolbook Bold) ((CenturySchoolbook.ttc 1 294656)))
((Century\ Schoolbook Bold\ Italic) ((CenturySchoolbook.ttc 3 294656)))
((Century\ Schoolbook Italic) ((CenturySchoolbook.ttc 2 294656)))
((Century\ Schoolbook Regular) ((CenturySchoolbook.ttc 0 294656)))
((Chalkboard Bold) ((Chalkboard.ttc 1 184212) (Chalkboard.ttc 1 166072) (Chalkboard.ttc 1 176872)))
((Chalkboard Regular) ((Chalkboard.ttc 0 184212) (Chalkboard.ttc 0 166072) (Chalkboard.ttc 0 176872)))
((Chalkboard\ SE Bold) ((ChalkboardSE.ttc 2 519772) (ChalkboardSE.ttc 2 558788) (ChalkboardSE.ttc 2 536756)))
((Chalkboard\ SE Light) ((ChalkboardSE.ttc 0 519772) (ChalkboardSE.ttc 0 558788) (ChalkboardSE.ttc 0 536756)))
((Chalkboard\ SE Regular) ((ChalkboardSE.ttc 1 519772) (ChalkboardSE.ttc 1 558788) (ChalkboardSE.ttc 1 536756)))
((Chalkduster Regular) ((Chalkduster.ttf 0 499996) (Chalkduster.ttf 0 483652) (Chalkduster.ttf 0 486860)))
((Charakterny Regular) ((Charakterny.otf 0 230200)))
((Charis\ SIL Bold) ((CharisSILB.ttf 0 1602332)))
((Charis\ SIL Bold\ Italic) ((CharisSILBI.ttf 0 1594156)))
((Charis\ SIL Italic) ((CharisSILI.ttf 0 1620428)))
((Charis\ SIL Regular) ((CharisSILR.ttf 0 1654136)))
((Charter Black) ((Charter.ttc 5 2097188) (Charter.ttc 5 2118332)))
((Charter Black\ Italic) ((Charter.ttc 4 2097188) (Charter.ttc 4 2118332)))
((Charter Bold) ((Charter.ttc 3 2097188) (Charter.ttc 3 2118332)))
((Charter Bold\ Italic) ((Charter.ttc 2 2097188) (Charter.ttc 2 2118332)))
((Charter Italic) ((Charter.ttc 1 2097188) (Charter.ttc 1 2118332)))
((Charter Roman) ((Charter.ttc 0 2097188) (Charter.ttc 0 2118332)))
((Chartrand Medium) ((Chartrand.otf 0 14732)))
((Chess\ Alpha\ Diagram Regular) ((AlphaDia.otf 0 13504)))
((Chivo Black) ((Chivo-Black.otf 0 75308)))
((Chivo Black\ Italic) ((Chivo-BlackItalic.otf 0 77856)))
((Chivo Bold) ((Chivo-Bold.otf 0 70560)))
((Chivo Bold\ Italic) ((Chivo-BoldItalic.otf 0 72556)))
((Chivo ExtraBold) ((Chivo-ExtraBold.otf 0 77444)))
((Chivo ExtraBold\ Italic) ((Chivo-ExtraBoldItalic.otf 0 79968)))
((Chivo Italic) ((Chivo-Italic.otf 0 73908)))
((Chivo Light) ((Chivo-Light.otf 0 81056)))
((Chivo Light\ Italic) ((Chivo-LightItalic.otf 0 84988)))
((Chivo Medium) ((Chivo-Medium.otf 0 78540)))
((Chivo Medium\ Italic) ((Chivo-MediumItalic.otf 0 78016)))
((Chivo Regular) ((Chivo-Regular.otf 0 76496)))
((Chivo Thin) ((Chivo-Thin.otf 0 78556)))
((Chivo Thin\ Italic) ((Chivo-ThinItalic.otf 0 82824)))
((Chronicles\ of\ Arkmar Regular) ((Chronicles_of_ArkMar.ttf 0 145356)))
((Cinzel Black) ((Cinzel-Black.ttf 0 58616)))
((Cinzel Bold) ((Cinzel-Bold.ttf 0 57740)))
((Cinzel Regular) ((Cinzel-Regular.ttf 0 56228)))
((Cinzel\ Decorative Black\ Black) ((CinzelDecorative-Black.ttf 0 62824)))
((Cinzel\ Decorative Bold) ((CinzelDecorative-Bold.ttf 0 62448)))
((Cinzel\ Decorative Regular) ((CinzelDecorative-Regular.ttf 0 60540)))
((Clara Bold) ((clarab.otf 0 100836)))
((Clara Bold-Italic) ((clarabi.otf 0 97444)))
((Clara Book) ((clarar.otf 0 171056)))
((Clara Italic) ((clarai.otf 0 126396)))
((Clear\ Sans Bold) ((ClearSans-Bold.ttf 0 269792)))
((Clear\ Sans Bold\ Italic) ((ClearSans-BoldItalic.ttf 0 287460)))
((Clear\ Sans Italic) ((ClearSans-Italic.ttf 0 282800) (ClearSans-MediumItalic.ttf 0 315792)))
((Clear\ Sans Light) ((ClearSans-Light.ttf 0 272724)))
((Clear\ Sans Regular) ((ClearSans-Medium.ttf 0 313308) (ClearSans-Regular.ttf 0 304516)))
((Clear\ Sans\ Thin Regular) ((ClearSans-Thin.ttf 0 272304)))
((CMU\ Bright Bold) ((cmunbbx.otf 0 219276)))
((CMU\ Bright BoldOblique) ((cmunbxo.otf 0 223376)))
((CMU\ Bright Oblique) ((cmunbmo.otf 0 218240)))
((CMU\ Bright Roman) ((cmunbmr.otf 0 241008)))
((CMU\ Bright SemiBold) ((cmunbsr.otf 0 212804)))
((CMU\ Bright SemiBoldOblique) ((cmunbso.otf 0 217292)))
((CMU\ Classical\ Serif Italic) ((cmunci.otf 0 248868)))
((CMU\ Concrete Bold) ((cmunobx.otf 0 254872)))
((CMU\ Concrete BoldItalic) ((cmunobi.otf 0 243956)))
((CMU\ Concrete Italic) ((cmunoti.otf 0 238356)))
((CMU\ Concrete Roman) ((cmunorm.otf 0 280304)))
((CMU\ Sans\ Serif Bold) ((cmunsx.otf 0 274384)))
((CMU\ Sans\ Serif BoldOblique) ((cmunso.otf 0 237356)))
((CMU\ Sans\ Serif DemiCondensed) ((cmunssdc.otf 0 220148)))
((CMU\ Sans\ Serif Medium) ((cmunss.otf 0 222060)))
((CMU\ Sans\ Serif Oblique) ((cmunsi.otf 0 222660)))
((CMU\ Sans\ Serif\ Demi Condensed\ DemiCondensed) ((cmunssdc.otf 0 220148)))
((CMU\ Serif Bold) ((cmunbx.otf 0 319676)))
((CMU\ Serif BoldItalic) ((cmunbi.otf 0 251884)))
((CMU\ Serif Italic) ((cmunti.otf 0 248088)))
((CMU\ Serif Roman) ((cmunrm.otf 0 330492)))
((CMU\ Serif\ Extra BoldNonextended) ((cmunrb.otf 0 226856)))
((CMU\ Serif\ Extra BoldSlanted) ((cmunbl.otf 0 320560)))
((CMU\ Serif\ Extra RomanSlanted) ((cmunsl.otf 0 320152)))
((CMU\ Serif\ Upright Italic\ UprightItalic) ((cmunui.otf 0 227084)))
((CMU\ Serif\ Upright\ Italic UprightItalic) ((cmunui.otf 0 227084)))
((CMU\ Typewriter\ Text Bold) ((cmuntb.otf 0 198108)))
((CMU\ Typewriter\ Text BoldItalic) ((cmuntx.otf 0 207728)))
((CMU\ Typewriter\ Text Italic) ((cmunit.otf 0 195444)))
((CMU\ Typewriter\ Text Light) ((cmunbtl.otf 0 188976)))
((CMU\ Typewriter\ Text LightOblique) ((cmunbto.otf 0 196448)))
((CMU\ Typewriter\ Text Oblique) ((cmunst.otf 0 244900)))
((CMU\ Typewriter\ Text Regular) ((cmuntt.otf 0 301664)))
((CMU\ Typewriter\ Text\ Variable\ Width Italic) ((cmunvi.otf 0 195716)))
((CMU\ Typewriter\ Text\ Variable\ Width Medium) ((cmunvt.otf 0 186996)))
((Cochin Bold) ((Cochin.ttc 1 886724) (Cochin.ttc 1 1224236) (Cochin.ttc 1 1222088) (Cochin.ttc 1 1240320)))
((Cochin Bold\ Italic) ((Cochin.ttc 3 886724) (Cochin.ttc 3 1224236) (Cochin.ttc 3 1222088) (Cochin.ttc 3 1240320)))
((Cochin Italic) ((Cochin.ttc 2 886724) (Cochin.ttc 2 1224236) (Cochin.ttc 2 1222088) (Cochin.ttc 2 1240320)))
((Cochin Regular) ((Cochin.ttc 0 886724) (Cochin.ttc 0 1224236) (Cochin.ttc 0 1222088) (Cochin.ttc 0 1240320)))
((Cochineal Bold) ((Cochineal-Bold.otf 0 221620)))
((Cochineal BoldItalic) ((Cochineal-BoldItalic.otf 0 202264)))
((Cochineal Italic) ((Cochineal-Italic.otf 0 222352)))
((Cochineal Roman) ((Cochineal-Roman.otf 0 220776)))
((Coelacanth Bold) ((CoelacanthBold.otf 0 798048)))
((Coelacanth ExtraLt) ((CoelacanthExtraLt.otf 0 784708)))
((Coelacanth Heavy) ((CoelacanthHeavy.otf 0 802404)))
((Coelacanth Italic) ((CoelacanthItalic.otf 0 371276)))
((Coelacanth Lt) ((CoelacanthLt.otf 0 786172)))
((Coelacanth Regular) ((Coelacanth.otf 0 666264)))
((Coelacanth Semibd) ((CoelacanthSemibd.otf 0 800360)))
((Comfortaa Bold) ((Comfortaa-Bold.ttf 0 176924) (Comfortaa-Bold.ttf 0 170432) (Comfortaa-Bold.ttf 0 134916)))
((Comfortaa Light) ((Comfortaa-Light.ttf 0 172812) (Comfortaa-Light.ttf 0 170140) (Comfortaa-Light.ttf 0 135420)))
((Comfortaa Regular) ((Comfortaa-Regular.ttf 0 169476) (Comfortaa-Regular.ttf 0 170716) (Comfortaa-Regular.ttf 0 135304)))
((Comic\ Neue Bold) ((ComicNeue_Bold.otf 0 30344)))
((Comic\ Neue Bold\ Oblique) ((ComicNeue_Bold_Oblique.otf 0 31028)))
((Comic\ Neue Light) ((ComicNeue_Light.otf 0 30060)))
((Comic\ Neue Light\ Oblique) ((ComicNeue_Light_Oblique.otf 0 31948)))
((Comic\ Neue Oblique) ((ComicNeue_Regular_Oblique.otf 0 31312)))
((Comic\ Neue Regular) ((ComicNeue_Regular.otf 0 29512)))
((Comic\ Neue\ Angular Bold) ((ComicNeue-Angular_Bold.otf 0 25652)))
((Comic\ Neue\ Angular Bold\ Oblique) ((ComicNeue-Angular_Bold_Oblique.otf 0 25884)))
((Comic\ Neue\ Angular Light) ((ComicNeue-Angular_Light.otf 0 25448)))
((Comic\ Neue\ Angular Light\ Oblique) ((ComicNeue-Angular_Light_Oblique.otf 0 25780)))
((Comic\ Neue\ Angular Oblique) ((ComicNeue-Angular_Regular_Oblique.otf 0 24804)))
((Comic\ Neue\ Angular Regular) ((ComicNeue-Angular_Regular.otf 0 24268)))
((Comic\ Sans\ MS Bold) ((Comic\ Sans\ MS\ Bold.ttf 0 120120) (comicbd.ttf 0 111476) (comicbd.ttf 0 229408)))
((Comic\ Sans\ MS Bold\ Italic) ((comicz.ttf 0 224252)))
((Comic\ Sans\ MS Italic) ((comici.ttf 0 226708)))
((Comic\ Sans\ MS Regular) ((Comic\ Sans\ MS.ttf 0 135484) (comic.ttf 0 127596) (comic.ttf 0 245600)))
((Consolas Bold) ((consolab.ttf 0 397896)))
((Consolas Bold\ Italic) ((consolaz.ttf 0 407956)))
((Consolas Italic) ((consolai.ttf 0 467584)))
((Consolas Regular) ((consola.ttf 0 459180)))
((Constantia Bold) ((constanb.ttf 0 451824)))
((Constantia Bold\ Italic) ((constanz.ttf 0 455564)))
((Constantia Italic) ((constani.ttf 0 448748)))
((Constantia Regular) ((constan.ttf 0 448376)))
((Constanze Regular) ((ConstanzeInitials.otf 0 8432)))
((Copperplate Bold) ((Copperplate.ttc 2 231116) (Copperplate.ttc 2 1257000) (Copperplate.ttc 2 331884) (Copperplate.ttc 2 1266824)))
((Copperplate Light) ((Copperplate.ttc 1 231116) (Copperplate.ttc 1 1257000) (Copperplate.ttc 1 331884) (Copperplate.ttc 1 1266824)))
((Copperplate Regular) ((Copperplate.ttc 0 231116) (Copperplate.ttc 0 1257000) (Copperplate.ttc 0 331884) (Copperplate.ttc 0 1266824)))
((Corbel Bold) ((corbelb.ttf 0 290908)))
((Corbel Bold\ Italic) ((corbelz.ttf 0 294692)))
((Corbel Italic) ((corbeli.ttf 0 284690)))
((Corbel Light) ((corbell.ttf 0 172256)))
((Corbel Light\ Italic) ((corbelli.ttf 0 169228)))
((Corbel Regular) ((corbel.ttf 0 277168)))
((Cormorant\ Garamond Bold) ((CormorantGaramond-Bold.ttf 0 944456)))
((Cormorant\ Garamond Bold\ Italic) ((CormorantGaramond-BoldItalic.ttf 0 660816)))
((Cormorant\ Garamond Italic) ((CormorantGaramond-Italic.ttf 0 637624)))
((Cormorant\ Garamond Light) ((CormorantGaramond-Light.ttf 0 963664)))
((Cormorant\ Garamond Light\ Italic) ((CormorantGaramond-LightItalic.ttf 0 633120)))
((Cormorant\ Garamond Medium) ((CormorantGaramond-Medium.ttf 0 956064)))
((Cormorant\ Garamond Medium\ Italic) ((CormorantGaramond-MediumItalic.ttf 0 646960)))
((Cormorant\ Garamond Regular) ((CormorantGaramond-Regular.ttf 0 963336)))
((Cormorant\ Garamond SemiBold) ((CormorantGaramond-SemiBold.ttf 0 948968)))
((Cormorant\ Garamond SemiBold\ Italic) ((CormorantGaramond-SemiBoldItalic.ttf 0 646744)))
((Corsiva\ Hebrew Bold) ((CorsivaBold.ttf 0 42096) (Corsiva.ttc 1 71784) (Corsiva.ttc 1 76120)))
((Corsiva\ Hebrew Regular) ((Corsiva.ttf 0 40340) (Corsiva.ttc 0 71784) (Corsiva.ttc 0 76120)))
((Countries\ of\ Europe Regular) ((countriesofeurope.otf 0 94696)))
((Courier\ New Bold) ((Courier\ New\ Bold.ttf 0 691796) (courbd.ttf 0 312920) (courbd.ttf 0 805244)))
((Courier\ New Bold\ Italic) ((Courier\ New\ Bold\ Italic.ttf 0 506640) (courbi.ttf 0 236148) (courbi.ttf 0 577488)))
((Courier\ New Italic) ((Courier\ New\ Italic.ttf 0 589900) (couri.ttf 0 245032) (couri.ttf 0 667440)))
((Courier\ New Regular) ((Courier\ New.ttf 0 684624) (cour.ttf 0 303296) (cour.ttf 0 806504)))
((Crimson Bold) ((Crimson-Bold.otf 0 131984)))
((Crimson BoldItalic) ((Crimson-BoldItalic.otf 0 99020)))
((Crimson Italic) ((Crimson-Italic.otf 0 167364)))
((Crimson Roman) ((Crimson-Roman.otf 0 194244)))
((Crimson Semibold) ((Crimson-Semibold.otf 0 71012)))
((Crimson SemiboldItalic) ((Crimson-SemiboldItalic.otf 0 68816)))
((Crimson\ Pro Black) ((CrimsonPro-Black.ttf 0 110240)))
((Crimson\ Pro Black\ Italic) ((CrimsonPro-BlackItalic.ttf 0 111500)))
((Crimson\ Pro Bold) ((CrimsonPro-Bold.ttf 0 109280)))
((Crimson\ Pro Bold\ Italic) ((CrimsonPro-BoldItalic.ttf 0 110852)))
((Crimson\ Pro ExtraBold) ((CrimsonPro-ExtraBold.ttf 0 109868)))
((Crimson\ Pro ExtraBold\ Italic) ((CrimsonPro-ExtraBoldItalic.ttf 0 111332)))
((Crimson\ Pro Italic) ((CrimsonPro-Italic.ttf 0 111032) (CrimsonPro-MediumItalic.ttf 0 110848)))
((Crimson\ Pro Light) ((CrimsonPro-Light.ttf 0 109552)))
((Crimson\ Pro Light\ Italic) ((CrimsonPro-LightItalic.ttf 0 111452)))
((Crimson\ Pro Regular) ((CrimsonPro-Medium.ttf 0 109144) (CrimsonPro-Regular.ttf 0 109292)))
((Crimson\ Pro SemiBold) ((CrimsonPro-SemiBold.ttf 0 109268)))
((Crimson\ Pro SemiBold\ Italic) ((CrimsonPro-SemiBoldItalic.ttf 0 110896)))
((Crimson\ Pro\ ExtraLight Italic) ((CrimsonPro-ExtraLightItalic.ttf 0 111388)))
((Crimson\ Pro\ ExtraLight Regular) ((CrimsonPro-ExtraLight.ttf 0 109316)))
((Cuprum Bold) ((Cuprum-Bold.ttf 0 100172)))
((Cuprum Bold\ Italic) ((Cuprum-BoldItalic.ttf 0 96188)))
((Cuprum Italic) ((Cuprum-Italic.ttf 0 96400)))
((Cuprum Regular) ((Cuprum-Regular.ttf 0 100608)))
((Cyen Regular) ((Cyen.ttf 0 9580)))
((Cyklop Italic) ((cyklop-italic.otf 0 111308)))
((Cyklop Regular) ((cyklop-regular.otf 0 112248)))
((Damascus Bold) ((Damascus.ttc 6 1973380) (Damascus.ttc 1 516276) (Damascus.ttc 6 3027948)))
((Damascus Light) ((Damascus.ttc 2 1973380) (Damascus.ttc 2 3027948)))
((Damascus Medium) ((Damascus.ttc 4 1973380) (Damascus.ttc 4 3027948)))
((Damascus Regular) ((Damascus.ttc 0 1973380) (Damascus.ttc 0 516276) (Damascus.ttc 0 3027948)))
((Damascus Semi\ Bold) ((Damascus.ttc 8 1973380) (Damascus.ttc 8 3027948)))
((Damascus\ PUA Bold) ((Damascus.ttc 7 1973380) (Damascus.ttc 7 3027948)))
((Damascus\ PUA Light) ((Damascus.ttc 3 1973380) (Damascus.ttc 3 3027948)))
((Damascus\ PUA Medium) ((Damascus.ttc 5 1973380) (Damascus.ttc 5 3027948)))
((Damascus\ PUA Regular) ((Damascus.ttc 1 1973380) (Damascus.ttc 1 3027948)))
((Damascus\ PUA Semi\ Bold) ((Damascus.ttc 9 1973380) (Damascus.ttc 9 3027948)))
((Dante Bold) ((DANTE-Bold.otf 0 16920)))
((Dante Bold-Italic) ((DANTE-Bold-Italic.otf 0 15544)))
((Dante Italic) ((DANTE-Italic.otf 0 15444)))
((Dante Normal) ((DANTE.otf 0 15324)))
((Dark\ Garden Regular) ((DarkGardenMK.ttf 0 62236)))
((Dear\ Joe\ Four Regular) ((DearJoe.ttc 0 1542160)))
((Dear\ Joe\ Four Small) ((DearJoe.ttc 1 1542160)))
((Dear\ Joe\ Four Small\ Semibold) ((DearJoe.ttc 2 1542160)))
((DecoType\ Naskh Regular) ((DecoTypeNaskh.ttf 0 67608) (DecoTypeNaskh.ttc 0 94656) (DecoTypeNaskh.ttf 0 67956) (DecoTypeNaskh.ttc 0 97544)))
((DecoType\ Naskh\ PUA Regular) ((DecoTypeNaskh.ttc 1 94656) (DecoTypeNaskh.ttc 1 97544)))
((DejaVu\ Sans Bold) ((DejaVuSans-Bold.ttf 0 584396) (DejaVuSans-Bold.ttf 0 672300) (DejaVuSans-Bold.ttf 0 693876)))
((DejaVu\ Sans Bold\ Condensed) ((DejaVuSansCondensed-Bold.ttf 0 545712)))
((DejaVu\ Sans Bold\ Condensed\ Oblique) ((DejaVuSansCondensed-BoldOblique.ttf 0 493756)))
((DejaVu\ Sans Bold\ Oblique) ((DejaVuSans-BoldOblique.ttf 0 524624) (DejaVuSans-BoldOblique.ttf 0 611212) (DejaVuSans-BoldOblique.ttf 0 632168)))
((DejaVu\ Sans Book) ((DejaVuSans.ttf 0 633604) (DejaVuSans.ttf 0 720012) (DejaVuSans.ttf 0 741536)))
((DejaVu\ Sans Condensed\ Bold) ((DejaVuSansCondensed-Bold.ttf 0 545712) (DejaVuSansCondensed-Bold.ttf 0 631992) (DejaVuSansCondensed-Bold.ttf 0 653336)))
((DejaVu\ Sans Condensed\ Bold\ Oblique) ((DejaVuSansCondensed-BoldOblique.ttf 0 493756) (DejaVuSansCondensed-BoldOblique.ttf 0 580168) (DejaVuSansCondensed-BoldOblique.ttf 0 600936)))
((DejaVu\ Sans Condensed\ Book) ((DejaVuSansCondensed.ttf 0 555944) (DejaVuSansCondensed.ttf 0 643852) (DejaVuSansCondensed.ttf 0 664972)))
((DejaVu\ Sans Condensed\ Oblique) ((DejaVuSansCondensed-Oblique.ttf 0 489032) (DejaVuSansCondensed-Oblique.ttf 0 576004) (DejaVuSansCondensed-Oblique.ttf 0 596596)))
((DejaVu\ Sans ExtraLight) ((DejaVuSans-ExtraLight.ttf 0 329444)))
((DejaVu\ Sans Light\ ExtraLight) ((DejaVuSans-ExtraLight.ttf 0 329444) (DejaVuSans-ExtraLight.ttf 0 345208) (DejaVuSans-ExtraLight.ttf 0 352492)))
((DejaVu\ Sans Oblique) ((DejaVuSans-Oblique.ttf 0 524396) (DejaVuSans-Oblique.ttf 0 611556) (DejaVuSans-Oblique.ttf 0 632416)))
((DejaVu\ Sans\ Mono Bold) ((DejaVuSansMono-Bold.ttf 0 302868) (DejaVuSansMono-Bold.ttf 0 313856) (DejaVuSansMono-Bold.ttf 0 318392)))
((DejaVu\ Sans\ Mono Bold\ Oblique) ((DejaVuSansMono-BoldOblique.ttf 0 224160) (DejaVuSansMono-BoldOblique.ttf 0 235848) (DejaVuSansMono-BoldOblique.ttf 0 239876)))
((DejaVu\ Sans\ Mono Book) ((DejaVuSansMono.ttf 0 322524) (DejaVuSansMono.ttf 0 333636) (DejaVuSansMono.ttf 0 335068)))
((DejaVu\ Sans\ Mono Oblique) ((DejaVuSansMono-Oblique.ttf 0 230244) (DejaVuSansMono-Oblique.ttf 0 241972) (DejaVuSansMono-Oblique.ttf 0 245948)))
((DejaVu\ Serif Bold) ((DejaVuSerif-Bold.ttf 0 307596) (DejaVuSerif-Bold.ttf 0 341072) (DejaVuSerif-Bold.ttf 0 345364)))
((DejaVu\ Serif Bold\ Condensed) ((DejaVuSerifCondensed-Bold.ttf 0 283140)))
((DejaVu\ Serif Bold\ Condensed\ Italic) ((DejaVuSerifCondensed-BoldItalic.ttf 0 294584)))
((DejaVu\ Serif Bold\ Italic) ((DejaVuSerif-BoldItalic.ttf 0 295360) (DejaVuSerif-BoldItalic.ttf 0 332036) (DejaVuSerif-BoldItalic.ttf 0 336884)))
((DejaVu\ Serif Book) ((DejaVuSerif.ttf 0 330052) (DejaVuSerif.ttf 0 363200) (DejaVuSerif.ttf 0 367260)))
((DejaVu\ Serif Condensed\ Bold) ((DejaVuSerifCondensed-Bold.ttf 0 283140) (DejaVuSerifCondensed-Bold.ttf 0 316440) (DejaVuSerifCondensed-Bold.ttf 0 320720)))
((DejaVu\ Serif Condensed\ Bold\ Italic) ((DejaVuSerifCondensed-BoldItalic.ttf 0 294584) (DejaVuSerifCondensed-BoldItalic.ttf 0 331128) (DejaVuSerifCondensed-BoldItalic.ttf 0 335940)))
((DejaVu\ Serif Condensed\ Book) ((DejaVuSerifCondensed.ttf 0 296976) (DejaVuSerifCondensed.ttf 0 330012) (DejaVuSerifCondensed.ttf 0 334040)))
((DejaVu\ Serif Condensed\ Italic) ((DejaVuSerifCondensed-Italic.ttf 0 302444) (DejaVuSerifCondensed-Italic.ttf 0 338140) (DejaVuSerifCondensed-Italic.ttf 0 342736)))
((DejaVu\ Serif Italic) ((DejaVuSerif-Italic.ttf 0 303004) (DejaVuSerif-Italic.ttf 0 338776) (DejaVuSerif-Italic.ttf 0 343388)))
((Delius Regular) ((Delius-Regular.ttf 0 77488)))
((Delius\ Swash\ Caps Regular) ((DeliusSwashCaps-Regular.ttf 0 63052)))
((Delius\ Unicase Bold) ((DeliusUnicase-Bold.ttf 0 36120)))
((Delius\ Unicase Regular) ((DeliusUnicase-Regular.ttf 0 32904)))
((Denise Regular) ((Denise_Handwriting.ttf 0 49788)))
((Designer\ Notes Bold) ((Designer-Notes-Bold.ttf 0 49748)))
((Designer\ Notes Regular) ((Designer-Notes.ttf 0 62808)))
((Devanagari\ MT Bold) ((DevanagariMTBold.ttf 0 315620) (DevanagariMT.ttc 1 406212) (DevanagariMT.ttc 1 409696)))
((Devanagari\ MT Regular) ((DevanagariMT.ttf 0 332324) (DevanagariMT.ttc 0 406212) (DevanagariMT.ttc 0 409696)))
((Devanagari\ Sangam\ MN Bold) ((Devanagari\ Sangam\ MN.ttc 1 695000) (Devanagari\ Sangam\ MN.ttc 1 672836) (Devanagari\ Sangam\ MN.ttc 1 1027920)))
((Devanagari\ Sangam\ MN Regular) ((Devanagari\ Sangam\ MN.ttc 0 695000) (Devanagari\ Sangam\ MN.ttc 0 672836) (Devanagari\ Sangam\ MN.ttc 0 1027920)))
((Didot Bold) ((Didot.ttc 2 352960) (Didot.ttc 2 712936) (Didot.ttc 2 352996) (Didot.ttc 2 722884)))
((Didot Italic) ((Didot.ttc 1 352960) (Didot.ttc 1 712936) (Didot.ttc 1 352996) (Didot.ttc 1 722884)))
((Didot Regular) ((Didot.ttc 0 352960) (Didot.ttc 0 712936) (Didot.ttc 0 352996) (Didot.ttc 0 722884)))
((Dijla Regular) ((Dijla.ttc 0 59588)))
((Dijla\ PUA Regular) ((Dijla.ttc 1 59588)))
((Din Condensed\ Bold) ((DIN\ Condensed\ Bold.ttf 0 82260) (DIN\ Condensed\ Bold.ttf 0 211528) (DIN\ Condensed\ Bold.ttf 0 211644)))
((DIN\ Alternate Bold) ((DIN\ Alternate\ Bold.ttf 0 147024) (DIN\ Alternate\ Bold.ttf 0 76716) (DIN\ Alternate\ Bold.ttf 0 151528)))
((Dinosaur\ Skin Regular) ((Dinosaur\ Skin.ttf 0 101328)))
((Diwan\ Kufi Regular) ((Diwan\ Kufi.ttc 0 90540) (Diwan\ Kufi.ttc 0 93724)))
((Diwan\ Kufi\ PUA Regular) ((Diwan\ Kufi.ttc 1 90540) (Diwan\ Kufi.ttc 1 93724)))
((Diwan\ Thuluth Regular) ((Diwan\ Thuluth.ttf 0 1318280) (Diwan\ Thuluth.ttf 0 1319880)))
((Domitian Bold) ((Domitian-Bold.otf 0 121584)))
((Domitian Bold\ Italic) ((Domitian-BoldItalic.otf 0 124996)))
((Domitian Italic) ((Domitian-Italic.otf 0 122760)))
((Domitian Roman) ((Domitian-Roman.otf 0 163516)))
((Doris\ PP bold) ((DORISBR.ttf 0 33980)))
((Double\ Strike Regular) ((Double\ Strike.ttf 0 60156) (DoubleStrike.otf 0 27864)))
((Doulos\ SIL Regular) ((DoulosSILR.ttf 0 1721928)))
((Droid\ Sans Bold) ((DroidSans-Bold.ttf 0 194488) (DroidSans-Bold.ttf 0 191032)))
((Droid\ Sans Regular) ((DroidSans.ttf 0 190776) (DroidSans.ttf 0 190044)))
((Droid\ Sans\ Mono Regular) ((DroidSansMono.ttf 0 119380) (DroidSansMono.ttf 0 117072)))
((Droid\ Serif Bold) ((DroidSerif-Bold.ttf 0 185228) (DroidSerif-Bold.ttf 0 184836) (DroidSerif-Bold.ttf 0 249880)))
((Droid\ Serif Bold\ Italic) ((DroidSerif-BoldItalic.ttf 0 190304) (DroidSerif-BoldItalic.ttf 0 189916) (DroidSerif-BoldItalic.ttf 0 265008)))
((Droid\ Serif Italic) ((DroidSerif-Italic.ttf 0 177560) (DroidSerif-Italic.ttf 0 177176) (DroidSerif-Italic.ttf 0 251944)))
((Droid\ Serif Regular) ((DroidSerif-Regular.ttf 0 172916) (DroidSerif-Regular.ttf 0 172532) (DroidSerif-Regular.ttf 0 248904)))
((Druk Bold) ((Druk.ttc 0 2620560)))
((Druk Bold\ Italic) ((Druk.ttc 1 2620560)))
((Druk Bold\ Wide) ((Druk.ttc 11 2620560)))
((Druk Heavy) ((Druk.ttc 2 2620560)))
((Druk Heavy\ Italic) ((Druk-HeavyItalic.ttf 0 227844) (Druk.ttc 3 2620560)))
((Druk Italic\ Bold\ Wide) ((Druk.ttc 12 2620560)))
((Druk Medium) ((Druk.ttc 4 2620560)))
((Druk Medium\ Italic) ((Druk.ttc 5 2620560)))
((Druk Super) ((Druk.ttc 6 2620560)))
((Druk Super\ Italic) ((Druk.ttc 7 2620560)))
((Druk Wide\ Medium) ((DrukWide-Medium.ttf 0 173364) (Druk.ttc 9 2620560)))
((Druk Wide\ Medium\ Italic) ((Druk.ttc 10 2620560)))
((Druk\ Text Bold) ((DrukText-Bold.ttf 0 180396) (Druk.ttc 8 2620560)))
((DuCahier\ xp Regular) ((TASSELXP.ttf 0 75512)))
((Dufay Normal) ((Dufay.ttf 0 44528)))
((Dustismo \ Bold) ((dustismo_bold.ttf 0 53168)))
((Dustismo \ Bold\ Italic) ((dustismo_bold_italic.ttf 0 62716)))
((Dustismo \ Italic) ((dustismo_italic.ttf 0 60948)))
((Dustismo Regular) ((Dustismo.ttf 0 52352)))
((Dustismo\ Roman Bold) ((Dustismo_Roman_Bold.ttf 0 61560)))
((Dustismo\ Roman Bold\ Italic) ((Dustismo_Roman_Italic_Bold.ttf 0 65524)))
((Dustismo\ Roman Italic) ((Dustismo_Roman_Italic.ttf 0 83048)))
((Dustismo\ Roman Regular) ((Dustismo_Roman.ttf 0 105340)))
((EB\ Garamond Bold) ((EBGaramond-Bold.otf 0 447000)))
((EB\ Garamond Bold\ Italic) ((EBGaramond-BoldItalic.otf 0 429484)))
((EB\ Garamond ExtraBold) ((EBGaramond-ExtraBold.otf 0 430508)))
((EB\ Garamond ExtraBold\ Italic) ((EBGaramond-ExtraBoldItalic.otf 0 416208)))
((EB\ Garamond Italic) ((EBGaramond-Italic.otf 0 398180)))
((EB\ Garamond Medium) ((EBGaramond-Medium.otf 0 450056)))
((EB\ Garamond Medium\ Italic) ((EBGaramond-MediumItalic.otf 0 429904)))
((EB\ Garamond Regular) ((EBGaramond-Regular.otf 0 404984)))
((EB\ Garamond SemiBold) ((EBGaramond-SemiBold.otf 0 446180)))
((EB\ Garamond SemiBold\ Italic) ((EBGaramond-SemiBoldItalic.otf 0 429620)))
((EB\ Garamond\ 12 Italic) ((EBGaramond12-Italic.ttf 0 508748)))
((EB\ Garamond\ 12 Regular) ((EBGaramond12-Regular.ttf 0 625440)))
((EB\ Garamond\ Initials Regular) ((EBGaramond-Initials.ttf 0 245764) (EBGaramond-Initials.otf 0 78512)))
((Ebrima Bold) ((ebrimabd.ttf 0 916908)))
((Ebrima Regular) ((ebrima.ttf 0 907232)))
((Elvifrance Regular) ((elvifrance.ttf 0 29928)))
((Erewhon Bold) ((Erewhon-Bold.otf 0 211228) (Erewhon-Bold.otf 0 217232)))
((Erewhon Bold\ Italic) ((Erewhon-BoldItalic.otf 0 189772) (Erewhon-BoldSlanted.otf 0 211232) (Erewhon-BoldItalic.otf 0 196368) (Erewhon-BoldSlanted.otf 0 218540)))
((Erewhon Italic) ((Erewhon-Italic.otf 0 187052) (Erewhon-RegularSlanted.otf 0 234744) (Erewhon-Italic.otf 0 193556) (Erewhon-RegularSlanted.otf 0 241284)))
((Erewhon Regular) ((Erewhon-Regular.otf 0 232372) (Erewhon-Regular.otf 0 239008)))
((Erewhon\ Math Regular) ((Erewhon-Math.otf 0 288048)))
((Essays1743 Bold) ((Essays1743-Bold.ttf 0 99788)))
((Essays1743 BoldItalic) ((Essays1743-BoldItalic.ttf 0 105300)))
((Essays1743 Italic) ((Essays1743-Italic.ttf 0 105124)))
((Essays1743 Medium) ((Essays1743.ttf 0 100660)))
((Estrangelo\ Edessa Regular) ((estre.ttf 0 79744)))
((ETbb Bold) ((ETbb-Bold.otf 0 111076)))
((ETbb BoldItalic) ((ETbb-BoldItalic.otf 0 105416)))
((ETbb Italic) ((ETbb-Italic.otf 0 98784)))
((ETbb Regular) ((ETbb-Regular.otf 0 111704)))
((Euphemia\ UCAS Bold) ((EuphemiaCASBold.ttf 0 175864) (EuphemiaCAS.ttc 1 550984) (EuphemiaCAS.ttc 1 547808) (EuphemiaCAS.ttc 1 534712) (EuphemiaCAS.ttc 1 543868)))
((Euphemia\ UCAS Italic) ((EuphemiaCASItalic.ttf 0 191116) (EuphemiaCAS.ttc 2 550984) (EuphemiaCAS.ttc 2 547808) (EuphemiaCAS.ttc 2 534712) (EuphemiaCAS.ttc 2 543868)))
((Euphemia\ UCAS Regular) ((EuphemiaCASRegular.ttf 0 212724) (EuphemiaCAS.ttc 0 550984) (EuphemiaCAS.ttc 0 547808) (EuphemiaCAS.ttc 0 534712) (EuphemiaCAS.ttc 0 543868)))
((EvilClown Regular) ((EVILCLOW.ttf 0 23244)))
((Fandol\ Braille\ Display Regular) ((FandolBraille-Display.otf 0 26072)))
((Fandol\ Braille\ Regular Regular) ((FandolBraille-Regular.otf 0 12484)))
((FandolFang Regular) ((FandolFang-Regular.otf 0 6148948)))
((FandolFang\ R Regular) ((FandolFang-Regular.otf 0 6961384)))
((FandolHei Bold) ((FandolHei-Bold.otf 0 3910356) (FandolHei-Bold.otf 0 3581972)))
((FandolHei Regular) ((FandolHei-Regular.otf 0 5102424) (FandolHei-Regular.otf 0 5808908)))
((FandolKai Regular) ((FandolKai-Regular.otf 0 6583228) (FandolKai-Regular.otf 0 7790552)))
((FandolSong Bold) ((FandolSong-Bold.otf 0 5194124) (FandolSong-Bold.otf 0 5777588)))
((FandolSong Regular) ((FandolSong-Regular.otf 0 3973332) (FandolSong-Regular.otf 0 4947904)))
((FangSong_GB2312 Regular) ((simfang.ttf 0 3996872)))
((Farah Regular) ((Farah.ttc 0 88452) (Farah.ttc 0 91112)))
((Farah\ PUA Regular) ((Farah.ttc 1 88452) (Farah.ttc 1 91112)))
((Farisi Regular) ((Farisi.ttf 0 279940) (Farisi.ttf 0 281512)))
((Fava Black) ((Fava-black.ttf 0 119888)))
((Fbb Bold) ((fbb-Bold.otf 0 131604)))
((Fbb Bold\ Italic) ((fbb-BoldItalic.otf 0 127100)))
((Fbb Italic) ((fbb-Italic.otf 0 137952)))
((Fbb Regular) ((fbb-Regular.otf 0 134068)))
((FdSymbol Bold) ((FdSymbol-Bold.otf 0 122904)))
((FdSymbol Book) ((FdSymbol-Book.otf 0 124088)))
((FdSymbol Medium) ((FdSymbol-Medium.otf 0 123980)))
((FdSymbol Regular) ((FdSymbol-Regular.otf 0 123676)))
((Fedorovsk\ Unicode Medium) ((FedorovskUnicode.otf 0 183532)))
((Fedorovsk\ Unicode\ TT Medium) ((FedorovskUnicode.ttf 0 320656)))
((Fira\ Math Regular) ((FiraMath-Regular.otf 0 152644)))
((Fira\ Mono Bold) ((FiraMono-Bold.otf 0 128404) (FiraMono-Bold.otf 0 138776)))
((Fira\ Mono BoldOblique) ((FiraMono-BoldOblique.otf 0 206760)))
((Fira\ Mono Medium) ((FiraMono-Medium.otf 0 126700)))
((Fira\ Mono Oblique) ((FiraMono-Oblique.otf 0 202164)))
((Fira\ Mono Regular) ((FiraMono-Regular.otf 0 125128) (FiraMono-Medium.otf 0 135288) (FiraMono-MediumOblique.otf 0 202752) (FiraMono-Regular.otf 0 134144)))
((Fira\ Sans Bold) ((FiraSans-Bold.otf 0 369296) (FiraSans-Bold.otf 0 521796)))
((Fira\ Sans Bold\ Italic) ((FiraSans-BoldItalic.otf 0 377540) (FiraSans-BoldItalic.otf 0 536828)))
((Fira\ Sans Book) ((FiraSans-Book.otf 0 359960) (FiraSans-Book.otf 0 505808)))
((Fira\ Sans Book\ Italic) ((FiraSans-BookItalic.otf 0 369000) (FiraSans-BookItalic.otf 0 524316)))
((Fira\ Sans ExtraBold) ((FiraSans-ExtraBold.otf 0 370488) (FiraSans-ExtraBold.otf 0 522992)))
((Fira\ Sans ExtraBold\ Italic) ((FiraSans-ExtraBoldItalic.otf 0 377028) (FiraSans-ExtraBoldItalic.otf 0 538016)))
((Fira\ Sans ExtraLight) ((FiraSans-ExtraLight.otf 0 359088) (FiraSans-ExtraLight.otf 0 505316)))
((Fira\ Sans ExtraLight\ Italic) ((FiraSans-ExtraLightItalic.otf 0 365936) (FiraSans-ExtraLightItalic.otf 0 522480)))
((Fira\ Sans Heavy) ((FiraSans-Heavy.otf 0 366400) (FiraSans-Heavy.otf 0 522316)))
((Fira\ Sans Heavy\ Italic) ((FiraSans-HeavyItalic.otf 0 377184) (FiraSans-HeavyItalic.otf 0 539708)))
((Fira\ Sans Italic) ((FiraSans-Italic.otf 0 367488) (FiraSans-Italic.otf 0 524840)))
((Fira\ Sans Light) ((FiraSans-Light.otf 0 359048) (FiraSans-Light.otf 0 505308)))
((Fira\ Sans Light\ Italic) ((FiraSans-LightItalic.otf 0 366088) (FiraSans-LightItalic.otf 0 522236)))
((Fira\ Sans Medium) ((FiraSans-Medium.otf 0 366052) (FiraSans-Medium.otf 0 514220)))
((Fira\ Sans Medium\ Italic) ((FiraSans-MediumItalic.otf 0 374076) (FiraSans-MediumItalic.otf 0 529328)))
((Fira\ Sans Regular) ((FiraSans-Regular.otf 0 357996) (FiraSans-Regular.otf 0 507828)))
((Fira\ Sans SemiBold) ((FiraSans-SemiBold.otf 0 367408) (FiraSans-SemiBold.otf 0 516884)))
((Fira\ Sans SemiBold\ Italic) ((FiraSans-SemiBoldItalic.otf 0 374548) (FiraSans-SemiBoldItalic.otf 0 532016)))
((Fira\ Sans Thin) ((FiraSans-Thin.otf 0 353880) (FiraSans-Thin.otf 0 504384)))
((Fira\ Sans Thin\ Italic) ((FiraSans-ThinItalic.otf 0 361200) (FiraSans-ThinItalic.otf 0 519864)))
((Fira\ Sans UltraLight) ((FiraSans-UltraLight.otf 0 356884) (FiraSans-UltraLight.otf 0 504696)))
((Fira\ Sans UltraLight\ Italic) ((FiraSans-UltraLightItalic.otf 0 364952) (FiraSans-UltraLightItalic.otf 0 522424)))
((Foglihten Regular) ((Foglihten-068.otf 0 390372)))
((FoglihtenBlackPcs BlackPcs) ((FoglihtenBlackPcs.otf 0 294832)))
((FoglihtenBPS01 Regular) ((FogBPS01.otf 0 18556)))
((FoglihtenFr01 Regular) ((FoglihtenFr01.otf 0 81340)))
((FoglihtenFr02 Regular) ((FoglihtenFr02.otf 0 100288)))
((FoglihtenNo01 Regular) ((FoglihtenNo01.otf 0 220820)))
((FoglihtenNo03 Regular) ((FoglihtenNo03.otf 0 219980)))
((FoglihtenNo04 Regular) ((FoglihtenNo04-070.otf 0 372592)))
((FoglihtenNo06 Regular) ((FoglihtenNo06.otf 0 343752)))
((FoglihtenPCS Petitecaps) ((FoglihtenPCS-068.otf 0 194132)))
((Font\ Awesome\ 5\ Brands\ Regular Regular) ((FontAwesome5Brands-Regular-400.otf 0 176972)))
((Font\ Awesome\ 5\ Free\ Regular Regular) ((FontAwesome5Free-Regular-400.otf 0 55132)))
((Font\ Awesome\ 5\ Free\ Solid Solid) ((FontAwesome5Free-Solid-900.otf 0 299424)))
((Font-mfizz mfizz) ((font-mfizz.ttf 0 63584)))
((FontAwesome Regular) ((FontAwesome.otf 0 132548)))
((Forgotten\ Futurist Bold) ((ForgottenFuturist.ttc 2 1256668)))
((Forgotten\ Futurist Bold\ Italic) ((ForgottenFuturist.ttc 3 1256668)))
((Forgotten\ Futurist Italic) ((ForgottenFuturist.ttc 1 1256668)))
((Forgotten\ Futurist Regular) ((ForgottenFuturist.ttc 0 1256668)))
((Forgotten\ Futurist Shadow) ((ForgottenFuturist.ttc 4 1256668)))
((Forum Regular) ((Forum-Bold.ttf 0 215332) (Forum-Regular.ttf 0 241080)))
((Foulis\ Greek Regular) ((FoulisGreek.ttf 0 267884)))
((FourierOrns Bold) ((FourierOrns-Bold.otf 0 31388)))
((FourierOrns BoldItalic) ((FourierOrns-BoldItalic.otf 0 31612)))
((FourierOrns Italic) ((FourierOrns-Italic.otf 0 31544)))
((FourierOrns Regular) ((FourierOrns-Regular.otf 0 31436)))
((Franklin\ Gothic Italic) ((framdit.ttf 0 152844) (framdit.ttf 0 148728)))
((Franklin\ Gothic Regular) ((framd.ttf 0 135984) (framd.ttf 0 133632)))
((Frederika2016 Normal) ((Frederika2016.otf 0 89864)))
((FreeMono Bold) ((FreeMonoBold.ttf 0 165028) (FreeMonoBold.ttf 0 296284) (FreeMonoBold.ttf 0 173608) (FreeMonoBold.otf 0 203376)))
((FreeMono Bold\ Oblique) ((FreeMonoBoldOblique.ttf 0 295360) (FreeMonoBoldOblique.otf 0 194716)))
((FreeMono BoldOblique) ((FreeMonoBoldOblique.ttf 0 145836) (FreeMonoBoldOblique.ttf 0 169936)))
((FreeMono Medium) ((FreeMono.ttf 0 314936) (FreeMono.ttf 0 343980)))
((FreeMono Oblique) ((FreeMonoOblique.ttf 0 197400) (FreeMonoOblique.ttf 0 390692) (FreeMonoOblique.ttf 0 208128) (FreeMonoOblique.otf 0 245408)))
((FreeMono Regular) ((FreeMono.ttf 0 584424) (FreeMono.otf 0 430884)))
((FreeSans Bold) ((FreeSansBold.ttf 0 172584) (FreeSansBold.ttf 0 416128) (FreeSansBold.ttf 0 359272) (FreeSansBold.otf 0 305436)))
((FreeSans Bold\ Oblique) ((FreeSansBoldOblique.ttf 0 342488) (FreeSansBoldOblique.otf 0 233476)))
((FreeSans BoldOblique) ((FreeSansBoldOblique.ttf 0 159048) (FreeSansBoldOblique.ttf 0 301188)))
((FreeSans Medium) ((FreeSans.ttf 0 460384) (FreeSans.ttf 0 714456)))
((FreeSans Oblique) ((FreeSansOblique.ttf 0 301100) (FreeSansOblique.ttf 0 763696) (FreeSansOblique.ttf 0 441432) (FreeSansOblique.otf 0 473976)))
((FreeSans Regular) ((FreeSans.ttf 0 1563256) (FreeSans.otf 0 856800)))
((FreeSerif Bold) ((FreeSerifBold.ttf 0 268612) (FreeSerifBold.ttf 0 1310828) (FreeSerifBold.ttf 0 615292) (FreeSerifBold.otf 0 954748)))
((FreeSerif Bold\ Italic) ((FreeSerifBoldItalic.ttf 0 608708) (FreeSerifBoldItalic.otf 0 425684)))
((FreeSerif BoldItalic) ((FreeSerifBoldItalic.ttf 0 241576) (FreeSerifBoldItalic.ttf 0 508412)))
((FreeSerif Italic) ((FreeSerifItalic.ttf 0 410068) (FreeSerifItalic.ttf 0 922088) (FreeSerifItalic.ttf 0 691448) (FreeSerifItalic.otf 0 597888)))
((FreeSerif Medium) ((FreeSerif.ttf 0 1288080) (FreeSerif.ttf 0 1687516)))
((FreeSerif Regular) ((FreeSerif.ttf 0 3303588) (FreeSerif.otf 0 2047320)))
((FreeSerifb Bold) ((FreeSerifbBold.otf 0 238036)))
((FreeSerifb BoldItalic) ((FreeSerifbBoldItalic.otf 0 229904)))
((FreeSerifb Italic) ((FreeSerifbItalic.otf 0 380040)))
((FreeSerifb Medium) ((FreeSerifb.otf 0 1080064)))
((FreeSerifb SmallCaps) ((FreeSerifb-SmallCaps.otf 0 26444)))
((FreeSerifb SmallCapsAlt) ((FreeSerifb-SmallCapsAlt.otf 0 27036)))
((Futura Bold) ((Futura.ttc 2 486592) (Futura.ttc 2 488604)))
((Futura Condensed\ ExtraBold) ((Futura.ttc 3 321740) (Futura.ttc 3 288740) (Futura.ttc 3 315748) (Futura.ttc 4 486592) (Futura.ttc 4 488604)))
((Futura Condensed\ Medium) ((Futura.ttc 2 321740) (Futura.ttc 2 288740) (Futura.ttc 2 315748) (Futura.ttc 3 486592) (Futura.ttc 3 488604)))
((Futura Medium) ((Futura.ttc 0 321740) (Futura.ttc 0 288740) (Futura.ttc 0 315748) (Futura.ttc 0 486592) (Futura.ttc 0 488604)))
((Futura Medium\ Italic) ((Futura.ttc 1 321740) (Futura.ttc 1 288740) (Futura.ttc 1 315748) (Futura.ttc 1 486592) (Futura.ttc 1 488604)))
((Gabriola Regular) ((Gabriola.ttf 0 1806004)))
((Gadugi Bold) ((gadugib.ttf 0 244912)))
((Gadugi Regular) ((gadugi.ttf 0 247240)))
((Galberik Regular) ((Galberik.otf 0 198496)))
((Galvji Bold) ((Galvji.ttc 1 430932)))
((Galvji Bold\ Oblique) ((Galvji.ttc 3 430932)))
((Galvji Oblique) ((Galvji.ttc 2 430932)))
((Galvji Regular) ((Galvji.ttc 0 430932)))
((Garamond Bold) ((Garamond.ttc 1 731976)))
((Garamond Bold\ Italic) ((Garamond.ttc 3 731976)))
((Garamond Italic) ((Garamond.ttc 2 731976)))
((Garamond Regular) ((Garamond.ttc 0 731976)))
((Garamond\ Libre Bold) ((GaramondLibre-Bold.otf 0 684492)))
((Garamond\ Libre Italic) ((GaramondLibre-Italic.otf 0 654884)))
((Garamond\ Libre Regular) ((GaramondLibre-Regular.otf 0 715780)))
((Garamond-Math Regular) ((Garamond-Math.otf 0 804812)))
((Gargi Medium) ((gargi.ttf 0 72500)))
((Garineldo Regular) ((Garineldo.otf 0 362280)))
((GarineldoNo01 Regular) ((GarineldoNo01.otf 0 387028)))
((GarineldoNo02 Regular) ((GarineldoNo02.otf 0 430552)))
((Garuda Bold) ((Garuda-Bold.ttf 0 76136) (Garuda-Bold.otf 0 44472)))
((Garuda BoldOblique) ((Garuda-BoldOblique.ttf 0 87180) (Garuda-BoldOblique.otf 0 46852)))
((Garuda Book) ((Garuda.ttf 0 74876)))
((Garuda Oblique) ((Garuda-Oblique.ttf 0 87788) (Garuda-Oblique.otf 0 46064)))
((Garuda Regular) ((Garuda.otf 0 44288)))
((Gatometrix Regular) ((Gatometrix.otf 0 191900)))
((Gautami Regular) ((gautami.ttf 0 214936)))
((Gears\ of\ Peace Regular) ((GearsOfPeace.ttf 0 19628)))
((Geeza\ Pro Bold) ((Geeza\ Pro\ Bold.ttf 0 169244) (GeezaPro.ttc 1 994932) (Geeza\ Pro\ Bold.ttf 0 272984) (GeezaPro.ttc 1 1018224)))
((Geeza\ Pro Regular) ((Geeza\ Pro.ttf 0 168796) (GeezaPro.ttc 0 994932) (Geeza\ Pro.ttf 0 271732) (GeezaPro.ttc 0 1018224)))
((Geeza\ Pro\ Interface Bold) ((GeezaPro.ttc 3 994932) (GeezaPro.ttc 3 1018224)))
((Geeza\ Pro\ Interface Light) ((GeezaPro.ttc 4 994932) (GeezaPro.ttc 4 1018224)))
((Geeza\ Pro\ Interface Regular) ((GeezaPro.ttc 2 994932) (GeezaPro.ttc 2 1018224)))
((Geeza\ Pro\ PUA Bold) ((GeezaPro.ttc 6 1018224)))
((Geeza\ Pro\ PUA Regular) ((GeezaPro.ttc 5 1018224)))
((Geeza\ PUA Bold) ((GeezaPro.ttc 6 994932)))
((Geeza\ PUA Regular) ((GeezaPro.ttc 5 994932)))
((Gentium Italic) ((GenI102.ttf 0 314476) (Gentium-I.ttf 0 314452)))
((Gentium Regular) ((GenR102.ttf 0 362664) (Gentium-R.ttf 0 362644)))
((Gentium\ Basic Bold) ((GenBasB.ttf 0 271648)))
((Gentium\ Basic Bold\ Italic) ((GenBasBI.ttf 0 250668)))
((Gentium\ Basic Italic) ((GenBasI.ttf 0 263504)))
((Gentium\ Basic Regular) ((GenBasR.ttf 0 269048)))
((Gentium\ Book\ Basic Bold) ((GenBkBasB.ttf 0 271832)))
((Gentium\ Book\ Basic Bold\ Italic) ((GenBkBasBI.ttf 0 249924)))
((Gentium\ Book\ Basic Italic) ((GenBkBasI.ttf 0 266156)))
((Gentium\ Book\ Basic Regular) ((GenBkBasR.ttf 0 272460)))
((Gentium\ Plus Italic) ((GentiumPlus-I.ttf 0 1818280)))
((Gentium\ Plus Regular) ((GentiumPlus-R.ttf 0 1918536)))
((Gentium\ Plus\ Compact Italic) ((GentiumPlusCompact-I.ttf 0 1708008)))
((Gentium\ Plus\ Compact Regular) ((GentiumPlusCompact-R.ttf 0 1740984)))
((GentiumAlt Italic) ((GenAI102.ttf 0 315860) (GentiumAlt-I.ttf 0 315840)))
((GentiumAlt Regular) ((GenAR102.ttf 0 364056) (GentiumAlt-R.ttf 0 364032)))
((Georgia Bold) ((Georgia\ Bold.ttf 0 148768) (georgiab.ttf 0 141032) (Georgia\ Bold.ttf 0 363800) (georgiab.ttf 0 207476)))
((Georgia Bold\ Italic) ((Georgia\ Bold\ Italic.ttf 0 167476) (georgiaz.ttf 0 159736) (Georgia\ Bold\ Italic.ttf 0 385768) (georgiaz.ttf 0 211780)))
((Georgia Italic) ((Georgia\ Italic.ttf 0 165208) (georgiai.ttf 0 157388) (Georgia\ Italic.ttf 0 400624) (georgiai.ttf 0 208444)))
((Georgia Regular) ((Georgia.ttf 0 159656) (georgia.ttf 0 155068) (Georgia.ttf 0 379588) (georgia.ttf 0 219712)))
((GFS\ Artemisia Bold) ((GFSArtemisiaBold.otf 0 118456)))
((GFS\ Artemisia Bold\ Italic) ((GFSArtemisiaBoldIt.otf 0 125116)))
((GFS\ Artemisia Italic) ((GFSArtemisiaIt.otf 0 118604)))
((GFS\ Artemisia Regular) ((GFSArtemisia.otf 0 152904)))
((GFS\ Baskerville Regular) ((GFSBaskerville.otf 0 73168)))
((GFS\ Bodoni Bold) ((GFSBodoniBold.otf 0 117092)))
((GFS\ Bodoni Bold\ Italic) ((GFSBodoniBoldIt.otf 0 102540)))
((GFS\ Bodoni Italic) ((GFSBodoniIt.otf 0 122956)))
((GFS\ Bodoni Regular) ((GFSBodoni.otf 0 142684)))
((GFS\ Complutum Regular) ((GFSPolyglot.otf 0 61524)))
((GFS\ Didot Bold) ((GFSDidotBold.otf 0 99164)))
((GFS\ Didot Bold\ Italic) ((GFSDidotBoldItalic.otf 0 141988)))
((GFS\ Didot Italic) ((GFSDidotItalic.otf 0 142668)))
((GFS\ Didot Regular) ((GFSDidot.otf 0 166580)))
((GFS\ DidotClassic Regular) ((GFSDidot_Classic.otf 0 62784)))
((GFS\ Neohellenic Bold) ((GFSNeohellenicBold.otf 0 91984)))
((GFS\ Neohellenic Bold\ Italic) ((GFSNeohellenicBoldIt.otf 0 103688)))
((GFS\ Neohellenic Italic) ((GFSNeohellenicIt.otf 0 102424)))
((GFS\ Neohellenic Regular) ((GFSNeohellenic.otf 0 122504)))
((GFS\ Neohellenic\ Math Regular) ((GFSNeohellenicMath.otf 0 675772)))
((GFS\ Olga Regular) ((GFSOlga.otf 0 31008)))
((GFS\ Porson Regular) ((GFSPorson.otf 0 30104)))
((GFS\ Solomos Regular) ((GFSSolomos.otf 0 46736)))
((Gill\ Sans Bold) ((GillSans.ttc 1 589392) (GillSans.ttc 1 1220852) (GillSans.ttc 1 603640) (GillSans.ttc 1 1251924) (GillSans.ttc 1 1253700)))
((Gill\ Sans Bold\ Italic) ((GillSans.ttc 2 589392) (GillSans.ttc 3 1220852) (GillSans.ttc 2 603640) (GillSans.ttc 3 1251924) (GillSans.ttc 3 1253700)))
((Gill\ Sans Italic) ((GillSans.ttc 3 589392) (GillSans.ttc 2 1220852) (GillSans.ttc 3 603640) (GillSans.ttc 2 1251924) (GillSans.ttc 2 1253700)))
((Gill\ Sans Light) ((GillSans.ttc 4 589392) (GillSans.ttc 7 1220852) (GillSans.ttc 4 603640) (GillSans.ttc 7 1251924) (GillSans.ttc 7 1253700)))
((Gill\ Sans Light\ Italic) ((GillSans.ttc 5 589392) (GillSans.ttc 8 1220852) (GillSans.ttc 5 603640) (GillSans.ttc 8 1251924) (GillSans.ttc 8 1253700)))
((Gill\ Sans Regular) ((GillSans.ttc 0 589392) (GillSans.ttc 0 1220852) (GillSans.ttc 0 603640) (GillSans.ttc 0 1251924) (GillSans.ttc 0 1253700)))
((Gill\ Sans SemiBold) ((GillSans.ttc 4 1220852) (GillSans.ttc 4 1251924) (GillSans.ttc 4 1253700)))
((Gill\ Sans SemiBold\ Italic) ((GillSans.ttc 5 1220852) (GillSans.ttc 5 1251924) (GillSans.ttc 5 1253700)))
((Gill\ Sans UltraBold) ((GillSans.ttc 6 1220852) (GillSans.ttc 6 1251924) (GillSans.ttc 6 1253700)))
((Gillius\ ADF Bold) ((GilliusADF-Bold.otf 0 37180)))
((Gillius\ ADF Bold\ Italic) ((GilliusADF-BoldItalic.otf 0 38048)))
((Gillius\ ADF Italic) ((GilliusADF-Italic.otf 0 37392)))
((Gillius\ ADF Regular) ((GilliusADF-Regular.otf 0 36488)))
((Gillius\ ADF\ Cond Bold) ((GilliusADFCond-Bold.otf 0 30740)))
((Gillius\ ADF\ Cond Bold\ Italic) ((GilliusADFCond-BoldItalic.otf 0 32092)))
((Gillius\ ADF\ Cond Italic) ((GilliusADFCond-Italic.otf 0 29908)))
((Gillius\ ADF\ Cond Regular) ((GilliusADFCond-Regular.otf 0 30048)))
((Gillius\ ADF\ No2 Bold) ((GilliusADFNo2-Bold.otf 0 37044)))
((Gillius\ ADF\ No2 Bold\ Italic) ((GilliusADFNo2-BoldItalic.otf 0 39812)))
((Gillius\ ADF\ No2 Italic) ((GilliusADFNo2-Italic.otf 0 39280)))
((Gillius\ ADF\ No2 Regular) ((GilliusADFNo2-Regular.otf 0 36280)))
((Gillius\ ADF\ No2\ Cond Bold) ((GilliusADFNo2Cond-Bold.otf 0 30504)))
((Gillius\ ADF\ No2\ Cond Bold\ Italic) ((GilliusADFNo2Cond-BoldItalic.otf 0 33760)))
((Gillius\ ADF\ No2\ Cond Italic) ((GilliusADFNo2Cond-Italic.otf 0 33776)))
((Gillius\ ADF\ No2\ Cond Regular) ((GilliusADFNo2Cond-Regular.otf 0 30192)))
((Go Bold) ((Go-Bold.ttf 0 144572)))
((Go Bold\ Italic) ((Go-Bold-Italic.ttf 0 150956)))
((Go Regular) ((Go-Medium.ttf 0 147076) (Go-Regular.ttf 0 140488)))
((Go Regular-Italic) ((Go-Regular-Italic.ttf 0 147248)))
((Go\ Mono Bold) ((GoMono-Bold.ttf 0 168340)))
((Go\ Mono Bold\ Italic) ((GoMono-Bold-Italic.ttf 0 176832)))
((Go\ Mono Italic) ((GoMono-Regular-Italic.ttf 0 173548)))
((Go\ Mono Regular) ((GoMono-Regular.ttf 0 164200)))
((GoSmallcaps Italic) ((GoSmallcaps-Italic.ttf 0 140712)))
((GoSmallcaps Regular) ((GoSmallcaps.ttf 0 133780)))
((Gotika Regular) ((Gotika.ttf 0 55868)))
((Gotika\ Apvalus Regular) ((Gotika\ Apvalus.ttf 0 55920)))
((Gotika\ Brokas Regular) ((Gotika\ Brokas.ttf 0 55136)))
((Gotika\ Serifai\ A Regular) ((Gotika\ Serifai\ A.ttf 0 36392)))
((Gotika\ Serifai\ B Regular) ((Gotika\ Serifai\ B.ttf 0 36748)))
((Goudy\ Bookletter\ 1911 Regular) ((GoudyBookletter1911.otf 0 39988)))
((Greciliae regular) ((greciliae.ttf 0 1092516)))
((Greciliae-hole hole) ((greciliae-hole.ttf 0 1105828)))
((Greciliae-hollow hollow) ((greciliae-hollow.ttf 0 1809560)))
((Greciliae-op op) ((greciliae-op.ttf 0 1130264)))
((Greciliae-op-hole op-hole) ((greciliae-op-hole.ttf 0 1105824)))
((Greciliae-op-hollow op-hollow) ((greciliae-op-hollow.ttf 0 1847248)))
((Greextra Medium) ((greextra.ttf 0 24760)))
((Gregall regular) ((gregall.ttf 0 159472)))
((Grelaon regular) ((grelaon.ttf 0 187528)))
((Gresgmodern Normal) ((gresgmodern.ttf 0 203284)))
((Grunge\ Handwriting Regular) ((Grunge\ Handwriting.ttf 0 651948) (GrungeHandwriting.otf 0 368408)))
((Gujarati\ MT Bold) ((GujaratiMTBold.ttf 0 213708) (GujaratiMT.ttc 1 381112) (GujaratiMT.ttc 1 384332)))
((Gujarati\ MT Regular) ((GujaratiMT.ttf 0 224940) (GujaratiMT.ttc 0 381112) (GujaratiMT.ttc 0 384332)))
((Gujarati\ Sangam\ MN Bold) ((Gujarati\ Sangam\ MN.ttc 1 222348) (Gujarati\ Sangam\ MN.ttc 1 439680) (Gujarati\ Sangam\ MN.ttc 1 543228)))
((Gujarati\ Sangam\ MN Regular) ((Gujarati\ Sangam\ MN.ttc 0 222348) (Gujarati\ Sangam\ MN.ttc 0 439680) (Gujarati\ Sangam\ MN.ttc 0 543228)))
((Gurmukhi\ MN Bold) ((Gurmukhi\ MN.ttc 1 87380) (Gurmukhi\ MN.ttc 1 185648) (Gurmukhi\ MN.ttc 1 201932) (Gurmukhi\ MN.ttc 1 229944)))
((Gurmukhi\ MN Regular) ((Gurmukhi\ MN.ttc 0 87380) (Gurmukhi\ MN.ttc 0 185648) (Gurmukhi\ MN.ttc 0 201932) (Gurmukhi\ MN.ttc 0 229944)))
((Gurmukhi\ MT Regular) ((Gurmukhi.ttf 0 64572) (Gurmukhi.ttf 0 63936) (Gurmukhi.ttf 0 65540)))
((Gurmukhi\ Sangam\ MN Bold) ((Gurmukhi\ Sangam\ MN.ttc 1 168080) (Gurmukhi\ Sangam\ MN.ttc 1 166960) (Gurmukhi\ Sangam\ MN.ttc 1 143344)))
((Gurmukhi\ Sangam\ MN Regular) ((Gurmukhi\ Sangam\ MN.ttc 0 168080) (Gurmukhi\ Sangam\ MN.ttc 0 166960) (Gurmukhi\ Sangam\ MN.ttc 0 143344)))
((Hairline\ Quadrata Medium) ((Hairline\ Quadrata.ttf 0 24064)))
((Hand\ Drawn\ Shapes Regular) ((Hand\ Drawn\ Shapes.ttf 0 69924) (HandDrawnShapes.otf 0 26284)))
((Handserif Medium) ((HanSrf.ttf 0 86184)))
((Hannotate\ SC Bold) ((Hannotate.ttc 2 85383868)))
((Hannotate\ SC Regular) ((Hannotate.ttc 0 85383868)))
((Hannotate\ TC Bold) ((Hannotate.ttc 3 85383868)))
((Hannotate\ TC Regular) ((Hannotate.ttc 1 85383868)))
((HanziPen\ SC Bold) ((Hanzipen.ttc 2 71898356)))
((HanziPen\ SC Regular) ((Hanzipen.ttc 0 71898356)))
((HanziPen\ TC Bold) ((Hanzipen.ttc 3 71898356)))
((HanziPen\ TC Regular) ((Hanzipen.ttc 1 71898356)))
((Harano\ Aji\ Gothic Bold) ((HaranoAjiGothic-Bold.otf 0 5314528)))
((Harano\ Aji\ Gothic Heavy) ((HaranoAjiGothic-Heavy.otf 0 5547508)))
((Harano\ Aji\ Gothic Light) ((HaranoAjiGothic-Light.otf 0 5135192)))
((Harano\ Aji\ Gothic Regular) ((HaranoAjiGothic-Medium.otf 0 5189360) (HaranoAjiGothic-Regular.otf 0 5169740)))
((Harano\ Aji\ Gothic\ ExtraLight Regular) ((HaranoAjiGothic-ExtraLight.otf 0 4888860)))
((Harano\ Aji\ Gothic\ Normal Regular) ((HaranoAjiGothic-Normal.otf 0 5159144)))
((Harano\ Aji\ Mincho Bold) ((HaranoAjiMincho-Bold.otf 0 6918196)))
((Harano\ Aji\ Mincho Heavy) ((HaranoAjiMincho-Heavy.otf 0 6853212)))
((Harano\ Aji\ Mincho Light) ((HaranoAjiMincho-Light.otf 0 6561816)))
((Harano\ Aji\ Mincho Regular) ((HaranoAjiMincho-Medium.otf 0 6718092) (HaranoAjiMincho-Regular.otf 0 6642776)))
((Harano\ Aji\ Mincho SemiBold) ((HaranoAjiMincho-SemiBold.otf 0 6755864)))
((Harano\ Aji\ Mincho\ ExtraLight Regular) ((HaranoAjiMincho-ExtraLight.otf 0 6159064)))
((HeadLineA Regular) ((HeadlineA.ttf 0 1215336) (HeadlineA.ttf 0 1198040)))
((Hei Regular) ((Hei.ttf 0 7502752)))
((Heiti\ SC Light) ((STHeiti\ Light.ttc 1 55331264) (STHeiti\ Light.ttc 1 55984748) (STHeiti\ Light.ttc 1 54382472) (STHeiti\ Light.ttc 1 56105488) (STHeiti\ Light.ttc 1 55782932)))
((Heiti\ SC Medium) ((STHeiti\ Medium.ttc 1 55380344) (STHeiti\ Medium.ttc 1 55954340) (STHeiti\ Medium.ttc 1 54257344) (STHeiti\ Medium.ttc 1 55947944) (STHeiti\ Medium.ttc 1 55753860)))
((Heiti\ TC Light) ((STHeiti\ Light.ttc 0 55331264) (STHeiti\ Light.ttc 0 55984748) (STHeiti\ Light.ttc 0 54382472) (STHeiti\ Light.ttc 0 56105488) (STHeiti\ Light.ttc 0 55782932)))
((Heiti\ TC Medium) ((STHeiti\ Medium.ttc 0 55380344) (STHeiti\ Medium.ttc 0 55954340) (STHeiti\ Medium.ttc 0 54257344) (STHeiti\ Medium.ttc 0 55947944) (STHeiti\ Medium.ttc 0 55753860)))
((HeitiUI\ GB18030PUA Thin) ((STHeiti\ Thin.ttc 2 8081556)))
((HeitiUI\ GB18030PUA Ultra\ Light) ((STHeiti\ UltraLight.ttc 2 8391392)))
((HeitiUI\ J Thin) ((STHeiti\ Thin.ttc 4 8081556)))
((HeitiUI\ J Ultra\ Light) ((STHeiti\ UltraLight.ttc 4 8391392)))
((HeitiUI\ K Thin) ((STHeiti\ Thin.ttc 3 8081556)))
((HeitiUI\ K Ultra\ Light) ((STHeiti\ UltraLight.ttc 3 8391392)))
((HeitiUI\ SC Thin) ((STHeiti\ Thin.ttc 1 8081556)))
((HeitiUI\ SC Ultra\ Light) ((STHeiti\ UltraLight.ttc 1 8391392)))
((HeitiUI\ TC Thin) ((STHeiti\ Thin.ttc 0 8081556)))
((HeitiUI\ TC Ultra\ Light) ((STHeiti\ UltraLight.ttc 0 8391392)))
((Helvetica Bold) ((Helvetica.ttc 1 2320268) (Helvetica.ttc 1 2356684)))
((Helvetica Bold\ Oblique) ((Helvetica.ttc 3 2320268) (Helvetica.ttc 3 2356684)))
((Helvetica Light) ((HelveticaLight.ttf 0 55756) (Helvetica.ttc 4 2320268) (Helvetica.ttc 4 2356684)))
((Helvetica Light\ Oblique) ((HelveticaLightItalic.ttf 0 50972) (Helvetica.ttc 5 2320268) (Helvetica.ttc 5 2356684)))
((Helvetica Oblique) ((Helvetica.ttc 2 2320268) (Helvetica.ttc 2 2356684)))
((Helvetica Regular) ((Helvetica.ttc 0 2320268) (Helvetica.ttc 0 2356684)))
((Helvetica\ Neue Bold) ((HelveticaNeue.ttc 1 1395352) (HelveticaNeue.ttc 1 6625940) (HelveticaNeue.ttc 1 5929340)))
((Helvetica\ Neue Bold\ Italic) ((HelveticaNeue.ttc 3 1395352) (HelveticaNeue.ttc 3 6625940) (HelveticaNeue.ttc 3 5929340)))
((Helvetica\ Neue Condensed\ Black) ((HelveticaNeue.ttc 8 1395352) (HelveticaNeue.ttc 9 6625940) (HelveticaNeue.ttc 9 5929340)))
((Helvetica\ Neue Condensed\ Bold) ((HelveticaNeue.ttc 9 1395352) (HelveticaNeue.ttc 4 6625940) (HelveticaNeue.ttc 4 5929340)))
((Helvetica\ Neue Italic) ((HelveticaNeue.ttc 2 1395352) (HelveticaNeue.ttc 2 6625940) (HelveticaNeue.ttc 2 5929340)))
((Helvetica\ Neue Light) ((HelveticaNeue.ttc 4 1395352) (HelveticaNeue.ttc 7 6625940) (HelveticaNeue.ttc 7 5929340)))
((Helvetica\ Neue Light\ Italic) ((HelveticaNeue.ttc 5 1395352) (HelveticaNeue.ttc 8 6625940) (HelveticaNeue.ttc 8 5929340)))
((Helvetica\ Neue Medium) ((HelveticaNeue.ttc 10 1395352) (HelveticaNeue.ttc 10 6625940) (HelveticaNeue.ttc 10 5929340)))
((Helvetica\ Neue Medium\ Italic) ((HelveticaNeue.ttc 11 6625940) (HelveticaNeue.ttc 11 5929340)))
((Helvetica\ Neue Regular) ((HelveticaNeue.ttc 0 1395352) (HelveticaNeue.ttc 0 6625940) (HelveticaNeue.ttc 0 5929340)))
((Helvetica\ Neue Thin) ((HelveticaNeue.ttc 12 6625940) (HelveticaNeue.ttc 12 5929340)))
((Helvetica\ Neue Thin\ Italic) ((HelveticaNeue.ttc 13 6625940) (HelveticaNeue.ttc 13 5929340)))
((Helvetica\ Neue UltraLight) ((HelveticaNeue.ttc 6 1395352) (HelveticaNeue.ttc 5 6625940) (HelveticaNeue.ttc 5 5929340)))
((Helvetica\ Neue UltraLight\ Italic) ((HelveticaNeue.ttc 7 1395352) (HelveticaNeue.ttc 6 6625940) (HelveticaNeue.ttc 6 5929340)))
((Helvetica\ Neue\ DeskInterface Bold) ((HelveticaNeueDeskUI.ttc 2 2877688) (HelveticaNeueDeskInterface.ttc 1 5372956) (HelveticaNeueDeskInterface.ttc 1 5427236)))
((Helvetica\ Neue\ DeskInterface Bold\ Italic) ((HelveticaNeueDeskUI.ttc 3 2877688) (HelveticaNeueDeskUI.ttc 3 2877688) (HelveticaNeueDeskInterface.ttc 3 5372956) (HelveticaNeueDeskInterface.ttc 3 5427236)))
((Helvetica\ Neue\ DeskInterface Heavy) ((HelveticaNeueDeskInterface.ttc 9 5372956) (HelveticaNeueDeskInterface.ttc 9 5427236)))
((Helvetica\ Neue\ DeskInterface Italic) ((HelveticaNeueDeskUI.ttc 1 2877688) (HelveticaNeueDeskInterface.ttc 2 5372956) (HelveticaNeueDeskInterface.ttc 2 5427236)))
((Helvetica\ Neue\ DeskInterface Light) ((HelveticaNeueDeskInterface.ttc 6 5372956) (HelveticaNeueDeskInterface.ttc 6 5427236)))
((Helvetica\ Neue\ DeskInterface Medium) ((HelveticaNeueDeskInterface.ttc 4 5372956) (HelveticaNeueDeskInterface.ttc 4 5427236)))
((Helvetica\ Neue\ DeskInterface Medium\ Italic) ((HelveticaNeueDeskInterface.ttc 5 5372956) (HelveticaNeueDeskInterface.ttc 5 5427236)))
((Helvetica\ Neue\ DeskInterface Regular) ((HelveticaNeueDeskUI.ttc 0 2877688) (HelveticaNeueDeskInterface.ttc 0 5372956) (HelveticaNeueDeskInterface.ttc 0 5427236)))
((Helvetica\ Neue\ DeskInterface Thin) ((HelveticaNeueDeskInterface.ttc 7 5372956) (HelveticaNeueDeskInterface.ttc 7 5427236)))
((Helvetica\ Neue\ DeskInterface UltraLight) ((HelveticaNeueDeskInterface.ttc 8 5372956) (HelveticaNeueDeskInterface.ttc 8 5427236)))
((Herculanum Regular) ((Herculanum.ttf 0 106264) (Herculanum.ttf 0 111124)))
((Heuristica Bold) ((Heuristica-Bold.otf 0 164476)))
((Heuristica Bold\ Italic) ((Heuristica-BoldItalic.otf 0 150764)))
((Heuristica Italic) ((Heuristica-Italic.otf 0 152144)))
((Heuristica Regular) ((Heuristica-Regular.otf 0 205372)))
((Hiragino\ Kaku\ Gothic\ Interface W0) ((ヒラギノ角ゴシック\ W0.ttc 1 3567792) (ヒラギノ角ゴシック\ W0.ttc 1 3581196) (ヒラギノ角ゴシック\ W0.ttc 1 3571028)))
((Hiragino\ Kaku\ Gothic\ Interface W1) ((ヒラギノ角ゴシック\ W1.ttc 1 7286744) (ヒラギノ角ゴシック\ W1.ttc 1 7304696) (ヒラギノ角ゴシック\ W1.ttc 1 7265348)))
((Hiragino\ Kaku\ Gothic\ Interface W2) ((ヒラギノ角ゴシック\ W2.ttc 1 7270552) (ヒラギノ角ゴシック\ W2.ttc 1 7288508) (ヒラギノ角ゴシック\ W2.ttc 1 7248588)))
((Hiragino\ Kaku\ Gothic\ Interface W3) ((ヒラギノ角ゴシック\ W3.ttc 1 7891480) (ヒラギノ角ゴシック\ W3.ttc 1 7916548) (ヒラギノ角ゴシック\ W3.ttc 1 7875588)))
((Hiragino\ Kaku\ Gothic\ Interface W4) ((ヒラギノ角ゴシック\ W4.ttc 1 7259328) (ヒラギノ角ゴシック\ W4.ttc 1 7277276) (ヒラギノ角ゴシック\ W4.ttc 1 7237344)))
((Hiragino\ Kaku\ Gothic\ Interface W5) ((ヒラギノ角ゴシック\ W5.ttc 1 7260984) (ヒラギノ角ゴシック\ W5.ttc 1 7278972) (ヒラギノ角ゴシック\ W5.ttc 1 7237760)))
((Hiragino\ Kaku\ Gothic\ Interface W6) ((ヒラギノ角ゴシック\ W6.ttc 1 7998200) (ヒラギノ角ゴシック\ W6.ttc 1 8023284) (ヒラギノ角ゴシック\ W6.ttc 1 7977668)))
((Hiragino\ Kaku\ Gothic\ Interface W7) ((ヒラギノ角ゴシック\ W7.ttc 1 3607768) (ヒラギノ角ゴシック\ W7.ttc 1 3621160) (ヒラギノ角ゴシック\ W7.ttc 1 3607384)))
((Hiragino\ Kaku\ Gothic\ Interface W8) ((ヒラギノ角ゴシック\ W8.ttc 1 4096288) (ヒラギノ角ゴシック\ W8.ttc 1 3770516) (ヒラギノ角ゴシック\ W8.ttc 1 3756024)))
((Hiragino\ Kaku\ Gothic\ Interface W9) ((ヒラギノ角ゴシック\ W9.ttc 1 3464676) (ヒラギノ角ゴシック\ W9.ttc 1 3478068) (ヒラギノ角ゴシック\ W9.ttc 1 3461360)))
((Hiragino\ Kaku\ Gothic\ Pro W3) ((ヒラギノ角ゴ\ Pro\ W3.otf 0 9362284) (ヒラギノ角ゴシック\ W3.ttc 3 7891480) (ヒラギノ角ゴ\ Pro\ W3.otf 0 9362244) (ヒラギノ角ゴシック\ W3.ttc 3 7916548) (ヒラギノ角ゴシック\ W3.ttc 3 7875588)))
((Hiragino\ Kaku\ Gothic\ Pro W6) ((ヒラギノ角ゴ\ Pro\ W6.otf 0 8871612) (ヒラギノ角ゴシック\ W6.ttc 3 7998200) (ヒラギノ角ゴ\ Pro\ W6.otf 0 8871572) (ヒラギノ角ゴシック\ W6.ttc 3 8023284) (ヒラギノ角ゴシック\ W6.ttc 3 7977668)))
((Hiragino\ Kaku\ Gothic\ ProN W3) ((ヒラギノ角ゴ\ ProN\ W3.otf 0 7508224) (ヒラギノ角ゴシック\ W3.ttc 2 7891480) (ヒラギノ角ゴ\ ProN\ W3.otf 0 7476024) (ヒラギノ角ゴシック\ W3.ttc 2 7916548) (ヒラギノ角ゴシック\ W3.ttc 2 7875588)))
((Hiragino\ Kaku\ Gothic\ ProN W6) ((ヒラギノ角ゴ\ ProN\ W6.otf 0 7555872) (ヒラギノ角ゴシック\ W6.ttc 2 7998200) (ヒラギノ角ゴ\ ProN\ W6.otf 0 7523672) (ヒラギノ角ゴシック\ W6.ttc 2 8023284) (ヒラギノ角ゴシック\ W6.ttc 2 7977668)))
((Hiragino\ Kaku\ Gothic\ Std W8) ((ヒラギノ角ゴ\ Std\ W8.otf 0 4276784) (ヒラギノ角ゴシック\ W8.ttc 2 4096288) (ヒラギノ角ゴ\ Std\ W8.otf 0 4276744) (ヒラギノ角ゴシック\ W8.ttc 2 3770516) (ヒラギノ角ゴシック\ W8.ttc 2 3756024)))
((Hiragino\ Kaku\ Gothic\ StdN W8) ((ヒラギノ角ゴ\ StdN\ W8.otf 0 3665584) (ヒラギノ角ゴシック\ W8.ttc 3 4096288) (ヒラギノ角ゴ\ StdN\ W8.otf 0 3639612) (ヒラギノ角ゴシック\ W8.ttc 3 3770516) (ヒラギノ角ゴシック\ W8.ttc 3 3756024)))
((Hiragino\ Maru\ Gothic\ Pro W4) ((ヒラギノ丸ゴ\ Pro\ W4.otf 0 10109552) (ヒラギノ丸ゴ\ ProN\ W4.ttc 0 11409608) (ヒラギノ丸ゴ\ Pro\ W4.otf 0 10109512) (ヒラギノ丸ゴ\ ProN\ W4.ttc 0 9881416) (ヒラギノ丸ゴ\ ProN\ W4.ttc 0 9796620)))
((Hiragino\ Maru\ Gothic\ ProN W4) ((ヒラギノ丸ゴ\ ProN\ W4.otf 0 9301332) (ヒラギノ丸ゴ\ ProN\ W4.ttc 1 11409608) (ヒラギノ丸ゴ\ ProN\ W4.otf 0 9269132) (ヒラギノ丸ゴ\ ProN\ W4.ttc 1 9881416) (ヒラギノ丸ゴ\ ProN\ W4.ttc 1 9796620)))
((Hiragino\ Mincho\ Pro W3) ((ヒラギノ明朝\ Pro\ W3.otf 0 11580728) (ヒラギノ明朝\ ProN\ W3.ttc 1 11867472) (ヒラギノ明朝\ Pro\ W3.otf 0 11580692) (ヒラギノ明朝\ ProN.ttc 1 19744888) (ヒラギノ明朝\ ProN.ttc 1 19605932)))
((Hiragino\ Mincho\ Pro W6) ((ヒラギノ明朝\ Pro\ W6.otf 0 11092140) (ヒラギノ明朝\ ProN\ W6.ttc 1 11975732) (ヒラギノ明朝\ Pro\ W6.otf 0 11092104) (ヒラギノ明朝\ ProN.ttc 3 19744888) (ヒラギノ明朝\ ProN.ttc 3 19605932)))
((Hiragino\ Mincho\ ProN W3) ((ヒラギノ明朝\ ProN\ W3.otf 0 9731332) (ヒラギノ明朝\ ProN\ W3.ttc 0 11867472) (ヒラギノ明朝\ ProN\ W3.otf 0 9699132) (ヒラギノ明朝\ ProN.ttc 0 19744888) (ヒラギノ明朝\ ProN.ttc 0 19605932)))
((Hiragino\ Mincho\ ProN W6) ((ヒラギノ明朝\ ProN\ W6.otf 0 9842776) (ヒラギノ明朝\ ProN\ W6.ttc 0 11975732) (ヒラギノ明朝\ ProN\ W6.otf 0 9810576) (ヒラギノ明朝\ ProN.ttc 2 19744888) (ヒラギノ明朝\ ProN.ttc 2 19605932)))
((Hiragino\ Sans W0) ((ヒラギノ角ゴシック\ W0.ttc 0 3567792) (ヒラギノ角ゴシック\ W0.ttc 0 3581196) (ヒラギノ角ゴシック\ W0.ttc 0 3571028)))
((Hiragino\ Sans W1) ((ヒラギノ角ゴシック\ W1.ttc 0 7286744) (ヒラギノ角ゴシック\ W1.ttc 0 7304696) (ヒラギノ角ゴシック\ W1.ttc 0 7265348)))
((Hiragino\ Sans W2) ((ヒラギノ角ゴシック\ W2.ttc 0 7270552) (ヒラギノ角ゴシック\ W2.ttc 0 7288508) (ヒラギノ角ゴシック\ W2.ttc 0 7248588)))
((Hiragino\ Sans W3) ((ヒラギノ角ゴシック\ W3.ttc 0 7891480) (ヒラギノ角ゴシック\ W3.ttc 0 7916548) (ヒラギノ角ゴシック\ W3.ttc 0 7875588)))
((Hiragino\ Sans W4) ((ヒラギノ角ゴシック\ W4.ttc 0 7259328) (ヒラギノ角ゴシック\ W4.ttc 0 7277276) (ヒラギノ角ゴシック\ W4.ttc 0 7237344)))
((Hiragino\ Sans W5) ((ヒラギノ角ゴシック\ W5.ttc 0 7260984) (ヒラギノ角ゴシック\ W5.ttc 0 7278972) (ヒラギノ角ゴシック\ W5.ttc 0 7237760)))
((Hiragino\ Sans W6) ((ヒラギノ角ゴシック\ W6.ttc 0 7998200) (ヒラギノ角ゴシック\ W6.ttc 0 8023284) (ヒラギノ角ゴシック\ W6.ttc 0 7977668)))
((Hiragino\ Sans W7) ((ヒラギノ角ゴシック\ W7.ttc 0 3607768) (ヒラギノ角ゴシック\ W7.ttc 0 3621160) (ヒラギノ角ゴシック\ W7.ttc 0 3607384)))
((Hiragino\ Sans W8) ((ヒラギノ角ゴシック\ W8.ttc 0 4096288) (ヒラギノ角ゴシック\ W8.ttc 0 3770516) (ヒラギノ角ゴシック\ W8.ttc 0 3756024)))
((Hiragino\ Sans W9) ((ヒラギノ角ゴシック\ W9.ttc 0 3464676) (ヒラギノ角ゴシック\ W9.ttc 0 3478068) (ヒラギノ角ゴシック\ W9.ttc 0 3461360)))
((Hiragino\ Sans\ GB W3) ((Hiragino\ Sans\ GB\ W3.otf 0 13176596) (Hiragino\ Sans\ GB\ W3.ttc 0 13179472) (Hiragino\ Sans\ GB\ W3.otf 0 13178508) (Hiragino\ Sans\ GB.ttc 0 25877216)))
((Hiragino\ Sans\ GB W6) ((Hiragino\ Sans\ GB\ W6.otf 0 13238616) (Hiragino\ Sans\ GB\ W6.ttc 0 13241340) (Hiragino\ Sans\ GB\ W6.otf 0 13240508) (Hiragino\ Sans\ GB.ttc 2 25877216)))
((Hiragino\ Sans\ GB\ Interface W3) ((Hiragino\ Sans\ GB\ W3.ttc 1 13179472) (Hiragino\ Sans\ GB.ttc 1 25877216)))
((Hiragino\ Sans\ GB\ Interface W6) ((Hiragino\ Sans\ GB\ W6.ttc 1 13241340) (Hiragino\ Sans\ GB.ttc 3 25877216)))
((Hoefler\ Text Black) ((Hoefler\ Text.ttc 1 1626664) (Hoefler\ Text.ttc 1 1633680) (Hoefler\ Text.ttc 1 1645292) (Hoefler\ Text.ttc 1 1645672)))
((Hoefler\ Text Black\ Italic) ((Hoefler\ Text.ttc 3 1626664) (Hoefler\ Text.ttc 3 1633680) (Hoefler\ Text.ttc 3 1645292) (Hoefler\ Text.ttc 3 1645672)))
((Hoefler\ Text Italic) ((Hoefler\ Text.ttc 2 1626664) (Hoefler\ Text.ttc 2 1633680) (Hoefler\ Text.ttc 2 1645292) (Hoefler\ Text.ttc 2 1645672)))
((Hoefler\ Text Ornaments) ((Hoefler\ Text\ Ornaments.ttf 0 40744) (Hoefler\ Text\ Ornaments.ttf 0 40988) (Hoefler\ Text\ Ornaments.ttf 0 43312)))
((Hoefler\ Text Regular) ((Hoefler\ Text.ttc 0 1626664) (Hoefler\ Text.ttc 0 1633680) (Hoefler\ Text.ttc 0 1645292) (Hoefler\ Text.ttc 0 1645672)))
((Hoefler\ Text\ Ornaments Ornaments) ((Hoefler\ Text\ Ornaments.ttf 0 43380)))
((Hopper\ Script Regular) ((Hopper\ Script.ttf 0 203716)))
((IBM\ Plex\ Mono Bold) ((IBMPlexMono-Bold.otf 0 64980)))
((IBM\ Plex\ Mono Bold\ Italic) ((IBMPlexMono-BoldItalic.otf 0 70096)))
((IBM\ Plex\ Mono Italic) ((IBMPlexMono-Italic.otf 0 68472) (IBMPlexMono-MediumItalic.otf 0 70436)))
((IBM\ Plex\ Mono Light) ((IBMPlexMono-Light.otf 0 62708)))
((IBM\ Plex\ Mono Light\ Italic) ((IBMPlexMono-LightItalic.otf 0 69008)))
((IBM\ Plex\ Mono Regular) ((IBMPlexMono-Medium.otf 0 64364) (IBMPlexMono-Regular.otf 0 62364)))
((IBM\ Plex\ Mono SemiBold) ((IBMPlexMono-SemiBold.otf 0 64412)))
((IBM\ Plex\ Mono SemiBold\ Italic) ((IBMPlexMono-SemiBoldItalic.otf 0 70496)))
((IBM\ Plex\ Mono\ ExtraLight Italic) ((IBMPlexMono-ExtraLightItalic.otf 0 68008)))
((IBM\ Plex\ Mono\ ExtraLight Regular) ((IBMPlexMono-ExtraLight.otf 0 62672)))
((IBM\ Plex\ Mono\ Text Italic) ((IBMPlexMono-TextItalic.otf 0 71884)))
((IBM\ Plex\ Mono\ Text Regular) ((IBMPlexMono-Text.otf 0 63652)))
((IBM\ Plex\ Mono\ Thin Italic) ((IBMPlexMono-ThinItalic.otf 0 65916)))
((IBM\ Plex\ Mono\ Thin Regular) ((IBMPlexMono-Thin.otf 0 61056)))
((IBM\ Plex\ Sans Bold) ((IBMPlexSans-Bold.otf 0 133120)))
((IBM\ Plex\ Sans Bold\ Italic) ((IBMPlexSans-BoldItalic.otf 0 140360)))
((IBM\ Plex\ Sans Condensed) ((IBMPlexSansCondensed-Medium.otf 0 70168) (IBMPlexSansCondensed-Regular.otf 0 69424)))
((IBM\ Plex\ Sans Condensed\ Bold) ((IBMPlexSansCondensed-Bold.otf 0 70012)))
((IBM\ Plex\ Sans Condensed\ Bold\ Italic) ((IBMPlexSansCondensed-BoldItalic.otf 0 73156)))
((IBM\ Plex\ Sans Condensed\ Italic) ((IBMPlexSansCondensed-Italic.otf 0 72564) (IBMPlexSansCondensed-MediumItalic.otf 0 75260)))
((IBM\ Plex\ Sans Italic) ((IBMPlexSans-Italic.otf 0 139336) (IBMPlexSans-MediumItalic.otf 0 142716)))
((IBM\ Plex\ Sans Light) ((IBMPlexSans-Light.otf 0 133832)))
((IBM\ Plex\ Sans Light\ Condensed) ((IBMPlexSansCondensed-Light.otf 0 70612)))
((IBM\ Plex\ Sans Light\ Condensed\ Italic) ((IBMPlexSansCondensed-LightItalic.otf 0 72584)))
((IBM\ Plex\ Sans Light\ Italic) ((IBMPlexSans-LightItalic.otf 0 141328)))
((IBM\ Plex\ Sans Regular) ((IBMPlexSans-Medium.otf 0 135660) (IBMPlexSans-Regular.otf 0 131036)))
((IBM\ Plex\ Sans SemiBold) ((IBMPlexSans-SemiBold.otf 0 135656)))
((IBM\ Plex\ Sans SemiBold\ Condensed) ((IBMPlexSansCondensed-SemiBold.otf 0 71124)))
((IBM\ Plex\ Sans SemiBold\ Condensed\ Italic) ((IBMPlexSansCondensed-SemiBoldItalic.otf 0 75236)))
((IBM\ Plex\ Sans SemiBold\ Italic) ((IBMPlexSans-SemiBoldItalic.otf 0 142140)))
((IBM\ Plex\ Sans\ ExtraLight Condensed) ((IBMPlexSansCondensed-ExtraLight.otf 0 69920)))
((IBM\ Plex\ Sans\ ExtraLight Condensed\ Italic) ((IBMPlexSansCondensed-ExtraLightItalic.otf 0 72444)))
((IBM\ Plex\ Sans\ ExtraLight Italic) ((IBMPlexSans-ExtraLightItalic.otf 0 141200)))
((IBM\ Plex\ Sans\ ExtraLight Regular) ((IBMPlexSans-ExtraLight.otf 0 133664)))
((IBM\ Plex\ Sans\ Text Condensed) ((IBMPlexSansCondensed-Text.otf 0 70144)))
((IBM\ Plex\ Sans\ Text Condensed\ Italic) ((IBMPlexSansCondensed-TextItalic.otf 0 73928)))
((IBM\ Plex\ Sans\ Text Italic) ((IBMPlexSans-TextItalic.otf 0 142664)))
((IBM\ Plex\ Sans\ Text Regular) ((IBMPlexSans-Text.otf 0 134048)))
((IBM\ Plex\ Sans\ Thin Condensed) ((IBMPlexSansCondensed-Thin.otf 0 68128)))
((IBM\ Plex\ Sans\ Thin Condensed\ Italic) ((IBMPlexSansCondensed-ThinItalic.otf 0 71316)))
((IBM\ Plex\ Sans\ Thin Italic) ((IBMPlexSans-ThinItalic.otf 0 135044)))
((IBM\ Plex\ Sans\ Thin Regular) ((IBMPlexSans-Thin.otf 0 128324)))
((IBM\ Plex\ Serif Bold) ((IBMPlexSerif-Bold.otf 0 113588)))
((IBM\ Plex\ Serif Bold\ Italic) ((IBMPlexSerif-BoldItalic.otf 0 122592)))
((IBM\ Plex\ Serif Italic) ((IBMPlexSerif-Italic.otf 0 122016) (IBMPlexSerif-MediumItalic.otf 0 124128)))
((IBM\ Plex\ Serif Light) ((IBMPlexSerif-Light.otf 0 113068)))
((IBM\ Plex\ Serif Light\ Italic) ((IBMPlexSerif-LightItalic.otf 0 121656)))
((IBM\ Plex\ Serif Regular) ((IBMPlexSerif-Medium.otf 0 115380) (IBMPlexSerif-Regular.otf 0 112564)))
((IBM\ Plex\ Serif SemiBold) ((IBMPlexSerif-SemiBold.otf 0 114948)))
((IBM\ Plex\ Serif SemiBold\ Italic) ((IBMPlexSerif-SemiBoldItalic.otf 0 123836)))
((IBM\ Plex\ Serif\ ExtraLight Italic) ((IBMPlexSerif-ExtraLightItalic.otf 0 120220)))
((IBM\ Plex\ Serif\ ExtraLight Regular) ((IBMPlexSerif-ExtraLight.otf 0 112908)))
((IBM\ Plex\ Serif\ Text Italic) ((IBMPlexSerif-TextItalic.otf 0 123160)))
((IBM\ Plex\ Serif\ Text Regular) ((IBMPlexSerif-Text.otf 0 114072)))
((IBM\ Plex\ Serif\ Thin Italic) ((IBMPlexSerif-ThinItalic.otf 0 113412)))
((IBM\ Plex\ Serif\ Thin Regular) ((IBMPlexSerif-Thin.otf 0 107924)))
((IM\ FELL\ English Italic) ((IMFeENit28P.otf 0 1177440)))
((IM\ FELL\ English Regular) ((IMFeENrm28P.otf 0 1114692)))
((IM\ FELL\ English\ SC Regular) ((IMFeENsc28P.otf 0 1060600)))
((Impact Regular) ((Impact.ttf 0 138488) (impact.ttf 0 137448) (impact.ttf 0 206784)))
((InaiMathi Bold) ((InaiMathi-MN.ttc 1 457432)))
((InaiMathi Regular) ((InaiMathi.ttf 0 228792) (InaiMathi.ttf 0 260064) (InaiMathi.ttf 0 263572) (InaiMathi-MN.ttc 0 457432)))
((InconsolataN Bold) ((InconsolataN-Bold.otf 0 28464)))
((InconsolataN Regular) ((InconsolataN-Regular.otf 0 26540)))
((Inconsolatazi4 Bold) ((Inconsolatazi4-Bold.otf 0 47780)))
((Inconsolatazi4 Regular) ((Inconsolatazi4-Regular.otf 0 37420)))
((Indiction\ Unicode Normal) ((IndictionUnicode.otf 0 909248)))
((Indiction\ Unicode\ TT Normal) ((IndictionUnicode.ttf 0 320260)))
((Ink\ Free Regular) ((Inkfree.ttf 0 41164)))
((Inria\ Sans Bold) ((InriaSans-Bold.otf 0 72588) (InriaSans-Bold.ttf 0 76868)))
((Inria\ Sans Bold\ Italic) ((InriaSans-BoldItalic.otf 0 73344) (InriaSans-BoldItalic.ttf 0 77692)))
((Inria\ Sans Italic) ((InriaSans-Italic.otf 0 73608) (InriaSans-Italic.ttf 0 78488)))
((Inria\ Sans Light) ((InriaSans-Light.otf 0 71060) (InriaSans-Light.ttf 0 77796)))
((Inria\ Sans Light\ Italic) ((InriaSans-LightItalic.otf 0 72112) (InriaSans-LightItalic.ttf 0 78536)))
((Inria\ Sans Regular) ((InriaSans-Regular.otf 0 72912) (InriaSans-Regular.ttf 0 76940)))
((Inria\ Serif Bold) ((InriaSerif-Bold.otf 0 81488) (InriaSerif-Bold.ttf 0 88800)))
((Inria\ Serif Bold\ Italic) ((InriaSerif-BoldItalic.otf 0 82484) (InriaSerif-BoldItalic.ttf 0 90220)))
((Inria\ Serif Italic) ((InriaSerif-Italic.otf 0 85188) (InriaSerif-Italic.ttf 0 91632)))
((Inria\ Serif Light) ((InriaSerif-Light.otf 0 82520) (InriaSerif-Light.ttf 0 90604)))
((Inria\ Serif Light\ Italic) ((InriaSerif-LightItalic.otf 0 83424) (InriaSerif-LightItalic.ttf 0 92404)))
((Inria\ Serif Regular) ((InriaSerif-Regular.otf 0 84524) (InriaSerif-Regular.ttf 0 90856)))
((Iowan\ Old\ Style Black) ((Iowan\ Old\ Style.ttc 4 3356712) (Iowan\ Old\ Style.ttc 4 3414732) (Iowan\ Old\ Style.ttc 4 3419188)))
((Iowan\ Old\ Style Black\ Italic) ((Iowan\ Old\ Style.ttc 5 3356712) (Iowan\ Old\ Style.ttc 5 3414732) (Iowan\ Old\ Style.ttc 5 3419188)))
((Iowan\ Old\ Style Bold) ((Iowan\ Old\ Style.ttc 1 3356712) (Iowan\ Old\ Style.ttc 1 3414732) (Iowan\ Old\ Style.ttc 1 3419188)))
((Iowan\ Old\ Style Bold\ Italic) ((Iowan\ Old\ Style.ttc 3 3356712) (Iowan\ Old\ Style.ttc 3 3414732) (Iowan\ Old\ Style.ttc 3 3419188)))
((Iowan\ Old\ Style Italic) ((Iowan\ Old\ Style.ttc 2 3356712) (Iowan\ Old\ Style.ttc 2 3414732) (Iowan\ Old\ Style.ttc 2 3419188)))
((Iowan\ Old\ Style Roman) ((Iowan\ Old\ Style.ttc 0 3356712) (Iowan\ Old\ Style.ttc 0 3414732) (Iowan\ Old\ Style.ttc 0 3419188)))
((Iowan\ Old\ Style Titling) ((Iowan\ Old\ Style.ttc 6 3356712) (Iowan\ Old\ Style.ttc 6 3414732) (Iowan\ Old\ Style.ttc 6 3419188)))
((IPAexGothic Regular) ((ipaexg.ttf 0 6099900)))
((IPAexMincho Regular) ((ipaexm.ttf 0 7835672)))
((IPAGothic Regular) ((ipag.ttf 0 2890224) (ipag.ttf 0 6235344)))
((IPAMincho Regular) ((ipam.ttf 0 3581092) (ipam.ttf 0 8046712)))
((IPAPGothic Regular) ((ipagp.ttf 0 2890444) (ipagp.ttf 0 6235712)))
((IPAPMincho Regular) ((ipamp.ttf 0 3581116) (ipamp.ttf 0 8046048)))
((IPAUIGothic Regular) ((ipagui.ttf 0 2890480)))
((Isabella Medium) ((Isabella.ttf 0 144636)))
((ISL_Andvari Regular) ((andvari.ttf 0 17188)))
((ISL_Jupiter Regular) ((jupiter.ttf 0 26552)))
((ITF\ Devanagari Bold) ((ITFDevanagari.ttc 1 826144) (ITFDevanagari.ttc 1 817376)))
((ITF\ Devanagari Book) ((ITFDevanagari.ttc 0 826144) (ITFDevanagari.ttc 0 817376)))
((ITF\ Devanagari Demi) ((ITFDevanagari.ttc 2 826144) (ITFDevanagari.ttc 2 817376)))
((ITF\ Devanagari Light) ((ITFDevanagari.ttc 3 826144) (ITFDevanagari.ttc 3 817376)))
((ITF\ Devanagari Medium) ((ITFDevanagari.ttc 4 826144) (ITFDevanagari.ttc 4 817376)))
((ITF\ Devanagari\ Marathi Bold) ((ITFDevanagari.ttc 6 826144) (ITFDevanagari.ttc 6 817376)))
((ITF\ Devanagari\ Marathi Book) ((ITFDevanagari.ttc 5 826144) (ITFDevanagari.ttc 5 817376)))
((ITF\ Devanagari\ Marathi Demi) ((ITFDevanagari.ttc 7 826144) (ITFDevanagari.ttc 7 817376)))
((ITF\ Devanagari\ Marathi Light) ((ITFDevanagari.ttc 8 826144) (ITFDevanagari.ttc 8 817376)))
((ITF\ Devanagari\ Marathi Medium) ((ITFDevanagari.ttc 9 826144) (ITFDevanagari.ttc 9 817376)))
((Itsadzoke Regular) ((itsadzoke-046.otf 0 525784)))
((ItsadzokeS01 Regular) ((itsadzokeS01-046.otf 0 672520)))
((ItsadzokeS02 Regular) ((itsadzokeS02.otf 0 643452)))
((Iwona Bold) ((Iwona-Bold.otf 0 153328)))
((Iwona Bold\ Italic) ((Iwona-BoldItalic.otf 0 153596)))
((Iwona Heavy) ((IwonaHeavy-Regular.otf 0 153084)))
((Iwona Heavy\ Italic) ((IwonaHeavy-Italic.otf 0 153656)))
((Iwona Italic) ((Iwona-Italic.otf 0 152896) (IwonaMedium-Italic.otf 0 153472)))
((Iwona Light) ((IwonaLight-Regular.otf 0 151980)))
((Iwona Light\ Italic) ((IwonaLight-Italic.otf 0 154488)))
((Iwona Regular) ((Iwona-Regular.otf 0 151936) (IwonaMedium-Regular.otf 0 152384)))
((Iwona\ Cond Bold) ((IwonaCond-Bold.otf 0 152524)))
((Iwona\ Cond Bold\ Italic) ((IwonaCond-BoldItalic.otf 0 152912)))
((Iwona\ Cond Heavy) ((IwonaCondHeavy-Regular.otf 0 153300)))
((Iwona\ Cond Heavy\ Italic) ((IwonaCondHeavy-Italic.otf 0 153284)))
((Iwona\ Cond Italic) ((IwonaCond-Italic.otf 0 152768) (IwonaCondMedium-Italic.otf 0 153168)))
((Iwona\ Cond Light) ((IwonaCondLight-Regular.otf 0 151848)))
((Iwona\ Cond Light\ Italic) ((IwonaCondLight-Italic.otf 0 154212)))
((Iwona\ Cond Regular) ((IwonaCond-Regular.otf 0 152096) (IwonaCondMedium-Regular.otf 0 152036)))
((Javanese\ Text Regular) ((javatext.ttf 0 304068)))
((Jazz\ LET Plain) ((Jazz\ LET\ Fonts.ttf 0 171488) (Jazz\ LET\ Fonts.ttf 0 172020)))
((Junicode Bold) ((Junicode-Bold.ttf 0 420380) (Junicode-Bold.ttf 0 151944) (Junicode-Bold.ttf 0 263044)))
((Junicode Bold\ Italic) ((Junicode-BoldItalic.ttf 0 317172) (Junicode-BoldItalic.ttf 0 107064) (Junicode-BoldItalic.ttf 0 201012)))
((Junicode Italic) ((Junicode-Italic.ttf 0 961024) (Junicode-Italic.ttf 0 463156) (Junicode-Italic.ttf 0 719420)))
((Junicode Regular) ((Junicode.ttf 0 1369504) (Junicode-Regular.ttf 0 1369504) (Junicode-Regular.ttf 0 770972) (Junicode.ttf 0 841688)))
((Jura Book) ((JuraBook.ttf 0 59000)))
((Jura DemiBold) ((JuraDemiBold.ttf 0 59448)))
((Jura Light) ((JuraLight.ttf 0 58180)))
((Jura Medium) ((JuraMedium.ttf 0 58388)))
((Justus Bold) ((Justus-Bold.ttf 0 35772)))
((Justus Italic) ((Justus-Italic.ttf 0 37172)))
((Justus ItalicOldstyle) ((Justus-ItalicOldstyle.ttf 0 37788)))
((Justus Oldstyle) ((Justus-Oldstyle.ttf 0 42400)))
((Justus Roman) ((Justus-Roman.ttf 0 42512)))
((Justus Versalitas) ((Justus-Versalitas.ttf 0 36428)))
((KacstOne Medium) ((KacstOne.ttf 0 51368)))
((Kai Regular) ((Kai.ttf 0 7888604)))
((Kailasa Bold) ((Kailasa.ttc 1 1175268) (Kailasa.ttc 1 1178516) (Kailasa.ttc 1 1178132)))
((Kailasa Regular) ((Kailasa.ttf 0 594792) (Kailasa.ttc 0 1175268) (Kailasa.ttf 0 620764) (Kailasa.ttc 0 1178516) (Kailasa.ttc 0 1178132)))
((Kaiti\ SC Black) ((Kaiti.ttc 0 70712356) (楷体.ttc 0 23433244)))
((Kaiti\ SC Bold) ((Kaiti.ttc 1 70712356) (楷体.ttc 1 23433244)))
((Kaiti\ SC Regular) ((Kaiti.ttc 3 70712356) (楷体.ttc 2 23433244)))
((Kaiti\ TC Bold) ((Kaiti.ttc 2 70712356)))
((Kaiti\ TC Regular) ((Kaiti.ttc 5 70712356)))
((KaiTi_GB2312 Regular) ((simkai.ttf 0 4135804)))
((Kannada\ MN Bold) ((Kannada\ MN.ttc 1 1148468) (Kannada\ MN.ttc 1 1151416) (Kannada\ MN.ttc 1 342980)))
((Kannada\ MN Regular) ((Kannada\ MN.ttc 0 1148468) (Kannada\ MN.ttc 0 1151416) (Kannada\ MN.ttc 0 342980)))
((Kannada\ Sangam\ MN Bold) ((Kannada\ Sangam\ MN.ttc 1 1031232) (Kannada\ Sangam\ MN.ttc 1 1032408) (Kannada\ Sangam\ MN.ttc 1 296796)))
((Kannada\ Sangam\ MN Regular) ((Kannada\ Sangam\ MN.ttc 0 1031232) (Kannada\ Sangam\ MN.ttc 0 1032408) (Kannada\ Sangam\ MN.ttc 0 296796)))
((Kartika Regular) ((kartika.ttf 0 121452)))
((Kawoszeh Medium) ((kawoszeh.otf 0 143952) (kawoszeh.ttf 0 188828)))
((Kedage Bold) ((Kedage-b.ttf 0 95404)))
((Kedage Normal) ((Kedage-n.ttf 0 100056)))
((Kefa Bold) ((Kefa.ttc 1 389880) (Kefa.ttc 1 391476) (Kefa.ttc 1 394040)))
((Kefa Regular) ((Kefa.ttc 0 389880) (Kefa.ttc 0 391476) (Kefa.ttc 0 394040)))
((Kepler\ Std Medium) ((ufonts.com_keplerstd-medium-1-opentype.otf 0 172060)))
((Kerkis Bold) ((Kerkis-Bold.otf 0 70324)))
((Kerkis BoldItalic) ((Kerkis-BoldItalic.otf 0 69348)))
((Kerkis BoldSmallCaps) ((Kerkis-BoldSmallCaps.otf 0 32392)))
((Kerkis Italic) ((Kerkis-Italic.otf 0 73304)))
((Kerkis Medium) ((Kerkis.otf 0 71304)))
((Kerkis SmallCaps) ((Kerkis-SmallCaps.otf 0 50556)))
((Kerkis-Calligraphic Calligraphic) ((Kerkis-Calligraphic.otf 0 36260)))
((Kerkis-SemiBold SemiBold) ((Kerkis-SemiBold.otf 0 82984)))
((Kerkis-SemiBold SemiBold-Italic) ((Kerkis-SemiBold-Italic.otf 0 86408)))
((KerkisSans Bold) ((KerkisSans-Bold.otf 0 51416)))
((KerkisSans BoldItalic) ((KerkisSans-BoldItalic.otf 0 59172)))
((KerkisSans Italic) ((KerkisSans-Italic.otf 0 61244)))
((KerkisSans Medium) ((KerkisSans.otf 0 52916)))
((KerkisSans SmallCaps) ((KerkisSans-SmallCaps.otf 0 23328)))
((Keyboard Regular) ((Keyboard.ttf 0 28564) (Keyboard.ttf 0 55840) (Keyboard.ttf 0 17700) (Keyboard.ttf 0 58088)))
((Keytin Regular) ((Keytin-Light.ttf 0 102580)))
((Khmer\ MN Bold) ((Khmer\ MN.ttc 1 727504) (Khmer\ MN.ttc 1 727456) (Khmer\ MN.ttc 1 495056)))
((Khmer\ MN Regular) ((Khmer\ MN.ttc 0 727504) (Khmer\ MN.ttc 0 727456) (Khmer\ MN.ttc 0 495056)))
((Khmer\ OS Regular) ((KhmerOS.ttf 0 265552)))
((Khmer\ OS\ System Regular) ((KhmerOSsys.ttf 0 265624)))
((Khmer\ Sangam\ MN Regular) ((Khmer\ Sangam\ MN.ttf 0 278472) (Khmer\ Sangam\ MN.ttf 0 278444) (Khmer\ Sangam\ MN.ttf 0 188048)))
((Kinnari Bold) ((Kinnari-Bold.ttf 0 69228) (Kinnari-Bold.otf 0 50028)))
((Kinnari BoldItalic) ((Kinnari-BoldItalic.ttf 0 81604) (Kinnari-BoldItalic.otf 0 53264)))
((Kinnari BoldOblique) ((Kinnari-BoldOblique.ttf 0 79888) (Kinnari-BoldOblique.otf 0 53540)))
((Kinnari Italic) ((Kinnari-Italic.ttf 0 80640) (Kinnari-Italic.otf 0 53844)))
((Kinnari Medium) ((Kinnari.ttf 0 69412)))
((Kinnari Oblique) ((Kinnari-Oblique.ttf 0 80472) (Kinnari-Oblique.otf 0 54300)))
((Kinnari Regular) ((Kinnari.otf 0 50116)))
((Klee Demibold) ((Klee.ttc 0 14802804)))
((Klee Medium) ((Klee.ttc 1 14802804)))
((Kochi\ Gothic Regular) ((kochi-gothic.ttf 0 4254160)))
((Kohinoor\ Bangla Bold) ((KohinoorBangla.ttc 3 635128) (KohinoorBangla.ttc 3 696040)))
((Kohinoor\ Bangla Light) ((KohinoorBangla.ttc 4 635128) (KohinoorBangla.ttc 4 696040)))
((Kohinoor\ Bangla Medium) ((KohinoorBangla.ttc 2 635128) (KohinoorBangla.ttc 2 696040)))
((Kohinoor\ Bangla Regular) ((KohinoorBangla.ttc 0 635128) (KohinoorBangla.ttc 0 696040)))
((Kohinoor\ Bangla Semibold) ((KohinoorBangla.ttc 1 635128) (KohinoorBangla.ttc 1 696040)))
((Kohinoor\ Devanagari Bold) ((Kohinoor.ttc 3 907504) (Kohinoor.ttc 3 1041880)))
((Kohinoor\ Devanagari Light) ((Kohinoor.ttc 4 907504) (Kohinoor.ttc 4 1041880)))
((Kohinoor\ Devanagari Medium) ((Kohinoor.ttc 1 907504) (Kohinoor.ttc 1 1041880)))
((Kohinoor\ Devanagari Regular) ((Kohinoor.ttc 0 907504) (Kohinoor.ttc 0 1041880)))
((Kohinoor\ Devanagari Semibold) ((Kohinoor.ttc 2 907504) (Kohinoor.ttc 2 1041880)))
((Kohinoor\ Gujarati Bold) ((KohinoorGujarati.ttc 0 538284)))
((Kohinoor\ Gujarati Light) ((KohinoorGujarati.ttc 1 538284)))
((Kohinoor\ Gujarati Medium) ((KohinoorGujarati.ttc 2 538284)))
((Kohinoor\ Gujarati Regular) ((KohinoorGujarati.ttc 3 538284)))
((Kohinoor\ Gujarati Semibold) ((KohinoorGujarati.ttc 4 538284)))
((Kohinoor\ Telugu Bold) ((KohinoorTelugu.ttc 3 343244) (KohinoorTelugu.ttc 3 672280)))
((Kohinoor\ Telugu Light) ((KohinoorTelugu.ttc 4 343244) (KohinoorTelugu.ttc 4 672280)))
((Kohinoor\ Telugu Medium) ((KohinoorTelugu.ttc 2 672280)))
((Kohinoor\ Telugu Regular) ((KohinoorTelugu.ttc 0 343244) (KohinoorTelugu.ttc 2 343244) (KohinoorTelugu.ttc 0 672280)))
((Kohinoor\ Telugu Semibold) ((KohinoorTelugu.ttc 1 672280)))
((Kohinoor\ Telugu\ Semibold Regular) ((KohinoorTelugu.ttc 1 343244)))
((Kokonor Regular) ((Kokonor.ttf 0 1006136) (Kokonor.ttf 0 973544) (Kokonor.ttf 0 974272) (Kokonor.ttf 0 676076)))
((Koufi\ Abjadi Regular) ((KoufiAbjadi.ttc 0 53320)))
((Koufi\ Abjadi\ PUA Regular) ((KoufiAbjadi.ttc 1 53320)))
((KpMath Bold) ((KpMath-Bold.otf 0 196892)))
((KpMath Light) ((KpMath-Light.otf 0 455424)))
((KpMath Regular) ((KpMath-Regular.otf 0 428692)))
((KpMath Semibold) ((KpMath-Semibold.otf 0 198620)))
((KpMathSans Regular) ((KpMath-Sans.otf 0 275556)))
((KpMono Bold) ((KpMono-Bold.otf 0 57768)))
((KpMono BoldItalic) ((KpMono-BoldItalic.otf 0 64992)))
((KpMono Italic) ((KpMono-Italic.otf 0 66300)))
((KpMono Regular) ((KpMono-Regular.otf 0 58904)))
((KpRoman Bold) ((KpRoman-Bold.otf 0 132080)))
((KpRoman BoldItalic) ((KpRoman-BoldItalic.otf 0 142704)))
((KpRoman Italic) ((KpRoman-Italic.otf 0 134260)))
((KpRoman Light) ((KpRoman-Light.otf 0 130328)))
((KpRoman LightItalic) ((KpRoman-LightItalic.otf 0 135176)))
((KpRoman Regular) ((KpRoman-Regular.otf 0 130976)))
((KpRoman Semibold) ((KpRoman-Semibold.otf 0 129324)))
((KpRoman SemiboldItalic) ((KpRoman-SemiboldItalic.otf 0 140488)))
((KpSans Bold) ((KpSans-Bold.otf 0 102972)))
((KpSans BoldItalic) ((KpSans-BoldItalic.otf 0 110904)))
((KpSans Italic) ((KpSans-Italic.otf 0 110936)))
((KpSans Regular) ((KpSans-Regular.otf 0 102384)))
((Krungthep Regular) ((Krungthep.ttf 0 183036) (Krungthep.ttf 0 186800) (Krungthep.ttf 0 187608) (Krungthep.ttf 0 190152)))
((KufiStandardGK Regular) ((KufiStandardGK.ttf 0 79292) (KufiStandardGK.ttc 0 85588) (KufiStandardGK.ttf 0 79988) (KufiStandardGK.ttc 0 57728)))
((KufiStandardGK\ PUA Regular) ((KufiStandardGK.ttc 1 85588) (KufiStandardGK.ttc 1 57728)))
((Kurier Bold) ((Kurier-Bold.otf 0 152340)))
((Kurier Bold\ Italic) ((Kurier-BoldItalic.otf 0 152468)))
((Kurier Heavy) ((KurierHeavy-Regular.otf 0 151760)))
((Kurier Heavy\ Italic) ((KurierHeavy-Italic.otf 0 152476)))
((Kurier Italic) ((Kurier-Italic.otf 0 151968) (KurierMedium-Italic.otf 0 151972)))
((Kurier Light) ((KurierLight-Regular.otf 0 150880)))
((Kurier Light\ Italic) ((KurierLight-Italic.otf 0 153200)))
((Kurier Regular) ((Kurier-Regular.otf 0 150796) (KurierMedium-Regular.otf 0 151032)))
((Kurier\ Cond Bold) ((KurierCond-Bold.otf 0 151088)))
((Kurier\ Cond Bold\ Italic) ((KurierCond-BoldItalic.otf 0 151840)))
((Kurier\ Cond Heavy) ((KurierCondHeavy-Regular.otf 0 152432)))
((Kurier\ Cond Heavy\ Italic) ((KurierCondHeavy-Italic.otf 0 152356)))
((Kurier\ Cond Italic) ((KurierCond-Italic.otf 0 151604) (KurierCondMedium-Italic.otf 0 152024)))
((Kurier\ Cond Light) ((KurierCondLight-Regular.otf 0 150764)))
((Kurier\ Cond Light\ Italic) ((KurierCondLight-Italic.otf 0 153308)))
((Kurier\ Cond Regular) ((KurierCond-Regular.otf 0 150552) (KurierCondMedium-Regular.otf 0 150948)))
((Laimoon Regular) ((Laimoon.ttc 0 64952)))
((Laimoon\ PUA Regular) ((Laimoon.ttc 1 64952)))
((Laksaman Bold) ((Laksaman-Bold.otf 0 69896)))
((Laksaman Bold\ Italic) ((Laksaman-BoldItalic.otf 0 74524)))
((Laksaman Italic) ((Laksaman-Italic.otf 0 75364)))
((Laksaman Regular) ((Laksaman.otf 0 72404)))
((Lampoon Regular) ((lampoon.ttf 0 11836)))
((Lantinghei\ SC Demibold) ((Lantinghei.ttc 0 43196124)))
((Lantinghei\ SC Extralight) ((Lantinghei.ttc 1 43196124)))
((Lantinghei\ SC Heavy) ((Lantinghei.ttc 2 43196124)))
((Lantinghei\ TC Demibold) ((Lantinghei.ttc 3 43196124)))
((Lantinghei\ TC Extralight) ((Lantinghei.ttc 4 43196124) (LantingheiTC-Extralight.ttf 0 6575944)))
((Lantinghei\ TC Heavy) ((Lantinghei.ttc 5 43196124)))
((Lao\ MN Bold) ((Lao\ MN.ttc 1 174672) (Lao\ MN.ttc 1 173580) (Lao\ MN.ttc 1 96348)))
((Lao\ MN Regular) ((Lao\ MN.ttc 0 174672) (Lao\ MN.ttc 0 173580) (Lao\ MN.ttc 0 96348)))
((Lao\ Sangam\ MN Regular) ((Lao\ Sangam\ MN.ttf 0 88532) (Lao\ Sangam\ MN.ttf 0 88000) (Lao\ Sangam\ MN.ttf 0 58092)))
((LastResort Regular) ((LastResort.ttf 0 13894924) (LastResort.ttf 0 3044) (LastResort.ttf 0 538692)))
((Latha Regular) ((latha.ttf 0 73292)))
((Latin\ Modern\ Math Regular) ((latinmodern-math.otf 0 733736)))
((Lato Black) ((Lato-Bla.ttf 0 114588) (Lato-Black.ttf 0 114588) (Lato-Black.ttf 0 89916) (Lato-Black.ttf 0 614544)))
((Lato Black\ Italic) ((Lato-BlaIta.ttf 0 111616) (Lato-BlackItalic.ttf 0 111616) (Lato-BlackItalic.ttf 0 82000) (Lato-BlackItalic.ttf 0 672480)))
((Lato Bold) ((Lato-Bol.ttf 0 121788) (Lato-Bold.ttf 0 121788) (Lato-Bold.ttf 0 93688) (Lato-Bold.ttf 0 657188)))
((Lato Bold\ Italic) ((Lato-BolIta.ttf 0 120312) (Lato-BoldItalic.ttf 0 120312) (Lato-BoldItalic.ttf 0 82396) (Lato-BoldItalic.ttf 0 699008)))
((Lato Hairline) ((Lato-Hai.ttf 0 115316) (Lato-Hairline.ttf 0 115316) (Lato-Hairline.ttf 0 128508) (Lato-Hairline.ttf 0 584784)))
((Lato Hairline\ Italic) ((Lato-HaiIta.ttf 0 91460) (Lato-HairlineItalic.ttf 0 91460) (Lato-HairlineItalic.ttf 0 96680) (Lato-HairlineItalic.ttf 0 609436)))
((Lato Heavy) ((Lato-Heavy.ttf 0 665420)))
((Lato Heavy\ Italic) ((Lato-HeavyItalic.ttf 0 698924)))
((Lato Italic) ((Lato-RegIta.ttf 0 118352) (Lato-Italic.ttf 0 118352) (Lato-Italic.ttf 0 84140) (Lato-Italic.ttf 0 723544)))
((Lato Light) ((Lato-Lig.ttf 0 122524) (Lato-Light.ttf 0 122524) (Lato-Light.ttf 0 111012) (Lato-Light.ttf 0 644556)))
((Lato Light\ Italic) ((Lato-LigIta.ttf 0 91600) (Lato-LightItalic.ttf 0 91600) (Lato-LightItalic.ttf 0 80252) (Lato-LightItalic.ttf 0 658212)))
((Lato Medium) ((Lato-Medium.ttf 0 637068)))
((Lato Medium\ Italic) ((Lato-MediumItalic.ttf 0 695588)))
((Lato Regular) ((Lato-Reg.ttf 0 120196) (Lato-Regular.ttf 0 120196) (Lato-Regular.ttf 0 96512) (Lato-Regular.ttf 0 657212)))
((Lato Semibold) ((Lato-Semibold.ttf 0 669228)))
((Lato Semibold\ Italic) ((Lato-SemiboldItalic.ttf 0 698028)))
((Lato Thin) ((Lato-Thin.ttf 0 627220)))
((Lato Thin\ Italic) ((Lato-ThinItalic.ttf 0 654216)))
((Leelawadee\ UI Bold) ((LeelaUIb.ttf 0 327420)))
((Leelawadee\ UI Regular) ((LeelawUI.ttf 0 393764)))
((Leelawadee\ UI SemiLight) ((LeelUIsl.ttf 0 386264)))
((Lexend\ Deca Regular) ((LexendDeca-Regular.ttf 0 138556)))
((Lexend\ Exa Regular) ((LexendExa-Regular.ttf 0 139896)))
((Lexend\ Giga Regular) ((LexendGiga-Regular.ttf 0 139936)))
((Lexend\ Mega Regular) ((LexendMega-Regular.ttf 0 139872)))
((Lexend\ Peta Regular) ((LexendPeta-Regular.ttf 0 139744)))
((Lexend\ Tera Regular) ((LexendTera-Regular.ttf 0 139836)))
((Lexend\ Zetta Regular) ((LexendZetta-Regular.ttf 0 138904)))
((Liberation\ Mono Bold) ((LiberationMono-Bold.ttf 0 105048) (LiberationMono-Bold.ttf 0 105116)))
((Liberation\ Mono Bold\ Italic) ((LiberationMono-BoldItalic.ttf 0 118112) (LiberationMono-BoldItalic.ttf 0 117800)))
((Liberation\ Mono Italic) ((LiberationMono-Italic.ttf 0 123304) (LiberationMono-Italic.ttf 0 123804)))
((Liberation\ Mono Regular) ((LiberationMono-Regular.ttf 0 108168) (LiberationMono-Regular.ttf 0 107696)))
((Liberation\ Sans Bold) ((LiberationSans-Bold.ttf 0 133488) (LiberationSans-Bold.ttf 0 139008)))
((Liberation\ Sans Bold\ Italic) ((LiberationSans-BoldItalic.ttf 0 128968) (LiberationSans-BoldItalic.ttf 0 134548)))
((Liberation\ Sans Italic) ((LiberationSans-Italic.ttf 0 155452) (LiberationSans-Italic.ttf 0 161020)))
((Liberation\ Sans Regular) ((LiberationSans-Regular.ttf 0 133828) (LiberationSans-Regular.ttf 0 139280)))
((Liberation\ Serif Bold) ((LiberationSerif-Bold.ttf 0 141180) (LiberationSerif-Bold.ttf 0 146184)))
((Liberation\ Serif Bold\ Italic) ((LiberationSerif-BoldItalic.ttf 0 144280) (LiberationSerif-BoldItalic.ttf 0 149804)))
((Liberation\ Serif Italic) ((LiberationSerif-Italic.ttf 0 138448) (LiberationSerif-Italic.ttf 0 143432)))
((Liberation\ Serif Regular) ((LiberationSerif-Regular.ttf 0 146324) (LiberationSerif-Regular.ttf 0 151480)))
((Libertinus\ Keyboard Regular) ((LibertinusKeyboard-Regular.otf 0 181064)))
((Libertinus\ Math Regular) ((LibertinusMath-Regular.otf 0 841272)))
((Libertinus\ Mono Regular) ((LibertinusMono-Regular.otf 0 106592)))
((Libertinus\ Sans Bold) ((LibertinusSans-Bold.otf 0 519552)))
((Libertinus\ Sans Italic) ((LibertinusSans-Italic.otf 0 509484)))
((Libertinus\ Sans Regular) ((LibertinusSans-Regular.otf 0 496504)))
((Libertinus\ Serif Bold) ((LibertinusSerif-Bold.otf 0 544712)))
((Libertinus\ Serif Bold\ Italic) ((LibertinusSerif-BoldItalic.otf 0 419320)))
((Libertinus\ Serif Italic) ((LibertinusSerif-Italic.otf 0 563644)))
((Libertinus\ Serif Regular) ((LibertinusSerif-Regular.otf 0 588156)))
((Libertinus\ Serif SemiBold) ((LibertinusSerif-Semibold.otf 0 543700)))
((Libertinus\ Serif SemiBold\ Italic) ((LibertinusSerif-SemiboldItalic.otf 0 592780)))
((Libertinus\ Serif\ Display Regular) ((LibertinusSerifDisplay-Regular.otf 0 520644)))
((Libertinus\ Serif\ Initials Regular) ((LibertinusSerifInitials-Regular.otf 0 153708)))
((Libian\ SC Regular) ((Libian.ttc 0 7528132)))
((Libre\ Baskerville Bold) ((LibreBaskerville-Bold.otf 0 81904)))
((Libre\ Baskerville BoldItalic) ((LibreBaskerville-BoldItalic.otf 0 90268)))
((Libre\ Baskerville Italic) ((LibreBaskerville-Italic.otf 0 128172)))
((Libre\ Baskerville Regular) ((LibreBaskerville-Regular.otf 0 81532)))
((Libre\ Bodoni Bold) ((LibreBodoni-Bold.otf 0 59372)))
((Libre\ Bodoni Bold\ Italic) ((LibreBodoni-BoldItalic.otf 0 56992)))
((Libre\ Bodoni Italic) ((LibreBodoni-Italic.otf 0 56112)))
((Libre\ Bodoni Regular) ((LibreBodoni-Regular.otf 0 58748)))
((Libre\ Caslon\ Text Bold) ((LibreCaslonText-Bold.otf 0 81624)))
((Libre\ Caslon\ Text BoldItalic) ((LibreCaslonText-BoldItalic.otf 0 111408)))
((Libre\ Caslon\ Text Italic) ((LibreCaslonText-Italic.otf 0 99000)))
((Libre\ Caslon\ Text Regular) ((LibreCaslonText-Regular.otf 0 79992)))
((Libre\ Franklin Black) ((LibreFranklin-Black.otf 0 68268)))
((Libre\ Franklin Black\ Italic) ((LibreFranklin-BlackItalic.otf 0 71176)))
((Libre\ Franklin Bold) ((LibreFranklin-Bold.otf 0 68328)))
((Libre\ Franklin Bold\ Italic) ((LibreFranklin-BoldItalic.otf 0 71060)))
((Libre\ Franklin ExtraBold) ((LibreFranklin-ExtraBold.otf 0 68956)))
((Libre\ Franklin ExtraBold\ Italic) ((LibreFranklin-ExtraBoldItalic.otf 0 71840)))
((Libre\ Franklin ExtraLight) ((LibreFranklin-ExtraLight.otf 0 65012)))
((Libre\ Franklin ExtraLight\ Italic) ((LibreFranklin-ExtraLightItalic.otf 0 68572)))
((Libre\ Franklin Italic) ((LibreFranklin-Italic.otf 0 68912)))
((Libre\ Franklin Light) ((LibreFranklin-Light.otf 0 65444)))
((Libre\ Franklin Light\ Italic) ((LibreFranklin-LightItalic.otf 0 68536)))
((Libre\ Franklin Medium) ((LibreFranklin-Medium.otf 0 65932)))
((Libre\ Franklin Medium\ Italic) ((LibreFranklin-MediumItalic.otf 0 69640)))
((Libre\ Franklin Regular) ((LibreFranklin-Regular.otf 0 65848)))
((Libre\ Franklin SemiBold) ((LibreFranklin-SemiBold.otf 0 66332)))
((Libre\ Franklin SemiBold\ Italic) ((LibreFranklin-SemiBoldItalic.otf 0 69228)))
((Libre\ Franklin Thin) ((LibreFranklin-Thin.otf 0 63376)))
((Libre\ Franklin Thin\ Italic) ((LibreFranklin-ThinItalic.otf 0 67604)))
((LiHei\ Pro Medium) ((儷黑\ Pro.ttf 0 10823828) (儷黑\ Pro.ttf 0 6977160)))
((Lilith Regular) ((fuente\ lilith.ttf 0 29312)))
((Linesquare\ Rounded Extended) ((linesquare_rounded_extended.ttf 0 56296)))
((Linguistics\ Pro Bold) ((LinguisticsPro-Bold.otf 0 116908)))
((Linguistics\ Pro Bold\ Italic) ((LinguisticsPro-BoldItalic.otf 0 225736)))
((Linguistics\ Pro Italic) ((LinguisticsPro-Italic.otf 0 220484)))
((Linguistics\ Pro Regular) ((LinguisticsPro-Regular.otf 0 170676)))
((Linux\ Biolinum Bold) ((LinBiolinum_RB.ttf 0 755872) (LinBiolinum_RB.otf 0 514532)))
((Linux\ Biolinum Italic) ((LinBiolinum_RI.ttf 0 838996) (LinBiolinum_RI.otf 0 662776)))
((Linux\ Biolinum Regular) ((LinBiolinum_R.ttf 0 763168) (LinBiolinum_R.otf 0 418076)))
((Linux\ Biolinum\ Capitals Bold) ((LinBiolinum_aSB.ttf 0 752004)))
((Linux\ Biolinum\ Capitals Italic) ((LinBiolinum_aSI.ttf 0 834824)))
((Linux\ Biolinum\ Capitals Regular) ((LinBiolinum_aS.ttf 0 760200)))
((Linux\ Biolinum\ Keyboard Regular) ((LinBiolinum_K.ttf 0 260632)))
((Linux\ Biolinum\ Keyboard\ O Regular) ((LinBiolinum_K.otf 0 122992)))
((Linux\ Biolinum\ O Bold) ((LinBiolinum_RB.otf 0 486092)))
((Linux\ Biolinum\ O Bold\ Oblique) ((LinBiolinum_RBO.otf 0 746100) (LinBiolinum_RBO.otf 0 1130108)))
((Linux\ Biolinum\ O Italic) ((LinBiolinum_RI.otf 0 662776)))
((Linux\ Biolinum\ O Regular) ((LinBiolinum_R.otf 0 418076)))
((Linux\ Biolinum\ Outline Bold) ((LinBiolinum_aUB.ttf 0 1556244)))
((Linux\ Biolinum\ Outline Italic) ((LinBiolinum_aUI.ttf 0 1817568)))
((Linux\ Biolinum\ Outline Regular) ((LinBiolinum_aU.ttf 0 1561212)))
((Linux\ Biolinum\ Shadow Bold) ((LinBiolinum_aWB.ttf 0 1531508)))
((Linux\ Biolinum\ Shadow Italic) ((LinBiolinum_aWI.ttf 0 1578504)))
((Linux\ Biolinum\ Shadow Regular) ((LinBiolinum_aW.ttf 0 1515372)))
((Linux\ Biolinum\ Slanted Bold\ Slanted) ((LinBiolinum_aBL.ttf 0 798160)))
((Linux\ Biolinum\ Slanted Slanted) ((LinBiolinum_aRL.ttf 0 835804)))
((Linux\ Libertine Bold) ((LinLibertine_RB.ttf 0 834472) (LinLibertine_RB.otf 0 426060)))
((Linux\ Libertine Bold\ Italic) ((LinLibertine_RBI.ttf 0 596808) (LinLibertine_RBI.otf 0 363740)))
((Linux\ Libertine Italic) ((LinLibertine_RI.ttf 0 852768) (LinLibertine_RI.otf 0 445044)))
((Linux\ Libertine Regular) ((LinLibertine_R.ttf 0 906980) (LinLibertine_R.otf 0 528064)))
((Linux\ Libertine Semibold) ((LinLibertine_RZ.ttf 0 771388)))
((Linux\ Libertine Semibold\ Italic) ((LinLibertine_RZI.ttf 0 870052)))
((Linux\ Libertine\ Capitals Bold) ((LinLibertine_aBS.ttf 0 833160)))
((Linux\ Libertine\ Capitals Italic) ((LinLibertine_aSI.ttf 0 849064)))
((Linux\ Libertine\ Capitals Regular) ((LinLibertine_aS.ttf 0 904204)))
((Linux\ Libertine\ Capitals Semibold\ Italic) ((LinLibertine_aSZI.ttf 0 869964)))
((Linux\ Libertine\ Display Regular) ((LinLibertine_DR.ttf 0 767840)))
((Linux\ Libertine\ Display\ Capitals Regular) ((LinLibertine_aDRS.ttf 0 768032)))
((Linux\ Libertine\ Display\ O Regular) ((LinLibertine_DR.otf 0 383672)))
((Linux\ Libertine\ Initials Initials) ((LinLibertine_I.ttf 0 282676)))
((Linux\ Libertine\ Initials\ O Initials) ((LinLibertine_I.otf 0 399004)))
((Linux\ Libertine\ Mono\ O Mono) ((LinLibertine_M.otf 0 139864) (LinLibertine_MO.otf 0 231828)))
((Linux\ Libertine\ Mono\ O\  Mono) ((LinLibertine_MB.otf 0 450864) (LinLibertine_MBO.otf 0 485724) (LinLibertine_MB.otf 0 442924) (LinLibertine_MBO.otf 0 457468)))
((Linux\ Libertine\ O Bold) ((LinLibertine_RB.otf 0 426060)))
((Linux\ Libertine\ O Bold\ Italic) ((LinLibertine_RBI.otf 0 261704)))
((Linux\ Libertine\ O Italic) ((LinLibertine_RI.otf 0 353408)))
((Linux\ Libertine\ O Regular) ((LinLibertine_R.otf 0 528064)))
((Linux\ Libertine\ O Semibold) ((LinLibertine_RZ.otf 0 300524)))
((Linux\ Libertine\ O Semibold\ Italic) ((LinLibertine_RZI.otf 0 391468) (LinLibertine_RZI.otf 0 397388)))
((Linux\ Libertine\ Slanted Bold\ Slanted) ((LinLibertine_aBL.ttf 0 879624)))
((Linux\ Libertine\ Slanted Semibold\ Slanted) ((LinLibertine_aZL.ttf 0 807272)))
((Linux\ Libertine\ Slanted Slanted) ((LinLibertine_aRL.ttf 0 976416)))
((LiSong\ Pro Light) ((儷宋\ Pro.ttf 0 17965572) (儷宋\ Pro.ttf 0 14119008)))
((LiSu Regular) ((simli.ttf 0 9223160)))
((Litos\ Script Italic) ((Litos\ Script\ Italic.otf 0 54008)))
((Litos\ Script Regular) ((Litos\ Script\ regular.otf 0 71900)))
((Litos\ Script SemiBold) ((Litos\ Script\ BOLD.otf 0 258100)))
((Litos\ Script SemiBold\ Italic) ((Litos\ Script_BOLD\ Italic.otf 0 47288)))
((Livia Medium) ((Livia\ Medium.ttf 0 17020)))
((LMTypewriter10\ Regular Regular) ((lmtypewriter10-regular.ttf 0 128340)))
((Lobster\ Two Bold) ((LobsterTwo-Bold.otf 0 92184) (LobsterTwo-Bold.ttf 0 241104)))
((Lobster\ Two Bold\ Italic) ((LobsterTwo-BoldItalic.otf 0 97008) (LobsterTwo-BoldItalic.ttf 0 235632)))
((Lobster\ Two Italic) ((LobsterTwo-Italic.otf 0 94632) (LobsterTwo-Italic.ttf 0 249896)))
((Lobster\ Two Regular) ((LobsterTwo-Regular.otf 0 93308) (LobsterTwo-Regular.ttf 0 254332)))
((Logix Regular) ((logix.otf 0 429804) (logix.ttf 0 1053108)))
((Lohit\ Bengali Regular) ((lohit_bn.ttf 0 141352)))
((Lohit\ Gujarati Regular) ((lohit_gu.ttf 0 79860)))
((Lohit\ Hindi Regular) ((lohit_hi.ttf 0 81484)))
((Lohit\ Punjabi Regular) ((lohit_pa.ttf 0 25852)))
((Lohit\ Tamil Regular) ((lohit_ta.ttf 0 67688)))
((Loma Bold) ((Loma-Bold.ttf 0 69352) (Loma-Bold.otf 0 48964)))
((Loma BoldOblique) ((Loma-BoldOblique.ttf 0 80500) (Loma-BoldOblique.otf 0 50944)))
((Loma Book) ((Loma.ttf 0 70412)))
((Loma Oblique) ((Loma-Oblique.ttf 0 83544) (Loma-Oblique.otf 0 52036)))
((Loma Regular) ((Loma.otf 0 50128)))
((Lucida\ Console Regular) ((lucon.ttf 0 115068) (lucon.ttf 0 111108)))
((Lucida\ Grande Bold) ((LucidaGrande.ttc 1 1757684) (LucidaGrande.ttc 1 3181856) (LucidaGrande.ttc 1 1746028) (LucidaGrande.ttc 1 3200180) (LucidaGrande.ttc 1 3200332)))
((Lucida\ Grande Regular) ((LucidaGrande.ttc 0 1757684) (LucidaGrande.ttc 0 3181856) (LucidaGrande.ttc 0 1746028) (LucidaGrande.ttc 0 3200180) (LucidaGrande.ttc 0 3200332)))
((Lucida\ Sans Demibold\ Italic) ((lsansdi.ttf 0 60664)))
((Lucida\ Sans Demibold\ Roman) ((lsansd.ttf 0 54320)))
((Lucida\ Sans Italic) ((lsansi.ttf 0 59636)))
((Lucida\ Sans Regular) ((lsans.ttf 0 58740)))
((Lucida\ Sans\ Unicode Regular) ((l_10646.ttf 0 323980) (l_10646.ttf 0 309516)))
((Luminari Regular) ((Luminari.ttf 0 553520) (Luminari.ttf 0 557856)))
((Luxi\ Mono Bold) ((luximb.ttf 0 74076)))
((Luxi\ Mono Bold\ Oblique) ((luximbi.ttf 0 69872)))
((Luxi\ Mono Oblique) ((luximri.ttf 0 69496)))
((Luxi\ Mono Regular) ((luximr.ttf 0 71784)))
((Luxi\ Sans Bold) ((luxisb.ttf 0 69972)))
((Luxi\ Sans Bold\ Oblique) ((luxisbi.ttf 0 65568)))
((Luxi\ Sans Oblique) ((luxisri.ttf 0 66372)))
((Luxi\ Sans Regular) ((luxisr.ttf 0 67548)))
((Luxi\ Serif Bold) ((luxirb.ttf 0 87160)))
((Luxi\ Serif Bold\ Oblique) ((luxirbi.ttf 0 85756)))
((Luxi\ Serif Oblique) ((luxirri.ttf 0 86396)))
((Luxi\ Serif Regular) ((luxirr.ttf 0 88732)))
((Maassslicer Regular) ((maass\ slicer\ Italic.ttf 0 116984)))
((Making\ a\ List\ Checking\ it\ Twice Regular) ((Making\ a\ List,\ Checking\ it\ Twice.ttf 0 92140) (MakingaListCheckingItTwice.otf 0 32296)))
((Malayalam\ MN Bold) ((Malayalam\ MN.ttc 1 336580) (Malayalam\ MN.ttc 1 337216) (Malayalam\ MN.ttc 1 175056)))
((Malayalam\ MN Regular) ((Malayalam\ MN.ttc 0 336580) (Malayalam\ MN.ttc 0 337216) (Malayalam\ MN.ttc 0 175056)))
((Malayalam\ Sangam\ MN Bold) ((Malayalam\ Sangam\ MN.ttc 1 330892) (Malayalam\ Sangam\ MN.ttc 1 330864) (Malayalam\ Sangam\ MN.ttc 1 185216)))
((Malayalam\ Sangam\ MN Regular) ((Malayalam\ Sangam\ MN.ttc 0 330892) (Malayalam\ Sangam\ MN.ttc 0 330864) (Malayalam\ Sangam\ MN.ttc 0 185216)))
((Malgun\ Gothic Bold) ((malgunbd.ttf 0 12598360)))
((Malgun\ Gothic Regular) ((malgun.ttf 0 13457164)))
((Malgun\ Gothic SemiLight) ((malgunsl.ttf 0 5083156)))
((Malgun\ Gothic\ Boot Regular) ((malgun_boot.ttf 0 178098) (malgunn_boot.ttf 0 175642)))
((Mallige Bold) ((Malige-b.ttf 0 104412)))
((Mallige Normal) ((Malige-n.ttf 0 121500)))
((Mangal Regular) ((mangal.ttf 0 143864)))
((Marcellus Regular) ((Marcellus-Regular.ttf 0 43348)))
((MarcellusSmallCaps Regular) ((MarcellusSmallCaps.ttf 0 45772)))
((Marion Bold) ((Marion.ttc 2 915352) (Marion.ttc 2 705260) (Marion.ttc 2 927292)))
((Marion Italic) ((Marion.ttc 1 915352) (Marion.ttc 1 705260) (Marion.ttc 1 927292)))
((Marion Regular) ((Marion.ttc 0 915352) (Marion.ttc 0 705260) (Marion.ttc 0 927292)))
((Marker\ Felt Thin) ((MarkerFelt.ttc 0 544364) (MarkerFelt.ttc 0 621152) (MarkerFelt.ttc 0 650364) (MarkerFelt.ttc 0 627492)))
((Marker\ Felt Wide) ((MarkerFelt.ttc 1 544364) (MarkerFelt.ttc 1 621152) (MarkerFelt.ttc 1 650364) (MarkerFelt.ttc 1 627492)))
((Marlett Regular) ((marlett.ttf 0 24124) (marlett.ttf 0 27724)))
((MarVoSym Regular) ((marvosym.ttf 0 69792)))
((MdSymbol Bold) ((MdSymbol-Bold.otf 0 124316)))
((MdSymbol Light) ((MdSymbol-Light.otf 0 121932)))
((MdSymbol Regular) ((MdSymbol-Regular.otf 0 121236)))
((MdSymbol Semibold) ((MdSymbol-Semibold.otf 0 121592)))
((Meera Regular) ((Meera_04.ttf 0 334404)))
((Meiryo\ Boot Regular) ((meiryo_boot.ttf 0 145891) (meiryon_boot.ttf 0 144230)))
((Menaion\ Unicode Regular) ((MenaionUnicode.otf 0 375004)))
((Menaion\ Unicode\ TT Regular) ((MenaionUnicode.ttf 0 430728)))
((Menlo Bold) ((Menlo.ttc 1 2172912) (Menlo.ttc 1 2140384) (Menlo.ttc 1 2144600) (Menlo.ttc 1 2153464)))
((Menlo Bold\ Italic) ((Menlo.ttc 3 2172912) (Menlo.ttc 3 2140384) (Menlo.ttc 3 2144600) (Menlo.ttc 3 2153464)))
((Menlo Italic) ((Menlo.ttc 2 2172912) (Menlo.ttc 2 2140384) (Menlo.ttc 2 2144600) (Menlo.ttc 2 2153464)))
((Menlo Regular) ((Menlo.ttc 0 2172912) (Menlo.ttc 0 2140384) (Menlo.ttc 0 2144600) (Menlo.ttc 0 2153464)))
((Merriweather Bold) ((Merriweather-Bold.ttf 0 167640)))
((Merriweather Bold\ Italic) ((Merriweather-BoldIt.ttf 0 175076)))
((Merriweather Italic) ((Merriweather-Italic.ttf 0 174316)))
((Merriweather Light) ((Merriweather-Light.ttf 0 168640)))
((Merriweather Light\ Italic) ((Merriweather-LightIt.ttf 0 175092)))
((Merriweather Regular) ((Merriweather-Regular.ttf 0 170016)))
((Merriweather\ UltraBold Italic) ((Merriweather-UltraBdIt.ttf 0 174436)))
((Merriweather\ UltraBold Regular) ((Merriweather-UltraBold.ttf 0 170180)))
((MerriweatherSans Bold) ((MerriweatherSans-Bold.ttf 0 88132)))
((MerriweatherSans Bold\ Italic) ((MerriweatherSans-BoldItalic.ttf 0 90400)))
((MerriweatherSans ExtraBold) ((MerriweatherSans-ExtraBold.ttf 0 88188)))
((MerriweatherSans ExtraBold\ Italic) ((MerriweatherSans-ExBoldIt.ttf 0 90264)))
((MerriweatherSans Italic) ((MerriweatherSans-Italic.ttf 0 89820)))
((MerriweatherSans Light) ((MerriweatherSans-Light.ttf 0 87752)))
((MerriweatherSans LightItalic) ((MerriweatherSans-LightItalic.ttf 0 89356)))
((MerriweatherSans Regular) ((MerriweatherSans-Regular.ttf 0 88316)))
((Meyne\ Textur Regular) ((meyne_textur.ttf 0 81588)))
((Miama\ Nueva Medium) ((miama.otf 0 218956)))
((Microsoft\ Himalaya Regular) ((himalaya.ttf 0 572776)))
((Microsoft\ JhengHei Bold) ((msjhbd.ttc 0 14439416)))
((Microsoft\ JhengHei Light) ((msjhl.ttc 0 12875740)))
((Microsoft\ JhengHei Regular) ((msjh.ttc 0 21402152)))
((Microsoft\ JhengHei\ Boot Regular) ((msjh_boot.ttf 0 165734) (msjhn_boot.ttf 0 163705)))
((Microsoft\ JhengHei\ UI Bold) ((msjhbd.ttc 1 14439416)))
((Microsoft\ JhengHei\ UI Light) ((msjhl.ttc 1 12875740)))
((Microsoft\ JhengHei\ UI Regular) ((msjh.ttc 1 21402152)))
((Microsoft\ New\ Tai\ Lue Bold) ((ntailub.ttf 0 67168)))
((Microsoft\ New\ Tai\ Lue Regular) ((ntailu.ttf 0 74464)))
((Microsoft\ PhagsPa Bold) ((phagspab.ttf 0 97476)))
((Microsoft\ PhagsPa Regular) ((phagspa.ttf 0 93720)))
((Microsoft\ Sans\ Serif Regular) ((Microsoft\ Sans\ Serif.ttf 0 652248) (micross.ttf 0 461672) (micross.ttf 0 876256)))
((Microsoft\ Tai\ Le Bold) ((taileb.ttf 0 58532)))
((Microsoft\ Tai\ Le Regular) ((taile.ttf 0 67568)))
((Microsoft\ YaHei Bold) ((msyhbd.ttc 0 16829116)))
((Microsoft\ YaHei Light) ((msyhl.ttc 0 12139380)))
((Microsoft\ YaHei Regular) ((msyh.ttc 0 19647736)))
((Microsoft\ YaHei\ Boot Regular) ((msyh_boot.ttf 0 157274) (msyhn_boot.ttf 0 155436)))
((Microsoft\ YaHei\ UI Bold) ((msyhbd.ttc 1 16829116)))
((Microsoft\ YaHei\ UI Light) ((msyhl.ttc 1 12139380)))
((Microsoft\ YaHei\ UI Regular) ((msyh.ttc 1 19647736)))
((Microsoft\ Yi\ Baiti Regular) ((msyi.ttf 0 301180)))
((Mikodacs Regular) ((Mikodacs.otf 0 238596)))
((MikodacsPCS Regular) ((MikodacsPCS.otf 0 130460)))
((MingLiU Regular) ((MingLiU.ttf 0 6272080)))
((MingLiU-ExtB Regular) ((mingliub.ttc 0 36786404)))
((MingLiU_HKSCS-ExtB Regular) ((mingliub.ttc 2 36786404)))
((Mint\ Spirit Bold) ((MintSpirit-Bold.otf 0 139060)))
((Mint\ Spirit Bold\ Italic) ((MintSpirit-BoldItalic.otf 0 148424)))
((Mint\ Spirit Italic) ((MintSpirit-Italic.otf 0 137588)))
((Mint\ Spirit Regular) ((MintSpirit-Regular.otf 0 155932)))
((Mint\ Spirit\ No2 Bold) ((MintSpiritNo2-Bold.otf 0 132068)))
((Mint\ Spirit\ No2 Bold\ Italic) ((MintSpiritNo2-BoldItalic.otf 0 141572)))
((Mint\ Spirit\ No2 Italic) ((MintSpiritNo2-Italic.otf 0 157284)))
((Mint\ Spirit\ No2 Regular) ((MintSpiritNo2-Regular.otf 0 146696)))
((Mishafi Regular) ((Mishafi.ttf 0 1425292) (Mishafi.ttf 0 1426864)))
((Mishafi\ Gold Regular) ((Mishafi\ Gold.ttf 0 658260) (Mishafi\ Gold.ttf 0 649384)))
((Missaali Regular) ((Missaali-Regular.otf 0 257432)))
((Mona\ Lisa\ Solid\ ITC\ TT Regular) ((Mona\ Lisa\ Solid\ ITC\ TT.ttf 0 161936)))
((Mongolian\ Baiti Regular) ((monbaiti.ttf 0 289052)))
((Monomakh\ Unicode Medium) ((MonomakhUnicode.otf 0 155520)))
((Monomakh\ Unicode\ TT Medium) ((MonomakhUnicode.ttf 0 553172)))
((Monteiro\ Lobato Regular) ((lobato.ttf 0 82204)))
((Montserrat Black) ((Montserrat-Black.otf 0 230384)))
((Montserrat Black\ Italic) ((Montserrat-BlackItalic.otf 0 234676)))
((Montserrat Bold) ((Montserrat-Bold.otf 0 234388)))
((Montserrat Bold\ Italic) ((Montserrat-BoldItalic.otf 0 241552)))
((Montserrat ExtraBold) ((Montserrat-ExtraBold.otf 0 234736)))
((Montserrat ExtraBold\ Italic) ((Montserrat-ExtraBoldItalic.otf 0 242520)))
((Montserrat ExtraLight) ((Montserrat-ExtraLight.otf 0 225960)))
((Montserrat ExtraLight\ Italic) ((Montserrat-ExtraLightItalic.otf 0 235284)))
((Montserrat Italic) ((Montserrat-Italic.otf 0 237504)))
((Montserrat Light) ((Montserrat-Light.otf 0 227300)))
((Montserrat Light\ Italic) ((Montserrat-LightItalic.otf 0 236584)))
((Montserrat Medium) ((Montserrat-Medium.otf 0 230456)))
((Montserrat Medium\ Italic) ((Montserrat-MediumItalic.otf 0 238876)))
((Montserrat Regular) ((Montserrat-Regular.otf 0 228724)))
((Montserrat SemiBold) ((Montserrat-SemiBold.otf 0 233196)))
((Montserrat SemiBold\ Italic) ((Montserrat-SemiBoldItalic.otf 0 241756)))
((Montserrat Thin) ((Montserrat-Thin.otf 0 216040)))
((Montserrat Thin\ Italic) ((Montserrat-ThinItalic.otf 0 225128)))
((Montserrat\ Alternates Black) ((MontserratAlternates-Black.otf 0 182020)))
((Montserrat\ Alternates Black\ Italic) ((MontserratAlternates-BlackItalic.otf 0 184720)))
((Montserrat\ Alternates Bold) ((MontserratAlternates-Bold.otf 0 185224)))
((Montserrat\ Alternates Bold\ Italic) ((MontserratAlternates-BoldItalic.otf 0 190224)))
((Montserrat\ Alternates ExtraBold) ((MontserratAlternates-ExtraBold.otf 0 185524)))
((Montserrat\ Alternates ExtraBold\ Italic) ((MontserratAlternates-ExtraBoldItalic.otf 0 190628)))
((Montserrat\ Alternates ExtraLight) ((MontserratAlternates-ExtraLight.otf 0 178708)))
((Montserrat\ Alternates ExtraLight\ Italic) ((MontserratAlternates-ExtraLightItalic.otf 0 184156)))
((Montserrat\ Alternates Italic) ((MontserratAlternates-Italic.otf 0 186696)))
((Montserrat\ Alternates Light) ((MontserratAlternates-Light.otf 0 179644)))
((Montserrat\ Alternates Light\ Italic) ((MontserratAlternates-LightItalic.otf 0 185168)))
((Montserrat\ Alternates Medium) ((MontserratAlternates-Medium.otf 0 181888)))
((Montserrat\ Alternates Medium\ Italic) ((MontserratAlternates-MediumItalic.otf 0 187420)))
((Montserrat\ Alternates Regular) ((MontserratAlternates-Regular.otf 0 180824)))
((Montserrat\ Alternates SemiBold) ((MontserratAlternates-SemiBold.otf 0 184324)))
((Montserrat\ Alternates SemiBold\ Italic) ((MontserratAlternates-SemiBoldItalic.otf 0 189716)))
((Montserrat\ Alternates Thin) ((MontserratAlternates-Thin.otf 0 172796)))
((Montserrat\ Alternates Thin\ Italic) ((MontserratAlternates-ThinItalic.otf 0 177272)))
((MPH\ 2B\ Damase Regular) ((damase_v.2.ttf 0 900260)))
((MS\ Gothic Regular) ((MS\ Gothic.ttf 0 7203212)))
((MS\ Mincho Regular) ((MS\ Mincho.ttf 0 9081312)))
((Mshtakan Bold) ((MshtakanBold.ttf 0 37320) (Mshtakan.ttc 2 169024) (Mshtakan.ttc 2 176224)))
((Mshtakan BoldOblique) ((MshtakanBoldOblique.ttf 0 41400) (Mshtakan.ttc 3 169024) (Mshtakan.ttc 3 176224)))
((Mshtakan Oblique) ((MshtakanOblique.ttf 0 51360) (Mshtakan.ttc 1 169024) (Mshtakan.ttc 1 176224)))
((Mshtakan Regular) ((MshtakanRegular.ttf 0 46172) (Mshtakan.ttc 0 169024) (Mshtakan.ttc 0 176224)))
((MuktaMahee Bold) ((MuktaMahee.ttc 6 1394452)))
((MuktaMahee ExtraBold) ((MuktaMahee.ttc 5 1394452)))
((MuktaMahee Light) ((MuktaMahee.ttc 3 1394452)))
((MuktaMahee Regular) ((MuktaMahee.ttc 2 1394452)))
((MuktaMahee SemiBold) ((MuktaMahee.ttc 1 1394452)))
((MuktaMahee\ ExtraLight Regular) ((MuktaMahee.ttc 4 1394452)))
((MuktaMahee\ Regular Regular) ((MuktaMahee.ttc 0 1394452)))
((Mukti Narrow) ((MuktiNarrow.ttf 0 185512)))
((Mukti Narrow\ Bold) ((MuktiNarrowBold.ttf 0 73936)))
((Muna Black) ((Muna.ttc 4 197916) (Muna.ttc 4 207352)))
((Muna Bold) ((Muna.ttc 2 197916) (Muna.ttc 2 207352)))
((Muna Regular) ((Muna.ttc 0 197916) (Muna.ttc 0 207352)))
((Muna\ PUA Black) ((Muna.ttc 5 197916) (Muna.ttc 5 207352)))
((Muna\ PUA Bold) ((Muna.ttc 3 197916) (Muna.ttc 3 207352)))
((Muna\ PUA Regular) ((Muna.ttc 1 197916) (Muna.ttc 1 207352)))
((MV\ Boli Regular) ((mvboli.ttf 0 40500) (mvboli.ttf 0 78272)))
((Myanmar\ MN Bold) ((Myanmar\ MN.ttc 1 444600) (Myanmar\ MN.ttc 1 445116) (Myanmar\ MN.ttc 1 242060)))
((Myanmar\ MN Regular) ((Myanmar\ MN.ttc 0 444600) (Myanmar\ MN.ttc 0 445116) (Myanmar\ MN.ttc 0 242060)))
((Myanmar\ Sangam\ MN Bold) ((Myanmar\ Sangam\ MN.ttc 1 300584) (Myanmar\ Sangam\ MN.ttc 1 193720)))
((Myanmar\ Sangam\ MN Regular) ((Myanmar\ Sangam\ MN.ttc 0 300584) (Myanmar\ Sangam\ MN.ttf 0 200600) (Myanmar\ Sangam\ MN.ttc 0 193720)))
((Myanmar\ Text Bold) ((mmrtextb.ttf 0 335368)))
((Myanmar\ Text Regular) ((mmrtext.ttf 0 355292)))
((Nadeem Regular) ((Nadeem.ttf 0 59096) (Nadeem.ttc 0 59452) (Nadeem.ttf 0 59452) (Nadeem.ttc 0 62716)))
((Nadeem\ PUA Regular) ((Nadeem.ttc 1 59452) (Nadeem.ttc 1 62716)))
((Nanum\ Brush\ Script Regular) ((NanumScript.ttc 0 7212984) (NanumScript.ttc 0 7242476)))
((Nanum\ Pen\ Script Regular) ((NanumScript.ttc 1 7212984) (NanumScript.ttc 1 7242476)))
((NanumGothic Bold) ((NanumGothic.ttc 1 12792016) (NanumGothic.ttc 1 12790388)))
((NanumGothic ExtraBold) ((NanumGothic.ttc 2 12792016) (NanumGothic.ttc 2 12790388)))
((NanumGothic Regular) ((NanumGothic.ttc 0 12792016) (NanumGothic.ttc 0 12790388)))
((NanumMyeongjo Bold) ((NanumMyeongjo.ttc 1 13175240) (NanumMyeongjo.ttc 1 13193888)))
((NanumMyeongjo ExtraBold) ((NanumMyeongjo.ttc 2 13175240) (NanumMyeongjo.ttc 2 13193888)))
((NanumMyeongjo Regular) ((NanumMyeongjo.ttc 0 13175240) (NanumMyeongjo.ttc 0 13193888)))
((New\ Peninim\ MT Bold) ((NewPeninimMTBold.ttf 0 48116) (NewPeninimMT.ttc 3 148656) (NewPeninimMT.ttc 3 157392)))
((New\ Peninim\ MT Bold\ Inclined) ((NewPeninimMTBoldInclined.ttf 0 50384) (NewPeninimMT.ttc 2 148656) (NewPeninimMT.ttc 2 157392)))
((New\ Peninim\ MT Inclined) ((NewPeninimMTInclined.ttf 0 44520) (NewPeninimMT.ttc 1 148656) (NewPeninimMT.ttc 1 157392)))
((New\ Peninim\ MT Regular) ((NewPeninimMT.ttf 0 43868) (NewPeninimMT.ttc 0 148656) (NewPeninimMT.ttc 0 157392)))
((New\ York Regular) ((NewYork.ttf 0 363388)))
((New\ York Regular\ Italic) ((NewYorkItalic.ttf 0 357684)))
((NimbusSanL Bold) ((zhv-Bol.otf 0 81376)))
((NimbusSanL Bold\ Italic) ((zhv-BolIta.otf 0 87348)))
((NimbusSanL Italic) ((zhv-RegIta.otf 0 86716)))
((NimbusSanL Regular) ((zhv-Reg.otf 0 79356)))
((Ninoshandwriting Medium) ((Ninoshandwriting.ttf 0 18688)))
((Nirmala\ UI Bold) ((NirmalaB.ttf 0 1402304)))
((Nirmala\ UI Regular) ((Nirmala.ttf 0 1448112)))
((Nirmala\ UI SemiLight) ((NirmalaS.ttf 0 1487800)))
((Nisan Regular) ((Nisan.ttc 0 62364)))
((Nisan\ PUA Regular) ((Nisan.ttc 1 62364)))
((NKD04\ Playing\ Card\'s\ Index Regular) ((nkd04_playing_cards_index.ttf 0 49152)))
((Norasi Bold) ((Norasi-Bold.ttf 0 102824) (Norasi-Bold.otf 0 61788)))
((Norasi BoldItalic) ((Norasi-BoldItalic.ttf 0 114920) (Norasi-BoldItalic.otf 0 65460)))
((Norasi BoldOblique) ((Norasi-BoldOblique.ttf 0 116420) (Norasi-BoldOblique.otf 0 65960)))
((Norasi Italic) ((Norasi-Italic.ttf 0 117488) (Norasi-Italic.otf 0 65232)))
((Norasi Oblique) ((Norasi-Oblique.ttf 0 118732) (Norasi-Oblique.otf 0 65588)))
((Norasi Regular) ((Norasi.ttf 0 104448) (Norasi.otf 0 62392)))
((Noteworthy Bold) ((Noteworthy.ttc 1 551924) (Noteworthy.ttc 1 427736) (Noteworthy.ttc 1 560844)))
((Noteworthy Light) ((Noteworthy.ttc 0 551924) (Noteworthy.ttc 0 427736) (Noteworthy.ttc 0 560844)))
((Noto\ Sans Bold) ((NotoSans-Bold.ttf 0 455164)))
((Noto\ Sans Bold\ Italic) ((NotoSans-BoldItalic.ttf 0 471004)))
((Noto\ Sans Italic) ((NotoSans-Italic.ttf 0 470472)))
((Noto\ Sans Light) ((NotoSans-Light.ttf 0 443040)))
((Noto\ Sans Light\ Italic) ((NotoSans-LightItalic.ttf 0 463608)))
((Noto\ Sans Regular) ((NotoSans-Regular.ttf 0 455188)))
((Noto\ Sans\ Cond Bold) ((NotoSans-CondensedBold.ttf 0 455020)))
((Noto\ Sans\ Cond Bold\ Italic) ((NotoSans-CondensedBoldItalic.ttf 0 474308)))
((Noto\ Sans\ Cond Italic) ((NotoSans-CondensedItalic.ttf 0 472532)))
((Noto\ Sans\ Cond Light) ((NotoSans-CondensedLight.ttf 0 444208)))
((Noto\ Sans\ Cond Light\ Italic) ((NotoSans-CondensedLightItalic.ttf 0 463128)))
((Noto\ Sans\ Cond Regular) ((NotoSans-Condensed.ttf 0 450924)))
((Noto\ Sans\ Mono Bold) ((NotoSansMono-Bold.ttf 0 438228)))
((Noto\ Sans\ Mono Light) ((NotoSansMono-Light.ttf 0 420748)))
((Noto\ Sans\ Mono Regular) ((NotoSansMono-Regular.ttf 0 426780)))
((Noto\ Sans\ Mono\ Cond Bold) ((NotoSansMono-CondensedBold.ttf 0 430728)))
((Noto\ Sans\ Mono\ Cond Light) ((NotoSansMono-CondensedLight.ttf 0 420828)))
((Noto\ Sans\ Mono\ Cond Regular) ((NotoSansMono-Condensed.ttf 0 427376)))
((Noto\ Serif Bold) ((NotoSerif-Bold.ttf 0 570708)))
((Noto\ Serif Bold\ Italic) ((NotoSerif-BoldItalic.ttf 0 608488)))
((Noto\ Serif Italic) ((NotoSerif-Italic.ttf 0 593748)))
((Noto\ Serif Light) ((NotoSerif-Light.ttf 0 564772)))
((Noto\ Serif Light\ Italic) ((NotoSerif-LightItalic.ttf 0 578480)))
((Noto\ Serif Regular) ((NotoSerif-Regular.ttf 0 552144)))
((NovelDeco Regular) ((NovelDeco.otf 0 132000)))
((NSimSun Regular) ((simsun.ttc 1 18214472)))
((NTS\ Akkhara Bold) ((NTSAkkhara-Bold.ttf 0 79592)))
((NTS\ Akkhara BoldItalic) ((NTSAkkhara-BoldItalic.ttf 0 86244)))
((NTS\ Akkhara Book) ((NTSAkkhara.ttf 0 76256)))
((NTS\ Akkhara Italic) ((NTSAkkhara-Italic.ttf 0 78984)))
((Ntxsups Bold) ((ntxsups-Bold.otf 0 16496)))
((Ntxsups BoldItalic) ((ntxsups-BoldItalic.otf 0 17708)))
((Ntxsups Italic) ((ntxsups-Italic.otf 0 17700)))
((Ntxsups Regular) ((ntxsups-Regular.otf 0 16976)))
((Odstemplik Bold) ((odstemplikBold.otf 0 113416)))
((Odstemplik Regular) ((odstemplik.otf 0 107392)))
((Old\ Standard Bold) ((OldStandard-Bold.otf 0 231252)))
((Old\ Standard BoldItalic) ((OldStandard-BoldItalic.otf 0 285856)))
((Old\ Standard Italic) ((OldStandard-Italic.otf 0 230264)))
((Old\ Standard Regular) ((OldStandard-Regular.otf 0 227684)))
((Oldprint Normal) ((Oldprint.ttf 0 57948)))
((OMGWilliamsSerifs Medium) ((OMGWilliamsSerifs.ttf 0 145204)))
((OMGWriteLikeWilliam Medium) ((OMGWriteLikeWilliam.ttf 0 221208)))
((Open\ Sans Bold) ((OpenSans-Bold.ttf 0 224592) (OpenSans-Bold.ttf 0 103616)))
((Open\ Sans Bold\ Italic) ((OpenSans-BoldItalic.ttf 0 213292) (OpenSans-BoldItalic.ttf 0 92124)))
((Open\ Sans Condensed\ Bold) ((OpenSansCondensed-Bold.ttf 0 137480)))
((Open\ Sans ExtraBold) ((OpenSans-ExtraBold.ttf 0 222584) (OpenSans-ExtraBold.ttf 0 101512)))
((Open\ Sans ExtraBold\ Italic) ((OpenSans-ExtraBoldItalic.ttf 0 213420) (OpenSans-ExtraBoldItalic.ttf 0 92196)))
((Open\ Sans Italic) ((OpenSans-Italic.ttf 0 212896) (OpenSans-Italic.ttf 0 91736)))
((Open\ Sans Light) ((OpenSans-Light.ttf 0 222412) (OpenSans-Light.ttf 0 101140)))
((Open\ Sans Light\ Condensed) ((OpenSans-CondLight.ttf 0 221108) (OpenSansCondensed-Light.ttf 0 99768)))
((Open\ Sans Light\ Condensed\ Italic) ((OpenSans-CondLightItalic.ttf 0 210804) (OpenSansCondensed-LightItalic.ttf 0 89532)))
((Open\ Sans Light\ Italic) ((OpenSans-LightItalic.ttf 0 213128) (OpenSans-LightItalic.ttf 0 91920)))
((Open\ Sans Regular) ((OpenSans-Regular.ttf 0 217360) (OpenSans-Regular.ttf 0 96428)))
((Open\ Sans SemiBold) ((OpenSans-Semibold.ttf 0 221328) (OpenSans-SemiBold.ttf 0 100256)))
((Open\ Sans SemiBold\ Italic) ((OpenSans-SemiboldItalic.ttf 0 212820) (OpenSans-SemiBoldItalic.ttf 0 91604)))
((OpenSymbol Regular) ((opens___.ttf 0 178396)))
((Optima Bold) ((Optima.ttc 1 577460) (Optima.ttc 1 569784) (Optima.ttc 1 567004) (Optima.ttc 1 263984)))
((Optima Bold\ Italic) ((Optima.ttc 3 577460) (Optima.ttc 3 569784) (Optima.ttc 3 567004) (Optima.ttc 3 263984)))
((Optima ExtraBlack) ((Optima.ttc 4 577460) (Optima.ttc 4 569784) (Optima.ttc 4 567004) (Optima.ttc 4 263984)))
((Optima Italic) ((Optima.ttc 2 577460) (Optima.ttc 2 569784) (Optima.ttc 2 567004) (Optima.ttc 2 263984)))
((Optima Regular) ((Optima.ttc 0 577460) (Optima.ttc 0 569784) (Optima.ttc 0 567004) (Optima.ttc 0 263984)))
((Oriya\ MN Bold) ((Oriya\ MN.ttc 1 469416) (Oriya\ MN.ttc 1 471280) (Oriya\ MN.ttc 1 214204)))
((Oriya\ MN Regular) ((Oriya\ MN.ttc 0 469416) (Oriya\ MN.ttc 0 471280) (Oriya\ MN.ttc 0 214204)))
((Oriya\ Sangam\ MN Bold) ((Oriya\ Sangam\ MN.ttc 1 215412) (Oriya\ Sangam\ MN.ttc 1 506260) (Oriya\ Sangam\ MN.ttc 1 180460)))
((Oriya\ Sangam\ MN Regular) ((Oriya\ Sangam\ MN.ttc 0 215412) (Oriya\ Sangam\ MN.ttc 0 506260) (Oriya\ Sangam\ MN.ttc 0 180460)))
((Osaka Regular) ((Osaka.ttf 0 3631328) (Osaka.ttf 0 3631848)))
((Osaka Regular-Mono) ((OsakaMono.ttf 0 2307144) (OsakaMono.ttf 0 2307664)))
((Overhaul Regular) ((Overhaul.otf 0 761084) (Overhaul.ttf 0 1254464)))
((Overlock Black) ((Overlock-Black.ttf 0 43224)))
((Overlock Black\ Italic) ((Overlock-BlackItalic.ttf 0 44088)))
((Overlock Bold) ((Overlock-Bold.ttf 0 42368)))
((Overlock Bold\ Italic) ((Overlock-BoldItalic.ttf 0 45836)))
((Overlock Italic) ((Overlock-Italic.ttf 0 44160)))
((Overlock Regular) ((Overlock-Regular.ttf 0 49656)))
((Overlock\ SC Regular) ((OverlockSC-Regular.ttf 0 34612)))
((OxfordCP Regular) ((OxfordCP.otf 0 20224)))
((Pacifico Regular) ((Pacifico.ttf 0 43632)))
((Padauk Bold) ((Padauk-Bold.ttf 0 428860)))
((Padauk Regular) ((Padauk-Regular.ttf 0 419868)))
((Padauk\ Book Bold) ((PadaukBook-Bold.ttf 0 429020)))
((Padauk\ Book Regular) ((PadaukBook-Regular.ttf 0 429160)))
((Palatino Bold) ((Palatino.ttc 2 1770652) (Palatino.ttc 2 1701880) (Palatino.ttc 2 1789092) (Palatino.ttc 2 1786600)))
((Palatino Bold\ Italic) ((Palatino.ttc 3 1770652) (Palatino.ttc 3 1701880) (Palatino.ttc 3 1789092) (Palatino.ttc 3 1786600)))
((Palatino Italic) ((Palatino.ttc 1 1770652) (Palatino.ttc 1 1701880) (Palatino.ttc 1 1789092) (Palatino.ttc 1 1786600)))
((Palatino Regular) ((Palatino.ttc 0 1770652) (Palatino.ttc 0 1701880) (Palatino.ttc 0 1789092) (Palatino.ttc 0 1786600)))
((Palatino\ Linotype Bold) ((palab.ttf 0 434004) (palab.ttf 0 419932)))
((Palatino\ Linotype Bold\ Italic) ((palabi.ttf 0 344288) (palabi.ttf 0 335292)))
((Palatino\ Linotype Italic) ((palai.ttf 0 430800) (palai.ttf 0 413708)))
((Palatino\ Linotype Regular) ((pala.ttf 0 489884) (pala.ttf 0 472284)))
((Paper\ Cuts\ 2 Regular) ((papercuts-2.ttf 0 32056)))
((Papyrus Condensed) ((Papyrus.ttc 1 208896) (Papyrus.ttc 0 1098704) (Papyrus.ttc 1 210844) (Papyrus.ttc 0 1110432)))
((Papyrus Regular) ((Papyrus.ttc 0 208896) (Papyrus.ttc 1 1098704) (Papyrus.ttc 0 210844) (Papyrus.ttc 1 1110432)))
((Party\ LET Plain) ((PartyLET-plain.ttf 0 213112) (PartyLET-plain.ttf 0 212604)))
((PCMyungjo Regular) ((PCmyoungjo.ttf 0 9494920) (PCmyoungjo.ttf 0 9450744) (PCmyoungjo.ttf 0 9515016)))
((Penguin\ Attack Regular) ((PenguinAttack.ttf 0 70356)))
((Perfect\ Dark\ Zero Regular) ((Perfect\ Dark\ Zero.ttf 0 18324)))
((Phaistos Regular) ((Phaistos.otf 0 40044)))
((Phetsarath\ OT Regular) ((Phetsarath_OT.ttf 0 92828)))
((Philokalia Regular) ((Philokalia-Regular.otf 0 123632)))
((Phosphate Inline) ((Phosphate.ttc 0 225784) (Phosphate.ttc 0 230964)))
((Phosphate Solid) ((Phosphate.ttc 1 225784) (Phosphate.ttc 1 230964)))
((PilGi Regular) ((Pilgiche.ttf 0 4676380) (Pilgiche.ttf 0 4635704)))
((PingFang\ HK Light) ((PingFang.ttc 9 70807596) (PingFang.ttc 27 70807596) (PingFang.ttc 9 80005872) (PingFang.ttc 27 80005872) (PingFang.ttc 9 77143596) (PingFang.ttc 27 77143596)))
((PingFang\ HK Medium) ((PingFang.ttc 3 70807596) (PingFang.ttc 21 70807596) (PingFang.ttc 3 80005872) (PingFang.ttc 21 80005872) (PingFang.ttc 3 77143596) (PingFang.ttc 21 77143596)))
((PingFang\ HK Regular) ((PingFang.ttc 0 70807596) (PingFang.ttc 18 70807596) (PingFang.ttc 0 80005872) (PingFang.ttc 18 80005872) (PingFang.ttc 0 77143596) (PingFang.ttc 18 77143596)))
((PingFang\ HK Semibold) ((PingFang.ttc 6 70807596) (PingFang.ttc 24 70807596) (PingFang.ttc 6 80005872) (PingFang.ttc 24 80005872) (PingFang.ttc 6 77143596) (PingFang.ttc 24 77143596)))
((PingFang\ HK Thin) ((PingFang.ttc 12 70807596) (PingFang.ttc 30 70807596) (PingFang.ttc 12 80005872) (PingFang.ttc 30 80005872) (PingFang.ttc 12 77143596) (PingFang.ttc 30 77143596)))
((PingFang\ HK Ultralight) ((PingFang.ttc 15 70807596) (PingFang.ttc 33 70807596) (PingFang.ttc 15 80005872) (PingFang.ttc 33 80005872) (PingFang.ttc 15 77143596) (PingFang.ttc 33 77143596)))
((PingFang\ SC Light) ((PingFang.ttc 11 70807596) (PingFang.ttc 11 80005872) (PingFang.ttc 29 80005872) (PingFang.ttc 11 77143596) (PingFang.ttc 29 77143596)))
((PingFang\ SC Medium) ((PingFang.ttc 5 70807596) (PingFang.ttc 23 70807596) (PingFang.ttc 5 80005872) (PingFang.ttc 23 80005872) (PingFang.ttc 5 77143596) (PingFang.ttc 23 77143596)))
((PingFang\ SC Regular) ((PingFang.ttc 2 70807596) (PingFang.ttc 20 70807596) (PingFang.ttc 2 80005872) (PingFang.ttc 20 80005872) (PingFang.ttc 2 77143596) (PingFang.ttc 20 77143596)))
((PingFang\ SC Semibold) ((PingFang.ttc 8 70807596) (PingFang.ttc 26 70807596) (PingFang.ttc 8 80005872) (PingFang.ttc 26 80005872) (PingFang.ttc 8 77143596) (PingFang.ttc 26 77143596)))
((PingFang\ SC Thin) ((PingFang.ttc 14 70807596) (PingFang.ttc 32 70807596) (PingFang.ttc 14 80005872) (PingFang.ttc 32 80005872) (PingFang.ttc 14 77143596) (PingFang.ttc 32 77143596)))
((PingFang\ SC Ultralight) ((PingFang.ttc 17 70807596) (PingFang.ttc 35 70807596) (PingFang.ttc 17 80005872) (PingFang.ttc 35 80005872) (PingFang.ttc 17 77143596) (PingFang.ttc 35 77143596)))
((PingFang\ SC }0) ((PingFang.ttc 29 70807596)))
((PingFang\ TC Light) ((PingFang.ttc 10 70807596) (PingFang.ttc 28 70807596) (PingFang.ttc 10 80005872) (PingFang.ttc 28 80005872) (PingFang.ttc 10 77143596) (PingFang.ttc 28 77143596)))
((PingFang\ TC Medium) ((PingFang.ttc 4 70807596) (PingFang.ttc 22 70807596) (PingFang.ttc 4 80005872) (PingFang.ttc 22 80005872) (PingFang.ttc 4 77143596) (PingFang.ttc 22 77143596)))
((PingFang\ TC Regular) ((PingFang.ttc 1 70807596) (PingFang.ttc 19 70807596) (PingFang.ttc 1 80005872) (PingFang.ttc 19 80005872) (PingFang.ttc 1 77143596) (PingFang.ttc 19 77143596)))
((PingFang\ TC Semibold) ((PingFang.ttc 7 70807596) (PingFang.ttc 25 70807596) (PingFang.ttc 7 80005872) (PingFang.ttc 25 80005872) (PingFang.ttc 7 77143596) (PingFang.ttc 25 77143596)))
((PingFang\ TC Thin) ((PingFang.ttc 13 70807596) (PingFang.ttc 31 70807596) (PingFang.ttc 13 80005872) (PingFang.ttc 31 80005872) (PingFang.ttc 13 77143596) (PingFang.ttc 31 77143596)))
((PingFang\ TC Ultralight) ((PingFang.ttc 16 70807596) (PingFang.ttc 34 70807596) (PingFang.ttc 16 80005872) (PingFang.ttc 34 80005872) (PingFang.ttc 16 77143596) (PingFang.ttc 34 77143596)))
((PipeSquare\ Rounded Regular) ((PipeSquare\ Rounded.ttf 0 147076)))
((Plantagenet\ Cherokee Regular) ((PlantagenetCherokee.ttf 0 75716) (PlantagenetCherokee.ttf 0 72052) (PlantagenetCherokee.ttf 0 72336) (PlantagenetCherokee.ttf 0 75012)))
((Playfair\ Display Black) ((PlayfairDisplay-Black.otf 0 156104)))
((Playfair\ Display Black\ Italic) ((PlayfairDisplay-BlackItalic.otf 0 146040)))
((Playfair\ Display Bold) ((PlayfairDisplay-Bold.otf 0 158148)))
((Playfair\ Display Bold\ Italic) ((PlayfairDisplay-BoldItalic.otf 0 153672)))
((Playfair\ Display Italic) ((PlayfairDisplay-Italic.otf 0 144252)))
((Playfair\ Display Regular) ((PlayfairDisplay-Regular.otf 0 148580)))
((PMingLiU-ExtB Regular) ((mingliub.ttc 1 36786404)))
((Pointfree Regular) ((pointfree.ttf 0 27052)))
((Poiret\ One Bold) ((PoiretOne-Bold.ttf 0 69636)))
((Poiret\ One Regular) ((PoiretOne-Regular.ttf 0 44728)))
((Pomorsky\ Unicode Regular) ((PomorskyUnicode.otf 0 105448)))
((Pomorsky\ Unicode\ TT Regular) ((PomorskyUnicode.ttf 0 219256)))
((Ponomar\ Unicode Regular) ((PonomarUnicode.otf 0 197916)))
((Ponomar\ Unicode\ TT Regular) ((PonomarUnicode.ttf 0 502120)))
((PortagoITC\ TT Regular) ((PortagoITC\ TT.ttf 0 140040)))
((Portmanteau Regular) ((Portmanteau\ Regular.ttf 0 182028) (Portmanteau-Regular.otf 0 106808)))
((Pothana2000 Regular) ((Pothana2000.ttf 0 194268) (Vemana.ttf 0 200092)))
((Pretzel Regular) ((Pretzel\ Regular.ttf 0 151136) (Pretzel-Regular.otf 0 54532)))
((PreussischeIV44Ausgabe3 Regular) ((Pr_IV_44_Ausg3.otf 0 20508)))
((Princetown\ LET Regular) ((Princetown\ LET\ Fonts.ttf 0 39728)))
((Prociono Regular) ((Prociono-Regular.otf 0 36512)))
((Promocyja Regular) ((Promocyja096.ttf 0 256300) (Promocyja_096.otf 0 336048)))
((Psicopatologia\ de\ la\ Vida\ Cotidiana Regular) ((freud.ttf 0 55032)))
((PT\ Mono Bold) ((PTMono.ttc 0 309348) (PTM75F.ttf 0 140464) (PTMono.ttc 0 315876)))
((PT\ Mono Regular) ((PTMono.ttc 1 309348) (PTM55F.ttf 0 174592) (PTMono.ttc 1 315876)))
((PT\ Sans Bold) ((PTS75F.ttf 0 458084) (PTSans.ttc 7 2767520) (PTSans.ttc 2 2763792) (PTSans.ttc 7 2794628)))
((PT\ Sans Bold\ Caption) ((PTC75F.ttf 0 386624)))
((PT\ Sans Bold\ Italic) ((PTS76F.ttf 0 363048) (PTSans.ttc 6 2767520) (PTSans.ttc 3 2763792) (PTSans.ttc 6 2794628)))
((PT\ Sans Bold\ Narrow) ((PTN77F.ttf 0 475564)))
((PT\ Sans Caption) ((PTC55F.ttf 0 430804) (PTSans.ttc 5 2767520) (PTC55F.ttf 0 375036) (PTSans.ttc 4 2763792) (PTSans.ttc 5 2794628)))
((PT\ Sans Caption\ Bold) ((PTSans.ttc 4 2767520) (PTC75F.ttf 0 386624) (PTSans.ttc 5 2763792) (PTSans.ttc 4 2794628)))
((PT\ Sans Italic) ((PTS56F.ttf 0 424296) (PTSans.ttc 1 2767520) (PTSans.ttc 1 2763792) (PTSans.ttc 1 2794628)))
((PT\ Sans Narrow) ((PTN57F.ttf 0 384056) (PTSans.ttc 3 2767520) (PTSans.ttc 6 2763792) (PTSans.ttc 3 2794628)))
((PT\ Sans Narrow\ Bold) ((PTSans.ttc 2 2767520) (PTN77F.ttf 0 475564) (PTSans.ttc 7 2763792) (PTSans.ttc 2 2794628)))
((PT\ Sans Regular) ((PTS55F.ttf 0 430804) (PTSans.ttc 0 2767520) (PTSans.ttc 0 2763792) (PTSans.ttc 0 2794628)))
((PT\ Serif Bold) ((PTF75F.ttf 0 327840) (PTSerif.ttc 3 1151720) (PTSerif.ttc 3 1164836)))
((PT\ Serif Bold\ Italic) ((PTF76F.ttf 0 325424) (PTSerif.ttc 2 1151720) (PTSerif.ttc 2 1164836)))
((PT\ Serif Caption) ((PTZ55F.ttf 0 387684) (PTSerifCaption.ttc 0 700100) (PTSerifCaption.ttc 0 706700)))
((PT\ Serif Caption\ Italic) ((PTSerifCaption.ttc 1 700100) (PTZ56F.ttf 0 394456) (PTSerifCaption.ttc 1 706700)))
((PT\ Serif Italic) ((PTF56F.ttf 0 363200) (PTSerif.ttc 1 1151720) (PTSerif.ttc 1 1164836)))
((PT\ Serif Italic\ Caption) ((PTZ56F.ttf 0 394456)))
((PT\ Serif Regular) ((PTF55F.ttf 0 346892) (PTSerif.ttc 0 1151720) (PTSerif.ttc 0 1164836)))
((Punk\ Nova Bold) ((punknova-bold.otf 0 432928)))
((Punk\ Nova BoldSlanted) ((punknova-boldslanted.otf 0 412488)))
((Punk\ Nova Regular) ((punknova-regular.otf 0 453944)))
((Punk\ Nova Slanted) ((punknova-slanted.otf 0 431484)))
((Purisa Bold) ((Purisa-Bold.ttf 0 142500) (Purisa-Bold.otf 0 79648)))
((Purisa BoldOblique) ((Purisa-BoldOblique.ttf 0 149580) (Purisa-BoldOblique.otf 0 82840)))
((Purisa Medium) ((Purisa.ttf 0 152384)))
((Purisa Oblique) ((Purisa-Oblique.ttf 0 156072) (Purisa-Oblique.otf 0 81808)))
((Purisa Regular) ((Purisa.otf 0 77368)))
((QTAbbie Medium) ((QTAbbie.otf 0 29004)))
((QTAgateType Bold) ((QTAgateType-Bold.otf 0 28496)))
((QTAgateType Italic) ((QTAgateType-Italic.otf 0 26528)))
((QTAgateType Medium) ((QTAgateType.otf 0 28084)))
((QTAncientOlive Bold) ((QTAncientOlive-Bold.otf 0 20512)))
((QTAncientOlive Medium) ((QTAncientOlive.otf 0 20264)))
((QTAntiquePost Medium) ((QTAntiquePost.otf 0 22860)))
((QTArabian Medium) ((QTArabian.otf 0 32648)))
((QTArnieB Medium) ((QTArnieB.otf 0 38404)))
((QTArtiston Medium) ((QTArtiston.otf 0 27184)))
((QTAtchen Medium) ((QTAtchen.otf 0 20792)))
((QTAvanti Italic) ((QTAvanti-Italic.otf 0 17992)))
((QTAvanti Medium) ((QTAvanti.otf 0 17676)))
((QTBasker Bold) ((QTBasker-Bold.otf 0 29280)))
((QTBasker Italic) ((QTBasker-Italic.otf 0 30748)))
((QTBasker Medium) ((QTBasker.otf 0 29892)))
((QTBeckman Medium) ((QTBeckman.otf 0 28692)))
((QTBengal Bold) ((QTBengal-Bold.otf 0 25056)))
((QTBengal Medium) ((QTBengal.otf 0 26984)))
((QTBlackForest BlackForest) ((QTBlackForest.otf 0 25140)))
((QTBlimpo Medium) ((QTBlimpo.otf 0 19212)))
((QTBodini Bold) ((QTBodini-Bold.otf 0 24180)))
((QTBodini Italic) ((QTBodini-Italic.otf 0 24732)))
((QTBodini Medium) ((QTBodini.otf 0 24636)))
((QTBodiniPoster Italic) ((QTBodiniPoster-Italic.otf 0 28704)))
((QTBodiniPoster Medium) ((QTBodiniPoster.otf 0 26588)))
((QTBookmann Bold) ((QTBookmann-Bold.otf 0 24564)))
((QTBookmann BoldItalic) ((QTBookmann-BoldItalic.otf 0 24904)))
((QTBookmann Bookmann) ((QTBookmann.otf 0 24796)))
((QTBookmann Italic) ((QTBookmann-Italic.otf 0 25276)))
((QTBoulevard Medium) ((QTBoulevard.otf 0 26016)))
((QTBrushStroke Medium) ((QTBrushStroke.otf 0 30568)))
((QTCaligulatype Medium) ((QTCaligulatype.otf 0 22260)))
((QTCanaithtype Medium) ((QTCanaithtype.otf 0 18512)))
((QTCascadetype Medium) ((QTCascadetype.otf 0 27356)))
((QTCaslan Bold) ((QTCaslan-Bold.otf 0 23404)))
((QTCaslan BoldItalic) ((QTCaslan-BoldItalic.otf 0 25356)))
((QTCaslan Italic) ((QTCaslan-Italic.otf 0 24868)))
((QTCaslan Medium) ((QTCaslan.otf 0 23748)))
((QTCaslanOpen Medium) ((QTCaslanOpen.otf 0 36712)))
((QTCasual Medium) ((QTCasual.otf 0 25132)))
((QTChanceryType Bold) ((QTChanceryType-Bold.otf 0 25216)))
((QTChanceryType Italic) ((QTChanceryType-Italic.otf 0 26024)))
((QTChanceryType Medium) ((QTChanceryType.otf 0 24120)))
((QTChicagoland Medium) ((QTChicagoland.otf 0 18292)))
((QTClaytablet Medium) ((QTClaytablet.otf 0 14544)))
((QTCloisteredMonk Medium) ((QTCloisteredMonk.otf 0 29604)))
((QTCoronation Medium) ((QTCoronation.otf 0 35756)))
((QTDeuce Medium) ((QTDeuce.otf 0 15744)))
((QTDingBits Medium) ((QTDingBits.otf 0 35292)))
((QTDoghaus Medium) ((QTDoghaus.otf 0 17536)))
((QTDoghausHeavy Heavy) ((QTDoghausHeavy.otf 0 17992)))
((QTDoghausLight Light) ((QTDoghausLight.otf 0 19188)))
((QTDublinIrish Medium) ((QTDublinIrish.otf 0 26148)))
((QTEraType Bold) ((QTEraType-Bold.otf 0 17812)))
((QTEraType Medium) ((QTEraType.otf 0 17708)))
((QTEurotype Bold) ((QTEurotype-Bold.otf 0 19664)))
((QTEurotype Medium) ((QTEurotype.otf 0 19472)))
((QTFloraline Bold) ((QTFloraline-Bold.otf 0 26368)))
((QTFloraline Medium) ((QTFloraline.otf 0 25572)))
((QTFlorencia Medium) ((QTFlorencia.otf 0 29852)))
((QTFraktur Medium) ((QTFraktur.otf 0 38336)))
((QTFrank Medium) ((QTFrank.otf 0 18600)))
((QTFrankHeavy Heavy) ((QTFrankHeavy.otf 0 18968)))
((QTFrizQuad Bold) ((QTFrizQuad-Bold.otf 0 24296)))
((QTFrizQuad Medium) ((QTFrizQuad.otf 0 24176)))
((QTFuture Italic) ((QTFuture-Italic.otf 0 19980)))
((QTFuture Medium) ((QTFuture.otf 0 19540)))
((QTFuturePoster Medium) ((QTFuturePoster.otf 0 20328)))
((QTGaromand Bold) ((QTGaromand-Bold.otf 0 29108)))
((QTGaromand BoldItalic) ((QTGaromand-BoldItalic.otf 0 30664)))
((QTGaromand Italic) ((QTGaromand-Italic.otf 0 32068)))
((QTGaromand Medium) ((QTGaromand.otf 0 30040)))
((QTGhoulFace Medium) ((QTGhoulFace.otf 0 44336)))
((QTGraphLite Medium) ((QTGraphLite.otf 0 30116)))
((QTGraveure Bold) ((QTGraveure-Bold.otf 0 27444)))
((QTGraveure Medium) ((QTGraveure.otf 0 29664)))
((QTGreece Medium) ((QTGreece.otf 0 17492)))
((QTHandwriting Medium) ((QTHandwriting.otf 0 33468)))
((QTHeidelbergType Medium) ((QTHeidelbergType.otf 0 29592)))
((QTHelvet-Black Black) ((QTHelvet-Black.otf 0 20488)))
((QTHelvet-BoldOutline BoldOutline) ((QTHelvet-BoldOutline.otf 0 30792)))
((QTHelvetCnd Medium) ((QTHelvetCnd.otf 0 20316)))
((QTHelvetCnd-Black Black) ((QTHelvetCnd-Black.otf 0 19648)))
((QTHelvetCnd-Light Light) ((QTHelvetCnd-Light.otf 0 20428)))
((QTHoboken Medium) ((QTHoboken.otf 0 28944)))
((QTHowardType Medium) ((QTHowardType.otf 0 20296)))
((QTHowardTypeFat Medium) ((QTHowardTypeFat.otf 0 20820)))
((QTImpromptu Regular) ((QTImpromptu.otf 0 55588)))
((QTJupiter Medium) ((QTJupiter.otf 0 22440)))
((QTKooper Italic) ((QTKooper-Italic.otf 0 33592)))
((QTKooper Medium) ((QTKooper.otf 0 30364)))
((QTKorrin Italic) ((QTKorrin-Italic.otf 0 24640)))
((QTKorrin Medium) ((QTKorrin.otf 0 22864)))
((QTKung-Fu Fu) ((QTKung-Fu.otf 0 17984)))
((QTLautrecType Medium) ((QTLautrecType.otf 0 27060)))
((QTLetterGoth Bold) ((QTLetterGoth-Bold.otf 0 17600)))
((QTLetterGoth BoldItalic) ((QTLetterGoth-BoldItalic.otf 0 17868)))
((QTLetterGoth Italic) ((QTLetterGoth-Italic.otf 0 17416)))
((QTLetterGoth Medium) ((QTLetterGoth.otf 0 17100)))
((QTLinoscroll Medium) ((QTLinoscroll.otf 0 30404)))
((QTLinostroke Medium) ((QTLinostroke.otf 0 34084)))
((QTLondonScroll Medium) ((QTLondonScroll.otf 0 31508)))
((QTMagicMarker Medium) ((QTMagicMarker.otf 0 56432)))
((QTMerryScript Medium) ((QTMerryScript.otf 0 33868)))
((QTMilitary Medium) ((QTMilitary.otf 0 25988)))
((QTOKCorral Medium) ((QTOKCorral.otf 0 21100)))
((QTOKCorral-Cnd Cnd) ((QTOKCorral-Cnd.otf 0 21480)))
((QTOKCorral-Ext Ext) ((QTOKCorral-Ext.otf 0 21708)))
((QTOldGoudy Bold) ((QTOldGoudy-Bold.otf 0 33088)))
((QTOldGoudy Italic) ((QTOldGoudy-Italic.otf 0 32112)))
((QTOldGoudy Medium) ((QTOldGoudy.otf 0 31112)))
((QTOptimum Bold) ((QTOptimum-Bold.otf 0 25188)))
((QTOptimum BoldItalic) ((QTOptimum-BoldItalic.otf 0 25072)))
((QTOptimum Italic) ((QTOptimum-Italic.otf 0 24076)))
((QTOptimum Medium) ((QTOptimum.otf 0 27024)))
((QTPalatine Bold) ((QTPalatine-Bold.otf 0 26852)))
((QTPalatine Italic) ((QTPalatine-Italic.otf 0 28428)))
((QTPalatine Medium) ((QTPalatine.otf 0 27940)))
((QTPandora Medium) ((QTPandora.otf 0 42668)))
((QTParisFrance Medium) ((QTParisFrance.otf 0 27548)))
((QTPeignoir Medium) ((QTPeignoir.otf 0 17584)))
((QTPeignoir-Lite Lite) ((QTPeignoir-Lite.otf 0 19188)))
((QTPiltdown Medium) ((QTPiltdown.otf 0 14616)))
((QTPristine Bold) ((QTPristine-Bold.otf 0 40996)))
((QTPristine BoldItalic) ((QTPristine-BoldItalic.otf 0 40660)))
((QTPristine Italic) ((QTPristine-Italic.otf 0 40664)))
((QTPristine Medium) ((QTPristine.otf 0 40680)))
((QTRobotic2000 Medium) ((QTRobotic2000.otf 0 36776)))
((QTSanDiego Medium) ((QTSanDiego.otf 0 30820)))
((QTSchoolCentury Bold) ((QTSchoolCentury-Bold.otf 0 25036)))
((QTSchoolCentury BoldItalic) ((QTSchoolCentury-BoldItalic.otf 0 27392)))
((QTSchoolCentury Italic) ((QTSchoolCentury-Italic.otf 0 26152)))
((QTSchoolCentury Medium) ((QTSchoolCentury.otf 0 25020)))
((QTSlogantype Medium) ((QTSlogantype.otf 0 31976)))
((QTSnowCaps Medium) ((QTSnowCaps.otf 0 47120)))
((QTStoryTimeCaps Medium) ((QTStoryTimeCaps.otf 0 50424)))
((QTTechtone Bold) ((QTTechtone-Bold.otf 0 26128)))
((QTTechtone BoldItalic) ((QTTechtone-BoldItalic.otf 0 28980)))
((QTTechtone Italic) ((QTTechtone-Italic.otf 0 29080)))
((QTTechtone Medium) ((QTTechtone.otf 0 24904)))
((QTTheatre Medium) ((QTTheatre.otf 0 25952)))
((QTTimeOutline Medium) ((QTTimeOutline.otf 0 38520)))
((QTTumbleweed Medium) ((QTTumbleweed.otf 0 29680)))
((QTUSA-Uncial Uncial) ((QTUSA-Uncial.otf 0 24980)))
((QTVagaRound Bold) ((QTVagaRound-Bold.otf 0 25676)))
((QTVagaRound Medium) ((QTVagaRound.otf 0 23692)))
((QTWeise Bold) ((QTWeise-Bold.otf 0 26608)))
((QTWeise Italic) ((QTWeise-Italic.otf 0 23416)))
((QTWeise Medium) ((QTWeise.otf 0 26312)))
((QTWestEnd Medium) ((QTWestEnd.otf 0 30260)))
((Quadrata\ Preciosa Extended\ Medium) ((Quadrata\ Preciosa\ Extended.ttf 0 51668)))
((Quadrata\ preciosa Medium) ((quadrata\ preciosa.ttf 0 20608)))
((Quattrocento Bold) ((Quattrocento-Bold.otf 0 213472)))
((Quattrocento BoldItalic) ((Quattrocento-BoldItalic.otf 0 247060)))
((Quattrocento Italic) ((Quattrocento-Italic.otf 0 262148)))
((Quattrocento Regular) ((Quattrocento.otf 0 207580)))
((Quattrocento\ Sans Bold) ((QuattrocentoSans-Bold.otf 0 98224)))
((Quattrocento\ Sans Bold\ Italic) ((QuattrocentoSans-BoldItalic.otf 0 105464)))
((Quattrocento\ Sans Italic) ((QuattrocentoSans-Italic.otf 0 106032)))
((Quattrocento\ Sans Regular) ((QuattrocentoSans.otf 0 99040)))
((QumpellkaNo12 Regular) ((QumpellkaNo12.otf 0 274120)))
((Raanana Bold) ((RaananaBold.ttf 0 31636) (Raanana.ttc 1 61296) (RaananaBold.ttf 0 31352) (Raanana.ttc 1 66456)))
((Raanana Regular) ((Raanana.ttf 0 32420) (Raanana.ttc 0 61296) (Raanana.ttf 0 32124) (Raanana.ttc 0 66456)))
((Raavi Regular) ((raavi.ttf 0 57348)))
((Rabanera Regular) ((Rabanera-outline-shadow.otf 0 83368) (Rabanera-outline-shadow.ttf 0 134836)))
((Rachana Regular) ((Rachana_04.ttf 0 383408)))
((Raleway Black) ((Raleway-Black.otf 0 104976)))
((Raleway Black\ Italic) ((Raleway-Black-Italic.otf 0 77296)))
((Raleway Bold) ((Raleway-Bold.otf 0 104164)))
((Raleway Bold\ Italic) ((Raleway-Bold-Italic.otf 0 77460)))
((Raleway ExtraBold) ((Raleway-ExtraBold.otf 0 103380)))
((Raleway ExtraBold\ Italic) ((Raleway-ExtraBold-Italic.otf 0 77496)))
((Raleway ExtraLight) ((Raleway-ExtraLight.otf 0 101700)))
((Raleway ExtraLight\ Italic) ((Raleway-ExtraLight-Italic.otf 0 75560)))
((Raleway Italic) ((Raleway-Regular-Italic.otf 0 75844)))
((Raleway Light) ((Raleway-Light.otf 0 101200)))
((Raleway Light\ Italic) ((Raleway-Light-Italic.otf 0 75992)))
((Raleway Medium) ((Raleway-Medium.otf 0 103052)))
((Raleway Medium\ Italic) ((Raleway-Medium-Italic.otf 0 76640)))
((Raleway Regular) ((Raleway-Regular.otf 0 101096)))
((Raleway SemiBold) ((Raleway-SemiBold.otf 0 103732)))
((Raleway SemiBold\ Italic) ((Raleway-SemiBold-Italic.otf 0 77844)))
((Raleway Thin) ((Raleway-Thin.otf 0 99648)))
((Raleway Thin\ Italic) ((Raleway-Thin-Italic.otf 0 74032)))
((Rawengulk Bold) ((RawengulkBold.otf 0 104776) (RawengulkBold.ttf 0 132536)))
((Rawengulk Demibold) ((RawengulkDemibold.otf 0 106796) (RawengulkDemibold.ttf 0 129180)))
((Rawengulk Light) ((RawengulkLight.otf 0 109404) (RawengulkLight.ttf 0 143284)))
((Rawengulk Regular) ((RawengulkRegular.otf 0 167952) (RawengulkRegular.ttf 0 193860)))
((Rawengulk Ultralight) ((RawengulkUltralight.otf 0 106708) (RawengulkUltralight.ttf 0 126588)))
((RawengulkPcs Regular) ((RawengulkPcs.otf 0 105212) (RawengulkPcs.ttf 0 123524)))
((RawengulkSans Regular) ((RawengulkSans-094.otf 0 223848) (RawengulkSans-094.ttf 0 284368)))
((Raya Regular) ((Raya.ttc 0 58788)))
((Raya\ PUA Regular) ((Raya.ttc 1 58788)))
((Rekha Medium) ((Rekha.ttf 0 83868)))
((Resagnicto Bold) ((ResagnictoBold.ttf 0 118608)))
((Resagnicto Italic) ((ResagnictoItalic.ttf 0 185760)))
((Resagnicto Regular) ((Resagnicto.ttf 0 123728)))
((Resagokr Bold) ((ResagokrBold.otf 0 287520)))
((Resagokr Light) ((ResagokrLight.otf 0 287204)))
((Resagokr Regular) ((Resagokr.otf 0 287896)))
((Reswysokr Regular) ((Reswysokr.otf 0 166036)))
((Ringling Regular) ((ringling.ttf 0 40932)))
((Roboto Black) ((Roboto-Black.otf 0 192776)))
((Roboto Black\ Italic) ((Roboto-BlackItalic.otf 0 212128)))
((Roboto Bold) ((Roboto-Bold.otf 0 185508)))
((Roboto Bold\ Italic) ((Roboto-BoldItalic.otf 0 204200)))
((Roboto Condensed) ((RobotoCondensed-Regular.otf 0 184208)))
((Roboto Condensed\ Bold) ((RobotoCondensed-Bold.otf 0 183352)))
((Roboto Condensed\ Bold\ Italic) ((RobotoCondensed-BoldItalic.otf 0 197848)))
((Roboto Condensed\ Italic) ((RobotoCondensed-Italic.otf 0 201768)))
((Roboto Italic) ((Roboto-Italic.otf 0 206388) (Roboto-MediumItalic.otf 0 216456)))
((Roboto Light) ((Roboto-Light.otf 0 200084)))
((Roboto Light\ Condensed) ((RobotoCondensed-Light.otf 0 187056)))
((Roboto Light\ Condensed\ Italic) ((RobotoCondensed-LightItalic.otf 0 205464)))
((Roboto Light\ Italic) ((Roboto-LightItalic.otf 0 219340)))
((Roboto Regular) ((Roboto-Medium.otf 0 197212) (Roboto-Regular.otf 0 186664)))
((Roboto\ Mono Bold) ((RobotoMono-Bold.otf 0 224608)))
((Roboto\ Mono Bold\ Italic) ((RobotoMono-BoldItalic.otf 0 261684)))
((Roboto\ Mono Italic) ((RobotoMono-Italic.otf 0 261620) (RobotoMono-MediumItalic.otf 0 260480)))
((Roboto\ Mono Light) ((RobotoMono-Light.otf 0 245404)))
((Roboto\ Mono Light\ Italic) ((RobotoMono-LightItalic.otf 0 269792)))
((Roboto\ Mono Regular) ((RobotoMono-Medium.otf 0 222804) (RobotoMono-Regular.otf 0 229340)))
((Roboto\ Mono\ Thin Italic) ((RobotoMono-ThinItalic.otf 0 272084)))
((Roboto\ Mono\ Thin Regular) ((RobotoMono-Thin.otf 0 265028)))
((Roboto\ Slab Bold) ((RobotoSlab-Bold.otf 0 179108)))
((Roboto\ Slab Light) ((RobotoSlab-Light.otf 0 176576)))
((Roboto\ Slab Regular) ((RobotoSlab-Regular.otf 0 175892)))
((Roboto\ Slab Thin) ((RobotoSlab-Thin.otf 0 174100)))
((Roboto\ Thin Italic) ((Roboto-ThinItalic.otf 0 217592)))
((Roboto\ Thin Regular) ((Roboto-Thin.otf 0 201232)))
((Rockwell Bold) ((Rockwell.ttc 2 487456)))
((Rockwell Bold\ Italic) ((Rockwell.ttc 3 487456)))
((Rockwell Italic) ((Rockwell.ttc 1 487456)))
((Rockwell Regular) ((Rockwell.ttc 0 487456)))
((Rosario Bold) ((Rosario-Bold.otf 0 71996)))
((Rosario Bold\ Italic) ((Rosario-BoldItalic.otf 0 88740)))
((Rosario Italic) ((Rosario-Italic.otf 0 89268)))
((Rosario Light) ((Rosario-Light.otf 0 88060)))
((Rosario Light\ Italic) ((Rosario-LightItalic.otf 0 92704)))
((Rosario Regular) ((Rosario-Regular.otf 0 83900)))
((Rosario SemiBold) ((Rosario-SemiBold.otf 0 87968)))
((Rosario SemiBold\ Italic) ((Rosario-SemiBoldItalic.otf 0 93188)))
((Saab Regular) ((Saab.ttf 0 114092)))
((Sana Regular) ((Sana.ttc 0 74936) (Sana.ttc 0 77604)))
((Sana\ PUA Regular) ((Sana.ttc 1 74936) (Sana.ttc 1 77604)))
((Santa\ Fe\ LET Plain) ((Santa\ Fe\ LET\ Fonts.ttf 0 113464)))
((Sathu Regular) ((Sathu.ttf 0 269148) (Sathu.ttf 0 414872) (Sathu.ttf 0 416152) (Sathu.ttf 0 417676)))
((Savoye\ LET Plain) ((Savoye\ LET.ttc 0 101512) (Savoye\ LET.ttc 0 109256)))
((Savoye\ LET\ CC. Plain) ((Savoye\ LET.ttc 1 101512) (Savoye\ LET.ttc 1 109256)))
((Sawasdee Bold) ((Sawasdee-Bold.ttf 0 83576) (Sawasdee-Bold.otf 0 48020)))
((Sawasdee BoldOblique) ((Sawasdee-BoldOblique.ttf 0 100596) (Sawasdee-BoldOblique.otf 0 51608)))
((Sawasdee Oblique) ((Sawasdee-Oblique.ttf 0 104276) (Sawasdee-Oblique.otf 0 50104)))
((Sawasdee Regular) ((Sawasdee.ttf 0 86108) (Sawasdee.otf 0 46548)))
((Sazanami\ Gothic Gothic-Regular) ((sazanami-gothic.ttf 0 7690324)))
((Sazanami\ Mincho Mincho-Regular) ((sazanami-mincho.ttf 0 10554196)))
((SchoolHouse\ Cursive\ B Regular) ((SchoolHouse\ Cursive\ B.ttf 0 66876)))
((SchoolHouse\ Printed\ A Regular) ((SchoolHouse\ Printed\ A.ttf 0 93504)))
((Schwaben\ Alt Bold) ((Schwaben\ Alt\ Bold.ttf 0 69740)))
((Seattle\ Avenue Regular) ((Seattle\ Avenue.ttf 0 45636) (SeattleAvenue.otf 0 22908)))
((Segoe\ Boot SemiLight) ((segoe_slboot.ttf 0 86290) (segoen_slboot.ttf 0 85974)))
((Segoe\ Mono\ Boot Regular) ((segmono_boot.ttf 0 44970)))
((Segoe\ Print Bold) ((segoeprb.ttf 0 167800)))
((Segoe\ Print Regular) ((segoepr.ttf 0 168404)))
((Segoe\ Script Bold) ((segoescb.ttf 0 581252)))
((Segoe\ Script Regular) ((segoesc.ttf 0 596948)))
((Segoe\ UI Black) ((seguibl.ttf 0 324260)))
((Segoe\ UI Black\ Italic) ((seguibli.ttf 0 356008)))
((Segoe\ UI Bold) ((segoeuib.ttf 0 951724)))
((Segoe\ UI Bold\ Italic) ((segoeuiz.ttf 0 541468)))
((Segoe\ UI Italic) ((segoeuii.ttf 0 529712)))
((Segoe\ UI Light) ((segoeuil.ttf 0 913712)))
((Segoe\ UI Light\ Italic) ((seguili.ttf 0 459940)))
((Segoe\ UI Regular) ((segoeui.ttf 0 955804)))
((Segoe\ UI SemiBold) ((seguisb.ttf 0 971080)))
((Segoe\ UI SemiBold\ Italic) ((seguisbi.ttf 0 457892)))
((Segoe\ UI SemiLight) ((segoeuisl.ttf 0 854140)))
((Segoe\ UI SemiLight\ Italic) ((seguisli.ttf 0 467180)))
((Segoe\ UI\ Emoji Regular) ((seguiemj.ttf 0 2072388)))
((Segoe\ UI\ Historic Regular) ((seguihis.ttf 0 1400724)))
((Segoe\ UI\ Soundlines Regular) ((SegoeUISoundlines.ttf 0 4728)))
((Segoe\ UI\ Symbol Regular) ((seguisym.ttf 0 2454728)))
((Seravek Bold) ((Seravek.ttc 9 4983524) (Seravek.ttc 9 6253688)))
((Seravek Bold\ Italic) ((Seravek.ttc 8 4983524) (Seravek.ttc 8 6253688)))
((Seravek Italic) ((Seravek.ttc 1 4983524) (Seravek.ttc 2 4983524) (Seravek.ttc 1 6253688) (Seravek.ttc 2 6253688)))
((Seravek Light) ((Seravek.ttc 5 4983524) (Seravek.ttc 5 6253688)))
((Seravek Light\ Italic) ((Seravek.ttc 4 4983524) (Seravek.ttc 4 6253688)))
((Seravek Regular) ((Seravek.ttc 0 4983524) (Seravek.ttc 3 4983524) (Seravek.ttc 0 6253688) (Seravek.ttc 3 6253688)))
((Seravek\ ExtraLight Italic) ((Seravek.ttc 6 4983524) (Seravek.ttc 6 6253688)))
((Seravek\ ExtraLight Regular) ((Seravek.ttc 7 4983524) (Seravek.ttc 7 6253688)))
((Sertig Light) ((Sertig.otf 0 28912)))
((SF\ Compact Black) ((SFCompact.ttf 0 1702676)))
((SF\ Compact Black\ Italic) ((SFCompactItalic.ttf 0 950840)))
((SF\ Compact\ Rounded Regular) ((SFCompactRounded.ttf 0 937048)))
((Sf\ ns Regular) ((SFNS.ttf 0 8292532)))
((Sf\ ns Regular\ Italic) ((SFNSItalic.ttf 0 1005672)))
((SF\ NS\ Display Black) ((SFNSDisplay-Black.otf 0 304012)))
((SF\ NS\ Display Bold) ((SFNSDisplay-Bold.otf 0 311816)))
((SF\ NS\ Display Heavy) ((SFNSDisplay-Heavy.otf 0 313040)))
((SF\ NS\ Display Light) ((SFNSDisplay-Light.otf 0 304324)))
((SF\ NS\ Display Medium) ((SFNSDisplay-Medium.otf 0 310712)))
((SF\ NS\ Display Regular) ((SFNSDisplay-Regular.otf 0 291356)))
((SF\ NS\ Display Semibold) ((SFNSDisplay-Semibold.otf 0 312592)))
((SF\ NS\ Display Thin) ((SFNSDisplay-Thin.otf 0 295308)))
((SF\ NS\ Display Ultralight) ((SFNSDisplay-Ultralight.otf 0 294600)))
((SF\ NS\ Mono Light) ((SFNSMono.ttf 0 218648)))
((SF\ NS\ Mono Light\ Italic) ((SFNSMonoItalic.ttf 0 199236)))
((SF\ NS\ Rounded Regular) ((SFNSRounded.ttf 0 1648304)))
((SF\ NS\ Text Bold) ((SFNSText-Bold.otf 0 329360)))
((SF\ NS\ Text Bold\ G1) ((SFNSText-BoldG1.otf 0 328928)))
((SF\ NS\ Text Bold\ G2) ((SFNSText-BoldG2.otf 0 328948)))
((SF\ NS\ Text Bold\ G3) ((SFNSText-BoldG3.otf 0 329484)))
((SF\ NS\ Text Bold\ Italic) ((SFNSText-BoldItalic.otf 0 238900)))
((SF\ NS\ Text Bold\ Italic\ G1) ((SFNSText-BoldItalicG1.otf 0 239636)))
((SF\ NS\ Text Bold\ Italic\ G2) ((SFNSText-BoldItalicG2.otf 0 239956)))
((SF\ NS\ Text Bold\ Italic\ G3) ((SFNSText-BoldItalicG3.otf 0 240000)))
((SF\ NS\ Text Heavy) ((SFNSText-Heavy.otf 0 329916)))
((SF\ NS\ Text Heavy\ Italic) ((SFNSText-HeavyItalic.otf 0 240528)))
((SF\ NS\ Text Italic) ((SFNSText-RegularItalic.otf 0 228824)))
((SF\ NS\ Text Italic\ G1) ((SFNSText-RegularItalicG1.otf 0 230992)))
((SF\ NS\ Text Italic\ G2) ((SFNSText-RegularItalicG2.otf 0 231192)))
((SF\ NS\ Text Italic\ G3) ((SFNSText-RegularItalicG3.otf 0 231440)))
((SF\ NS\ Text Light) ((SFNSText-Light.otf 0 325916)))
((SF\ NS\ Text Light\ Italic) ((SFNSText-LightItalic.otf 0 237132)))
((SF\ NS\ Text Medium) ((SFNSText-Medium.otf 0 329308)))
((SF\ NS\ Text Medium\ Italic) ((SFNSText-MediumItalic.otf 0 239252)))
((SF\ NS\ Text Regular) ((SFNSText-Regular.otf 0 317760)))
((SF\ NS\ Text Regular\ G1) ((SFNSText-RegularG1.otf 0 320908)))
((SF\ NS\ Text Regular\ G2) ((SFNSText-RegularG2.otf 0 320296)))
((SF\ NS\ Text Regular\ G3) ((SFNSText-RegularG3.otf 0 320556)))
((SF\ NS\ Text Semibold) ((SFNSText-Semibold.otf 0 328956)))
((SF\ NS\ Text Semibold\ Italic) ((SFNSText-SemiboldItalic.otf 0 239784)))
((Shobhika Bold) ((Shobhika-Bold.otf 0 350680)))
((Shobhika\ Regular Regular) ((Shobhika-Regular.otf 0 368156)))
((Shree\ Devanagari\ 714 Bold) ((Shree714.ttc 1 520156) (Shree714.ttc 1 531372)))
((Shree\ Devanagari\ 714 Bold\ Italic) ((Shree714.ttc 3 520156) (Shree714.ttc 3 531372)))
((Shree\ Devanagari\ 714 Italic) ((Shree714.ttc 2 520156) (Shree714.ttc 2 531372)))
((Shree\ Devanagari\ 714 Regular) ((Shree714.ttc 0 520156) (Shree714.ttc 0 531372)))
((Shruti Regular) ((shruti.ttf 0 234280)))
((SignPainter-HouseScript Regular) ((SignPainter.otf 0 163412) (SignPainter.ttc 0 400316) (SignPainter.ttc 0 391376)))
((SignPainter-HouseScript Semibold) ((SignPainter.ttc 1 400316) (SignPainter.ttc 1 391376)))
((Silom Regular) ((Silom.ttf 0 281848) (Silom.ttf 0 288864) (Silom.ttf 0 289492) (Silom.ttf 0 291508)))
((SimHei Regular) ((simhei.ttf 0 9751960)))
((SimSun Regular) ((simsun.ttc 0 10499104) (simsun.ttc 0 18214472)))
((SimSun-ExtB Regular) ((simsunb.ttf 0 17064180)))
((Sinhala\ MN Bold) ((Sinhala\ MN.ttc 1 1466440) (Sinhala\ MN.ttc 1 1467868) (Sinhala\ MN.ttc 1 780240)))
((Sinhala\ MN Regular) ((Sinhala\ MN.ttc 0 1466440) (Sinhala\ MN.ttc 0 1467868) (Sinhala\ MN.ttc 0 780240)))
((Sinhala\ Sangam\ MN Bold) ((Sinhala\ Sangam\ MN.ttc 1 642408) (Sinhala\ Sangam\ MN.ttc 1 642756) (Sinhala\ Sangam\ MN.ttc 1 757768)))
((Sinhala\ Sangam\ MN Regular) ((Sinhala\ Sangam\ MN.ttc 0 642408) (Sinhala\ Sangam\ MN.ttc 0 642756) (Sinhala\ Sangam\ MN.ttc 0 757768)))
((Sitka\ Banner Bold) ((SitkaB.ttc 5 933972)))
((Sitka\ Banner Bold\ Italic) ((SitkaZ.ttc 5 980296)))
((Sitka\ Banner Italic) ((SitkaI.ttc 5 990728)))
((Sitka\ Banner Regular) ((Sitka.ttc 5 945616)))
((Sitka\ Display Bold) ((SitkaB.ttc 4 933972)))
((Sitka\ Display Bold\ Italic) ((SitkaZ.ttc 4 980296)))
((Sitka\ Display Italic) ((SitkaI.ttc 4 990728)))
((Sitka\ Display Regular) ((Sitka.ttc 4 945616)))
((Sitka\ Heading Bold) ((SitkaB.ttc 3 933972)))
((Sitka\ Heading Bold\ Italic) ((SitkaZ.ttc 3 980296)))
((Sitka\ Heading Italic) ((SitkaI.ttc 3 990728)))
((Sitka\ Heading Regular) ((Sitka.ttc 3 945616)))
((Sitka\ Small Bold) ((SitkaB.ttc 0 933972)))
((Sitka\ Small Bold\ Italic) ((SitkaZ.ttc 0 980296)))
((Sitka\ Small Italic) ((SitkaI.ttc 0 990728)))
((Sitka\ Small Regular) ((Sitka.ttc 0 945616)))
((Sitka\ Subheading Bold) ((SitkaB.ttc 2 933972)))
((Sitka\ Subheading Bold\ Italic) ((SitkaZ.ttc 2 980296)))
((Sitka\ Subheading Italic) ((SitkaI.ttc 2 990728)))
((Sitka\ Subheading Regular) ((Sitka.ttc 2 945616)))
((Sitka\ Text Bold) ((SitkaB.ttc 1 933972)))
((Sitka\ Text Bold\ Italic) ((SitkaZ.ttc 1 980296)))
((Sitka\ Text Italic) ((SitkaI.ttc 1 990728)))
((Sitka\ Text Regular) ((Sitka.ttc 1 945616)))
((SkakNew-Diagram Regular) ((SkakNew-Diagram.otf 0 17948) (SkakNew-DiagramT.otf 0 15780)))
((SkakNew-Figurine Regular) ((SkakNew-Figurine.otf 0 8000)))
((SkakNewFigurine Bold) ((SkakNew-FigurineBold.otf 0 8204)))
((Skia Regular) ((Skia.ttf 0 475656) (Skia.ttf 0 489424) (Skia.ttf 0 489984)))
((Snell\ Roundhand Black) ((SnellRoundhand.ttc 2 3587668) (SnellRoundhand.ttc 2 3599752) (SnellRoundhand.ttc 2 3588844)))
((Snell\ Roundhand Bold) ((SnellRoundhand.ttc 1 3587668) (SnellRoundhand.ttc 1 3599752) (SnellRoundhand.ttc 1 3588844)))
((Snell\ Roundhand Regular) ((SnellRoundhand.ttc 0 3587668) (SnellRoundhand.ttc 0 3599752) (SnellRoundhand.ttc 0 3588844)))
((Somer Regular) ((Somer.ttc 0 59840)))
((Somer\ PUA Regular) ((Somer.ttc 1 59840)))
((Songti\ SC Black) ((Songti.ttc 0 66899384) (宋体.ttc 0 45078972) (Songti.ttc 0 66933252) (Songti.ttc 0 66936780)))
((Songti\ SC Bold) ((Songti.ttc 1 66899384) (宋体.ttc 1 45078972) (Songti.ttc 1 66933252) (Songti.ttc 1 66936780)))
((Songti\ SC Light) ((Songti.ttc 3 66899384) (宋体.ttc 2 45078972) (Songti.ttc 3 66933252) (Songti.ttc 3 66936780)))
((Songti\ SC Regular) ((Songti.ttc 6 66899384) (宋体.ttc 4 45078972) (Songti.ttc 6 66933252) (Songti.ttc 6 66936780)))
((Songti\ TC Bold) ((Songti.ttc 2 66899384) (Songti.ttc 2 66933252) (Songti.ttc 2 66936780)))
((Songti\ TC Light) ((Songti.ttc 5 66899384) (Songti.ttc 5 66933252) (Songti.ttc 5 66936780)))
((Songti\ TC Regular) ((Songti.ttc 7 66899384) (Songti.ttc 7 66933252) (Songti.ttc 7 66936780)))
((Source\ Code\ Pro Black) ((SourceCodePro-Black.otf 0 149272)))
((Source\ Code\ Pro Black\ Italic) ((SourceCodePro-BlackIt.otf 0 124432)))
((Source\ Code\ Pro Bold) ((SourceCodePro-Bold.otf 0 148456)))
((Source\ Code\ Pro Bold\ Italic) ((SourceCodePro-BoldIt.otf 0 123112)))
((Source\ Code\ Pro Italic) ((SourceCodePro-MediumIt.otf 0 122368) (SourceCodePro-RegularIt.otf 0 122288)))
((Source\ Code\ Pro Light) ((SourceCodePro-Light.otf 0 145036)))
((Source\ Code\ Pro Light\ Italic) ((SourceCodePro-LightIt.otf 0 123040)))
((Source\ Code\ Pro Regular) ((SourceCodePro-Medium.otf 0 145516) (SourceCodePro-Regular.otf 0 145556)))
((Source\ Code\ Pro SemiBold) ((SourceCodePro-Semibold.otf 0 146808)))
((Source\ Code\ Pro SemiBold\ Italic) ((SourceCodePro-SemiboldIt.otf 0 122652)))
((Source\ Code\ Pro\ ExtraLight Italic) ((SourceCodePro-ExtraLightIt.otf 0 120104)))
((Source\ Code\ Pro\ ExtraLight Regular) ((SourceCodePro-ExtraLight.otf 0 141356)))
((Source\ Han\ Sans\ SC Bold) ((SourceHanSansSC-Bold.otf 0 16983696) (SourceHanSansSC-Bold.otf 0 18455676)))
((Source\ Han\ Sans\ SC ExtraLight) ((SourceHanSansSC-ExtraLight.otf 0 15140064) (SourceHanSansSC-ExtraLight.otf 0 17912280)))
((Source\ Han\ Sans\ SC Heavy) ((SourceHanSansSC-Heavy.otf 0 17324776) (SourceHanSansSC-Heavy.otf 0 19698584)))
((Source\ Han\ Sans\ SC Light) ((SourceHanSansSC-Light.otf 0 16229588) (SourceHanSansSC-Light.otf 0 17870940)))
((Source\ Han\ Sans\ SC Medium) ((SourceHanSansSC-Medium.otf 0 16490072) (SourceHanSansSC-Medium.otf 0 17886896)))
((Source\ Han\ Sans\ SC Normal) ((SourceHanSansSC-Normal.otf 0 16353464) (SourceHanSansSC-Normal.otf 0 17862884)))
((Source\ Han\ Sans\ SC Regular) ((SourceHanSansSC-Regular.otf 0 16412776) (SourceHanSansSC-Regular.otf 0 17849568)))
((Source\ Sans\ Pro Black) ((SourceSansPro-Black.otf 0 234176)))
((Source\ Sans\ Pro Black\ Italic) ((SourceSansPro-BlackIt.otf 0 81120)))
((Source\ Sans\ Pro Bold) ((SourceSansPro-Bold.otf 0 235128)))
((Source\ Sans\ Pro Bold\ Italic) ((SourceSansPro-BoldIt.otf 0 80392)))
((Source\ Sans\ Pro Italic) ((SourceSansPro-RegularIt.otf 0 79724)))
((Source\ Sans\ Pro Light) ((SourceSansPro-Light.otf 0 226032)))
((Source\ Sans\ Pro Light\ Italic) ((SourceSansPro-LightIt.otf 0 77816)))
((Source\ Sans\ Pro Regular) ((SourceSansPro-Regular.otf 0 229588)))
((Source\ Sans\ Pro SemiBold) ((SourceSansPro-Semibold.otf 0 232680)))
((Source\ Sans\ Pro SemiBold\ Italic) ((SourceSansPro-SemiboldIt.otf 0 80316)))
((Source\ Sans\ Pro\ ExtraLight Italic) ((SourceSansPro-ExtraLightIt.otf 0 76400)))
((Source\ Sans\ Pro\ ExtraLight Regular) ((SourceSansPro-ExtraLight.otf 0 221580)))
((Source\ Serif\ Pro Black) ((SourceSerifPro-Black.otf 0 222452)))
((Source\ Serif\ Pro Black\ Italic) ((SourceSerifPro-BlackIt.otf 0 73068)))
((Source\ Serif\ Pro Bold) ((SourceSerifPro-Bold.otf 0 228024)))
((Source\ Serif\ Pro Bold\ Italic) ((SourceSerifPro-BoldIt.otf 0 75016)))
((Source\ Serif\ Pro Italic) ((SourceSerifPro-RegularIt.otf 0 73408)))
((Source\ Serif\ Pro Light) ((SourceSerifPro-Light.otf 0 217212)))
((Source\ Serif\ Pro Light\ Italic) ((SourceSerifPro-LightIt.otf 0 74164)))
((Source\ Serif\ Pro Regular) ((SourceSerifPro-Regular.otf 0 217280)))
((Source\ Serif\ Pro SemiBold) ((SourceSerifPro-Semibold.otf 0 227008)))
((Source\ Serif\ Pro SemiBold\ Italic) ((SourceSerifPro-SemiboldIt.otf 0 75188)))
((Source\ Serif\ Pro\ ExtraLight Italic) ((SourceSerifPro-ExtraLightIt.otf 0 72544)))
((Source\ Serif\ Pro\ ExtraLight Regular) ((SourceSerifPro-ExtraLight.otf 0 212300)))
((Step Bold) ((STEP-Bold.otf 0 166744)))
((Step Bold\ Italic) ((STEP-BoldItalic.otf 0 126224)))
((Step Italic) ((STEP-Italic.otf 0 132912)))
((Step Regular) ((STEP-Regular.otf 0 296192)))
((STEP\ Math Bold) ((STEPMath-Bold.otf 0 245508)))
((STEP\ Math Regular) ((STEPMath-Regular.otf 0 553244)))
((STFangsong Regular) ((华文仿宋.ttf 0 15734488) (华文仿宋.ttf 0 15884236) (华文仿宋.ttf 0 15884824)))
((STHeiti Light) ((华文细黑.ttf 0 17140620) (华文细黑.ttf 0 15642136) (华文细黑.ttf 0 15692256)))
((STHeiti Regular) ((华文黑体.ttf 0 13631224) (华文黑体.ttf 0 13631780)))
((Stix Bold) ((STIX-Bold.otf 0 209464) (STIX-Bold.otf 0 206200)))
((Stix Bold\ Italic) ((STIX-BoldItalic.otf 0 174404) (STIX-BoldItalic.otf 0 172348)))
((Stix Italic) ((STIX-Italic.otf 0 177388) (STIX-Italic.otf 0 175332)))
((Stix Regular) ((STIX-Regular.otf 0 426992) (STIX-Regular.otf 0 426932)))
((Stix\ Math Regular) ((STIXMath-Regular.otf 0 477848) (STIXMath-Regular.otf 0 476872)))
((STKaiti Regular) ((华文楷体.ttf 0 17502796) (Kaiti.ttc 4 70712356) (楷体.ttc 3 23433244)))
((Stone\ Sans\ ITC\ TT Bold) ((Stone\ Sans.ttc 2 432996) (Stone\ Sans.ttc 2 499532)))
((Stone\ Sans\ Sem\ ITC\ TT Semi) ((Stone\ Sans.ttc 0 432996) (Stone\ Sans.ttc 0 499532)))
((Stone\ Sans\ Sem\ ITC\ TT SemiIta) ((Stone\ Sans.ttc 1 432996) (Stone\ Sans.ttc 1 499532)))
((STSong Regular) ((华文宋体.ttf 0 16163136) (Songti.ttc 4 66899384) (宋体.ttc 3 45078972) (Songti.ttc 4 66933252) (Songti.ttc 4 66936780)))
((Sukhumvit\ Set Bold) ((SukhumvitSet.ttc 5 626056) (SukhumvitSet.ttc 5 642396)))
((Sukhumvit\ Set Light) ((SukhumvitSet.ttc 1 626056) (SukhumvitSet.ttc 1 642396)))
((Sukhumvit\ Set Medium) ((SukhumvitSet.ttc 3 626056) (SukhumvitSet.ttc 3 642396)))
((Sukhumvit\ Set Semi\ Bold) ((SukhumvitSet.ttc 4 626056) (SukhumvitSet.ttc 4 642396)))
((Sukhumvit\ Set Text) ((SukhumvitSet.ttc 2 626056) (SukhumvitSet.ttc 2 642396)))
((Sukhumvit\ Set Thin) ((SukhumvitSet.ttc 0 626056) (SukhumvitSet.ttc 0 642396)))
((Superclarendon Black) ((SuperClarendon.ttc 7 2681496) (SuperClarendon.ttc 7 2712224)))
((Superclarendon Black\ Italic) ((SuperClarendon.ttc 6 2681496) (SuperClarendon.ttc 6 2712224)))
((Superclarendon Bold) ((SuperClarendon.ttc 5 2681496) (SuperClarendon.ttc 5 2712224)))
((Superclarendon Bold\ Italic) ((SuperClarendon.ttc 4 2681496) (SuperClarendon.ttc 4 2712224)))
((Superclarendon Italic) ((SuperClarendon.ttc 1 2681496) (SuperClarendon.ttc 1 2712224)))
((Superclarendon Light) ((SuperClarendon.ttc 3 2681496) (SuperClarendon.ttc 3 2712224)))
((Superclarendon Light\ Italic) ((SuperClarendon.ttc 2 2681496) (SuperClarendon.ttc 2 2712224)))
((Superclarendon Regular) ((SuperClarendon.ttc 0 2681496) (SuperClarendon.ttc 0 2712224)))
((SVRsymbols Regular) ((SVRsymbols.otf 0 26584)))
((Sylfaen Regular) ((sylfaen.ttf 0 221676) (sylfaen.ttf 0 256528)))
((Symbol Regular) ((Symbol.ttf 0 103400) (symbol.ttf 0 69464) (Symbol.ttf 0 105752) (Symbol.ttf 0 80016) (symbol.ttf 0 69036)))
((Synchro\ LET Regular) ((Synchro\ LET\ Fonts.ttf 0 160848)))
((Tabaquera Regular) ((Tabaquera.ttf 0 175964)))
((Tahoma Bold) ((Tahoma\ Bold.ttf 0 626928) (tahomabd.ttf 0 355680) (tahomabd.ttf 0 867988)))
((Tahoma Regular) ((Tahoma.ttf 0 681120) (tahoma.ttf 0 383804) (tahoma.ttf 0 939280)))
((TakaoExGothic Regular) ((TakaoExGothic.ttf 0 6008858)))
((TakaoExMincho Regular) ((TakaoExMincho.ttf 0 7754918)))
((TakaoGothic Regular) ((TakaoGothic.ttf 0 6234398)))
((TakaoMincho Regular) ((TakaoMincho.ttf 0 8061610)))
((TakaoPGothic Regular) ((TakaoPGothic.ttf 0 6234746) (ttf-japanese-gothic.ttf 0 6234746)))
((TakaoPMincho Regular) ((TakaoPMincho.ttf 0 8060926) (ttf-japanese-mincho.otf 0 8060926)))
((Tamil\ MN Bold) ((Tamil\ MN.ttc 1 400396) (Tamil\ MN.ttc 1 400164) (Tamil\ MN.ttc 1 188700)))
((Tamil\ MN Regular) ((Tamil\ MN.ttc 0 400396) (Tamil\ MN.ttc 0 400164) (Tamil\ MN.ttc 0 188700)))
((Tamil\ Sangam\ MN Bold) ((Tamil\ Sangam\ MN.ttc 1 384780) (Tamil\ Sangam\ MN.ttc 1 338136) (Tamil\ Sangam\ MN.ttc 1 168628)))
((Tamil\ Sangam\ MN Regular) ((Tamil\ Sangam\ MN.ttc 0 384780) (Tamil\ Sangam\ MN.ttc 0 338136) (Tamil\ Sangam\ MN.ttc 0 168628)))
((Tangerine Bold) ((Tangerine_Bold.ttf 0 66492)))
((Tangerine Regular) ((Tangerine_Regular.ttf 0 61484)))
((Telugu\ MN Bold) ((Telugu\ MN.ttc 1 1736356) (Telugu\ MN.ttc 1 1740836) (Telugu\ MN.ttc 1 333016)))
((Telugu\ MN Regular) ((Telugu\ MN.ttc 0 1736356) (Telugu\ MN.ttc 0 1740836) (Telugu\ MN.ttc 0 333016)))
((Telugu\ Sangam\ MN Bold) ((Telugu\ Sangam\ MN.ttc 1 1224792) (Telugu\ Sangam\ MN.ttc 1 1229264) (Telugu\ Sangam\ MN.ttc 1 305548)))
((Telugu\ Sangam\ MN Regular) ((Telugu\ Sangam\ MN.ttc 0 1224792) (Telugu\ Sangam\ MN.ttc 0 1229264) (Telugu\ Sangam\ MN.ttc 0 305548)))
((Tempora Bold) ((Tempora-Bold.otf 0 169756)))
((Tempora Bold\ Italic) ((Tempora-BoldItalic.otf 0 181372)))
((Tempora Italic) ((Tempora-Italic.otf 0 153648)))
((Tempora Regular) ((Tempora-Regular.otf 0 172648)))
((TeX\ AMS\ Blackboard\ Bold Regular) ((msbm10.tfm 0 908)))
((TeX\ Bard) ((bard.tfm 0 924)))
((TeX\ Blackboard\ Bold Bold) ((bbmbx10.tfm 0 580) (bbmbx10.tfm 0 644)))
((TeX\ Blackboard\ Bold Bold Oblique) ((bbmbxsl10.tfm 0 764)))
((TeX\ Blackboard\ Bold Oblique) ((bbmsl10.tfm 0 676) (bbmsl10.tfm 0 740)))
((TeX\ Blackboard\ Bold Regular) ((bbm10.tfm 0 560) (bbm10.tfm 0 624)))
((TeX\ Blackboard\ Bold\ Sans Bold) ((bbmssbx10.tfm 0 568) (bbmssbx10.tfm 0 644)))
((TeX\ Blackboard\ Bold\ Sans Italic) ((bbmssi10.tfm 0 708)))
((TeX\ Blackboard\ Bold\ Sans Regular) ((bbmss10.tfm 0 600) (bbmss10.tfm 0 664)))
((TeX\ Blackboard\ Bold\ Variant Regular) ((bbold10.tfm 0 788) (bbold10.tfm 0 852)))
((TeX\ Blackletter Regular) ((blackletter.tfm 0 720)))
((TeX\ Calligraphic Regular) ((callig15.tfm 0 1764)))
((TeX\ Calligraphic\ Capitals Bold) ((cmbsy10.tfm 0 1116)))
((TeX\ Calligraphic\ Capitals Regular) ((cmsy10.tfm 0 1124)))
((TeX\ Capital\ Baseball Regular) ((capbas.tfm 0 332)))
((TeX\ Children\ Handwriting Regular) ((la14.tfm 0 2292)))
((TeX\ Cypriot) ((cypr10.tfm 0 480)))
((TeX\ Double\ Stroke Regular) ((dsrom10.tfm 0 452)))
((TeX\ Double\ Stroke\ Sans Regular) ((dsss10.tfm 0 460)))
((TeX\ Duerer Bold) ((cdb10.tfm 0 360)))
((TeX\ Duerer Italic) ((cdi10.tfm 0 376)))
((TeX\ Duerer Oblique) ((cdsl10.tfm 0 360)))
((TeX\ Duerer Regular) ((cdr10.tfm 0 360)))
((TeX\ Duerer\ Mono Regular) ((cdtt10.tfm 0 192)))
((TeX\ Duerer\ Sans Regular) ((cdss10.tfm 0 360)))
((TeX\ Etruscan) ((etr10.tfm 0 388)))
((TeX\ Euler\ Calligraphic Regular) ((euxm10.tfm 0 904)))
((TeX\ German\ Handwriting Regular) ((twcal14.tfm 0 17516)))
((TeX\ Gothic Regular) ((ygoth.tfm 0 1300)))
((TeX\ Greek\ 4\ CBC) ((givbc10.tfm 0 428)))
((TeX\ Greek\ 6\ CBC) ((gvibc10.tfm 0 372)))
((TeX\ Gyre\ Adventor Bold) ((texgyreadventor-bold.otf 0 176096)))
((TeX\ Gyre\ Adventor Bold\ Italic) ((texgyreadventor-bolditalic.otf 0 175456)))
((TeX\ Gyre\ Adventor Italic) ((texgyreadventor-italic.otf 0 170968)))
((TeX\ Gyre\ Adventor Regular) ((texgyreadventor-regular.otf 0 170364)))
((TeX\ Gyre\ Bonum Bold) ((texgyrebonum-bold.otf 0 141140)))
((TeX\ Gyre\ Bonum Bold\ Italic) ((texgyrebonum-bolditalic.otf 0 145488)))
((TeX\ Gyre\ Bonum Italic) ((texgyrebonum-italic.otf 0 147120)))
((TeX\ Gyre\ Bonum Regular) ((texgyrebonum-regular.otf 0 142660)))
((TeX\ Gyre\ Bonum\ Math Regular) ((texgyrebonum-math.otf 0 527408)))
((TeX\ Gyre\ Chorus Regular) ((texgyrechorus-mediumitalic.otf 0 100924)))
((TeX\ Gyre\ Cursor Bold) ((texgyrecursor-bold.otf 0 87288)))
((TeX\ Gyre\ Cursor Bold\ Italic) ((texgyrecursor-bolditalic.otf 0 90360)))
((TeX\ Gyre\ Cursor Italic) ((texgyrecursor-italic.otf 0 87536)))
((TeX\ Gyre\ Cursor Regular) ((texgyrecursor-regular.otf 0 84652)))
((TeX\ Gyre\ Heros Bold) ((texgyreheros-bold.otf 0 135204)))
((TeX\ Gyre\ Heros Bold\ Italic) ((texgyreheros-bolditalic.otf 0 135264)))
((TeX\ Gyre\ Heros Italic) ((texgyreheros-italic.otf 0 139208)))
((TeX\ Gyre\ Heros Regular) ((texgyreheros-regular.otf 0 133600)))
((TeX\ Gyre\ Heros\ Cn Bold) ((texgyreheroscn-bold.otf 0 133220)))
((TeX\ Gyre\ Heros\ Cn Bold\ Italic) ((texgyreheroscn-bolditalic.otf 0 138876)))
((TeX\ Gyre\ Heros\ Cn Italic) ((texgyreheroscn-italic.otf 0 138940)))
((TeX\ Gyre\ Heros\ Cn Regular) ((texgyreheroscn-regular.otf 0 132372)))
((TeX\ Gyre\ Pagella Bold) ((texgyrepagella-bold.otf 0 219564)))
((TeX\ Gyre\ Pagella Bold\ Italic) ((texgyrepagella-bolditalic.otf 0 216296)))
((TeX\ Gyre\ Pagella Italic) ((texgyrepagella-italic.otf 0 221936)))
((TeX\ Gyre\ Pagella Regular) ((texgyrepagella-regular.otf 0 218100)))
((TeX\ Gyre\ Pagella\ Math Regular) ((texgyrepagella-math.otf 0 601220)))
((TeX\ Gyre\ Schola Bold) ((texgyreschola-bold.otf 0 141752)))
((TeX\ Gyre\ Schola Bold\ Italic) ((texgyreschola-bolditalic.otf 0 144864)))
((TeX\ Gyre\ Schola Italic) ((texgyreschola-italic.otf 0 143152)))
((TeX\ Gyre\ Schola Regular) ((texgyreschola-regular.otf 0 140596)))
((TeX\ Gyre\ Schola\ Math Regular) ((texgyreschola-math.otf 0 596860)))
((TeX\ Gyre\ Termes Bold) ((texgyretermes-bold.otf 0 139480)))
((TeX\ Gyre\ Termes Bold\ Italic) ((texgyretermes-bolditalic.otf 0 144180)))
((TeX\ Gyre\ Termes Italic) ((texgyretermes-italic.otf 0 141324)))
((TeX\ Gyre\ Termes Regular) ((texgyretermes-regular.otf 0 140932)))
((TeX\ Gyre\ Termes\ Math Regular) ((texgyretermes-math.otf 0 532404)))
((TeX\ Hershey Regular) ((hscs10.tfm 0 0)))
((TeX\ Linear\ B) ((linb10.tfm 0 972)))
((TeX\ Ogham) ((ogham10.tfm 0 360)))
((TeX\ Old\ English Regular) ((hge10.tfm 0 696)))
((TeX\ Pacioli Oblique) ((cpcsl10.tfm 0 824) (cpcsl10.tfm 0 760)))
((TeX\ Pacioli Regular) ((cpcr10.tfm 0 784) (cpcr10.tfm 0 720)))
((TeX\ Pandora Bold) ((pnb10.tfm 0 1892)))
((TeX\ Pandora Oblique) ((pnsl10.tfm 1896)))
((TeX\ Pandora Regular) ((pnr10.tfm 0 1896)))
((TeX\ Pandora\ Mono Regular) ((pntt9.tfm 720)))
((TeX\ Pandora\ Sans Bold) ((pnssb10.tfm 1888)))
((TeX\ Pandora\ Sans Italic) ((pnssi10.tfm 1892)))
((TeX\ Pandora\ Sans Regular) ((pnss10.tfm 1892)))
((TeX\ Phoenician) ((phnc10.tfm 0 496)))
((TeX\ Punk Bold) ((punkbx20.tfm 0 740) (punkbx20.tfm 0 676)))
((TeX\ Punk Oblique) ((punksl20.tfm 0 748) (punksl20.tfm 0 684)))
((TeX\ Punk Regular) ((punk20.tfm 0 740) (punk20.tfm 0 676)))
((TeX\ Ralph\ Smith Regular) ((rsfs10.tfm 0 688) (rsfs10.tfm 0 752)))
((TeX\ Runic\ Futharc) ((fut10.tfm 0 504)))
((TeX\ Runic\ Futhol) ((futhol10.tfm 0 280)))
((TeX\ Runic\ Futhor) ((futhor10.tfm 0 280)))
((TeX\ Schwell Regular) ((schwell.tfm 0 2192)))
((TeX\ Slavonic) ((izhitsa10.tfm 0 0)))
((TeX\ Southarabian) ((SouthArabian.tfm 0 0)))
((TeX\ Suet Regular) ((suet14.tfm 0 2104)))
((TeX\ Swab Regular) ((yswab.tfm 0 1440)))
((TeX\ Syriac) ((estrangelo.tfm 0 0)))
((TeX\ Ugaritic) ((ugarithic.tfm 0 504)))
((TeX\ Va\ Handwriting Regular) ((va14.tfm 0 2100)))
((TeXmacs\ Avant\ Garde Bold) ((avant-garde-bx10.tfm 0 5856)))
((TeXmacs\ Avant\ Garde Bold\ Italic) ((avant-garde-bi10.tfm 0 6124)))
((TeXmacs\ Avant\ Garde Italic) ((avant-garde-ti10.tfm 0 6264)))
((TeXmacs\ Avant\ Garde Regular) ((avant-garde-rm10.tfm 0 6124)))
((TeXmacs\ Bookman Bold) ((bookman-bx10.tfm 0 5888)))
((TeXmacs\ Bookman Bold\ Italic) ((bookman-bi10.tfm 0 6264)))
((TeXmacs\ Bookman Italic) ((bookman-ti10.tfm 0 6284)))
((TeXmacs\ Bookman Regular) ((bookman-rm10.tfm 0 5996)))
((TeXmacs\ Computer\ Modern Bold) ((ecbx10.tfm 0 3200)))
((TeXmacs\ Computer\ Modern Bold\ Condensed) ((ecrb10.tfm 0 3196)))
((TeXmacs\ Computer\ Modern Bold\ Italic) ((ecbi10.tfm 0 2900)))
((TeXmacs\ Computer\ Modern Bold\ Oblique) ((ecbl10.tfm 0 3412)))
((TeXmacs\ Computer\ Modern Bold\ Oblique\ SmallCaps) ((ecoc10.tfm 0 3060)))
((TeXmacs\ Computer\ Modern Bold\ SmallCaps) ((ecxc10.tfm 0 2852)))
((TeXmacs\ Computer\ Modern Italic) ((ecti10.tfm 0 2840)))
((TeXmacs\ Computer\ Modern ItalicUpright) ((ecui10.tfm 3072)))
((TeXmacs\ Computer\ Modern Long) ((ecdh10.tfm 0 3152)))
((TeXmacs\ Computer\ Modern Oblique) ((ecsl10.tfm 0 3372)))
((TeXmacs\ Computer\ Modern Regular) ((ecrm10.tfm 0 3148)))
((TeXmacs\ Computer\ Modern SmallCaps) ((eccc10.tfm 0 2788)))
((TeXmacs\ Computer\ Modern\ Mono Flat) ((ecltt10.tfm 0 1536)))
((TeXmacs\ Computer\ Modern\ Mono Italic\ Proportional) ((ecvi10.tfm 0 2752)))
((TeXmacs\ Computer\ Modern\ Mono Oblique) ((ecst10.tfm 0 1356)))
((TeXmacs\ Computer\ Modern\ Mono Proportional) ((ecvt10.tfm 0 3104)))
((TeXmacs\ Computer\ Modern\ Mono Regular) ((ectt10.tfm 0 1348)))
((TeXmacs\ Computer\ Modern\ Mono SmallCaps) ((ectc10.tfm 0 1352)))
((TeXmacs\ Computer\ Modern\ Sans Bold) ((ecsx10.tfm 0 3132)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Condensed) ((ecssdc10.tfm 0 3128)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Flat) ((eclb10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Italic\ Flat) ((eclo10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Bold\ Oblique) ((ecso10.tfm 0 3352)))
((TeXmacs\ Computer\ Modern\ Sans Flat) ((eclq10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Italic\ Flat) ((ecli10.tfm 0 3584)))
((TeXmacs\ Computer\ Modern\ Sans Oblique) ((ecsi10.tfm 0 3360)))
((TeXmacs\ Computer\ Modern\ Sans Regular) ((ecss10.tfm 0 3140)))
((TeXmacs\ Concrete Bold) ((ecbx10.tfm 0 3200)))
((TeXmacs\ Concrete Bold\ Condensed) ((ecrb10.tfm 0 3196)))
((TeXmacs\ Concrete Bold\ Italic) ((ecbi10.tfm 0 2900)))
((TeXmacs\ Concrete Bold\ Oblique) ((ecbl10.tfm 0 3412)))
((TeXmacs\ Concrete Italic) ((eoti10.tfm 0 2868)))
((TeXmacs\ Concrete Oblique) ((eosl10.tfm 0 3440)))
((TeXmacs\ Concrete Regular) ((eorm10.tfm 0 3220)))
((TeXmacs\ Concrete SmallCaps) ((eocc10.tfm 0 2812)))
((TeXmacs\ Concrete\ Mono Oblique) ((ecst10.tfm 0 1356)))
((TeXmacs\ Concrete\ Mono Proportional) ((ecvt10.tfm 0 3104)))
((TeXmacs\ Concrete\ Mono Regular) ((ectt10.tfm 0 2011)))
((TeXmacs\ Concrete\ Mono SmallCaps) ((ectc10.tfm 0 1352)))
((TeXmacs\ Concrete\ Sans Bold) ((ecsx10.tfm 0 3132)))
((TeXmacs\ Concrete\ Sans Oblique) ((etsi10.tfm 0 3360)))
((TeXmacs\ Concrete\ Sans Regular) ((ecss10.tfm 0 3140)))
((TeXmacs\ Courier Bold) ((courier-bx10.tfm 0 1328)))
((TeXmacs\ Courier Bold\ Italic) ((courier-bi10.tfm 0 1580)))
((TeXmacs\ Courier Italic) ((courier-ti10.tfm 0 1488)))
((TeXmacs\ Courier Regular) ((courier-rm10.tfm 0 1328)))
((TeXmacs\ Euler Bold) ((eufb10.tfm 0 1028)))
((TeXmacs\ Euler Regular) ((eufm10.tfm 0 1040)))
((TeXmacs\ Euler\ New\ Roman Bold) ((eurb10.tfm 0 1208)))
((TeXmacs\ Euler\ New\ Roman Regular) ((eurm10.tfm 0 1228)))
((TeXmacs\ Helvetica Bold) ((helvetica-bx10.tfm 0 40892)))
((TeXmacs\ Helvetica Bold\ Italic) ((helvetica-bi10.tfm 0 41140)))
((TeXmacs\ Helvetica Italic) ((helvetica-ti10.tfm 0 41164)))
((TeXmacs\ Helvetica Regular) ((helvetica-rm10.tfm 0 40928)))
((TeXmacs\ New\ Century\ Schoolbook Bold) ((nc-schoolbook-bx10.tfm 0 5900)))
((TeXmacs\ New\ Century\ Schoolbook Bold\ Italic) ((nc-schoolbook-bi10.tfm 0 6096)))
((TeXmacs\ New\ Century\ Schoolbook Italic) ((nc-schoolbook-ti10.tfm 0 6092)))
((TeXmacs\ New\ Century\ Schoolbook Regular) ((nc-schoolbook-rm10.tfm 0 5936)))
((TeXmacs\ Palatino Bold) ((palatino-bx10.tfm 0 3296)))
((TeXmacs\ Palatino Bold\ Italic) ((palatino-bi10.tfm 0 3628)))
((TeXmacs\ Palatino Bold\ Oblique) ((palatino-bl10.tfm 0 3296)))
((TeXmacs\ Palatino Bold\ SmallCaps) ((palatino-xc10.tfm 0 5544)))
((TeXmacs\ Palatino Italic) ((palatino-ti10.tfm 0 3536)))
((TeXmacs\ Palatino Oblique) ((palatino-sl10.tfm 0 3648)))
((TeXmacs\ Palatino Regular) ((palatino-rm10.tfm 0 3648)))
((TeXmacs\ Palatino SmallCaps) ((palatino-cc10.tfm 0 6108)))
((TeXmacs\ Times Bold) ((times-bx10.tfm 0 64028)))
((TeXmacs\ Times Bold\ Italic) ((times-bi10.tfm 0 66560)))
((TeXmacs\ Times Bold\ Oblique) ((times-bl10.tfm 0 64280)))
((TeXmacs\ Times Bold\ SmallCaps) ((times-xc10.tfm 0 1508)))
((TeXmacs\ Times Italic) ((times-ti10.tfm 0 69636)))
((TeXmacs\ Times Oblique) ((times-sl10.tfm 0 66036)))
((TeXmacs\ Times Regular) ((times-rm10.tfm 0 65812)))
((TeXmacs\ Times SmallCaps) ((times-cc10.tfm 0 1540)))
((Theano\ Didot Bold) ((TheanoDidot-Bold.ttf 0 136472)))
((Theano\ Didot Regular) ((TheanoDidot-Regular.ttf 0 169668)))
((Theano\ Modern Bold) ((TheanoModern-Bold.ttf 0 145472)))
((Theano\ Modern Regular) ((TheanoModern-Regular.ttf 0 180344)))
((Theano\ Old\ Style Bold) ((TheanoOldStyle-Bold.ttf 0 170856)))
((Theano\ Old\ Style Regular) ((TheanoOldStyle-Regular.ttf 0 208336)))
((Thickhead Regular) ((THICKHEA.ttf 0 34852)))
((Thonburi Bold) ((ThonburiBold.ttf 0 255412) (Thonburi.ttc 1 2411184) (ThonburiBold.ttf 0 256856) (Thonburi.ttc 1 2421960)))
((Thonburi Light) ((Thonburi.ttc 2 2411184) (Thonburi.ttc 2 2421960)))
((Thonburi Regular) ((Thonburi.ttf 0 223404) (Thonburi.ttc 0 2411184) (Thonburi.ttf 0 224784) (Thonburi.ttc 0 2421960)))
((Times Bold) ((Times.ttc 1 915932) (Times.ttc 1 917516)))
((Times Bold\ Italic) ((Times.ttc 3 915932) (Times.ttc 3 917516)))
((Times Italic) ((Times.ttc 2 915932) (Times.ttc 2 917516)))
((Times Regular) ((Times.ttc 0 915932) (Times.ttc 0 917516)))
((Times\ New\ Roman Bold) ((Times\ New\ Roman\ Bold.ttf 0 842168) (timesbd.ttf 0 398372) (timesbd.ttf 0 1175904)))
((Times\ New\ Roman Bold\ Italic) ((Times\ New\ Roman\ Bold\ Italic.ttf 0 620008) (timesbi.ttf 0 239692) (timesbi.ttf 0 881860)))
((Times\ New\ Roman Italic) ((Times\ New\ Roman\ Italic.ttf 0 660268) (timesi.ttf 0 248368) (timesi.ttf 0 940288)))
((Times\ New\ Roman Regular) ((Times\ New\ Roman.ttf 0 834452) (times.ttf 0 409280) (times.ttf 0 1195688)))
((Tinos Bold) ((Tinos-Bold.ttf 0 452284)))
((Tinos Bold\ Italic) ((Tinos-BoldItalic.ttf 0 457320)))
((Tinos Italic) ((Tinos-Italic.ttf 0 456156)))
((Tinos Regular) ((Tinos-Regular.ttf 0 475996)))
((Tlwg\ Typist Bold) ((TlwgTypist-Bold.ttf 0 96040) (TlwgTypist-Bold.otf 0 49856)))
((Tlwg\ Typist BoldOblique) ((TlwgTypist-BoldOblique.ttf 0 108408) (TlwgTypist-BoldOblique.otf 0 52072)))
((Tlwg\ Typist Medium) ((TlwgTypist.ttf 0 92472)))
((Tlwg\ Typist Oblique) ((TlwgTypist-Oblique.ttf 0 107864) (TlwgTypist-Oblique.otf 0 51364)))
((Tlwg\ Typist Regular) ((TlwgTypist.otf 0 45940)))
((Tlwg\ Typo Bold) ((TlwgTypo-Bold.ttf 0 96096) (TlwgTypo-Bold.otf 0 50520)))
((Tlwg\ Typo BoldOblique) ((TlwgTypo-BoldOblique.ttf 0 108368) (TlwgTypo-BoldOblique.otf 0 52692)))
((Tlwg\ Typo Medium) ((TlwgTypo.ttf 0 92508)))
((Tlwg\ Typo Oblique) ((TlwgTypo-Oblique.ttf 0 108332) (TlwgTypo-Oblique.otf 0 51756)))
((Tlwg\ Typo Regular) ((TlwgTypo.otf 0 46092)))
((TlwgMono Bold) ((TlwgMono-Bold.ttf 0 90652) (TlwgMono-Bold.otf 0 40828)))
((TlwgMono BoldOblique) ((TlwgMono-BoldOblique.ttf 0 100156) (TlwgMono-BoldOblique.otf 0 42872)))
((TlwgMono Medium) ((TlwgMono.ttf 0 83804)))
((TlwgMono Oblique) ((TlwgMono-Oblique.ttf 0 99016) (TlwgMono-Oblique.otf 0 43188)))
((TlwgMono Regular) ((TlwgMono.otf 0 38824)))
((TlwgTypewriter Bold) ((TlwgTypewriter-Bold.ttf 0 93908) (TlwgTypewriter-Bold.otf 0 47604)))
((TlwgTypewriter BoldOblique) ((TlwgTypewriter-BoldOblique.ttf 0 102652) (TlwgTypewriter-BoldOblique.otf 0 49480)))
((TlwgTypewriter Medium) ((TlwgTypewriter.ttf 0 86976)))
((TlwgTypewriter Oblique) ((TlwgTypewriter-Oblique.ttf 0 101520) (TlwgTypewriter-Oblique.otf 0 48948)))
((TlwgTypewriter Regular) ((TlwgTypewriter.otf 0 45372)))
((Trattatello Regular) ((Trattatello.ttf 0 1160004) (Trattatello.ttf 0 932128)))
((Trebuchet\ MS Bold) ((Trebuchet\ MS\ Bold.ttf 0 129360) (trebucbd.ttf 0 123096) (trebucbd.ttf 0 244124)))
((Trebuchet\ MS Bold\ Italic) ((Trebuchet\ MS\ Bold\ Italic.ttf 0 137008) (trebucbi.ttf 0 131188) (trebucbi.ttf 0 225868)))
((Trebuchet\ MS Italic) ((Trebuchet\ MS\ Italic.ttf 0 144820) (trebucit.ttf 0 139288) (trebucit.ttf 0 252224)))
((Trebuchet\ MS Regular) ((Trebuchet\ MS.ttf 0 138848) (trebuc.ttf 0 134108) (trebuc.ttf 0 254396)))
((TriangleETcircle\ Shadow Regular) ((TriangleETcircle\ Shadow.otf 0 39260)))
((TriangleETcircle\ Shadowed Regular) ((TriangleETcircle\ Shadowed.otf 0 23844)))
((Tsukushi\ A\ Round\ Gothic Bold) ((TsukushiAMaruGothic.ttc 1 7916648)))
((Tsukushi\ A\ Round\ Gothic Regular) ((TsukushiAMaruGothic.ttc 0 7916648)))
((Tsukushi\ B\ Round\ Gothic Bold) ((TsukushiBMaruGothic.ttc 1 7980496)))
((Tsukushi\ B\ Round\ Gothic Regular) ((TsukushiBMaruGothic.ttc 0 7980496)))
((Tt-Kp Medium) ((TT-KP-ME.ttf 0 26928)))
((Tt-Kp Regular) ((TT-KP-RE.ttf 0 27044)))
((Tuffy Bold) ((Tuffy_Bold.otf 0 21904) (Tuffy_Bold.ttf 0 17196)))
((Tuffy Bold-Italic) ((Tuffy_Bold_Italic.otf 0 32456) (Tuffy_Bold_Italic.ttf 0 18828)))
((Tuffy Italic) ((Tuffy_Italic.otf 0 24464) (Tuffy_Italic.ttf 0 19284)))
((Tuffy Regular) ((Tuffy.otf 0 18900) (Tuffy.ttf 0 18444)))
((Tunga Regular) ((tunga.ttf 0 148624)))
((Tw\ Cen\ MT Bold) ((TwentiethCentury.ttc 1 290348)))
((Tw\ Cen\ MT Bold\ Italic) ((TwentiethCentury.ttc 3 290348)))
((Tw\ Cen\ MT Italic) ((TwentiethCentury.ttc 2 290348)))
((Tw\ Cen\ MT Regular) ((TwentiethCentury.ttc 0 290348)))
((Twemoji\ Mozilla Regular) ((TwemojiMozilla.ttf 0 1244336)))
((Type\ Embellishments\ One\ LET Embellishments\ One\ LET\ Plain) ((Type\ Embellishments\ One\ LET.ttf 0 89364)))
((Typicons Book) ((typicons.ttf 0 99920)))
((Ubuntu Bold) ((Ubuntu-B.ttf 0 312932)))
((Ubuntu Bold\ Italic) ((Ubuntu-BI.ttf 0 400740)))
((Ubuntu Italic) ((Ubuntu-I.ttf 0 349560)))
((Ubuntu Regular) ((Ubuntu-R.ttf 0 318280)))
((Ubuntu-Title Title) ((Ubuntu-Title.ttf 0 15108)))
((Ubuntu-Title-fr Title-fr) ((ubuntu-title-fr-1.1.ttf 0 22268)))
((UM\ Typewriter Bold) ((UMTypewriter-Bold.otf 0 177884)))
((UM\ Typewriter Bold\ Italic) ((UMTypewriter-BoldItalic.otf 0 192012)))
((UM\ Typewriter Italic) ((UMTypewriter-Italic.otf 0 159572) (UMTypewriter-Oblique.otf 0 107412)))
((UM\ Typewriter Regular) ((UMTypewriter-Regular.otf 0 161460)))
((Umpush Bold) ((Umpush-Bold.ttf 0 68016) (Umpush-Bold.otf 0 49196)))
((Umpush BoldOblique) ((Umpush-BoldOblique.ttf 0 80156) (Umpush-BoldOblique.otf 0 51256)))
((Umpush Book) ((Umpush.ttf 0 69964)))
((Umpush Light) ((Umpush-Light.ttf 0 69896) (Umpush-Light.otf 0 49356)))
((Umpush LightOblique) ((Umpush-LightOblique.ttf 0 82852) (Umpush-LightOblique.otf 0 51668)))
((Umpush Oblique) ((Umpush-Oblique.ttf 0 82692) (Umpush-Oblique.otf 0 52004)))
((Umpush Regular) ((Umpush.otf 0 50140)))
((UnBatang Bold) ((UnBatangBold.ttf 0 3863046) (UnBatangBold.ttf 0 4071104) (UnBatangBold.ttf 0 6794692)))
((UnBatang Regular) ((UnBatang.ttf 0 3678974) (UnBatang.ttf 0 6157280)))
((UnDinaru Bold) ((UnDinaruBold.ttf 0 1021752)))
((UnDinaru Light) ((UnDinaruLight.ttf 0 1023908)))
((UnDinaru Regular) ((UnDinaru.ttf 0 1028216)))
((UnDotum Bold) ((UnDotumBold.ttf 0 2603854) (UnDotumBold.ttf 0 2808292) (UnDotumBold.ttf 0 4093740)))
((UnDotum Regular) ((UnDotum.ttf 0 2209390) (UnDotum.ttf 0 3656228)))
((UnGraphic Bold) ((UnGraphicBold.ttf 0 768906) (UnGraphicBold.ttf 0 1148776)))
((UnGraphic Regular) ((UnGraphic.ttf 0 788458) (UnGraphic.ttf 0 1167148)))
((UnGungseo Regular) ((UnGungseo.ttf 0 4149866) (UnGungseo.ttf 0 6275084)))
((Universalis\ ADF\ Std Bold) ((UniversalisADFStd-Bold.otf 0 39224)))
((Universalis\ ADF\ Std Bold\ Italic) ((UniversalisADFStd-BoldItalic.otf 0 41936)))
((Universalis\ ADF\ Std Italic) ((UniversalisADFStd-Italic.otf 0 40452)))
((Universalis\ ADF\ Std Regular) ((UniversalisADFStd-Regular.otf 0 37724)))
((Universalis\ ADF\ Std\ Cond Bold\ Italic) ((UniversalisADFStd-BoldCondIt.otf 0 41496)))
((Universalis\ ADF\ Std\ Cond Italic) ((UniversalisADFStd-CondItalic.otf 0 40808)))
((Universalis\ ADF\ Std\ Cond Regular) ((UniversalisADFStd-Cond.otf 0 37776)))
((Universalis\ ADF\ Std\ cond Bold) ((UniversalisADFStd-BoldCond.otf 0 38796)))
((UnJamoBatang Regular) ((UnJamoBatang.ttf 0 1154296)))
((UnJamoDotum Regular) ((UnJamoDotum.ttf 0 917360)))
((UnJamoNovel Regular) ((UnJamoNovel.ttf 0 914976)))
((UnJamoSora Regular) ((UnJamoSora.ttf 0 913204)))
((UnPen Regular) ((UnPen.ttf 0 1263576)))
((UnPenheulim Regular) ((UnPenheulim.ttf 0 1186424)))
((UnPilgi Bold) ((UnPilgiBold.ttf 0 654486) (UnPilgiBold.ttf 0 923780)))
((UnPilgi Regular) ((UnPilgi.ttf 0 660502) (UnPilgi.ttf 0 932748)))
((UnPilgia Regular) ((UnPilgia.ttf 0 1026488)))
((UnShinmun Regular) ((UnShinmun.ttf 0 5168192)))
((UnTaza Regular) ((UnTaza.ttf 0 668472)))
((UnVada Regular) ((UnVada.ttf 0 922288)))
((UnYetgul Bold) ((UnYetgul.ttf 0 6230116)))
((Utkal Medium) ((utkal.ttf 0 156500)))
((Verdana Bold) ((Verdana\ Bold.ttf 0 153260) (verdanab.ttf 0 137616) (verdanab.ttf 0 211260)))
((Verdana Bold\ Italic) ((Verdana\ Bold\ Italic.ttf 0 173132) (verdanaz.ttf 0 154800) (verdanaz.ttf 0 229800)))
((Verdana Italic) ((Verdana\ Italic.ttf 0 174612) (verdanai.ttf 0 155076) (verdanai.ttf 0 223268)))
((Verdana Regular) ((Verdana.ttf 0 186188) (verdana.ttf 0 171792) (verdana.ttf 0 243304)))
((Verily\ Serif\ Mono Book) ((VerilySerifMono.otf 0 45800)))
((Vermi\ di\ Rouge Regular) ((vermidirouge\ 1.0.ttf 0 60248)))
((Victor Regular) ((Victor.otf 0 155008)))
((Vipond\ Angular Regular) ((vipond_angular.ttf 0 20892)))
((Vipond\ Octic Regular) ((vipond_octic.ttf 0 17292)))
((Vrinda Regular) ((vrinda.ttf 0 252820)))
((Waree Bold) ((Waree-Bold.ttf 0 85352) (Waree-Bold.otf 0 57840)))
((Waree BoldOblique) ((Waree-BoldOblique.ttf 0 96324) (Waree-BoldOblique.otf 0 59660)))
((Waree Book) ((Waree.ttf 0 86772)))
((Waree Oblique) ((Waree-Oblique.ttf 0 99456) (Waree-Oblique.otf 0 58940)))
((Waree Regular) ((Waree.otf 0 57360)))
((Waseem Light) ((Waseem.ttc 1 368184) (Waseem.ttc 1 370732)))
((Waseem Regular) ((Waseem.ttc 0 368184) (Waseem.ttc 0 370732)))
((Wawati\ SC Regular) ((WawaSC-Regular.otf 0 17435944)))
((Wawati\ TC Regular) ((WawaTC-Regular.otf 0 17488424)))
((Webdings Regular) ((Webdings.ttf 0 124308) (webdings.ttf 0 118752) (webdings.ttf 0 120560)))
((WeblySleek\ UI Light) ((weblysleekuil.ttf 0 676412)))
((WeblySleek\ UI Light\ Italic) ((weblysleekuili.ttf 0 396444)))
((WeblySleek\ UI SemiBold) ((weblysleekuisb.ttf 0 655596)))
((WeblySleek\ UI SemiBold\ Italic) ((weblysleekuisbi.ttf 0 394584)))
((WeblySleek\ UI SemiLight) ((weblysleekuisl.ttf 0 622892)))
((WeblySleek\ UI SemiLight\ Italic) ((weblysleekuisli.ttf 0 404012)))
((Weibei\ SC Bold) ((WeibeiSC-Bold.otf 0 24058332)))
((Weibei\ TC Bold) ((WeibeiTC-Bold.otf 0 14896268)))
((WenQuanYi\ Micro\ Hei Regular) ((wqy-microhei.ttc 0 5177387)))
((WenQuanYi\ Micro\ Hei\ Mono Regular) ((wqy-microhei.ttc 1)))
((WenQuanYi\ Zen\ Hei Medium) ((wqy-zenhei.ttf 0 10808952)))
((Wingdings Regular) ((Wingdings.ttf 0 86384) (wingding.ttf 0 81000) (wingding.ttf 0 82180)))
((Wingdings\ 2 Regular) ((Wingdings\ 2.ttf 0 68768)))
((Wingdings\ 3 Regular) ((Wingdings\ 3.ttf 0 38308)))
((Wolgast\ Two Bold) ((Wolgast\ Two\ Bold.otf 0 52148)))
((Wolgast\ Two Normal) ((Wolgast\ Two\ Normal.otf 0 44244)))
((XCharter Bold) ((XCharter-Bold.otf 0 132032)))
((XCharter Bold\ Italic) ((XCharter-BoldItalic.otf 0 112980)))
((XCharter Bold\ Slanted) ((XCharter-BoldSlanted.otf 0 133620)))
((XCharter Italic) ((XCharter-Italic.otf 0 120748)))
((XCharter Roman) ((XCharter-Roman.otf 0 128828)))
((XCharter Slanted) ((XCharter-Slanted.otf 0 130712)))
((Xingkai\ SC Bold) ((Xingkai.ttc 0 14454688)))
((Xingkai\ SC Light) ((Xingkai.ttc 1 14454688)))
((Xits Bold) ((XITS-Bold.otf 0 154176)))
((Xits Bold\ Italic) ((XITS-BoldItalic.otf 0 112708)))
((Xits Italic) ((XITS-Italic.otf 0 116632)))
((Xits Regular) ((XITS-Regular.otf 0 270496)))
((XITS\ Math Bold) ((XITSMath-Bold.otf 0 250768)))
((XITS\ Math Regular) ((XITSMath-Regular.otf 0 548096)))
((Yaziji Regular) ((Yaziji.ttc 0 61668)))
((Yaziji\ PUA Regular) ((Yaziji.ttc 1 61668)))
((Yiggivoo\ Unicode Regular) ((Yiggivoo\ UC.ttf 0 213120)))
((Yiggivoo\ Unicode\  Italic) ((Yiggivoo\ UC_I.ttf 0 181960)))
((Yiggivoo\ Unicode\ 3D Italic) ((Yiggivoo\ UC_I_3D.ttf 0 283268)))
((Yiggivoo\ Unicode\ 3D Regular) ((Yiggivoo\ UC\ 3D.ttf 0 451884)))
((Yinit Regular) ((Yinit.otf 0 698840)))
((Yokawerad Regular) ((Yokawerad.otf 0 382696)))
((YouYuan Regular) ((simyou.ttf 0 6700204)))
((Yuanti\ SC Bold) ((Yuanti.ttc 0 78417612)))
((Yuanti\ SC Light) ((Yuanti.ttc 2 78417612)))
((Yuanti\ SC Regular) ((Yuanti.ttc 4 78417612)))
((Yuanti\ TC Bold) ((Yuanti.ttc 1 78417612)))
((Yuanti\ TC Light) ((Yuanti.ttc 3 78417612)))
((Yuanti\ TC Regular) ((Yuanti.ttc 5 78417612)))
((YuGothic Bold) ((Yu\ Gothic\ Bold.otf 0 8160676)))
((YuGothic Medium) ((Yu\ Gothic\ Medium.otf 0 8218324)))
((YuMincho Demibold) ((YuMincho.ttc 1 21174132)))
((YuMincho Medium) ((YuMincho.ttc 0 21174132)))
((YuMincho\ +36p\ Kana Demibold) ((YuMincho.ttc 3 21174132)))
((YuMincho\ +36p\ Kana Medium) ((YuMincho.ttc 2 21174132)))
((Yuppy\ SC Regular) ((YuppySC-Regular.otf 0 3509868) (雅痞-简.otf 0 3509868)))
((Yuppy\ TC Regular) ((YuppyTC-Regular.otf 0 5320088) (雅痞-繁.otf 0 5320088)))
((Zantroke Regular) ((Zantroke.otf 0 282524)))
((Zapf\ Dingbats Regular) ((ZapfDingbats.ttf 0 154496) (ZapfDingbats.ttf 0 154132) (ZapfDingbats.ttf 0 156088)))
((Zapfino Regular) ((Zapfino.ttf 0 528844) (Zapfino.ttf 0 398884) (Zapfino.ttf 0 403264)))
((Zawra Bold) ((Zawra.ttc 0 168544)))
((Zawra Heavy) ((Zawra.ttc 2 168544)))
((Zawra\ PUA Bold) ((Zawra.ttc 1 168544)))
((Zawra\ PUA Heavy) ((Zawra.ttc 3 168544)))
((Zco Bold) ((zco-Bold.otf 0 89568)))
((Zco Bold\ Italic) ((zco-BoldOblique.otf 0 93188)))
((Zco Italic) ((zco-LightOblique.otf 0 87164) (zco-Oblique.otf 0 104844)))
((Zco Light) ((zco-Light.otf 0 80720)))
((Zco Regular) ((zco-Regular.otf 0 94816)))
((ZcoN Oblique) ((zcoN-Oblique.otf 0 106036)))
((ZcoN Regular) ((zcoN-Regular.otf 0 95092)))
((Znikomit Regular) ((Znikomit.otf 0 677128)))
((ZnikomitNo24 Regular) ((ZnikomitNo24.otf 0 777128)))
((ZnikomitNo24 Thin) ((ZnikomitNo24Thin.otf 0 841584)))
((Ztm Med) ((ztm-Med.otf 0 123296)))
((Ztm MedIta) ((ztm-MedIta.otf 0 134488)))
((Ztm MedObl) ((ztm-MedObl.otf 0 216576)))
((Ztm Reg) ((ztm-Reg.otf 0 124272)))
((Ztm RegIta) ((ztm-RegIta.otf 0 135820)))
((Ztm RegObl) ((ztm-RegObl.otf 0 128192)))
